package androidx.webkit;

import android.webkit.WebSettings;
import androidx.webkit.internal.WebSettingsAdapter;
import androidx.webkit.internal.WebViewFeatureInternal;
import androidx.webkit.internal.WebViewGlueCommunicator;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

public class WebSettingsCompat {
    public static final int DARK_STRATEGY_PREFER_WEB_THEME_OVER_USER_AGENT_DARKENING = 2;
    public static final int DARK_STRATEGY_USER_AGENT_DARKENING_ONLY = 0;
    public static final int DARK_STRATEGY_WEB_THEME_DARKENING_ONLY = 1;
    public static final int FORCE_DARK_AUTO = 1;
    public static final int FORCE_DARK_OFF = 0;
    public static final int FORCE_DARK_ON = 2;

    @Target({ElementType.PARAMETER, ElementType.METHOD})
    @Retention(RetentionPolicy.SOURCE)
    public @interface ForceDark {
    }

    @Target({ElementType.PARAMETER, ElementType.METHOD})
    @Retention(RetentionPolicy.SOURCE)
    public @interface ForceDarkStrategy {
    }

    @Target({ElementType.PARAMETER, ElementType.METHOD})
    @Retention(RetentionPolicy.SOURCE)
    public @interface MenuItemFlags {
    }

    private WebSettingsCompat() {
    }

    public static void setOffscreenPreRaster(WebSettings settings, boolean enabled) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("OFF_SCREEN_PRERASTER");
        if (webviewFeature.isSupportedByFramework()) {
            settings.setOffscreenPreRaster(enabled);
        } else if (webviewFeature.isSupportedByWebView()) {
            getAdapter(settings).setOffscreenPreRaster(enabled);
        } else {
            throw WebViewFeatureInternal.getUnsupportedOperationException();
        }
    }

    public static boolean getOffscreenPreRaster(WebSettings settings) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("OFF_SCREEN_PRERASTER");
        if (webviewFeature.isSupportedByFramework()) {
            return settings.getOffscreenPreRaster();
        }
        if (webviewFeature.isSupportedByWebView()) {
            return getAdapter(settings).getOffscreenPreRaster();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static void setSafeBrowsingEnabled(WebSettings settings, boolean enabled) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("SAFE_BROWSING_ENABLE");
        if (webviewFeature.isSupportedByFramework()) {
            settings.setSafeBrowsingEnabled(enabled);
        } else if (webviewFeature.isSupportedByWebView()) {
            getAdapter(settings).setSafeBrowsingEnabled(enabled);
        } else {
            throw WebViewFeatureInternal.getUnsupportedOperationException();
        }
    }

    public static boolean getSafeBrowsingEnabled(WebSettings settings) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("SAFE_BROWSING_ENABLE");
        if (webviewFeature.isSupportedByFramework()) {
            return settings.getSafeBrowsingEnabled();
        }
        if (webviewFeature.isSupportedByWebView()) {
            return getAdapter(settings).getSafeBrowsingEnabled();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static void setDisabledActionModeMenuItems(WebSettings settings, int menuItems) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("DISABLED_ACTION_MODE_MENU_ITEMS");
        if (webviewFeature.isSupportedByFramework()) {
            settings.setDisabledActionModeMenuItems(menuItems);
        } else if (webviewFeature.isSupportedByWebView()) {
            getAdapter(settings).setDisabledActionModeMenuItems(menuItems);
        } else {
            throw WebViewFeatureInternal.getUnsupportedOperationException();
        }
    }

    public static int getDisabledActionModeMenuItems(WebSettings settings) {
        WebViewFeatureInternal webviewFeature = WebViewFeatureInternal.getFeature("DISABLED_ACTION_MODE_MENU_ITEMS");
        if (webviewFeature.isSupportedByFramework()) {
            return settings.getDisabledActionModeMenuItems();
        }
        if (webviewFeature.isSupportedByWebView()) {
            return getAdapter(settings).getDisabledActionModeMenuItems();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static void setWillSuppressErrorPage(WebSettings settings, boolean suppressed) {
        if (WebViewFeatureInternal.getFeature("SUPPRESS_ERROR_PAGE").isSupportedByWebView()) {
            getAdapter(settings).setWillSuppressErrorPage(suppressed);
            return;
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static boolean willSuppressErrorPage(WebSettings settings) {
        if (WebViewFeatureInternal.getFeature("SUPPRESS_ERROR_PAGE").isSupportedByWebView()) {
            return getAdapter(settings).willSuppressErrorPage();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static void setForceDark(WebSettings settings, int forceDarkMode) {
        WebViewFeatureInternal webViewFeature = WebViewFeatureInternal.getFeature("FORCE_DARK");
        if (webViewFeature.isSupportedByFramework()) {
            settings.setForceDark(forceDarkMode);
        } else if (webViewFeature.isSupportedByWebView()) {
            getAdapter(settings).setForceDark(forceDarkMode);
        } else {
            throw WebViewFeatureInternal.getUnsupportedOperationException();
        }
    }

    public static int getForceDark(WebSettings settings) {
        WebViewFeatureInternal webViewFeature = WebViewFeatureInternal.getFeature("FORCE_DARK");
        if (webViewFeature.isSupportedByFramework()) {
            return settings.getForceDark();
        }
        if (webViewFeature.isSupportedByWebView()) {
            return getAdapter(settings).getForceDark();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static void setForceDarkStrategy(WebSettings settings, int forceDarkBehavior) {
        if (WebViewFeatureInternal.getFeature(WebViewFeature.FORCE_DARK_STRATEGY).isSupportedByWebView()) {
            getAdapter(settings).setForceDarkStrategy(forceDarkBehavior);
            return;
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    public static int getForceDarkStrategy(WebSettings settings) {
        if (WebViewFeatureInternal.getFeature(WebViewFeature.FORCE_DARK_STRATEGY).isSupportedByWebView()) {
            return getAdapter(settings).getForceDark();
        }
        throw WebViewFeatureInternal.getUnsupportedOperationException();
    }

    private static WebSettingsAdapter getAdapter(WebSettings settings) {
        return WebViewGlueCommunicator.getCompatConverter().convertSettings(settings);
    }
}
