package com.alibaba.android.bindingx.core;

import android.content.Context;
import android.text.TextUtils;
import com.alibaba.android.bindingx.core.internal.BindingXConstants;
import com.alibaba.android.bindingx.core.internal.BindingXOrientationHandler;
import com.alibaba.android.bindingx.core.internal.BindingXTimingHandler;
import com.alibaba.android.bindingx.core.internal.BindingXTouchHandler;
import com.alibaba.android.bindingx.core.internal.ExpressionPair;
import com.alibaba.android.bindingx.core.internal.Utils;
import com.taobao.weex.el.parse.Operators;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import org.json.JSONObject;

public class BindingXCore {
    private static final Map<String, ObjectCreator<IEventHandler, Context, PlatformManager>> sGlobalEventHandlerCreatorMap = new HashMap(4);
    private Map<String, Map<String, IEventHandler>> mBindingCouples;
    private final Map<String, ObjectCreator<IEventHandler, Context, PlatformManager>> mInternalEventHandlerCreatorMap = new HashMap(8);
    private final PlatformManager mPlatformManager;

    public interface JavaScriptCallback {
        void callback(Object obj);
    }

    public interface ObjectCreator<Type, ParamA, ParamB> {
        Type createWith(ParamA parama, ParamB paramb, Object... objArr);
    }

    public BindingXCore(PlatformManager platformManager) {
        this.mPlatformManager = platformManager;
        registerEventHandler("pan", new ObjectCreator<IEventHandler, Context, PlatformManager>() {
            /* class com.alibaba.android.bindingx.core.BindingXCore.AnonymousClass1 */

            public IEventHandler createWith(Context context, PlatformManager manager, Object... extension) {
                return new BindingXTouchHandler(context, manager, extension);
            }
        });
        registerEventHandler("orientation", new ObjectCreator<IEventHandler, Context, PlatformManager>() {
            /* class com.alibaba.android.bindingx.core.BindingXCore.AnonymousClass2 */

            public IEventHandler createWith(Context context, PlatformManager manager, Object... extension) {
                return new BindingXOrientationHandler(context, manager, extension);
            }
        });
        registerEventHandler(BindingXEventType.TYPE_TIMING, new ObjectCreator<IEventHandler, Context, PlatformManager>() {
            /* class com.alibaba.android.bindingx.core.BindingXCore.AnonymousClass3 */

            public IEventHandler createWith(Context context, PlatformManager manager, Object... extension) {
                return new BindingXTimingHandler(context, manager, extension);
            }
        });
    }

    public String doBind(Context context, String instanceId, Map<String, Object> params, JavaScriptCallback callback, Object... extension) {
        Map<String, Object> configMap;
        String eventType = Utils.getStringValue(params, BindingXConstants.KEY_EVENT_TYPE);
        String anchorInstanceId = Utils.getStringValue(params, "instanceId");
        LogProxy.enableLogIfNeeded(params);
        Object configObj = params.get("options");
        if (configObj != null && (configObj instanceof Map)) {
            try {
                configMap = Utils.toMap(new JSONObject((Map) configObj));
            } catch (Exception e) {
                LogProxy.e("parse external config failed.\n", e);
            }
            return doBind(Utils.getStringValue(params, "anchor"), anchorInstanceId, eventType, configMap, Utils.getExpressionPair(params, BindingXConstants.KEY_EXIT_EXPRESSION), Utils.getRuntimeProps(params), Utils.getCustomInterceptors(params), callback, context, instanceId, extension);
        }
        configMap = null;
        return doBind(Utils.getStringValue(params, "anchor"), anchorInstanceId, eventType, configMap, Utils.getExpressionPair(params, BindingXConstants.KEY_EXIT_EXPRESSION), Utils.getRuntimeProps(params), Utils.getCustomInterceptors(params), callback, context, instanceId, extension);
    }

    public void doUnbind(Map<String, Object> params) {
        if (params != null) {
            doUnbind(Utils.getStringValue(params, "token"), Utils.getStringValue(params, BindingXConstants.KEY_EVENT_TYPE));
        }
    }

    public void doUnbind(String token, String eventType) {
        LogProxy.d("disable binding [" + token + "," + eventType + Operators.ARRAY_END_STR);
        if (TextUtils.isEmpty(token) || TextUtils.isEmpty(eventType)) {
            LogProxy.d("disable binding failed(0x1) [" + token + "," + eventType + Operators.ARRAY_END_STR);
            return;
        }
        Map<String, Map<String, IEventHandler>> map = this.mBindingCouples;
        if (map == null || map.isEmpty()) {
            LogProxy.d("disable binding failed(0x2) [" + token + "," + eventType + Operators.ARRAY_END_STR);
            return;
        }
        Map<String, IEventHandler> handlerMap = this.mBindingCouples.get(token);
        if (handlerMap == null || handlerMap.isEmpty()) {
            LogProxy.d("disable binding failed(0x3) [" + token + "," + eventType + Operators.ARRAY_END_STR);
            return;
        }
        IEventHandler handler = handlerMap.get(eventType);
        if (handler == null) {
            LogProxy.d("disable binding failed(0x4) [" + token + "," + eventType + Operators.ARRAY_END_STR);
        } else if (handler.onDisable(token, eventType)) {
            this.mBindingCouples.remove(token);
            LogProxy.d("disable binding success[" + token + "," + eventType + Operators.ARRAY_END_STR);
        } else {
            LogProxy.d("disabled failed(0x4) [" + token + "," + eventType + Operators.ARRAY_END_STR);
        }
    }

    public void doRelease() {
        Map<String, Map<String, IEventHandler>> map = this.mBindingCouples;
        if (map != null) {
            try {
                for (Map<String, IEventHandler> handlerMap : map.values()) {
                    if (handlerMap != null && !handlerMap.isEmpty()) {
                        for (IEventHandler h : handlerMap.values()) {
                            if (h != null) {
                                h.onDestroy();
                            }
                        }
                    }
                }
                this.mBindingCouples.clear();
                this.mBindingCouples = null;
            } catch (Exception e) {
                LogProxy.e("release failed", e);
            }
        }
    }

    public String doPrepare(Context context, String instanceId, String anchor, String anchorInstanceId, String eventType, Map<String, Object> globalConfig) {
        IEventHandler targetHandler;
        if (TextUtils.isEmpty(eventType)) {
            LogProxy.e("[doPrepare] failed. can not found eventType");
            return null;
        } else if (context == null) {
            LogProxy.e("[doPrepare] failed. context or wxInstance is null");
            return null;
        } else {
            String token = TextUtils.isEmpty(anchor) ? generateToken() : anchor;
            if (this.mBindingCouples == null) {
                this.mBindingCouples = new HashMap();
            }
            Map<String, IEventHandler> handlerMap = this.mBindingCouples.get(token);
            if (handlerMap == null || (targetHandler = handlerMap.get(eventType)) == null) {
                if (handlerMap == null) {
                    handlerMap = new HashMap(4);
                    this.mBindingCouples.put(token, handlerMap);
                }
                IEventHandler targetHandler2 = createEventHandler(context, instanceId, eventType);
                if (targetHandler2 != null) {
                    targetHandler2.setAnchorInstanceId(anchorInstanceId);
                    targetHandler2.setToken(token);
                    targetHandler2.setGlobalConfig(globalConfig);
                    if (targetHandler2.onCreate(token, eventType)) {
                        targetHandler2.onStart(token, eventType);
                        handlerMap.put(eventType, targetHandler2);
                        LogProxy.d("enableBinding success.[token:" + token + ",type:" + eventType + Operators.ARRAY_END_STR);
                    } else {
                        LogProxy.e("expression enabled failed. [token:" + token + ",type:" + eventType + Operators.ARRAY_END_STR);
                        return null;
                    }
                } else {
                    LogProxy.e("unknown eventType: " + eventType);
                    return null;
                }
            } else {
                LogProxy.d("you have already enabled binding,[token:" + token + ",type:" + eventType + Operators.ARRAY_END_STR);
                targetHandler.onStart(token, eventType);
                LogProxy.d("enableBinding success.[token:" + token + ",type:" + eventType + Operators.ARRAY_END_STR);
            }
            return token;
        }
    }

    public String doBind(String anchor, String anchorInstanceId, String eventType, Map<String, Object> globalConfig, ExpressionPair exitExpressionPair, List<Map<String, Object>> expressionArgs, Map<String, ExpressionPair> interceptors, JavaScriptCallback callback, Context context, String instanceId, Object... extension) {
        IEventHandler handler;
        Map<String, Map<String, IEventHandler>> map;
        Map<String, IEventHandler> handlerMap;
        if (!TextUtils.isEmpty(eventType)) {
            if (expressionArgs != null) {
                String token = anchor;
                if (this.mBindingCouples == null || TextUtils.isEmpty(anchor)) {
                    handler = null;
                } else {
                    Map<String, IEventHandler> handlerMap2 = this.mBindingCouples.get(anchor);
                    if (handlerMap2 != null) {
                        handler = handlerMap2.get(eventType);
                    } else {
                        handler = null;
                    }
                }
                if (handler == null) {
                    LogProxy.d("binding not enabled,try auto enable it.[sourceRef:" + anchor + ",eventType:" + eventType + Operators.ARRAY_END_STR);
                    token = doPrepare(context, instanceId, anchor, anchorInstanceId, eventType, globalConfig);
                    if (!(TextUtils.isEmpty(token) || (map = this.mBindingCouples) == null || (handlerMap = map.get(token)) == null)) {
                        handler = handlerMap.get(eventType);
                    }
                }
                if (handler != null) {
                    handler.onBindExpression(eventType, globalConfig, exitExpressionPair, expressionArgs, callback);
                    LogProxy.d("createBinding success.[exitExp:" + exitExpressionPair + ",args:" + expressionArgs + Operators.ARRAY_END_STR);
                    handler.setInterceptors(interceptors);
                    handler.setExtensionParams(extension);
                } else {
                    LogProxy.e("internal error.binding failed for ref:" + anchor + ",type:" + eventType);
                }
                return token;
            }
        }
        LogProxy.e("doBind failed,illegal argument.[" + eventType + "," + expressionArgs + Operators.ARRAY_END_STR);
        return null;
    }

    public void onActivityPause() {
        Map<String, Map<String, IEventHandler>> map = this.mBindingCouples;
        if (map != null) {
            try {
                for (Map<String, IEventHandler> map2 : map.values()) {
                    for (IEventHandler h : map2.values()) {
                        try {
                            h.onActivityPause();
                        } catch (Exception e) {
                            LogProxy.e("execute activity pause failed.", e);
                        }
                    }
                }
            } catch (Exception e2) {
                LogProxy.e("activity pause failed", e2);
            }
        }
    }

    public void onActivityResume() {
        Map<String, Map<String, IEventHandler>> map = this.mBindingCouples;
        if (map != null) {
            try {
                for (Map<String, IEventHandler> map2 : map.values()) {
                    for (IEventHandler h : map2.values()) {
                        try {
                            h.onActivityResume();
                        } catch (Exception e) {
                            LogProxy.e("execute activity pause failed.", e);
                        }
                    }
                }
            } catch (Exception e2) {
                LogProxy.e("activity pause failed", e2);
            }
        }
    }

    public void registerEventHandler(String eventType, ObjectCreator<IEventHandler, Context, PlatformManager> creator) {
        if (!TextUtils.isEmpty(eventType) && creator != null) {
            this.mInternalEventHandlerCreatorMap.put(eventType, creator);
        }
    }

    public static void registerGlobalEventHandler(String eventType, ObjectCreator<IEventHandler, Context, PlatformManager> creator) {
        if (!TextUtils.isEmpty(eventType) && creator != null) {
            sGlobalEventHandlerCreatorMap.put(eventType, creator);
        }
    }

    public static boolean unregisterGlobalEventHandler(String eventType) {
        return sGlobalEventHandlerCreatorMap.remove(eventType) != null;
    }

    private String generateToken() {
        return UUID.randomUUID().toString();
    }

    private IEventHandler createEventHandler(Context context, String instanceId, String eventType) {
        if (this.mInternalEventHandlerCreatorMap.isEmpty() || this.mPlatformManager == null) {
            return null;
        }
        ObjectCreator<IEventHandler, Context, PlatformManager> creator = this.mInternalEventHandlerCreatorMap.get(eventType);
        if (creator == null) {
            creator = sGlobalEventHandlerCreatorMap.get(eventType);
        }
        if (creator == null) {
            return null;
        }
        return creator.createWith(context, this.mPlatformManager, instanceId);
    }
}
