package com.alibaba.android.bindingx.core;

import android.os.Handler;
import android.os.Looper;
import android.view.View;
import com.alibaba.android.bindingx.core.PlatformManager;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class BindingXPropertyInterceptor {
    private static BindingXPropertyInterceptor sInstance = new BindingXPropertyInterceptor();
    private final LinkedList<IPropertyUpdateInterceptor> mPropertyInterceptors = new LinkedList<>();
    private final Handler sUIHandler = new Handler(Looper.getMainLooper());

    public interface IPropertyUpdateInterceptor {
        boolean updateView(View view, String str, Object obj, PlatformManager.IDeviceResolutionTranslator iDeviceResolutionTranslator, Map<String, Object> map, Object... objArr);
    }

    private BindingXPropertyInterceptor() {
    }

    public static BindingXPropertyInterceptor getInstance() {
        return sInstance;
    }

    public void addInterceptor(IPropertyUpdateInterceptor interceptor) {
        if (interceptor != null) {
            this.mPropertyInterceptors.add(interceptor);
        }
    }

    public boolean removeInterceptor(IPropertyUpdateInterceptor interceptor) {
        if (interceptor != null) {
            return this.mPropertyInterceptors.remove(interceptor);
        }
        return false;
    }

    public void clear() {
        this.mPropertyInterceptors.clear();
    }

    public void performIntercept(final View targetView, final String propertyName, final Object propertyValue, final PlatformManager.IDeviceResolutionTranslator translator, final Map<String, Object> config, final Object... extension) {
        if (!this.mPropertyInterceptors.isEmpty()) {
            this.sUIHandler.post(new WeakRunnable(new Runnable() {
                /* class com.alibaba.android.bindingx.core.BindingXPropertyInterceptor.AnonymousClass1 */

                public void run() {
                    Iterator it = BindingXPropertyInterceptor.this.mPropertyInterceptors.iterator();
                    while (it.hasNext()) {
                        ((IPropertyUpdateInterceptor) it.next()).updateView(targetView, propertyName, propertyValue, translator, config, extension);
                    }
                }
            }));
        }
    }

    public void clearCallbacks() {
        this.sUIHandler.removeCallbacksAndMessages(null);
    }

    public List<IPropertyUpdateInterceptor> getInterceptors() {
        return Collections.unmodifiableList(this.mPropertyInterceptors);
    }
}
