package com.alibaba.android.bindingx.core;

import android.view.View;
import java.util.Map;

public class PlatformManager {
    private IDeviceResolutionTranslator mResolutionTranslator;
    private IViewFinder mViewFinder;
    private IViewUpdater mViewUpdater;

    public interface IDeviceResolutionTranslator {
        double nativeToWeb(double d, Object... objArr);

        double webToNative(double d, Object... objArr);
    }

    public interface IViewFinder {
        View findViewBy(String str, Object... objArr);
    }

    public interface IViewUpdater {
        void synchronouslyUpdateViewOnUIThread(View view, String str, Object obj, IDeviceResolutionTranslator iDeviceResolutionTranslator, Map<String, Object> map, Object... objArr);
    }

    private PlatformManager() {
    }

    public IDeviceResolutionTranslator getResolutionTranslator() {
        return this.mResolutionTranslator;
    }

    public IViewFinder getViewFinder() {
        return this.mViewFinder;
    }

    public IViewUpdater getViewUpdater() {
        return this.mViewUpdater;
    }

    public static class Builder {
        private IDeviceResolutionTranslator deviceResolutionTranslator;
        private IViewFinder viewFinder;
        private IViewUpdater viewUpdater;

        public PlatformManager build() {
            PlatformManager factory = new PlatformManager();
            factory.mViewFinder = this.viewFinder;
            factory.mResolutionTranslator = this.deviceResolutionTranslator;
            factory.mViewUpdater = this.viewUpdater;
            return factory;
        }

        public Builder withDeviceResolutionTranslator(IDeviceResolutionTranslator translator) {
            this.deviceResolutionTranslator = translator;
            return this;
        }

        public Builder withViewFinder(IViewFinder finder) {
            this.viewFinder = finder;
            return this;
        }

        public Builder withViewUpdater(IViewUpdater viewUpdater2) {
            this.viewUpdater = viewUpdater2;
            return this;
        }
    }
}
