package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import android.text.TextUtils;
import android.view.View;
import com.alibaba.android.bindingx.core.BindingXCore;
import com.alibaba.android.bindingx.core.BindingXJSFunctionRegister;
import com.alibaba.android.bindingx.core.BindingXPropertyInterceptor;
import com.alibaba.android.bindingx.core.IEventHandler;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.taobao.weex.el.parse.Operators;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import org.json.JSONException;
import org.json.JSONObject;

public abstract class AbstractEventHandler implements IEventHandler {
    protected String mAnchorInstanceId;
    private Cache<String, Expression> mCachedExpressionMap = new Cache<>(16);
    protected BindingXCore.JavaScriptCallback mCallback;
    protected Context mContext;
    protected ExpressionPair mExitExpressionPair;
    protected volatile Map<String, List<ExpressionHolder>> mExpressionHoldersMap;
    protected Object[] mExtensionParams;
    protected String mInstanceId;
    protected volatile Map<String, ExpressionPair> mInterceptorsMap;
    protected PlatformManager mPlatformManager;
    protected final Map<String, Object> mScope = new HashMap();
    protected String mToken;

    /* access modifiers changed from: protected */
    public abstract void onExit(Map<String, Object> map);

    /* access modifiers changed from: protected */
    public abstract void onUserIntercept(String str, Map<String, Object> map);

    public AbstractEventHandler(Context context, PlatformManager manager, Object... extension) {
        this.mContext = context;
        this.mPlatformManager = manager;
        this.mInstanceId = (extension == null || extension.length <= 0 || !(extension[0] instanceof String)) ? null : (String) extension[0];
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void setAnchorInstanceId(String anchorInstanceId) {
        this.mAnchorInstanceId = anchorInstanceId;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void setGlobalConfig(Map<String, Object> map) {
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onBindExpression(String eventType, Map<String, Object> map, ExpressionPair exitExpressionPair, List<Map<String, Object>> expressionArgs, BindingXCore.JavaScriptCallback callback) {
        clearExpressions();
        transformArgs(eventType, expressionArgs);
        this.mCallback = callback;
        this.mExitExpressionPair = exitExpressionPair;
        if (!this.mScope.isEmpty()) {
            this.mScope.clear();
        }
        applyFunctionsToScope();
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onDestroy() {
        this.mCachedExpressionMap.clear();
        BindingXPropertyInterceptor.getInstance().clearCallbacks();
    }

    private void applyFunctionsToScope() {
        JSMath.applyToScope(this.mScope);
        TimingFunctions.applyToScope(this.mScope);
        Map<String, JSFunctionInterface> customFunctions = BindingXJSFunctionRegister.getInstance().getJSFunctions();
        if (customFunctions != null && !customFunctions.isEmpty()) {
            this.mScope.putAll(customFunctions);
        }
    }

    private void transformArgs(String eventType, List<Map<String, Object>> originalArgs) {
        Map<String, Object> configMap;
        if (this.mExpressionHoldersMap == null) {
            this.mExpressionHoldersMap = new HashMap();
        }
        for (Map<String, Object> arg : originalArgs) {
            String targetRef = Utils.getStringValue(arg, BindingXConstants.KEY_ELEMENT);
            String targetInstanceId = Utils.getStringValue(arg, "instanceId");
            String property = Utils.getStringValue(arg, "property");
            ExpressionPair expressionPair = Utils.getExpressionPair(arg, BindingXConstants.KEY_EXPRESSION);
            Object configObj = arg.get("config");
            if (configObj != null && (configObj instanceof Map)) {
                try {
                    configMap = Utils.toMap(new JSONObject((Map) configObj));
                } catch (Exception e) {
                    LogProxy.e("parse config failed", e);
                }
                if (!TextUtils.isEmpty(targetRef) || TextUtils.isEmpty(property) || expressionPair == null) {
                    LogProxy.e("skip illegal binding args[" + targetRef + "," + property + "," + expressionPair + Operators.ARRAY_END_STR);
                } else {
                    ExpressionHolder holder = new ExpressionHolder(targetRef, targetInstanceId, expressionPair, property, eventType, configMap);
                    List<ExpressionHolder> holders = this.mExpressionHoldersMap.get(targetRef);
                    if (holders == null) {
                        List<ExpressionHolder> holders2 = new ArrayList<>(4);
                        this.mExpressionHoldersMap.put(targetRef, holders2);
                        holders2.add(holder);
                    } else if (!holders.contains(holder)) {
                        holders.add(holder);
                    }
                }
            }
            configMap = null;
            if (!TextUtils.isEmpty(targetRef)) {
            }
            LogProxy.e("skip illegal binding args[" + targetRef + "," + property + "," + expressionPair + Operators.ARRAY_END_STR);
        }
    }

    /* access modifiers changed from: protected */
    public boolean evaluateExitExpression(ExpressionPair exitExpression, Map<String, Object> scope) {
        boolean exit = false;
        if (ExpressionPair.isValid(exitExpression)) {
            try {
                exit = ((Boolean) new Expression(exitExpression.transformed).execute(scope)).booleanValue();
            } catch (Exception e) {
                LogProxy.e("evaluateExitExpression failed. ", e);
            }
        }
        if (exit) {
            clearExpressions();
            try {
                onExit(scope);
            } catch (Exception e2) {
                LogProxy.e("execute exit expression failed: ", e2);
            }
            LogProxy.d("exit = true,consume finished");
        }
        return exit;
    }

    @Override // com.alibaba.android.bindingx.core.IEventInterceptor
    public void setInterceptors(Map<String, ExpressionPair> params) {
        this.mInterceptorsMap = params;
    }

    @Override // com.alibaba.android.bindingx.core.IEventInterceptor
    public void performInterceptIfNeeded(String interceptorName, ExpressionPair condition, Map<String, Object> scope) {
        if (ExpressionPair.isValid(condition)) {
            boolean shouldIntercept = false;
            try {
                shouldIntercept = ((Boolean) new Expression(condition.transformed).execute(scope)).booleanValue();
            } catch (Exception e) {
                LogProxy.e("evaluate interceptor [" + interceptorName + "] expression failed. ", e);
            }
            if (shouldIntercept) {
                onUserIntercept(interceptorName, scope);
            }
        }
    }

    private void tryInterceptAllIfNeeded(Map<String, Object> scope) {
        if (!(this.mInterceptorsMap == null || this.mInterceptorsMap.isEmpty())) {
            for (Map.Entry<String, ExpressionPair> entry : this.mInterceptorsMap.entrySet()) {
                String interceptorName = entry.getKey();
                ExpressionPair interceptCondition = entry.getValue();
                if (!TextUtils.isEmpty(interceptorName) && interceptCondition != null) {
                    performInterceptIfNeeded(interceptorName, interceptCondition, scope);
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public void consumeExpression(Map<String, List<ExpressionHolder>> args, Map<String, Object> scope, String currentType) throws IllegalArgumentException, JSONException {
        Map<String, Object> map = scope;
        String str = currentType;
        tryInterceptAllIfNeeded(map);
        if (args == null) {
            LogProxy.e("expression args is null");
        } else if (args.isEmpty()) {
            LogProxy.e("no expression need consumed");
        } else {
            if (LogProxy.sEnableLog) {
                LogProxy.d(String.format(Locale.getDefault(), "consume expression with %d tasks. event type is %s", Integer.valueOf(args.size()), str));
            }
            List<Object> extension = new LinkedList<>();
            for (List<ExpressionHolder> holderList : args.values()) {
                for (ExpressionHolder holder : holderList) {
                    if (!str.equals(holder.eventType)) {
                        LogProxy.d("skip expression with wrong event type.[expected:" + str + ",found:" + holder.eventType + Operators.ARRAY_END_STR);
                    } else {
                        extension.clear();
                        Object[] objArr = this.mExtensionParams;
                        if (objArr != null && objArr.length > 0) {
                            Collections.addAll(extension, objArr);
                        }
                        String instanceId = TextUtils.isEmpty(holder.targetInstanceId) ? this.mInstanceId : holder.targetInstanceId;
                        if (!TextUtils.isEmpty(instanceId)) {
                            extension.add(instanceId);
                        }
                        ExpressionPair expressionPair = holder.expressionPair;
                        if (ExpressionPair.isValid(expressionPair)) {
                            Expression expression = this.mCachedExpressionMap.get(expressionPair.transformed);
                            if (expression == null) {
                                expression = new Expression(expressionPair.transformed);
                                this.mCachedExpressionMap.put(expressionPair.transformed, expression);
                            }
                            Object obj = expression.execute(map);
                            if (obj == null) {
                                LogProxy.e("failed to execute expression,expression result is null");
                            } else if ((!(obj instanceof Double) || !Double.isNaN(((Double) obj).doubleValue())) && (!(obj instanceof Float) || !Float.isNaN(((Float) obj).floatValue()))) {
                                View targetView = this.mPlatformManager.getViewFinder().findViewBy(holder.targetRef, extension.toArray());
                                BindingXPropertyInterceptor.getInstance().performIntercept(targetView, holder.prop, obj, this.mPlatformManager.getResolutionTranslator(), holder.config, holder.targetRef, instanceId);
                                if (targetView == null) {
                                    LogProxy.e("failed to execute expression,target view not found.[ref:" + holder.targetRef + Operators.ARRAY_END_STR);
                                    map = scope;
                                    str = currentType;
                                } else {
                                    this.mPlatformManager.getViewUpdater().synchronouslyUpdateViewOnUIThread(targetView, holder.prop, obj, this.mPlatformManager.getResolutionTranslator(), holder.config, holder.targetRef, instanceId);
                                    map = scope;
                                    str = currentType;
                                }
                            } else {
                                LogProxy.e("failed to execute expression,expression result is NaN");
                            }
                        }
                    }
                }
                map = scope;
                str = currentType;
            }
        }
    }

    /* access modifiers changed from: protected */
    public void clearExpressions() {
        LogProxy.d("all expression are cleared");
        if (this.mExpressionHoldersMap != null) {
            this.mExpressionHoldersMap.clear();
            this.mExpressionHoldersMap = null;
        }
        this.mExitExpressionPair = null;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void setToken(String token) {
        this.mToken = token;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void setExtensionParams(Object[] params) {
        this.mExtensionParams = params;
    }

    /* access modifiers changed from: package-private */
    public static class Cache<K, V> extends LinkedHashMap<K, V> {
        private int maxSize;

        Cache(int maxSize2) {
            super(4, 0.75f, true);
            this.maxSize = Math.max(maxSize2, 4);
        }

        /* access modifiers changed from: protected */
        @Override // java.util.LinkedHashMap
        public boolean removeEldestEntry(Map.Entry eldest) {
            return size() > this.maxSize;
        }
    }
}
