package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import java.util.Collections;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;

public abstract class AbstractScrollEventHandler extends AbstractEventHandler {
    private boolean isStart = false;
    protected int mContentOffsetX;
    protected int mContentOffsetY;

    public AbstractScrollEventHandler(Context context, PlatformManager manager, Object... extension) {
        super(context, manager, extension);
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onDisable(String sourceRef, String eventType) {
        clearExpressions();
        this.isStart = false;
        fireEventByState("end", (double) this.mContentOffsetX, (double) this.mContentOffsetY, 0.0d, 0.0d, 0.0d, 0.0d, new Object[0]);
        return true;
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onExit(Map<String, Object> scope) {
        fireEventByState("exit", ((Double) scope.get("internal_x")).doubleValue(), ((Double) scope.get("internal_y")).doubleValue(), 0.0d, 0.0d, 0.0d, 0.0d, new Object[0]);
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onUserIntercept(String interceptorName, Map<String, Object> scope) {
        fireEventByState(BindingXConstants.STATE_INTERCEPTOR, ((Double) scope.get("internal_x")).doubleValue(), ((Double) scope.get("internal_y")).doubleValue(), ((Double) scope.get("dx")).doubleValue(), ((Double) scope.get(Constants.Name.DISTANCE_Y)).doubleValue(), ((Double) scope.get("tdx")).doubleValue(), ((Double) scope.get("tdy")).doubleValue(), Collections.singletonMap(BindingXConstants.STATE_INTERCEPTOR, interceptorName));
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onDestroy() {
        super.onDestroy();
        this.isStart = false;
    }

    /* access modifiers changed from: protected */
    public void handleScrollEvent(int contentOffsetX, int contentOffsetY, int dx, int dy, int tdx, int tdy) {
        if (LogProxy.sEnableLog) {
            LogProxy.d(String.format(Locale.getDefault(), "[ScrollHandler] scroll changed. (contentOffsetX:%d,contentOffsetY:%d,dx:%d,dy:%d,tdx:%d,tdy:%d)", Integer.valueOf(contentOffsetX), Integer.valueOf(contentOffsetY), Integer.valueOf(dx), Integer.valueOf(dy), Integer.valueOf(tdx), Integer.valueOf(tdy)));
        }
        this.mContentOffsetX = contentOffsetX;
        this.mContentOffsetY = contentOffsetY;
        if (!this.isStart) {
            this.isStart = true;
            fireEventByState("start", (double) contentOffsetX, (double) contentOffsetY, (double) dx, (double) dy, (double) tdx, (double) tdy, new Object[0]);
        }
        try {
            JSMath.applyScrollValuesToScope(this.mScope, (double) contentOffsetX, (double) contentOffsetY, (double) dx, (double) dy, (double) tdx, (double) tdy, this.mPlatformManager.getResolutionTranslator());
            if (!evaluateExitExpression(this.mExitExpressionPair, this.mScope)) {
                consumeExpression(this.mExpressionHoldersMap, this.mScope, "scroll");
            }
        } catch (Exception e) {
            LogProxy.e("runtime error", e);
        }
    }

    /* access modifiers changed from: protected */
    public void fireEventByState(String state, double contentOffsetX, double contentOffsetY, double dx, double dy, double tdx, double tdy, Object... extension) {
        if (this.mCallback != null) {
            Map<String, Object> param = new HashMap<>();
            param.put("state", state);
            double x = this.mPlatformManager.getResolutionTranslator().nativeToWeb(contentOffsetX, new Object[0]);
            double y = this.mPlatformManager.getResolutionTranslator().nativeToWeb(contentOffsetY, new Object[0]);
            param.put(Constants.Name.X, Double.valueOf(x));
            param.put(Constants.Name.Y, Double.valueOf(y));
            double _dx = this.mPlatformManager.getResolutionTranslator().nativeToWeb(dx, new Object[0]);
            double _dy = this.mPlatformManager.getResolutionTranslator().nativeToWeb(dy, new Object[0]);
            param.put("dx", Double.valueOf(_dx));
            param.put(Constants.Name.DISTANCE_Y, Double.valueOf(_dy));
            double _tdx = this.mPlatformManager.getResolutionTranslator().nativeToWeb(tdx, new Object[0]);
            double _tdy = this.mPlatformManager.getResolutionTranslator().nativeToWeb(tdy, new Object[0]);
            param.put("tdx", Double.valueOf(_tdx));
            param.put("tdy", Double.valueOf(_tdy));
            param.put("token", this.mToken);
            if (extension != null && extension.length > 0 && (extension[0] instanceof Map)) {
                param.putAll((Map) extension[0]);
            }
            this.mCallback.callback(param);
            LogProxy.d(">>>>>>>>>>>fire event:(" + state + "," + x + "," + y + "," + _dx + "," + _dy + "," + _tdx + "," + _tdy + Operators.BRACKET_END_STR);
        }
    }
}
