package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import android.text.TextUtils;
import com.alibaba.android.bindingx.core.BindingXCore;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.alibaba.android.bindingx.core.internal.OrientationDetector;
import com.amap.api.maps.utils.SpatialRelationUtil;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.feature.weex_amap.adapter.Constant;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map;

public class BindingXOrientationHandler extends AbstractEventHandler implements OrientationDetector.OnOrientationChangedListener {
    private boolean isStarted = false;
    private OrientationEvaluator mEvaluator3D;
    private OrientationEvaluator mEvaluatorX;
    private OrientationEvaluator mEvaluatorY;
    private double mLastAlpha;
    private double mLastBeta;
    private double mLastGamma;
    private OrientationDetector mOrientationDetector;
    private LinkedList<Double> mRecordsAlpha = new LinkedList<>();
    private String mSceneType;
    private double mStartAlpha;
    private double mStartBeta;
    private double mStartGamma;
    private ValueHolder mValueHolder = new ValueHolder(0.0d, 0.0d, 0.0d);
    private Vector3 mVectorX = new Vector3(0.0d, 0.0d, 1.0d);
    private Vector3 mVectorY = new Vector3(0.0d, 1.0d, 1.0d);

    public BindingXOrientationHandler(Context context, PlatformManager manager, Object... extension) {
        super(context, manager, extension);
        if (context != null) {
            this.mOrientationDetector = OrientationDetector.getInstance(context);
        }
    }

    BindingXOrientationHandler(Context context, PlatformManager manager, OrientationDetector detector, Object... extension) {
        super(context, manager, extension);
        this.mOrientationDetector = detector;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onCreate(String sourceRef, String eventType) {
        OrientationDetector orientationDetector = this.mOrientationDetector;
        if (orientationDetector == null) {
            return false;
        }
        orientationDetector.addOrientationChangedListener(this);
        return this.mOrientationDetector.start(1);
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onStart(String sourceRef, String eventType) {
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onBindExpression(String eventType, Map<String, Object> globalConfig, ExpressionPair exitExpressionPair, List<Map<String, Object>> expressionArgs, BindingXCore.JavaScriptCallback callback) {
        super.onBindExpression(eventType, globalConfig, exitExpressionPair, expressionArgs, callback);
        String sceneType = null;
        if (globalConfig != null) {
            String sceneType2 = (String) globalConfig.get(BindingXConstants.KEY_SCENE_TYPE);
            if (TextUtils.isEmpty(sceneType2)) {
                sceneType = "2d";
            } else {
                sceneType = sceneType2.toLowerCase();
            }
        }
        if (TextUtils.isEmpty(sceneType) || (!"2d".equals(sceneType) && !"3d".equals(sceneType))) {
            sceneType = "2d";
        }
        this.mSceneType = sceneType;
        LogProxy.d("[ExpressionOrientationHandler] sceneType is " + sceneType);
        if ("2d".equals(sceneType)) {
            this.mEvaluatorX = new OrientationEvaluator(null, Double.valueOf(90.0d), null);
            this.mEvaluatorY = new OrientationEvaluator(Double.valueOf(0.0d), null, Double.valueOf(90.0d));
        } else if ("3d".equals(sceneType)) {
            this.mEvaluator3D = new OrientationEvaluator(null, null, null);
        }
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onDisable(String sourceRef, String eventType) {
        clearExpressions();
        if (this.mOrientationDetector == null) {
            return false;
        }
        fireEventByState("end", this.mLastAlpha, this.mLastBeta, this.mLastGamma, new Object[0]);
        return this.mOrientationDetector.removeOrientationChangedListener(this);
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onDestroy() {
        super.onDestroy();
        OrientationDetector orientationDetector = this.mOrientationDetector;
        if (orientationDetector != null) {
            orientationDetector.removeOrientationChangedListener(this);
            this.mOrientationDetector.stop();
        }
        if (this.mExpressionHoldersMap != null) {
            this.mExpressionHoldersMap.clear();
            this.mExpressionHoldersMap = null;
        }
    }

    @Override // com.alibaba.android.bindingx.core.internal.OrientationDetector.OnOrientationChangedListener
    public void onOrientationChanged(double alpha, double beta, double gamma) {
        char c;
        double gamma2;
        boolean result;
        Exception e;
        double alpha2 = (double) Math.round(alpha);
        double beta2 = (double) Math.round(beta);
        double gamma3 = (double) Math.round(gamma);
        if (alpha2 != this.mLastAlpha || beta2 != this.mLastBeta || gamma3 != this.mLastGamma) {
            if (!this.isStarted) {
                this.isStarted = true;
                c = 1;
                fireEventByState("start", alpha2, beta2, gamma3, new Object[0]);
                this.mStartAlpha = alpha2;
                this.mStartBeta = beta2;
                gamma2 = gamma3;
                this.mStartGamma = gamma2;
            } else {
                gamma2 = gamma3;
                c = 1;
            }
            if ("2d".equals(this.mSceneType)) {
                result = calculate2D(alpha2, beta2, gamma2);
            } else if ("3d".equals(this.mSceneType)) {
                result = calculate3D(alpha2, beta2, gamma2);
            } else {
                result = false;
            }
            if (result) {
                double x = this.mValueHolder.x;
                double y = this.mValueHolder.y;
                double z = this.mValueHolder.z;
                this.mLastAlpha = alpha2;
                this.mLastBeta = beta2;
                this.mLastGamma = gamma2;
                try {
                    if (LogProxy.sEnableLog) {
                        try {
                            Locale locale = Locale.getDefault();
                            try {
                                Object[] objArr = new Object[6];
                                objArr[0] = Double.valueOf(alpha2);
                                objArr[c] = Double.valueOf(beta2);
                                objArr[2] = Double.valueOf(gamma2);
                                objArr[3] = Double.valueOf(x);
                                objArr[4] = Double.valueOf(y);
                                objArr[5] = Double.valueOf(z);
                                LogProxy.d(String.format(locale, "[OrientationHandler] orientation changed. (alpha:%f,beta:%f,gamma:%f,x:%f,y:%f,z:%f)", objArr));
                            } catch (Exception e2) {
                                e = e2;
                            }
                        } catch (Exception e3) {
                            e = e3;
                            LogProxy.e("runtime error", e);
                        }
                    }
                    try {
                        try {
                        } catch (Exception e4) {
                            e = e4;
                            LogProxy.e("runtime error", e);
                        }
                    } catch (Exception e5) {
                        e = e5;
                        LogProxy.e("runtime error", e);
                    }
                    try {
                        try {
                            JSMath.applyOrientationValuesToScope(this.mScope, alpha2, beta2, gamma2, this.mStartAlpha, this.mStartBeta, this.mStartGamma, x, y, z);
                            if (!evaluateExitExpression(this.mExitExpressionPair, this.mScope)) {
                                consumeExpression(this.mExpressionHoldersMap, this.mScope, "orientation");
                            }
                        } catch (Exception e6) {
                            e = e6;
                            LogProxy.e("runtime error", e);
                        }
                    } catch (Exception e7) {
                        e = e7;
                        LogProxy.e("runtime error", e);
                    }
                } catch (Exception e8) {
                    e = e8;
                    LogProxy.e("runtime error", e);
                }
            }
        }
    }

    private boolean calculate2D(double alpha, double beta, double gamma) {
        if (!(this.mEvaluatorX == null || this.mEvaluatorY == null)) {
            this.mRecordsAlpha.add(Double.valueOf(alpha));
            if (this.mRecordsAlpha.size() > 5) {
                this.mRecordsAlpha.removeFirst();
            }
            formatRecords(this.mRecordsAlpha, SpatialRelationUtil.A_CIRCLE_DEGREE);
            LinkedList<Double> linkedList = this.mRecordsAlpha;
            double formatAlpha = (linkedList.get(linkedList.size() - 1).doubleValue() - this.mStartAlpha) % 360.0d;
            Quaternion quaternionX = this.mEvaluatorX.calculate(alpha, beta, gamma, formatAlpha);
            Quaternion quaternionY = this.mEvaluatorY.calculate(alpha, beta, gamma, formatAlpha);
            this.mVectorX.set(0.0d, 0.0d, 1.0d);
            this.mVectorX.applyQuaternion(quaternionX);
            this.mVectorY.set(0.0d, 1.0d, 1.0d);
            this.mVectorY.applyQuaternion(quaternionY);
            double x = Math.toDegrees(Math.acos(this.mVectorX.x)) - 90.0d;
            double y = Math.toDegrees(Math.acos(this.mVectorY.y)) - 90.0d;
            if (Double.isNaN(x) || Double.isNaN(y) || Double.isInfinite(x) || Double.isInfinite(y)) {
                return false;
            }
            this.mValueHolder.x = (double) Math.round(x);
            this.mValueHolder.y = (double) Math.round(y);
        }
        return true;
    }

    private boolean calculate3D(double alpha, double beta, double gamma) {
        if (this.mEvaluator3D != null) {
            this.mRecordsAlpha.add(Double.valueOf(alpha));
            if (this.mRecordsAlpha.size() > 5) {
                this.mRecordsAlpha.removeFirst();
            }
            formatRecords(this.mRecordsAlpha, SpatialRelationUtil.A_CIRCLE_DEGREE);
            LinkedList<Double> linkedList = this.mRecordsAlpha;
            Quaternion q = this.mEvaluator3D.calculate(alpha, beta, gamma, (linkedList.get(linkedList.size() - 1).doubleValue() - this.mStartAlpha) % 360.0d);
            if (Double.isNaN(q.x) || Double.isNaN(q.y) || Double.isNaN(q.z) || Double.isInfinite(q.x) || Double.isInfinite(q.y) || Double.isInfinite(q.z)) {
                return false;
            }
            this.mValueHolder.x = q.x;
            this.mValueHolder.y = q.y;
            this.mValueHolder.z = q.z;
        }
        return true;
    }

    private void formatRecords(List<Double> records, int threshold) {
        int l = records.size();
        if (l > 1) {
            for (int i = 1; i < l; i++) {
                if (!(records.get(i - 1) == null || records.get(i) == null)) {
                    if (records.get(i).doubleValue() - records.get(i - 1).doubleValue() < ((double) ((-threshold) / 2))) {
                        records.set(i, Double.valueOf(records.get(i).doubleValue() + (((double) threshold) * (Math.floor(records.get(i - 1).doubleValue() / ((double) threshold)) + 1.0d))));
                    }
                    if (records.get(i).doubleValue() - records.get(i - 1).doubleValue() > ((double) (threshold / 2))) {
                        records.set(i, Double.valueOf(records.get(i).doubleValue() - ((double) threshold)));
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onExit(Map<String, Object> scope) {
        fireEventByState("exit", ((Double) scope.get(Constant.JSONKEY.ALPHE)).doubleValue(), ((Double) scope.get("beta")).doubleValue(), ((Double) scope.get("gamma")).doubleValue(), new Object[0]);
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onUserIntercept(String interceptorName, Map<String, Object> scope) {
        fireEventByState(BindingXConstants.STATE_INTERCEPTOR, ((Double) scope.get(Constant.JSONKEY.ALPHE)).doubleValue(), ((Double) scope.get("beta")).doubleValue(), ((Double) scope.get("gamma")).doubleValue(), Collections.singletonMap(BindingXConstants.STATE_INTERCEPTOR, interceptorName));
    }

    private void fireEventByState(String state, double alpha, double beta, double gamma, Object... extension) {
        if (this.mCallback != null) {
            Map<String, Object> param = new HashMap<>();
            param.put("state", state);
            param.put(Constant.JSONKEY.ALPHE, Double.valueOf(alpha));
            param.put("beta", Double.valueOf(beta));
            param.put("gamma", Double.valueOf(gamma));
            param.put("token", this.mToken);
            if (extension != null && extension.length > 0 && (extension[0] instanceof Map)) {
                param.putAll((Map) extension[0]);
            }
            this.mCallback.callback(param);
            LogProxy.d(">>>>>>>>>>>fire event:(" + state + "," + alpha + "," + beta + "," + gamma + Operators.BRACKET_END_STR);
        }
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityPause() {
        OrientationDetector orientationDetector = this.mOrientationDetector;
        if (orientationDetector != null) {
            orientationDetector.stop();
        }
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityResume() {
        OrientationDetector orientationDetector = this.mOrientationDetector;
        if (orientationDetector != null) {
            orientationDetector.start(1);
        }
    }

    /* access modifiers changed from: package-private */
    public static class ValueHolder {
        double x;
        double y;
        double z;

        ValueHolder() {
        }

        ValueHolder(double x2, double y2, double z2) {
            this.x = x2;
            this.y = y2;
            this.z = z2;
        }
    }
}
