package com.alibaba.android.bindingx.core.internal;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import com.alibaba.android.bindingx.core.BindingXCore;
import com.alibaba.android.bindingx.core.BindingXEventType;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.taobao.weex.el.parse.Operators;
import java.lang.reflect.Method;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

public class BindingXTouchHandler extends AbstractEventHandler implements View.OnTouchListener, GestureDetector.OnGestureListener {
    private long downTimeMillis = 0;
    private float downX = 0.0f;
    private float downY = 0.0f;
    private boolean isFlickGestureAvailable;
    private boolean isPanGestureAvailable;
    private float mDownX;
    private float mDownY;
    private double mDx;
    private double mDy;
    private GestureDetector mGestureDetector;
    private int movetime = 0;
    private int touchTime = 0;
    private float upX = 0.0f;
    private float upY = 0.0f;

    public BindingXTouchHandler(Context context, PlatformManager manager, Object... extension) {
        super(context, manager, extension);
        this.mGestureDetector = new GestureDetector(context, this, new Handler(Looper.myLooper() == null ? Looper.getMainLooper() : Looper.myLooper()));
    }

    /* access modifiers changed from: package-private */
    public void setPanGestureAvailable(boolean available) {
        this.isPanGestureAvailable = available;
    }

    /* access modifiers changed from: package-private */
    public void setFlickGestureAvailable(boolean available) {
        this.isFlickGestureAvailable = available;
    }

    /* access modifiers changed from: package-private */
    public boolean isPanGestureAvailable() {
        return this.isPanGestureAvailable;
    }

    /* access modifiers changed from: package-private */
    public boolean isFlickGestureAvailable() {
        return this.isFlickGestureAvailable;
    }

    public boolean onTouch(View v, MotionEvent event) {
        try {
            int actionMasked = event.getActionMasked();
            if (actionMasked == 0) {
                this.mDownX = event.getRawX();
                this.mDownY = event.getRawY();
                fireEventByState("start", 0.0d, 0.0d, new Object[0]);
                this.downTimeMillis = System.currentTimeMillis();
                this.downX = event.getRawX();
                this.downY = event.getRawY();
            } else if (actionMasked == 1) {
                this.mDownX = 0.0f;
                this.mDownY = 0.0f;
                this.upX = event.getRawX();
                this.upY = event.getRawY();
                clearExpressions();
                fireEventByState("end", this.mDx, this.mDy, new Object[0]);
                this.mDx = 0.0d;
                this.mDy = 0.0d;
            } else if (actionMasked != 2) {
                if (actionMasked == 3) {
                    this.mDownX = 0.0f;
                    this.mDownY = 0.0f;
                    clearExpressions();
                    fireEventByState(BindingXConstants.STATE_CANCEL, this.mDx, this.mDy, new Object[0]);
                }
            } else if (this.mDownX == 0.0f && this.mDownY == 0.0f) {
                this.mDownX = event.getRawX();
                this.mDownY = event.getRawY();
                fireEventByState("start", 0.0d, 0.0d, new Object[0]);
            } else {
                this.mDx = (double) (event.getRawX() - this.mDownX);
                this.mDy = (double) (event.getRawY() - this.mDownY);
            }
        } catch (Exception e) {
            LogProxy.e("runtime error ", e);
        }
        return this.mGestureDetector.onTouchEvent(event);
    }

    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        float downY2;
        float downX2;
        this.movetime++;
        if (!this.isPanGestureAvailable) {
            LogProxy.d("pan gesture is not enabled");
            return false;
        }
        if (e1 == null) {
            float downX3 = this.mDownX;
            downY2 = this.mDownY;
            downX2 = downX3;
        } else {
            float downX4 = e1.getRawX();
            downY2 = e1.getRawY();
            downX2 = downX4;
        }
        if (e2 == null) {
            return false;
        }
        float deltaX = e2.getRawX() - downX2;
        float deltaY = e2.getRawY() - downY2;
        try {
            if (LogProxy.sEnableLog) {
                LogProxy.d(String.format(Locale.getDefault(), "[TouchHandler] pan moved. (x:%f,y:%f)", Float.valueOf(deltaX), Float.valueOf(deltaY)));
            }
            JSMath.applyXYToScope(this.mScope, (double) deltaX, (double) deltaY, this.mPlatformManager.getResolutionTranslator());
            if (!evaluateExitExpression(this.mExitExpressionPair, this.mScope)) {
                consumeExpression(this.mExpressionHoldersMap, this.mScope, "pan");
            }
        } catch (Exception e) {
            LogProxy.e("runtime error", e);
        }
        return false;
    }

    public void onLongPress(MotionEvent e) {
    }

    public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
        return !this.isFlickGestureAvailable ? false : false;
    }

    public boolean onDown(MotionEvent e) {
        return false;
    }

    public void onShowPress(MotionEvent e) {
    }

    public boolean onSingleTapUp(MotionEvent e) {
        return false;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onCreate(String sourceRef, String eventType) {
        View sourceView = this.mPlatformManager.getViewFinder().findViewBy(sourceRef, TextUtils.isEmpty(this.mAnchorInstanceId) ? this.mInstanceId : this.mAnchorInstanceId);
        if (sourceView == null) {
            LogProxy.e("[ExpressionTouchHandler] onCreate failed. sourceView not found:" + sourceRef);
            return false;
        }
        this.movetime = 0;
        sourceView.setOnTouchListener(this);
        try {
            Method m = sourceView.getClass().getDeclaredMethod("addPan", Object.class);
            if (m != null) {
                m.setAccessible(true);
                m.invoke(sourceView, this);
            }
        } catch (Exception ignored) {
            ignored.printStackTrace();
        }
        LogProxy.d("[ExpressionTouchHandler] onCreate success. {source:" + sourceRef + ",type:" + eventType + "}");
        return true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0027  */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x002e  */
    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onStart(String sourceRef, String eventType) {
        char c;
        int hashCode = eventType.hashCode();
        if (hashCode != 110749) {
            if (hashCode == 97520651 && eventType.equals(BindingXEventType.TYPE_FLICK)) {
                c = 1;
                if (c == 0) {
                    setPanGestureAvailable(true);
                    return;
                } else if (c == 1) {
                    setFlickGestureAvailable(true);
                    return;
                } else {
                    return;
                }
            }
        } else if (eventType.equals("pan")) {
            c = 0;
            if (c == 0) {
            }
        }
        c = 65535;
        if (c == 0) {
        }
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onBindExpression(String eventType, Map<String, Object> globalConfig, ExpressionPair exitExpressionPair, List<Map<String, Object>> expressionArgs, BindingXCore.JavaScriptCallback callback) {
        super.onBindExpression(eventType, globalConfig, exitExpressionPair, expressionArgs, callback);
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x0028  */
    /* JADX WARNING: Removed duplicated region for block: B:14:0x002f  */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0039  */
    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onDisable(String sourceRef, String eventType) {
        char c;
        int hashCode = eventType.hashCode();
        if (hashCode != 110749) {
            if (hashCode == 97520651 && eventType.equals(BindingXEventType.TYPE_FLICK)) {
                c = 1;
                if (c == 0) {
                    setPanGestureAvailable(false);
                } else if (c == 1) {
                    setFlickGestureAvailable(false);
                }
                if (!isPanGestureAvailable() || isFlickGestureAvailable()) {
                    return false;
                }
                View hostView = this.mPlatformManager.getViewFinder().findViewBy(sourceRef, TextUtils.isEmpty(this.mAnchorInstanceId) ? this.mInstanceId : this.mAnchorInstanceId);
                if (hostView != null) {
                    hostView.setOnTouchListener(null);
                    this.movetime = 0;
                    try {
                        Method m = hostView.getClass().getDeclaredMethod("removePan", new Class[0]);
                        if (m != null) {
                            m.setAccessible(true);
                            m.invoke(hostView, new Object[0]);
                        }
                    } catch (Exception ignored) {
                        ignored.printStackTrace();
                    }
                }
                LogProxy.d("remove touch listener success.[" + sourceRef + "," + eventType + Operators.ARRAY_END_STR);
                return true;
            }
        } else if (eventType.equals("pan")) {
            c = 0;
            if (c == 0) {
            }
            if (!isPanGestureAvailable()) {
            }
            return false;
        }
        c = 65535;
        if (c == 0) {
        }
        if (!isPanGestureAvailable()) {
        }
        return false;
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onDestroy() {
        super.onDestroy();
        if (this.mExpressionHoldersMap != null) {
            this.mExpressionHoldersMap.clear();
            this.mExpressionHoldersMap = null;
        }
        this.mExitExpressionPair = null;
        this.mCallback = null;
        this.isFlickGestureAvailable = false;
        this.isPanGestureAvailable = false;
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onExit(Map<String, Object> scope) {
        fireEventByState("exit", ((Double) scope.get("internal_x")).doubleValue(), ((Double) scope.get("internal_y")).doubleValue(), new Object[0]);
    }

    /* access modifiers changed from: protected */
    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler
    public void onUserIntercept(String interceptorName, Map<String, Object> scope) {
        fireEventByState(BindingXConstants.STATE_INTERCEPTOR, ((Double) scope.get("internal_x")).doubleValue(), ((Double) scope.get("internal_y")).doubleValue(), Collections.singletonMap(BindingXConstants.STATE_INTERCEPTOR, interceptorName));
    }

    private void fireEventByState(String state, double dx, double dy, Object... extension) {
        if (this.mCallback != null) {
            Map<String, Object> param = new HashMap<>();
            param.put("state", state);
            double x = this.mPlatformManager.getResolutionTranslator().nativeToWeb(dx, new Object[0]);
            double y = this.mPlatformManager.getResolutionTranslator().nativeToWeb(dy, new Object[0]);
            param.put("deltaX", Double.valueOf(x));
            param.put("deltaY", Double.valueOf(y));
            param.put("token", this.mToken);
            if (extension != null && extension.length > 0 && (extension[0] instanceof Map)) {
                param.putAll((Map) extension[0]);
            }
            this.mCallback.callback(param);
            LogProxy.d(">>>>>>>>>>>fire event:(" + state + "," + x + "," + y + Operators.BRACKET_END_STR);
        }
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityPause() {
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityResume() {
    }
}
