package com.alibaba.android.bindingx.core.internal;

/* access modifiers changed from: package-private */
public class OrientationEvaluator {
    private final Euler EULER = new Euler();
    private final Quaternion Q0 = new Quaternion();
    private final Quaternion Q1 = new Quaternion(-Math.sqrt(0.5d), 0.0d, 0.0d, Math.sqrt(0.5d));
    private final Vector3 ZEE = new Vector3(0.0d, 0.0d, 1.0d);
    private Double constraintAlpha = null;
    private double constraintAlphaOffset = 0.0d;
    private Double constraintBeta = null;
    private double constraintBetaOffset = 0.0d;
    private Double constraintGamma = null;
    private double constraintGammaOffset = 0.0d;
    private Quaternion quaternion = new Quaternion(0.0d, 0.0d, 0.0d, 1.0d);

    OrientationEvaluator(Double constraintAlpha2, Double constraintBeta2, Double constraintGamma2) {
        this.constraintAlpha = constraintAlpha2;
        this.constraintBeta = constraintBeta2;
        this.constraintGamma = constraintGamma2;
    }

    /* access modifiers changed from: package-private */
    public Quaternion calculate(double deviceAlpha, double deviceBeta, double deviceGamma, double normalizedAlpha) {
        Double d = this.constraintAlpha;
        double alpha = Math.toRadians(d != null ? d.doubleValue() : normalizedAlpha + this.constraintAlphaOffset);
        Double d2 = this.constraintBeta;
        double beta = Math.toRadians(d2 != null ? d2.doubleValue() : deviceBeta + this.constraintBetaOffset);
        Double d3 = this.constraintGamma;
        setObjectQuaternion(this.quaternion, alpha, beta, Math.toRadians(d3 != null ? d3.doubleValue() : deviceGamma + this.constraintGammaOffset), 0.0d);
        return this.quaternion;
    }

    private void setObjectQuaternion(Quaternion quaternion2, double alpha, double beta, double gamma, double orient) {
        this.EULER.setValue(beta, alpha, -gamma, "YXZ");
        quaternion2.setFromEuler(this.EULER);
        quaternion2.multiply(this.Q1);
        quaternion2.multiply(this.Q0.setFromAxisAngle(this.ZEE, -orient));
    }
}
