package com.alibaba.android.bindingx.core.internal;

import android.view.animation.Interpolator;
import androidx.core.view.animation.PathInterpolatorCompat;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Deque;
import java.util.Map;
import org.json.JSONException;

/* access modifiers changed from: package-private */
public class TimingFunctions {
    private static final InnerCache<BezierInterpolatorWrapper> cache = new InnerCache<>(4);
    private static Object cubicBezier = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass2 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double x1 = ((Double) arguments.get(4)).doubleValue();
            double y1 = ((Double) arguments.get(5)).doubleValue();
            double x2 = ((Double) arguments.get(6)).doubleValue();
            double y2 = ((Double) arguments.get(7)).doubleValue();
            double t2 = Math.min(t, d);
            if (t2 == d) {
                return Double.valueOf(b + c);
            }
            BezierInterpolatorWrapper bezierInterpolator = TimingFunctions.isCacheHit((float) x1, (float) y1, (float) x2, (float) y2);
            if (bezierInterpolator == null) {
                bezierInterpolator = new BezierInterpolatorWrapper((float) x1, (float) y1, (float) x2, (float) y2);
                TimingFunctions.cache.add(bezierInterpolator);
            }
            return Double.valueOf((c * ((double) bezierInterpolator.getInterpolation((float) (t2 / d)))) + b);
        }
    };
    private static Object easeInBack = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass27 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf((t2 * c * t2 * (((1.0d + 1.70158d) * t2) - 1.70158d)) + b);
        }
    };
    private static Object easeInBounce = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass30 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf(TimingFunctions.easeInBounce(Math.min(t, d), b, c, d));
        }
    };
    private static Object easeInCirc = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass21 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf(((-c) * (Math.sqrt(1.0d - (t2 * t2)) - 1.0d)) + b);
        }
    };
    private static Object easeInCubic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass6 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf((t2 * c * t2 * t2) + b);
        }
    };
    private static Object easeInElastic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass24 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double s;
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            double a = c;
            if (t2 == 0.0d) {
                return Double.valueOf(b);
            }
            double t3 = t2 / d;
            if (t3 == 1.0d) {
                return Double.valueOf(b + c);
            }
            double p = 0.3d * d;
            if (a < Math.abs(c)) {
                a = c;
                s = p / 4.0d;
            } else {
                s = (p / 6.283185307179586d) * Math.asin(c / a);
            }
            double t4 = t3 - 1.0d;
            return Double.valueOf((-(Math.pow(2.0d, t4 * 10.0d) * a * Math.sin((((t4 * d) - s) * 6.283185307179586d) / p))) + b);
        }
    };
    private static Object easeInExpo = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass18 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            return Double.valueOf(t2 == 0.0d ? b : (Math.pow(2.0d, ((t2 / d) - 1.0d) * 10.0d) * c) + b);
        }
    };
    private static Object easeInOutBack = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass29 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                double s = 1.525d * 1.70158d;
                return Double.valueOf(((c / 2.0d) * t2 * t2 * (((s + 1.0d) * t2) - s)) + b);
            }
            double t3 = t2 - 2.0d;
            double s2 = 1.525d * 1.70158d;
            return Double.valueOf(((c / 2.0d) * ((t3 * t3 * (((s2 + 1.0d) * t3) + s2)) + 2.0d)) + b);
        }
    };
    private static Object easeInOutBounce = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass32 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            if (t2 < d / 2.0d) {
                return Double.valueOf((TimingFunctions.easeInBounce(t2 * 2.0d, 0.0d, c, d) * 0.5d) + b);
            }
            return Double.valueOf((TimingFunctions.easeOutBounce((2.0d * t2) - d, 0.0d, c, d) * 0.5d) + (0.5d * c) + b);
        }
    };
    private static Object easeInOutCirc = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass23 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                return Double.valueOf((((-c) / 2.0d) * (Math.sqrt(1.0d - (t2 * t2)) - 1.0d)) + b);
            }
            double t3 = t2 - 2.0d;
            return Double.valueOf(((c / 2.0d) * (Math.sqrt(1.0d - (t3 * t3)) + 1.0d)) + b);
        }
    };
    private static Object easeInOutCubic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass8 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                return Double.valueOf(((c / 2.0d) * t2 * t2 * t2) + b);
            }
            double t3 = t2 - 2.0d;
            return Double.valueOf(((c / 2.0d) * ((t3 * t3 * t3) + 2.0d)) + b);
        }
    };
    private static Object easeInOutElastic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass26 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) {
            double s;
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            double a = c;
            if (t2 == 0.0d) {
                return Double.valueOf(b);
            }
            double t3 = t2 / (d / 2.0d);
            if (t3 == 2.0d) {
                return Double.valueOf(b + c);
            }
            double p = 0.44999999999999996d * d;
            if (a < Math.abs(c)) {
                a = c;
                s = p / 4.0d;
            } else {
                s = (p / 6.283185307179586d) * Math.asin(c / a);
            }
            if (t3 < 1.0d) {
                double t4 = t3 - 1.0d;
                return Double.valueOf((Math.pow(2.0d, t4 * 10.0d) * a * Math.sin((((t4 * d) - s) * 6.283185307179586d) / p) * -0.5d) + b);
            }
            double t5 = t3 - 1.0d;
            return Double.valueOf((Math.pow(2.0d, -10.0d * t5) * a * Math.sin((((t5 * d) - s) * 6.283185307179586d) / p) * 0.5d) + c + b);
        }
    };
    private static Object easeInOutExpo = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass20 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            if (t2 == 0.0d) {
                return Double.valueOf(b);
            }
            if (t2 == d) {
                return Double.valueOf(b + c);
            }
            double t3 = t2 / (d / 2.0d);
            if (t3 < 1.0d) {
                return Double.valueOf(((c / 2.0d) * Math.pow(2.0d, (t3 - 1.0d) * 10.0d)) + b);
            }
            return Double.valueOf(((c / 2.0d) * ((-Math.pow(2.0d, (t3 - 1.0d) * -10.0d)) + 2.0d)) + b);
        }
    };
    private static Object easeInOutQuad = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass5 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                return Double.valueOf(((c / 2.0d) * t2 * t2) + b);
            }
            double t3 = t2 - 1.0d;
            return Double.valueOf((((-c) / 2.0d) * ((t3 * (t3 - 2.0d)) - 1.0d)) + b);
        }
    };
    private static Object easeInOutQuart = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass11 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                return Double.valueOf(((c / 2.0d) * t2 * t2 * t2 * t2) + b);
            }
            double t3 = t2 - 2.0d;
            return Double.valueOf((((-c) / 2.0d) * ((((t3 * t3) * t3) * t3) - 2.0d)) + b);
        }
    };
    private static Object easeInOutQuint = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass14 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / (d / 2.0d);
            if (t2 < 1.0d) {
                return Double.valueOf(((c / 2.0d) * t2 * t2 * t2 * t2 * t2) + b);
            }
            double t3 = t2 - 2.0d;
            return Double.valueOf(((c / 2.0d) * ((t3 * t3 * t3 * t3 * t3) + 2.0d)) + b);
        }
    };
    private static Object easeInOutSine = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass17 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf((((-c) / 2.0d) * (Math.cos((3.141592653589793d * Math.min(t, d)) / d) - 1.0d)) + b);
        }
    };
    private static Object easeInQuad = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass3 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf((t2 * c * t2) + b);
        }
    };
    private static Object easeInQuart = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass9 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf((t2 * c * t2 * t2 * t2) + b);
        }
    };
    private static Object easeInQuint = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass12 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf((t2 * c * t2 * t2 * t2 * t2) + b);
        }
    };
    private static Object easeInSine = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass15 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf(((-c) * Math.cos((Math.min(t, d) / d) * 1.5707963267948966d)) + c + b);
        }
    };
    private static Object easeOutBack = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass28 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = (Math.min(t, d) / d) - 1.0d;
            return Double.valueOf((((t2 * t2 * (((1.70158d + 1.0d) * t2) + 1.70158d)) + 1.0d) * c) + b);
        }
    };
    private static Object easeOutBounce = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass31 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf(TimingFunctions.easeOutBounce(Math.min(t, d), b, c, d));
        }
    };
    private static Object easeOutCirc = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass22 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = (Math.min(t, d) / d) - 1.0d;
            return Double.valueOf((Math.sqrt(1.0d - (t2 * t2)) * c) + b);
        }
    };
    private static Object easeOutCubic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass7 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = (Math.min(t, d) / d) - 1.0d;
            return Double.valueOf((((t2 * t2 * t2) + 1.0d) * c) + b);
        }
    };
    private static Object easeOutElastic = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass25 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) {
            double s;
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            double a = c;
            if (t2 == 0.0d) {
                return Double.valueOf(b);
            }
            double t3 = t2 / d;
            if (t3 == 1.0d) {
                return Double.valueOf(b + c);
            }
            double p = 0.3d * d;
            if (a < Math.abs(c)) {
                a = c;
                s = p / 4.0d;
            } else {
                s = (p / 6.283185307179586d) * Math.asin(c / a);
            }
            return Double.valueOf((Math.pow(2.0d, t3 * -10.0d) * a * Math.sin((((t3 * d) - s) * 6.283185307179586d) / p)) + c + b);
        }
    };
    private static Object easeOutExpo = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass19 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d);
            return Double.valueOf(t2 == d ? b + c : (((-Math.pow(2.0d, (-10.0d * t2) / d)) + 1.0d) * c) + b);
        }
    };
    private static Object easeOutQuad = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass4 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = Math.min(t, d) / d;
            return Double.valueOf(((-c) * t2 * (t2 - 2.0d)) + b);
        }
    };
    private static Object easeOutQuart = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass10 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = (Math.min(t, d) / d) - 1.0d;
            return Double.valueOf(((-c) * ((((t2 * t2) * t2) * t2) - 1.0d)) + b);
        }
    };
    private static Object easeOutQuint = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass13 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            double t2 = (Math.min(t, d) / d) - 1.0d;
            return Double.valueOf((((t2 * t2 * t2 * t2 * t2) + 1.0d) * c) + b);
        }
    };
    private static Object easeOutSine = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass16 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf((Math.sin((Math.min(t, d) / d) * 1.5707963267948966d) * c) + b);
        }
    };
    private static Object linear = new JSFunctionInterface() {
        /* class com.alibaba.android.bindingx.core.internal.TimingFunctions.AnonymousClass1 */

        @Override // com.alibaba.android.bindingx.core.internal.JSFunctionInterface
        public Object execute(ArrayList<Object> arguments) throws NumberFormatException, JSONException {
            double t = ((Double) arguments.get(0)).doubleValue();
            double b = ((Double) arguments.get(1)).doubleValue();
            double c = ((Double) arguments.get(2)).doubleValue();
            double d = ((Double) arguments.get(3)).doubleValue();
            return Double.valueOf(((Math.min(t, d) / d) * c) + b);
        }
    };

    private TimingFunctions() {
    }

    static void applyToScope(Map<String, Object> scope) {
        scope.put("linear", linear);
        scope.put("easeInQuad", easeInQuad);
        scope.put("easeOutQuad", easeOutQuad);
        scope.put("easeInOutQuad", easeInOutQuad);
        scope.put("easeInCubic", easeInCubic);
        scope.put("easeOutCubic", easeOutCubic);
        scope.put("easeInOutCubic", easeInOutCubic);
        scope.put("easeInQuart", easeInQuart);
        scope.put("easeOutQuart", easeOutQuart);
        scope.put("easeInOutQuart", easeInOutQuart);
        scope.put("easeInQuint", easeInQuint);
        scope.put("easeOutQuint", easeOutQuint);
        scope.put("easeInOutQuint", easeInOutQuint);
        scope.put("easeInSine", easeInSine);
        scope.put("easeOutSine", easeOutSine);
        scope.put("easeInOutSine", easeInOutSine);
        scope.put("easeInExpo", easeInExpo);
        scope.put("easeOutExpo", easeOutExpo);
        scope.put("easeInOutExpo", easeInOutExpo);
        scope.put("easeInCirc", easeInCirc);
        scope.put("easeOutCirc", easeOutCirc);
        scope.put("easeInOutCirc", easeInOutCirc);
        scope.put("easeInElastic", easeInElastic);
        scope.put("easeOutElastic", easeOutElastic);
        scope.put("easeInOutElastic", easeInOutElastic);
        scope.put("easeInBack", easeInBack);
        scope.put("easeOutBack", easeOutBack);
        scope.put("easeInOutBack", easeInOutBack);
        scope.put("easeInBounce", easeInBounce);
        scope.put("easeOutBounce", easeOutBounce);
        scope.put("easeInOutBounce", easeInOutBounce);
        scope.put("cubicBezier", cubicBezier);
    }

    /* access modifiers changed from: private */
    public static BezierInterpolatorWrapper isCacheHit(float x1, float y1, float x2, float y2) {
        for (BezierInterpolatorWrapper bezier : cache.getAll()) {
            if (Float.compare(bezier.x1, x1) == 0 && Float.compare(bezier.x2, x2) == 0 && Float.compare(bezier.y1, y1) == 0 && Float.compare(bezier.y2, y2) == 0) {
                return bezier;
            }
        }
        return null;
    }

    /* access modifiers changed from: private */
    public static double easeInBounce(double t, double b, double c, double d) {
        return (c - easeOutBounce(d - t, 0.0d, c, d)) + b;
    }

    /* access modifiers changed from: private */
    public static double easeOutBounce(double t, double b, double c, double d) {
        double t2 = t / d;
        if (t2 < 0.36363636363636365d) {
            return (7.5625d * t2 * t2 * c) + b;
        }
        if (t2 < 0.7272727272727273d) {
            double t3 = t2 - 0.5454545454545454d;
            return (((t3 * 7.5625d * t3) + 0.75d) * c) + b;
        } else if (t2 < 0.9090909090909091d) {
            double t4 = t2 - 0.8181818181818182d;
            return (((t4 * 7.5625d * t4) + 0.9375d) * c) + b;
        } else {
            double t5 = t2 - 0.9545454545454546d;
            return (((t5 * 7.5625d * t5) + 0.984375d) * c) + b;
        }
    }

    /* access modifiers changed from: private */
    public static class InnerCache<T> {
        private final ArrayDeque<T> deque;

        InnerCache(int size) {
            this.deque = new ArrayDeque<>(size);
        }

        /* access modifiers changed from: package-private */
        public void add(T t) {
            if (this.deque.size() >= 4) {
                this.deque.removeFirst();
                this.deque.addLast(t);
                return;
            }
            this.deque.addLast(t);
        }

        /* access modifiers changed from: package-private */
        public Deque<T> getAll() {
            return this.deque;
        }
    }

    /* access modifiers changed from: private */
    public static class BezierInterpolatorWrapper implements Interpolator {
        private Interpolator mInnerInterpolator;
        float x1;
        float x2;
        float y1;
        float y2;

        BezierInterpolatorWrapper(float x12, float y12, float x22, float y22) {
            this.x1 = x12;
            this.y1 = y12;
            this.x2 = x22;
            this.y2 = y22;
            this.mInnerInterpolator = PathInterpolatorCompat.create(x12, y12, x22, y22);
        }

        public float getInterpolation(float input) {
            return this.mInnerInterpolator.getInterpolation(input);
        }
    }
}
