package com.alibaba.android.bindingx.plugin.weex;

import android.content.Context;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.alibaba.android.bindingx.core.internal.BindingXTouchHandler;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXUtils;
import java.util.Map;

public class BindingXGestureHandler extends BindingXTouchHandler {
    private boolean experimental = false;
    private WXGesture mWeexGestureHandler = null;

    public BindingXGestureHandler(Context context, PlatformManager manager, Object... extension) {
        super(context, manager, extension);
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void setGlobalConfig(Map<String, Object> globalConfig) {
        super.setGlobalConfig(globalConfig);
        if (globalConfig != null) {
            this.experimental = WXUtils.getBoolean(globalConfig.get("experimentalGestureFeatures"), false).booleanValue();
        }
    }

    @Override // com.alibaba.android.bindingx.core.internal.BindingXTouchHandler, com.alibaba.android.bindingx.core.IEventHandler
    public boolean onCreate(String sourceRef, String eventType) {
        if (!this.experimental) {
            return super.onCreate(sourceRef, eventType);
        }
        WXComponent sourceComponent = WXModuleUtils.findComponentByRef(TextUtils.isEmpty(this.mAnchorInstanceId) ? this.mInstanceId : this.mAnchorInstanceId, sourceRef);
        if (sourceComponent == null) {
            return super.onCreate(sourceRef, eventType);
        }
        View view = sourceComponent.getHostView();
        if (!(view instanceof ViewGroup) || !(view instanceof WXGestureObservable)) {
            return super.onCreate(sourceRef, eventType);
        }
        try {
            WXGesture gestureListener = ((WXGestureObservable) view).getGestureListener();
            this.mWeexGestureHandler = gestureListener;
            if (gestureListener == null) {
                return super.onCreate(sourceRef, eventType);
            }
            gestureListener.addOnTouchListener(this);
            LogProxy.d("[ExpressionGestureHandler] onCreate success. {source:" + sourceRef + ",type:" + eventType + "}");
            return true;
        } catch (Throwable e) {
            LogProxy.e("experimental gesture features open failed." + e.getMessage());
            return super.onCreate(sourceRef, eventType);
        }
    }

    @Override // com.alibaba.android.bindingx.core.internal.BindingXTouchHandler, com.alibaba.android.bindingx.core.IEventHandler
    public boolean onDisable(String sourceRef, String eventType) {
        WXGesture wXGesture;
        boolean result = super.onDisable(sourceRef, eventType);
        if (!this.experimental || (wXGesture = this.mWeexGestureHandler) == null) {
            return result;
        }
        try {
            return result | wXGesture.removeTouchListener(this);
        } catch (Throwable e) {
            LogProxy.e("[ExpressionGestureHandler]  disabled failed." + e.getMessage());
            return result;
        }
    }
}
