package com.alibaba.android.bindingx.plugin.weex;

import android.content.Context;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import androidx.core.view.ViewCompat;
import androidx.recyclerview.widget.RecyclerView;
import com.alibaba.android.bindingx.core.BindingXCore;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.alibaba.android.bindingx.core.internal.AbstractScrollEventHandler;
import com.alibaba.android.bindingx.core.internal.BindingXConstants;
import com.alibaba.android.bindingx.core.internal.ExpressionPair;
import com.google.android.material.appbar.AppBarLayout;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXScroller;
import com.taobao.weex.ui.component.list.WXListComponent;
import com.taobao.weex.ui.view.WXHorizontalScrollView;
import com.taobao.weex.ui.view.WXScrollView;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.refresh.core.WXSwipeLayout;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceScrollerView;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class BindingXScrollHandler extends AbstractScrollEventHandler {
    private static HashMap<String, ContentOffsetHolder> sOffsetHolderMap = new HashMap<>();
    private WXHorizontalScrollView.ScrollViewListener mHorizontalViewScrollListener;
    private RecyclerView.OnScrollListener mListOnScrollListener;
    private AppBarLayout.OnOffsetChangedListener mOnOffsetChangedListener;
    private WXSwipeLayout.OnRefreshOffsetChangedListener mRefreshOffsetChangedListener;
    private String mSourceRef;
    private WXScrollView.WXScrollViewListener mWxScrollViewListener;

    public BindingXScrollHandler(Context context, PlatformManager manager, Object... extension) {
        super(context, manager, extension);
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public boolean onCreate(String sourceRef, String eventType) {
        WXSwipeLayout layout;
        WXComponent sourceComponent = WXModuleUtils.findComponentByRef(TextUtils.isEmpty(this.mAnchorInstanceId) ? this.mInstanceId : this.mAnchorInstanceId, sourceRef);
        if (sourceComponent == null) {
            LogProxy.e("[ExpressionScrollHandler]source component not found.");
            return false;
        }
        this.mSourceRef = sourceRef;
        if (sourceComponent instanceof WXScroller) {
            WXScroller scroller = (WXScroller) sourceComponent;
            ViewGroup group = (ViewGroup) scroller.getHostView();
            if (!(group == null || !(group instanceof BounceScrollerView) || (layout = ((BounceScrollerView) group).getSwipeLayout()) == null)) {
                InnerSwipeOffsetListener innerSwipeOffsetListener = new InnerSwipeOffsetListener();
                this.mRefreshOffsetChangedListener = innerSwipeOffsetListener;
                layout.addOnRefreshOffsetChangedListener(innerSwipeOffsetListener);
            }
            View innerView = scroller.getInnerView();
            if (innerView != null && (innerView instanceof WXScrollView)) {
                InnerScrollViewListener innerScrollViewListener = new InnerScrollViewListener();
                this.mWxScrollViewListener = innerScrollViewListener;
                ((WXScrollView) innerView).addScrollViewListener(innerScrollViewListener);
                return true;
            } else if (innerView != null && (innerView instanceof WXHorizontalScrollView)) {
                InnerScrollViewListener innerScrollViewListener2 = new InnerScrollViewListener();
                this.mHorizontalViewScrollListener = innerScrollViewListener2;
                ((WXHorizontalScrollView) innerView).addScrollViewListener(innerScrollViewListener2);
                return true;
            }
        } else if (sourceComponent instanceof WXListComponent) {
            WXListComponent list = (WXListComponent) sourceComponent;
            BounceRecyclerView hostView = (BounceRecyclerView) list.getHostView();
            if (hostView != null) {
                WXSwipeLayout layout2 = hostView.getSwipeLayout();
                if (layout2 != null) {
                    InnerSwipeOffsetListener innerSwipeOffsetListener2 = new InnerSwipeOffsetListener();
                    this.mRefreshOffsetChangedListener = innerSwipeOffsetListener2;
                    layout2.addOnRefreshOffsetChangedListener(innerSwipeOffsetListener2);
                }
                WXRecyclerView recyclerView = (WXRecyclerView) hostView.getInnerView();
                boolean isVertical = list.getOrientation() == 1;
                if (recyclerView != null) {
                    HashMap<String, ContentOffsetHolder> hashMap = sOffsetHolderMap;
                    if (hashMap != null && hashMap.get(sourceRef) == null) {
                        sOffsetHolderMap.put(sourceRef, new ContentOffsetHolder(0, 0));
                    }
                    InnerListScrollListener innerListScrollListener = new InnerListScrollListener(isVertical, new WeakReference(list));
                    this.mListOnScrollListener = innerListScrollListener;
                    recyclerView.addOnScrollListener(innerListScrollListener);
                    return true;
                }
            }
        } else if (sourceComponent.getHostView() != null && (sourceComponent.getHostView() instanceof AppBarLayout)) {
            InnerAppBarOffsetChangedListener innerAppBarOffsetChangedListener = new InnerAppBarOffsetChangedListener();
            this.mOnOffsetChangedListener = innerAppBarOffsetChangedListener;
            sourceComponent.getHostView().addOnOffsetChangedListener(innerAppBarOffsetChangedListener);
            return true;
        }
        return false;
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onStart(String sourceRef, String eventType) {
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onBindExpression(String eventType, Map<String, Object> globalConfig, ExpressionPair exitExpressionPair, List<Map<String, Object>> expressionArgs, BindingXCore.JavaScriptCallback callback) {
        super.onBindExpression(eventType, globalConfig, exitExpressionPair, expressionArgs, callback);
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractScrollEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public boolean onDisable(String sourceRef, String eventType) {
        BounceRecyclerView hostView;
        RecyclerView.OnScrollListener onScrollListener;
        WXHorizontalScrollView.ScrollViewListener scrollViewListener;
        WXScrollView.WXScrollViewListener wXScrollViewListener;
        WXSwipeLayout layout;
        WXSwipeLayout.OnRefreshOffsetChangedListener onRefreshOffsetChangedListener;
        ContentOffsetHolder h;
        super.onDisable(sourceRef, eventType);
        if (!(sOffsetHolderMap == null || TextUtils.isEmpty(this.mSourceRef) || (h = sOffsetHolderMap.get(this.mSourceRef)) == null)) {
            h.x = this.mContentOffsetX;
            h.y = this.mContentOffsetY;
        }
        WXComponent sourceComponent = WXModuleUtils.findComponentByRef(TextUtils.isEmpty(this.mAnchorInstanceId) ? this.mInstanceId : this.mAnchorInstanceId, sourceRef);
        if (sourceComponent == null) {
            LogProxy.e("[ExpressionScrollHandler]source component not found.");
            return false;
        }
        if (sourceComponent instanceof WXScroller) {
            WXScroller scroller = (WXScroller) sourceComponent;
            ViewGroup group = (ViewGroup) scroller.getHostView();
            if (!(group == null || !(group instanceof BounceScrollerView) || (layout = ((BounceScrollerView) group).getSwipeLayout()) == null || (onRefreshOffsetChangedListener = this.mRefreshOffsetChangedListener) == null)) {
                layout.removeOnRefreshOffsetChangedListener(onRefreshOffsetChangedListener);
            }
            View innerView = scroller.getInnerView();
            if (innerView != null && (innerView instanceof WXScrollView) && (wXScrollViewListener = this.mWxScrollViewListener) != null) {
                ((WXScrollView) innerView).removeScrollViewListener(wXScrollViewListener);
                return true;
            } else if (!(innerView == null || !(innerView instanceof WXHorizontalScrollView) || (scrollViewListener = this.mHorizontalViewScrollListener) == null)) {
                ((WXHorizontalScrollView) innerView).removeScrollViewListener(scrollViewListener);
                return true;
            }
        } else if ((sourceComponent instanceof WXListComponent) && (hostView = (BounceRecyclerView) ((WXListComponent) sourceComponent).getHostView()) != null) {
            if (!(hostView.getSwipeLayout() == null || this.mRefreshOffsetChangedListener == null)) {
                hostView.getSwipeLayout().removeOnRefreshOffsetChangedListener(this.mRefreshOffsetChangedListener);
            }
            WXRecyclerView recyclerView = (WXRecyclerView) hostView.getInnerView();
            if (!(recyclerView == null || (onScrollListener = this.mListOnScrollListener) == null)) {
                recyclerView.removeOnScrollListener(onScrollListener);
                return true;
            }
        }
        return false;
    }

    @Override // com.alibaba.android.bindingx.core.internal.AbstractScrollEventHandler, com.alibaba.android.bindingx.core.internal.AbstractEventHandler, com.alibaba.android.bindingx.core.IEventHandler
    public void onDestroy() {
        super.onDestroy();
        this.mListOnScrollListener = null;
        this.mWxScrollViewListener = null;
        this.mOnOffsetChangedListener = null;
        HashMap<String, ContentOffsetHolder> hashMap = sOffsetHolderMap;
        if (hashMap != null) {
            hashMap.clear();
        }
    }

    private class InnerAppBarOffsetChangedListener implements AppBarLayout.OnOffsetChangedListener {
        private int mContentOffsetY;
        private int mLastDy;
        private int mTy;

        private InnerAppBarOffsetChangedListener() {
            this.mContentOffsetY = 0;
            this.mTy = 0;
            this.mLastDy = 0;
        }

        public void onOffsetChanged(AppBarLayout appBarLayout, int verticalOffset) {
            int verticalOffset2 = -verticalOffset;
            final int dy = verticalOffset2 - this.mContentOffsetY;
            this.mContentOffsetY = verticalOffset2;
            if (dy != 0) {
                boolean isTurning = false;
                if (!BindingXScrollHandler.this.isSameDirection(dy, this.mLastDy)) {
                    this.mTy = this.mContentOffsetY;
                    isTurning = true;
                }
                int i = this.mContentOffsetY;
                final int tdy = i - this.mTy;
                this.mLastDy = dy;
                if (isTurning) {
                    BindingXScrollHandler.super.fireEventByState(BindingXConstants.STATE_TURNING, 0.0d, (double) i, 0.0d, (double) dy, 0.0d, (double) tdy, new Object[0]);
                }
                WXBridgeManager.getInstance().post(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.BindingXScrollHandler.InnerAppBarOffsetChangedListener.AnonymousClass1 */

                    public void run() {
                        InnerAppBarOffsetChangedListener.super.handleScrollEvent(0, InnerAppBarOffsetChangedListener.this.mContentOffsetY, 0, dy, 0, tdy);
                    }
                }, BindingXScrollHandler.this.mInstanceId);
            }
        }
    }

    private class InnerScrollViewListener implements WXScrollView.WXScrollViewListener, WXHorizontalScrollView.ScrollViewListener {
        private int mContentOffsetX;
        private int mContentOffsetY;
        private int mLastDx;
        private int mLastDy;
        private int mTx;
        private int mTy;

        private InnerScrollViewListener() {
            this.mContentOffsetX = 0;
            this.mContentOffsetY = 0;
            this.mTx = 0;
            this.mTy = 0;
            this.mLastDx = 0;
            this.mLastDy = 0;
        }

        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
        public void onScroll(WXScrollView wxScrollView, int x, int y) {
            onScrollInternal(x, y);
        }

        @Override // com.taobao.weex.ui.view.WXHorizontalScrollView.ScrollViewListener
        public void onScrollChanged(WXHorizontalScrollView wxHorizontalScrollView, int x, int y, int oldX, int oldY) {
            onScrollInternal(x, y);
        }

        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
        public void onScrollChanged(WXScrollView wxScrollView, int i, int i1, int i2, int i3) {
        }

        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
        public void onScrollToBottom(WXScrollView wxScrollView, int i, int i1) {
        }

        @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
        public void onScrollStopped(WXScrollView wxScrollView, int i, int i1) {
        }

        private void onScrollInternal(int x, int y) {
            boolean isTurning;
            final int dx;
            final int dy;
            int dx2 = x - this.mContentOffsetX;
            int dy2 = y - this.mContentOffsetY;
            this.mContentOffsetX = x;
            this.mContentOffsetY = y;
            if (dx2 != 0 || dy2 != 0) {
                if (!BindingXScrollHandler.this.isSameDirection(dy2, this.mLastDy)) {
                    this.mTy = this.mContentOffsetY;
                    isTurning = true;
                } else {
                    isTurning = false;
                }
                int i = this.mContentOffsetX;
                final int tdx = i - this.mTx;
                int i2 = this.mContentOffsetY;
                final int tdy = i2 - this.mTy;
                this.mLastDx = dx2;
                this.mLastDy = dy2;
                if (isTurning) {
                    dy = dy2;
                    dx = dx2;
                    BindingXScrollHandler.super.fireEventByState(BindingXConstants.STATE_TURNING, (double) i, (double) i2, (double) dx2, (double) dy2, (double) tdx, (double) tdy, new Object[0]);
                } else {
                    dx = dx2;
                    dy = dy2;
                }
                WXBridgeManager.getInstance().post(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.BindingXScrollHandler.InnerScrollViewListener.AnonymousClass1 */

                    public void run() {
                        InnerScrollViewListener.super.handleScrollEvent(InnerScrollViewListener.this.mContentOffsetX, InnerScrollViewListener.this.mContentOffsetY, dx, dy, tdx, tdy);
                    }
                }, BindingXScrollHandler.this.mInstanceId);
            }
        }
    }

    private class InnerSwipeOffsetListener implements WXSwipeLayout.OnRefreshOffsetChangedListener {
        private int mContentOffsetY;
        private int mLastDy;
        private int mTy;

        private InnerSwipeOffsetListener() {
            this.mContentOffsetY = 0;
            this.mTy = 0;
            this.mLastDy = 0;
        }

        @Override // com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.OnRefreshOffsetChangedListener
        public void onOffsetChanged(int offset) {
            int normalizedOffset = -offset;
            final int dy = normalizedOffset - this.mContentOffsetY;
            this.mContentOffsetY = normalizedOffset;
            if (dy != 0) {
                boolean isTurning = false;
                if (!BindingXScrollHandler.this.isSameDirection(dy, this.mLastDy)) {
                    this.mTy = this.mContentOffsetY;
                    isTurning = true;
                }
                final int tdy = this.mContentOffsetY - this.mTy;
                this.mLastDy = dy;
                if (isTurning) {
                    BindingXScrollHandler bindingXScrollHandler = BindingXScrollHandler.this;
                    BindingXScrollHandler.super.fireEventByState(BindingXConstants.STATE_TURNING, (double) bindingXScrollHandler.mContentOffsetX, (double) this.mContentOffsetY, 0.0d, (double) dy, 0.0d, (double) tdy, new Object[0]);
                }
                WXBridgeManager.getInstance().post(new Runnable() {
                    /* class com.alibaba.android.bindingx.plugin.weex.BindingXScrollHandler.InnerSwipeOffsetListener.AnonymousClass1 */

                    public void run() {
                        InnerSwipeOffsetListener.super.handleScrollEvent(BindingXScrollHandler.this.mContentOffsetX, InnerSwipeOffsetListener.this.mContentOffsetY, 0, dy, 0, tdy);
                    }
                }, BindingXScrollHandler.this.mInstanceId);
            }
        }
    }

    private class InnerListScrollListener extends RecyclerView.OnScrollListener {
        private boolean isVertical;
        private WeakReference<WXListComponent> mComponentRef;
        private int mContentOffsetX = 0;
        private int mContentOffsetY = 0;
        private int mLastDx = 0;
        private int mLastDy = 0;
        private int mTx = 0;
        private int mTy = 0;

        InnerListScrollListener(boolean isVertical2, WeakReference<WXListComponent> componentRef) {
            ContentOffsetHolder holder;
            this.isVertical = isVertical2;
            this.mComponentRef = componentRef;
            if (!TextUtils.isEmpty(BindingXScrollHandler.this.mSourceRef) && BindingXScrollHandler.sOffsetHolderMap != null && (holder = (ContentOffsetHolder) BindingXScrollHandler.sOffsetHolderMap.get(BindingXScrollHandler.this.mSourceRef)) != null) {
                this.mContentOffsetX = holder.x;
                this.mContentOffsetY = holder.y;
            }
        }

        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
        public void onScrolled(RecyclerView recyclerView, final int dx, final int dy) {
            boolean isTurning;
            WeakReference<WXListComponent> weakReference;
            if (!ViewCompat.isInLayout(recyclerView) || (weakReference = this.mComponentRef) == null || weakReference.get() == null) {
                this.mContentOffsetY += dy;
            } else {
                this.mContentOffsetY = Math.abs(this.mComponentRef.get().calcContentOffset(recyclerView));
            }
            this.mContentOffsetX += dx;
            boolean isTurning2 = false;
            if (!BindingXScrollHandler.this.isSameDirection(dx, this.mLastDx) && !this.isVertical) {
                this.mTx = this.mContentOffsetX;
                isTurning2 = true;
            }
            if (BindingXScrollHandler.this.isSameDirection(dy, this.mLastDy) || !this.isVertical) {
                isTurning = isTurning2;
            } else {
                this.mTy = this.mContentOffsetY;
                isTurning = true;
            }
            int i = this.mContentOffsetX;
            final int tdx = i - this.mTx;
            int i2 = this.mContentOffsetY;
            final int tdy = i2 - this.mTy;
            this.mLastDx = dx;
            this.mLastDy = dy;
            if (isTurning) {
                BindingXScrollHandler.this.fireEventByState(BindingXConstants.STATE_TURNING, (double) i, (double) i2, (double) dx, (double) dy, (double) tdx, (double) tdy, new Object[0]);
            }
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.alibaba.android.bindingx.plugin.weex.BindingXScrollHandler.InnerListScrollListener.AnonymousClass1 */

                public void run() {
                    InnerListScrollListener.super.handleScrollEvent(InnerListScrollListener.this.mContentOffsetX, InnerListScrollListener.this.mContentOffsetY, dx, dy, tdx, tdy);
                }
            }, BindingXScrollHandler.this.mInstanceId);
        }
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityPause() {
    }

    @Override // com.alibaba.android.bindingx.core.IEventHandler
    public void onActivityResume() {
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isSameDirection(int currentValue, int lastValue) {
        return (currentValue > 0 && lastValue > 0) || (currentValue < 0 && lastValue < 0);
    }

    /* access modifiers changed from: private */
    public static class ContentOffsetHolder {
        int x;
        int y;

        ContentOffsetHolder(int x2, int y2) {
            this.x = x2;
            this.y = y2;
        }
    }
}
