package com.alibaba.android.bindingx.plugin.weex;

import android.content.Context;
import android.graphics.Color;
import android.graphics.RectF;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.text.Layout;
import android.text.SpannableString;
import android.text.style.ForegroundColorSpan;
import android.util.Log;
import android.view.View;
import com.alibaba.android.bindingx.core.BindingXCore;
import com.alibaba.android.bindingx.core.BindingXEventType;
import com.alibaba.android.bindingx.core.IEventHandler;
import com.alibaba.android.bindingx.core.LogProxy;
import com.alibaba.android.bindingx.core.PlatformManager;
import com.alibaba.android.bindingx.core.internal.Utils;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.animation.TransformParser;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXText;
import com.taobao.weex.ui.view.WXTextView;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.uniapp.dom.AbsCSSShorthand;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

public class WXBindingXModule extends WXSDKEngine.DestroyableModule {
    private BindingXCore mBindingXCore;
    private PlatformManager mPlatformManager;

    public WXBindingXModule() {
    }

    WXBindingXModule(BindingXCore core) {
        this.mBindingXCore = core;
    }

    private void prepareInternal() {
        if (this.mPlatformManager == null) {
            this.mPlatformManager = createPlatformManager(this.mWXSDKInstance);
        }
        if (this.mBindingXCore == null) {
            BindingXCore bindingXCore = new BindingXCore(this.mPlatformManager);
            this.mBindingXCore = bindingXCore;
            bindingXCore.registerEventHandler("scroll", new BindingXCore.ObjectCreator<IEventHandler, Context, PlatformManager>() {
                /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass1 */

                public IEventHandler createWith(Context context, PlatformManager manager, Object... extension) {
                    return new BindingXScrollHandler(context, manager, extension);
                }
            });
            this.mBindingXCore.registerEventHandler("pan", new BindingXCore.ObjectCreator<IEventHandler, Context, PlatformManager>() {
                /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass2 */

                public IEventHandler createWith(Context context, PlatformManager manager, Object... extension) {
                    return new BindingXGestureHandler(context, manager, extension);
                }
            });
        }
    }

    @JSMethod(uiThread = false)
    public void prepare(Map<String, Object> map) {
        prepareInternal();
    }

    @JSMethod(uiThread = false)
    public Map<String, String> bind(Map<String, Object> params, final JSCallback callback) {
        prepareInternal();
        BindingXCore bindingXCore = this.mBindingXCore;
        String str = null;
        Context context = this.mWXSDKInstance == null ? null : this.mWXSDKInstance.getContext();
        if (this.mWXSDKInstance != null) {
            str = this.mWXSDKInstance.getInstanceId();
        }
        String token = bindingXCore.doBind(context, str, params == null ? Collections.emptyMap() : params, new BindingXCore.JavaScriptCallback() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass3 */

            @Override // com.alibaba.android.bindingx.core.BindingXCore.JavaScriptCallback
            public void callback(Object params) {
                if (callback != null) {
                    Log.e("触发去往前端的回调", WXBridgeManager.METHOD_CALLBACK);
                    callback.invokeAndKeepAlive(params);
                }
            }
        }, new Object[0]);
        Map<String, String> result = new HashMap<>(2);
        result.put("token", token);
        return result;
    }

    @JSMethod(uiThread = false)
    public void bindAsync(Map<String, Object> params, JSCallback callback, JSCallback tokenCallback) {
        Map<String, String> result = bind(params, callback);
        if (tokenCallback != null && result != null) {
            tokenCallback.invoke(result);
        }
    }

    @JSMethod(uiThread = false)
    public void unbind(Map<String, Object> params) {
        BindingXCore bindingXCore = this.mBindingXCore;
        if (bindingXCore != null) {
            bindingXCore.doUnbind(params);
        }
    }

    @JSMethod(uiThread = false)
    public void unbindAll() {
        BindingXCore bindingXCore = this.mBindingXCore;
        if (bindingXCore != null) {
            bindingXCore.doRelease();
        }
    }

    @JSMethod(uiThread = false)
    public List<String> supportFeatures() {
        return Arrays.asList("pan", "orientation", BindingXEventType.TYPE_TIMING, "scroll", "experimentalGestureFeatures");
    }

    @JSMethod(uiThread = false)
    public void getComputedStyleAsync(String ref, JSCallback callback) {
        Map<String, Object> result = getComputedStyle(ref);
        if (callback != null) {
            callback.invoke(result);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x023c  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x02aa  */
    @JSMethod(uiThread = false)
    public Map<String, Object> getComputedStyle(String ref) {
        double bottomRight;
        prepareInternal();
        PlatformManager.IDeviceResolutionTranslator resolutionTranslator = this.mPlatformManager.getResolutionTranslator();
        WXComponent component = WXModuleUtils.findComponentByRef(this.mWXSDKInstance.getInstanceId(), ref);
        if (component == null) {
            return Collections.emptyMap();
        }
        View sourceView = component.getHostView();
        if (sourceView == null) {
            return Collections.emptyMap();
        }
        Map<String, Object> map = new HashMap<>();
        map.put("width", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getLayoutWidth(), new Object[0])));
        map.put("height", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getLayoutHeight(), new Object[0])));
        map.put(AbsoluteConst.JSON_KEY_PADDING_LEFT, Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getPadding().get(AbsCSSShorthand.EDGE.LEFT), new Object[0])));
        map.put("padding-top", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getPadding().get(AbsCSSShorthand.EDGE.TOP), new Object[0])));
        map.put(AbsoluteConst.JSON_KEY_PADDING_RIGHT, Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getPadding().get(AbsCSSShorthand.EDGE.RIGHT), new Object[0])));
        map.put("padding-bottom", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getPadding().get(AbsCSSShorthand.EDGE.BOTTOM), new Object[0])));
        map.put("margin-left", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getMargin().get(AbsCSSShorthand.EDGE.LEFT), new Object[0])));
        map.put("margin-top", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getMargin().get(AbsCSSShorthand.EDGE.TOP), new Object[0])));
        map.put("margin-right", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getMargin().get(AbsCSSShorthand.EDGE.RIGHT), new Object[0])));
        map.put("margin-bottom", Double.valueOf(resolutionTranslator.nativeToWeb((double) component.getMargin().get(AbsCSSShorthand.EDGE.BOTTOM), new Object[0])));
        map.put("translateX", Double.valueOf(resolutionTranslator.nativeToWeb((double) sourceView.getTranslationX(), new Object[0])));
        map.put("translateY", Double.valueOf(resolutionTranslator.nativeToWeb((double) sourceView.getTranslationY(), new Object[0])));
        map.put("rotateX", Float.valueOf(Utils.normalizeRotation(sourceView.getRotationX())));
        map.put("rotateY", Float.valueOf(Utils.normalizeRotation(sourceView.getRotationY())));
        map.put(TransformParser.WX_ROTATE_Z, Float.valueOf(Utils.normalizeRotation(sourceView.getRotation())));
        map.put("scaleX", Float.valueOf(sourceView.getScaleX()));
        map.put("scaleY", Float.valueOf(sourceView.getScaleY()));
        map.put("opacity", Float.valueOf(sourceView.getAlpha()));
        Drawable drawable = sourceView.getBackground();
        double topLeft = 0.0d;
        double topRight = 0.0d;
        double bottomLeft = 0.0d;
        if (drawable != null && (drawable instanceof BorderDrawable)) {
            float[] result = ((BorderDrawable) drawable).getBorderRadius(new RectF(0.0f, 0.0f, (float) sourceView.getWidth(), (float) sourceView.getHeight()));
            if (result.length == 8) {
                topLeft = (double) result[0];
                topRight = (double) result[2];
                bottomLeft = (double) result[6];
                bottomRight = (double) result[4];
                map.put("border-top-left-radius", Double.valueOf(resolutionTranslator.nativeToWeb(topLeft, new Object[0])));
                map.put("border-top-right-radius", Double.valueOf(resolutionTranslator.nativeToWeb(topRight, new Object[0])));
                map.put("border-bottom-left-radius", Double.valueOf(resolutionTranslator.nativeToWeb(bottomLeft, new Object[0])));
                map.put("border-bottom-right-radius", Double.valueOf(resolutionTranslator.nativeToWeb(bottomRight, new Object[0])));
                if (sourceView.getBackground() == null) {
                    int backgroundColor = -16777216;
                    if (sourceView.getBackground() instanceof ColorDrawable) {
                        backgroundColor = ((ColorDrawable) sourceView.getBackground()).getColor();
                    } else if (sourceView.getBackground() instanceof BorderDrawable) {
                        backgroundColor = ((BorderDrawable) sourceView.getBackground()).getColor();
                    }
                    map.put("background-color", String.format(Locale.getDefault(), "rgba(%d,%d,%d,%f)", Integer.valueOf(Color.red(backgroundColor)), Integer.valueOf(Color.green(backgroundColor)), Integer.valueOf(Color.blue(backgroundColor)), Double.valueOf(((double) Color.alpha(backgroundColor)) / 255.0d)));
                }
                if (!(component instanceof WXText) && (sourceView instanceof WXTextView)) {
                    Layout layout = ((WXTextView) sourceView).getTextLayout();
                    if (layout != null) {
                        CharSequence sequence = layout.getText();
                        if (sequence != null && (sequence instanceof SpannableString)) {
                            ForegroundColorSpan[] spans = (ForegroundColorSpan[]) ((SpannableString) sequence).getSpans(0, sequence.length(), ForegroundColorSpan.class);
                            if (spans != null && spans.length == 1) {
                                int fontColor = spans[0].getForegroundColor();
                                map.put("color", String.format(Locale.getDefault(), "rgba(%d,%d,%d,%f)", Integer.valueOf(Color.red(fontColor)), Integer.valueOf(Color.green(fontColor)), Integer.valueOf(Color.blue(fontColor)), Double.valueOf(((double) Color.alpha(fontColor)) / 255.0d)));
                            }
                        }
                    }
                }
                return map;
            }
        }
        bottomRight = 0.0d;
        map.put("border-top-left-radius", Double.valueOf(resolutionTranslator.nativeToWeb(topLeft, new Object[0])));
        map.put("border-top-right-radius", Double.valueOf(resolutionTranslator.nativeToWeb(topRight, new Object[0])));
        map.put("border-bottom-left-radius", Double.valueOf(resolutionTranslator.nativeToWeb(bottomLeft, new Object[0])));
        map.put("border-bottom-right-radius", Double.valueOf(resolutionTranslator.nativeToWeb(bottomRight, new Object[0])));
        if (sourceView.getBackground() == null) {
        }
        if (!(component instanceof WXText)) {
        }
        return map;
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass4 */

            public void run() {
                if (WXBindingXModule.this.mBindingXCore != null) {
                    WXBindingXModule.this.mBindingXCore.doRelease();
                    WXBindingXModule.this.mBindingXCore = null;
                }
                WXViewUpdateService.clearCallbacks();
            }
        }, null);
    }

    static PlatformManager createPlatformManager(WXSDKInstance instance) {
        final int viewPort = instance == null ? 750 : instance.getInstanceViewPortWidth();
        return new PlatformManager.Builder().withViewFinder(new PlatformManager.IViewFinder() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass7 */

            @Override // com.alibaba.android.bindingx.core.PlatformManager.IViewFinder
            public View findViewBy(String ref, Object... extension) {
                if (extension.length <= 0 || !(extension[0] instanceof String)) {
                    return null;
                }
                return WXModuleUtils.findViewByRef((String) extension[0], ref);
            }
        }).withViewUpdater(new PlatformManager.IViewUpdater() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass6 */

            @Override // com.alibaba.android.bindingx.core.PlatformManager.IViewUpdater
            public void synchronouslyUpdateViewOnUIThread(View targetView, String propertyName, Object propertyValue, PlatformManager.IDeviceResolutionTranslator translator, Map<String, Object> config, Object... extension) {
                if (extension != null && extension.length >= 2 && (extension[0] instanceof String) && (extension[1] instanceof String)) {
                    String ref = (String) extension[0];
                    String instanceId = (String) extension[1];
                    WXComponent targetComponent = WXModuleUtils.findComponentByRef(instanceId, ref);
                    if (targetComponent == null) {
                        LogProxy.e("unexpected error. component not found [ref:" + ref + ",instanceId:" + instanceId + Operators.ARRAY_END_STR);
                        return;
                    }
                    WXViewUpdateService.findUpdater(propertyName).update(targetComponent, targetView, propertyValue, translator, config);
                }
            }
        }).withDeviceResolutionTranslator(new PlatformManager.IDeviceResolutionTranslator() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass5 */

            @Override // com.alibaba.android.bindingx.core.PlatformManager.IDeviceResolutionTranslator
            public double webToNative(double rawSize, Object... extension) {
                return (double) WXViewUtils.getRealPxByWidth((float) rawSize, viewPort);
            }

            @Override // com.alibaba.android.bindingx.core.PlatformManager.IDeviceResolutionTranslator
            public double nativeToWeb(double rawSize, Object... extension) {
                return (double) WXViewUtils.getWebPxByWidth((float) rawSize, viewPort);
            }
        }).build();
    }

    @Override // com.taobao.weex.common.WXModule
    public void onActivityPause() {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass8 */

            public void run() {
                if (WXBindingXModule.this.mBindingXCore != null) {
                    WXBindingXModule.this.mBindingXCore.onActivityPause();
                }
            }
        }, null);
    }

    @Override // com.taobao.weex.common.WXModule
    public void onActivityResume() {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.alibaba.android.bindingx.plugin.weex.WXBindingXModule.AnonymousClass9 */

            public void run() {
                if (WXBindingXModule.this.mBindingXCore != null) {
                    WXBindingXModule.this.mBindingXCore.onActivityResume();
                }
            }
        }, null);
    }
}
