package com.alibaba.fastjson;

import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexerBase;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.parser.deserializer.FieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.FieldSerializer;
import com.alibaba.fastjson.serializer.JavaBeanSerializer;
import com.alibaba.fastjson.serializer.ObjectSerializer;
import com.alibaba.fastjson.serializer.SerializeConfig;
import com.alibaba.fastjson.util.IOUtils;
import com.alibaba.fastjson.util.TypeUtils;
import com.alipay.sdk.m.n.a;
import com.igexin.push.core.b;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.reflect.Array;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Calendar;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.regex.Pattern;

public class JSONPath implements JSONAware {
    static final long LENGTH = -1580386065683472715L;
    static final long SIZE = 5614464919154503228L;
    private static ConcurrentMap<String, JSONPath> pathCache = new ConcurrentHashMap(128, 0.75f, 1);
    private boolean hasRefSegment;
    private boolean ignoreNullValue;
    private ParserConfig parserConfig;
    private final String path;
    private Segment[] segments;
    private SerializeConfig serializeConfig;

    /* access modifiers changed from: package-private */
    public interface Filter {
        boolean apply(JSONPath jSONPath, Object obj, Object obj2, Object obj3);
    }

    /* access modifiers changed from: package-private */
    public enum Operator {
        EQ,
        NE,
        GT,
        GE,
        LT,
        LE,
        LIKE,
        NOT_LIKE,
        RLIKE,
        NOT_RLIKE,
        IN,
        NOT_IN,
        BETWEEN,
        NOT_BETWEEN,
        And,
        Or,
        REG_MATCH
    }

    /* access modifiers changed from: package-private */
    public interface Segment {
        Object eval(JSONPath jSONPath, Object obj, Object obj2);

        void extract(JSONPath jSONPath, DefaultJSONParser defaultJSONParser, Context context);
    }

    public JSONPath(String path2) {
        this(path2, SerializeConfig.getGlobalInstance(), ParserConfig.getGlobalInstance(), true);
    }

    public JSONPath(String path2, boolean ignoreNullValue2) {
        this(path2, SerializeConfig.getGlobalInstance(), ParserConfig.getGlobalInstance(), ignoreNullValue2);
    }

    public JSONPath(String path2, SerializeConfig serializeConfig2, ParserConfig parserConfig2, boolean ignoreNullValue2) {
        if (path2 == null || path2.length() == 0) {
            throw new JSONPathException("json-path can not be null or empty");
        }
        this.path = path2;
        this.serializeConfig = serializeConfig2;
        this.parserConfig = parserConfig2;
        this.ignoreNullValue = ignoreNullValue2;
    }

    /* access modifiers changed from: protected */
    public void init() {
        if (this.segments == null) {
            if ("*".equals(this.path)) {
                this.segments = new Segment[]{WildCardSegment.instance};
                return;
            }
            JSONPathParser parser = new JSONPathParser(this.path);
            this.segments = parser.explain();
            this.hasRefSegment = parser.hasRefSegment;
        }
    }

    public boolean isRef() {
        try {
            init();
            for (int i = 0; i < this.segments.length; i++) {
                Class segmentType = this.segments[i].getClass();
                if (!(segmentType == ArrayAccessSegment.class || segmentType == PropertySegment.class)) {
                    return false;
                }
            }
            return true;
        } catch (JSONPathException e) {
            return false;
        }
    }

    public Object eval(Object rootObject) {
        if (rootObject == null) {
            return null;
        }
        init();
        Object currentObject = rootObject;
        int i = 0;
        while (true) {
            Segment[] segmentArr = this.segments;
            if (i >= segmentArr.length) {
                return currentObject;
            }
            currentObject = segmentArr[i].eval(this, rootObject, currentObject);
            i++;
        }
    }

    public <T> T eval(Object rootObject, Type clazz, ParserConfig parserConfig2) {
        return (T) TypeUtils.cast(eval(rootObject), clazz, parserConfig2);
    }

    public <T> T eval(Object rootObject, Type clazz) {
        return (T) eval(rootObject, clazz, ParserConfig.getGlobalInstance());
    }

    public Object extract(DefaultJSONParser parser) {
        boolean eval;
        if (parser == null) {
            return null;
        }
        init();
        if (this.hasRefSegment) {
            return eval(parser.parse());
        }
        Segment[] segmentArr = this.segments;
        if (segmentArr.length == 0) {
            return parser.parse();
        }
        Segment lastSegment = segmentArr[segmentArr.length - 1];
        if ((lastSegment instanceof TypeSegment) || (lastSegment instanceof FloorSegment) || (lastSegment instanceof MultiIndexSegment)) {
            return eval(parser.parse());
        }
        Context context = null;
        int i = 0;
        while (true) {
            Segment[] segmentArr2 = this.segments;
            if (i >= segmentArr2.length) {
                return context.object;
            }
            Segment segment = segmentArr2[i];
            boolean last = i == segmentArr2.length - 1;
            if (context == null || context.object == null) {
                if (!last) {
                    Segment nextSegment = this.segments[i + 1];
                    if ((segment instanceof PropertySegment) && ((PropertySegment) segment).deep && ((nextSegment instanceof ArrayAccessSegment) || (nextSegment instanceof MultiIndexSegment) || (nextSegment instanceof MultiPropertySegment) || (nextSegment instanceof SizeSegment) || (nextSegment instanceof PropertySegment) || (nextSegment instanceof FilterSegment))) {
                        eval = true;
                    } else if ((nextSegment instanceof ArrayAccessSegment) && ((ArrayAccessSegment) nextSegment).index < 0) {
                        eval = true;
                    } else if (nextSegment instanceof FilterSegment) {
                        eval = true;
                    } else if (segment instanceof WildCardSegment) {
                        eval = true;
                    } else if (segment instanceof MultiIndexSegment) {
                        eval = true;
                    } else {
                        eval = false;
                    }
                } else {
                    eval = true;
                }
                context = new Context(context, eval);
                segment.extract(this, parser, context);
            } else {
                context.object = segment.eval(this, null, context.object);
            }
            i++;
        }
    }

    /* access modifiers changed from: private */
    public static class Context {
        final boolean eval;
        Object object;
        final Context parent;

        public Context(Context parent2, boolean eval2) {
            this.parent = parent2;
            this.eval = eval2;
        }
    }

    public boolean contains(Object rootObject) {
        if (rootObject == null) {
            return false;
        }
        init();
        Object currentObject = rootObject;
        int i = 0;
        while (true) {
            Segment[] segmentArr = this.segments;
            if (i >= segmentArr.length) {
                return true;
            }
            currentObject = segmentArr[i].eval(this, rootObject, currentObject);
            if (currentObject == null) {
                return false;
            }
            if (currentObject == Collections.EMPTY_LIST && (currentObject instanceof List)) {
                return ((List) currentObject).contains(currentObject);
            }
            i++;
        }
    }

    public boolean containsValue(Object rootObject, Object value) {
        Object currentObject = eval(rootObject);
        if (currentObject == value) {
            return true;
        }
        if (currentObject == null) {
            return false;
        }
        if (!(currentObject instanceof Iterable)) {
            return eq(currentObject, value);
        }
        for (Object item : (Iterable) currentObject) {
            if (eq(item, value)) {
                return true;
            }
        }
        return false;
    }

    public int size(Object rootObject) {
        if (rootObject == null) {
            return -1;
        }
        init();
        Object currentObject = rootObject;
        int i = 0;
        while (true) {
            Segment[] segmentArr = this.segments;
            if (i >= segmentArr.length) {
                return evalSize(currentObject);
            }
            currentObject = segmentArr[i].eval(this, rootObject, currentObject);
            i++;
        }
    }

    public Set<?> keySet(Object rootObject) {
        if (rootObject == null) {
            return null;
        }
        init();
        Object currentObject = rootObject;
        int i = 0;
        while (true) {
            Segment[] segmentArr = this.segments;
            if (i >= segmentArr.length) {
                return evalKeySet(currentObject);
            }
            currentObject = segmentArr[i].eval(this, rootObject, currentObject);
            i++;
        }
    }

    public void patchAdd(Object rootObject, Object value, boolean replace) {
        Object newResult;
        if (rootObject != null) {
            init();
            Object currentObject = rootObject;
            Object parentObject = null;
            int i = 0;
            while (true) {
                Segment[] segmentArr = this.segments;
                if (i >= segmentArr.length) {
                    break;
                }
                parentObject = currentObject;
                Segment segment = segmentArr[i];
                currentObject = segment.eval(this, rootObject, currentObject);
                if (currentObject == null && i != this.segments.length - 1 && (segment instanceof PropertySegment)) {
                    currentObject = new JSONObject();
                    ((PropertySegment) segment).setValue(this, parentObject, currentObject);
                }
                i++;
            }
            if (replace || !(currentObject instanceof Collection)) {
                if (currentObject == null || replace) {
                    newResult = value;
                } else {
                    Class<?> resultClass = currentObject.getClass();
                    if (resultClass.isArray()) {
                        int length = Array.getLength(currentObject);
                        Object descArray = Array.newInstance(resultClass.getComponentType(), length + 1);
                        System.arraycopy(currentObject, 0, descArray, 0, length);
                        Array.set(descArray, length, value);
                        newResult = descArray;
                    } else if (Map.class.isAssignableFrom(resultClass)) {
                        newResult = value;
                    } else {
                        throw new JSONException("unsupported array put operation. " + resultClass);
                    }
                }
                Segment[] segmentArr2 = this.segments;
                Segment lastSegment = segmentArr2[segmentArr2.length - 1];
                if (lastSegment instanceof PropertySegment) {
                    ((PropertySegment) lastSegment).setValue(this, parentObject, newResult);
                } else if (lastSegment instanceof ArrayAccessSegment) {
                    ((ArrayAccessSegment) lastSegment).setValue(this, parentObject, newResult);
                } else {
                    throw new UnsupportedOperationException();
                }
            } else {
                ((Collection) currentObject).add(value);
            }
        }
    }

    public void arrayAdd(Object rootObject, Object... values) {
        if (values != null && values.length != 0 && rootObject != null) {
            init();
            Object currentObject = rootObject;
            Object parentObject = null;
            int i = 0;
            while (true) {
                Segment[] segmentArr = this.segments;
                if (i >= segmentArr.length) {
                    break;
                }
                if (i == segmentArr.length - 1) {
                    parentObject = currentObject;
                }
                currentObject = this.segments[i].eval(this, rootObject, currentObject);
                i++;
            }
            if (currentObject != null) {
                if (currentObject instanceof Collection) {
                    Collection collection = (Collection) currentObject;
                    for (Object value : values) {
                        collection.add(value);
                    }
                    return;
                }
                Class<?> resultClass = currentObject.getClass();
                if (resultClass.isArray()) {
                    int length = Array.getLength(currentObject);
                    Object descArray = Array.newInstance(resultClass.getComponentType(), values.length + length);
                    System.arraycopy(currentObject, 0, descArray, 0, length);
                    for (int i2 = 0; i2 < values.length; i2++) {
                        Array.set(descArray, length + i2, values[i2]);
                    }
                    Segment[] segmentArr2 = this.segments;
                    Segment lastSegment = segmentArr2[segmentArr2.length - 1];
                    if (lastSegment instanceof PropertySegment) {
                        ((PropertySegment) lastSegment).setValue(this, parentObject, descArray);
                    } else if (lastSegment instanceof ArrayAccessSegment) {
                        ((ArrayAccessSegment) lastSegment).setValue(this, parentObject, descArray);
                    } else {
                        throw new UnsupportedOperationException();
                    }
                } else {
                    throw new JSONException("unsupported array put operation. " + resultClass);
                }
            } else {
                throw new JSONPathException("value not found in path " + this.path);
            }
        }
    }

    public boolean remove(Object rootObject) {
        if (rootObject == null) {
            return false;
        }
        init();
        Object currentObject = rootObject;
        Object parentObject = null;
        Segment[] segmentArr = this.segments;
        Segment lastSegment = segmentArr[segmentArr.length - 1];
        int i = 0;
        while (true) {
            Segment[] segmentArr2 = this.segments;
            if (i >= segmentArr2.length) {
                break;
            } else if (i == segmentArr2.length - 1) {
                parentObject = currentObject;
                break;
            } else {
                Segment segement = segmentArr2[i];
                if (i == segmentArr2.length - 2 && (lastSegment instanceof FilterSegment) && (segement instanceof PropertySegment)) {
                    FilterSegment filterSegment = (FilterSegment) lastSegment;
                    if (currentObject instanceof List) {
                        PropertySegment propertySegment = (PropertySegment) segement;
                        Iterator it = ((List) currentObject).iterator();
                        while (it.hasNext()) {
                            Object result = propertySegment.eval(this, rootObject, it.next());
                            if (result instanceof Iterable) {
                                filterSegment.remove(this, rootObject, result);
                            } else if ((result instanceof Map) && filterSegment.filter.apply(this, rootObject, currentObject, result)) {
                                it.remove();
                            }
                        }
                        return true;
                    } else if (currentObject instanceof Map) {
                        PropertySegment propertySegment2 = (PropertySegment) segement;
                        Object result2 = propertySegment2.eval(this, rootObject, currentObject);
                        if (result2 == null) {
                            return false;
                        }
                        if ((result2 instanceof Map) && filterSegment.filter.apply(this, rootObject, currentObject, result2)) {
                            propertySegment2.remove(this, currentObject);
                            return true;
                        }
                    }
                }
                currentObject = segement.eval(this, rootObject, currentObject);
                if (currentObject == null) {
                    break;
                }
                i++;
            }
        }
        if (parentObject == null) {
            return false;
        }
        if (lastSegment instanceof PropertySegment) {
            PropertySegment propertySegment3 = (PropertySegment) lastSegment;
            if (parentObject instanceof Collection) {
                Segment[] segmentArr3 = this.segments;
                if (segmentArr3.length > 1) {
                    Segment parentSegment = segmentArr3[segmentArr3.length - 2];
                    if ((parentSegment instanceof RangeSegment) || (parentSegment instanceof MultiIndexSegment)) {
                        boolean removedOnce = false;
                        for (Object item : (Collection) parentObject) {
                            if (propertySegment3.remove(this, item)) {
                                removedOnce = true;
                            }
                        }
                        return removedOnce;
                    }
                }
            }
            return propertySegment3.remove(this, parentObject);
        } else if (lastSegment instanceof ArrayAccessSegment) {
            return ((ArrayAccessSegment) lastSegment).remove(this, parentObject);
        } else {
            if (lastSegment instanceof FilterSegment) {
                return ((FilterSegment) lastSegment).remove(this, rootObject, parentObject);
            }
            throw new UnsupportedOperationException();
        }
    }

    public boolean set(Object rootObject, Object value) {
        return set(rootObject, value, true);
    }

    public boolean set(Object rootObject, Object value, boolean p) {
        if (rootObject == null) {
            return false;
        }
        init();
        Object currentObject = rootObject;
        Object parentObject = null;
        int i = 0;
        while (true) {
            Segment[] segmentArr = this.segments;
            if (i >= segmentArr.length) {
                break;
            }
            parentObject = currentObject;
            Segment segment = segmentArr[i];
            currentObject = segment.eval(this, rootObject, currentObject);
            if (currentObject == null) {
                Segment nextSegment = null;
                Segment[] segmentArr2 = this.segments;
                if (i < segmentArr2.length - 1) {
                    nextSegment = segmentArr2[i + 1];
                }
                Object newObj = null;
                if (nextSegment instanceof PropertySegment) {
                    JavaBeanDeserializer beanDeserializer = null;
                    Class<?> fieldClass = null;
                    if (segment instanceof PropertySegment) {
                        String propertyName = ((PropertySegment) segment).propertyName;
                        JavaBeanDeserializer parentBeanDeserializer = getJavaBeanDeserializer(parentObject.getClass());
                        if (parentBeanDeserializer != null) {
                            fieldClass = parentBeanDeserializer.getFieldDeserializer(propertyName).fieldInfo.fieldClass;
                            beanDeserializer = getJavaBeanDeserializer(fieldClass);
                        }
                    }
                    if (beanDeserializer == null) {
                        newObj = new JSONObject();
                    } else if (beanDeserializer.beanInfo.defaultConstructor == null) {
                        return false;
                    } else {
                        newObj = beanDeserializer.createInstance((DefaultJSONParser) null, fieldClass);
                    }
                } else if (nextSegment instanceof ArrayAccessSegment) {
                    newObj = new JSONArray();
                }
                if (newObj != null) {
                    if (!(segment instanceof PropertySegment)) {
                        if (!(segment instanceof ArrayAccessSegment)) {
                            break;
                        }
                        ((ArrayAccessSegment) segment).setValue(this, parentObject, newObj);
                        currentObject = newObj;
                    } else {
                        ((PropertySegment) segment).setValue(this, parentObject, newObj);
                        currentObject = newObj;
                    }
                } else {
                    break;
                }
            }
            i++;
        }
        if (parentObject == null) {
            return false;
        }
        Segment[] segmentArr3 = this.segments;
        Segment lastSegment = segmentArr3[segmentArr3.length - 1];
        if (lastSegment instanceof PropertySegment) {
            ((PropertySegment) lastSegment).setValue(this, parentObject, value);
            return true;
        } else if (lastSegment instanceof ArrayAccessSegment) {
            return ((ArrayAccessSegment) lastSegment).setValue(this, parentObject, value);
        } else {
            throw new UnsupportedOperationException();
        }
    }

    public static Object eval(Object rootObject, String path2) {
        return compile(path2).eval(rootObject);
    }

    public static Object eval(Object rootObject, String path2, boolean ignoreNullValue2) {
        return compile(path2, ignoreNullValue2).eval(rootObject);
    }

    public static int size(Object rootObject, String path2) {
        JSONPath jsonpath = compile(path2);
        return jsonpath.evalSize(jsonpath.eval(rootObject));
    }

    public static Set<?> keySet(Object rootObject, String path2) {
        JSONPath jsonpath = compile(path2);
        return jsonpath.evalKeySet(jsonpath.eval(rootObject));
    }

    public static boolean contains(Object rootObject, String path2) {
        if (rootObject == null) {
            return false;
        }
        return compile(path2).contains(rootObject);
    }

    public static boolean containsValue(Object rootObject, String path2, Object value) {
        return compile(path2).containsValue(rootObject, value);
    }

    public static void arrayAdd(Object rootObject, String path2, Object... values) {
        compile(path2).arrayAdd(rootObject, values);
    }

    public static boolean set(Object rootObject, String path2, Object value) {
        return compile(path2).set(rootObject, value);
    }

    public static boolean remove(Object root, String path2) {
        return compile(path2).remove(root);
    }

    public static JSONPath compile(String path2) {
        if (path2 != null) {
            JSONPath jsonpath = pathCache.get(path2);
            if (jsonpath != null) {
                return jsonpath;
            }
            JSONPath jsonpath2 = new JSONPath(path2);
            if (pathCache.size() >= 1024) {
                return jsonpath2;
            }
            pathCache.putIfAbsent(path2, jsonpath2);
            return pathCache.get(path2);
        }
        throw new JSONPathException("jsonpath can not be null");
    }

    public static JSONPath compile(String path2, boolean ignoreNullValue2) {
        if (path2 != null) {
            JSONPath jsonpath = pathCache.get(path2);
            if (jsonpath != null) {
                return jsonpath;
            }
            JSONPath jsonpath2 = new JSONPath(path2, ignoreNullValue2);
            if (pathCache.size() >= 1024) {
                return jsonpath2;
            }
            pathCache.putIfAbsent(path2, jsonpath2);
            return pathCache.get(path2);
        }
        throw new JSONPathException("jsonpath can not be null");
    }

    public static Object read(String json, String path2) {
        return compile(path2).eval(JSON.parse(json));
    }

    public static <T> T read(String json, String path2, Type clazz, ParserConfig parserConfig2) {
        return (T) compile(path2).eval(JSON.parse(json), clazz, parserConfig2);
    }

    public static <T> T read(String json, String path2, Type clazz) {
        return (T) read(json, path2, clazz, null);
    }

    public static Object extract(String json, String path2, ParserConfig config, int features, Feature... optionFeatures) {
        DefaultJSONParser parser = new DefaultJSONParser(json, config, features | Feature.OrderedField.mask);
        Object result = compile(path2).extract(parser);
        parser.lexer.close();
        return result;
    }

    public static Object extract(String json, String path2) {
        return extract(json, path2, ParserConfig.global, JSON.DEFAULT_PARSER_FEATURE, new Feature[0]);
    }

    public static Map<String, Object> paths(Object javaObject) {
        return paths(javaObject, SerializeConfig.globalInstance);
    }

    public static Map<String, Object> paths(Object javaObject, SerializeConfig config) {
        Map<Object, String> values = new IdentityHashMap<>();
        Map<String, Object> paths = new HashMap<>();
        paths(values, paths, "/", javaObject, config);
        return paths;
    }

    private static void paths(Map<Object, String> values, Map<String, Object> paths, String parent, Object javaObject, SerializeConfig config) {
        StringBuilder sb;
        StringBuilder sb2;
        StringBuilder sb3;
        StringBuilder sb4;
        if (javaObject != null) {
            if (values.put(javaObject, parent) != null) {
                Class<?> type = javaObject.getClass();
                if (!(type == String.class || type == Boolean.class || type == Character.class || type == UUID.class || type.isEnum() || (javaObject instanceof Number) || (javaObject instanceof Date))) {
                    return;
                }
            }
            paths.put(parent, javaObject);
            if (javaObject instanceof Map) {
                for (Map.Entry entry : ((Map) javaObject).entrySet()) {
                    Object key = entry.getKey();
                    if (key instanceof String) {
                        if (parent.equals("/")) {
                            sb4 = new StringBuilder();
                        } else {
                            sb4 = new StringBuilder();
                            sb4.append(parent);
                        }
                        sb4.append("/");
                        sb4.append(key);
                        paths(values, paths, sb4.toString(), entry.getValue(), config);
                    }
                }
            } else if (javaObject instanceof Collection) {
                int i = 0;
                for (Object item : (Collection) javaObject) {
                    if (parent.equals("/")) {
                        sb3 = new StringBuilder();
                    } else {
                        sb3 = new StringBuilder();
                        sb3.append(parent);
                    }
                    sb3.append("/");
                    sb3.append(i);
                    paths(values, paths, sb3.toString(), item, config);
                    i++;
                }
            } else {
                Class<?> clazz = javaObject.getClass();
                if (clazz.isArray()) {
                    int len = Array.getLength(javaObject);
                    for (int i2 = 0; i2 < len; i2++) {
                        Object item2 = Array.get(javaObject, i2);
                        if (parent.equals("/")) {
                            sb2 = new StringBuilder();
                        } else {
                            sb2 = new StringBuilder();
                            sb2.append(parent);
                        }
                        sb2.append("/");
                        sb2.append(i2);
                        paths(values, paths, sb2.toString(), item2, config);
                    }
                } else if (!ParserConfig.isPrimitive2(clazz) && !clazz.isEnum()) {
                    ObjectSerializer serializer = config.getObjectWriter(clazz);
                    if (serializer instanceof JavaBeanSerializer) {
                        try {
                            for (Map.Entry<String, Object> entry2 : ((JavaBeanSerializer) serializer).getFieldValuesMap(javaObject).entrySet()) {
                                String key2 = entry2.getKey();
                                if (key2 instanceof String) {
                                    if (parent.equals("/")) {
                                        sb = new StringBuilder();
                                        sb.append("/");
                                        sb.append(key2);
                                    } else {
                                        sb = new StringBuilder();
                                        sb.append(parent);
                                        sb.append("/");
                                        sb.append(key2);
                                    }
                                    paths(values, paths, sb.toString(), entry2.getValue(), config);
                                }
                            }
                        } catch (Exception e) {
                            throw new JSONException("toJSON error", e);
                        }
                    }
                }
            }
        }
    }

    public String getPath() {
        return this.path;
    }

    /* access modifiers changed from: package-private */
    public static class JSONPathParser {
        private static final Pattern strArrayPatternx = Pattern.compile(strArrayRegex);
        private static final String strArrayRegex = "'\\s*,\\s*'";
        private char ch;
        private boolean hasRefSegment;
        private int level;
        private final String path;
        private int pos;

        public JSONPathParser(String path2) {
            this.path = path2;
            next();
        }

        /* access modifiers changed from: package-private */
        public void next() {
            String str = this.path;
            int i = this.pos;
            this.pos = i + 1;
            this.ch = str.charAt(i);
        }

        /* access modifiers changed from: package-private */
        public char getNextChar() {
            return this.path.charAt(this.pos);
        }

        /* access modifiers changed from: package-private */
        public boolean isEOF() {
            return this.pos >= this.path.length();
        }

        /* access modifiers changed from: package-private */
        public Segment readSegement() {
            char c;
            boolean objectOnly = true;
            if (this.level == 0 && this.path.length() == 1) {
                if (isDigitFirst(this.ch)) {
                    return new ArrayAccessSegment(this.ch - '0');
                }
                int index = this.ch;
                if ((index >= 97 && index <= 122) || ((c = this.ch) >= 'A' && c <= 'Z')) {
                    return new PropertySegment(Character.toString(this.ch), false);
                }
            }
            while (!isEOF()) {
                skipWhitespace();
                char c2 = this.ch;
                if (c2 == '$') {
                    next();
                    skipWhitespace();
                    if (this.ch == '?') {
                        return new FilterSegment((Filter) parseArrayAccessFilter(false));
                    }
                } else if (c2 == '.' || c2 == '/') {
                    int c0 = this.ch;
                    boolean deep = false;
                    next();
                    if (c0 == 46 && this.ch == '.') {
                        next();
                        deep = true;
                        int length = this.path.length();
                        int i = this.pos;
                        if (length > i + 3 && this.ch == '[' && this.path.charAt(i) == '*' && this.path.charAt(this.pos + 1) == ']' && this.path.charAt(this.pos + 2) == '.') {
                            next();
                            next();
                            next();
                            next();
                        }
                    }
                    char c3 = this.ch;
                    if (c3 == '*' || (deep && c3 == '[')) {
                        if (this.ch != '[') {
                            objectOnly = false;
                        }
                        if (!isEOF()) {
                            next();
                        }
                        if (!deep) {
                            return WildCardSegment.instance;
                        }
                        if (objectOnly) {
                            return WildCardSegment.instance_deep_objectOnly;
                        }
                        return WildCardSegment.instance_deep;
                    } else if (isDigitFirst(this.ch)) {
                        return parseArrayAccess(false);
                    } else {
                        String propertyName = readName();
                        if (this.ch != '(') {
                            return new PropertySegment(propertyName, deep);
                        }
                        next();
                        if (this.ch == ')') {
                            if (!isEOF()) {
                                next();
                            }
                            if (AbsoluteConst.JSON_KEY_SIZE.equals(propertyName) || "length".equals(propertyName)) {
                                return SizeSegment.instance;
                            }
                            if ("max".equals(propertyName)) {
                                return MaxSegment.instance;
                            }
                            if (Constants.Name.MIN.equals(propertyName)) {
                                return MinSegment.instance;
                            }
                            if ("keySet".equals(propertyName)) {
                                return KeySetSegment.instance;
                            }
                            if ("type".equals(propertyName)) {
                                return TypeSegment.instance;
                            }
                            if ("floor".equals(propertyName)) {
                                return FloorSegment.instance;
                            }
                            throw new JSONPathException("not support jsonpath : " + this.path);
                        }
                        throw new JSONPathException("not support jsonpath : " + this.path);
                    }
                } else if (c2 == '[') {
                    return parseArrayAccess(true);
                } else {
                    if (this.level == 0) {
                        return new PropertySegment(readName(), false);
                    }
                    if (c2 == '?') {
                        return new FilterSegment((Filter) parseArrayAccessFilter(false));
                    }
                    throw new JSONPathException("not support jsonpath : " + this.path);
                }
            }
            return null;
        }

        public final void skipWhitespace() {
            while (true) {
                char c = this.ch;
                if (c > ' ') {
                    return;
                }
                if (c == ' ' || c == '\r' || c == '\n' || c == '\t' || c == '\f' || c == '\b') {
                    next();
                } else {
                    return;
                }
            }
        }

        /* access modifiers changed from: package-private */
        public Segment parseArrayAccess(boolean acceptBracket) {
            Object object = parseArrayAccessFilter(acceptBracket);
            if (object instanceof Segment) {
                return (Segment) object;
            }
            return new FilterSegment((Filter) object);
        }

        /* JADX INFO: Multiple debug info for r6v13 char: [D('filter' com.alibaba.fastjson.JSONPath$RefOpSegement), D('value' long)] */
        /* access modifiers changed from: package-private */
        /* JADX WARNING: Removed duplicated region for block: B:35:0x007c  */
        /* JADX WARNING: Removed duplicated region for block: B:36:0x0080  */
        public Object parseArrayAccessFilter(boolean acceptBracket) {
            char c;
            char c2;
            char c3;
            char c4;
            char c5;
            Filter filter;
            char c6;
            Filter filter2;
            char c7;
            String[] containsValues;
            Operator op;
            char c8;
            char c9;
            char c10;
            Filter filter3;
            char c11;
            boolean z;
            char c12;
            char c13;
            char c14;
            int end;
            String propName;
            char c22;
            if (acceptBracket) {
                accept(Operators.ARRAY_START);
            }
            boolean predicateFlag = false;
            int lparanCount = 0;
            if (this.ch == '?') {
                next();
                accept(Operators.BRACKET_START);
                while (true) {
                    lparanCount++;
                    if (this.ch != '(') {
                        break;
                    }
                    next();
                }
                predicateFlag = true;
            }
            skipWhitespace();
            if (predicateFlag || IOUtils.firstIdentifier(this.ch) || Character.isJavaIdentifierStart(this.ch) || (c14 = this.ch) == '\\' || c14 == '@') {
                if (this.ch == '@') {
                    next();
                    accept(Operators.DOT);
                }
                String propertyName = readName();
                skipWhitespace();
                if (predicateFlag && this.ch == ')') {
                    next();
                    Filter filter4 = new NotNullSegement(propertyName, false);
                    while (true) {
                        c13 = this.ch;
                        if (c13 != ' ') {
                            break;
                        }
                        next();
                    }
                    if (c13 == '&' || c13 == '|') {
                        filter4 = filterRest(filter4);
                    }
                    if (acceptBracket) {
                        accept(Operators.ARRAY_END);
                    }
                    return filter4;
                } else if (!acceptBracket || this.ch != ']') {
                    boolean function = false;
                    skipWhitespace();
                    if (this.ch == '(') {
                        next();
                        accept(Operators.BRACKET_END);
                        skipWhitespace();
                        function = true;
                    }
                    Operator op2 = readOp();
                    skipWhitespace();
                    if (op2 != Operator.BETWEEN) {
                        if (op2 != Operator.NOT_BETWEEN) {
                            if (op2 == Operator.IN || op2 == Operator.NOT_IN) {
                                boolean not = op2 == Operator.NOT_IN;
                                accept(Operators.BRACKET_START);
                                List<Object> valueList = new JSONArray();
                                valueList.add(readValue());
                                while (true) {
                                    skipWhitespace();
                                    if (this.ch != ',') {
                                        break;
                                    }
                                    next();
                                    valueList.add(readValue());
                                    lparanCount = lparanCount;
                                }
                                boolean isInt = true;
                                boolean isIntObj = true;
                                boolean isString = true;
                                for (Object item : valueList) {
                                    if (item != null) {
                                        Class<?> clazz = item.getClass();
                                        if (!(!isInt || clazz == Byte.class || clazz == Short.class || clazz == Integer.class || clazz == Long.class)) {
                                            isInt = false;
                                            isIntObj = false;
                                        }
                                        if (isString && clazz != String.class) {
                                            isString = false;
                                        }
                                    } else if (isInt) {
                                        isInt = false;
                                    }
                                }
                                if (valueList.size() == 1 && valueList.get(0) == null) {
                                    if (not) {
                                        filter = new NotNullSegement(propertyName, function);
                                    } else {
                                        filter = new NullSegement(propertyName, function);
                                    }
                                    while (true) {
                                        c6 = this.ch;
                                        if (c6 != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (c6 == '&' || c6 == '|') {
                                        filter = filterRest(filter);
                                    }
                                    accept(Operators.BRACKET_END);
                                    if (predicateFlag) {
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter;
                                } else if (isInt) {
                                    if (valueList.size() == 1) {
                                        Filter filter5 = new IntOpSegement(propertyName, function, TypeUtils.longExtractValue((Number) valueList.get(0)), not ? Operator.NE : Operator.EQ);
                                        while (true) {
                                            c5 = this.ch;
                                            if (c5 != ' ') {
                                                break;
                                            }
                                            next();
                                            lparanCount = lparanCount;
                                        }
                                        if (c5 == '&' || c5 == '|') {
                                            filter5 = filterRest(filter5);
                                        }
                                        accept(Operators.BRACKET_END);
                                        if (predicateFlag) {
                                            accept(Operators.BRACKET_END);
                                        }
                                        if (acceptBracket) {
                                            accept(Operators.ARRAY_END);
                                        }
                                        return filter5;
                                    }
                                    long[] values = new long[valueList.size()];
                                    for (int i = 0; i < values.length; i++) {
                                        values[i] = TypeUtils.longExtractValue((Number) valueList.get(i));
                                    }
                                    Filter filter6 = new IntInSegement(propertyName, function, values, not);
                                    while (true) {
                                        c4 = this.ch;
                                        if (c4 != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (c4 == '&' || c4 == '|') {
                                        filter6 = filterRest(filter6);
                                    }
                                    accept(Operators.BRACKET_END);
                                    if (predicateFlag) {
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter6;
                                } else if (isString) {
                                    if (valueList.size() == 1) {
                                        Filter filter7 = new StringOpSegement(propertyName, function, (String) valueList.get(0), not ? Operator.NE : Operator.EQ);
                                        while (true) {
                                            c3 = this.ch;
                                            if (c3 != ' ') {
                                                break;
                                            }
                                            next();
                                        }
                                        if (c3 == '&' || c3 == '|') {
                                            filter7 = filterRest(filter7);
                                        }
                                        accept(Operators.BRACKET_END);
                                        if (predicateFlag) {
                                            accept(Operators.BRACKET_END);
                                        }
                                        if (acceptBracket) {
                                            accept(Operators.ARRAY_END);
                                        }
                                        return filter7;
                                    }
                                    String[] values2 = new String[valueList.size()];
                                    valueList.toArray(values2);
                                    Filter filter8 = new StringInSegement(propertyName, function, values2, not);
                                    while (true) {
                                        c2 = this.ch;
                                        if (c2 != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (c2 == '&' || c2 == '|') {
                                        filter8 = filterRest(filter8);
                                    }
                                    accept(Operators.BRACKET_END);
                                    if (predicateFlag) {
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter8;
                                } else if (isIntObj) {
                                    Long[] values3 = new Long[valueList.size()];
                                    for (int i2 = 0; i2 < values3.length; i2++) {
                                        Number item2 = (Number) valueList.get(i2);
                                        if (item2 != null) {
                                            values3[i2] = Long.valueOf(TypeUtils.longExtractValue(item2));
                                        }
                                    }
                                    Filter filter9 = new IntObjInSegement(propertyName, function, values3, not);
                                    while (true) {
                                        c = this.ch;
                                        if (c != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (c == '&' || c == '|') {
                                        filter9 = filterRest(filter9);
                                    }
                                    accept(Operators.BRACKET_END);
                                    if (predicateFlag) {
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter9;
                                } else {
                                    throw new UnsupportedOperationException();
                                }
                            } else {
                                char c15 = this.ch;
                                if (c15 == '\'' || c15 == '\"') {
                                    String strValue = readString();
                                    if (op2 == Operator.RLIKE) {
                                        filter2 = new RlikeSegement(propertyName, function, strValue, false);
                                    } else if (op2 == Operator.NOT_RLIKE) {
                                        filter2 = new RlikeSegement(propertyName, function, strValue, true);
                                    } else if (op2 == Operator.LIKE || op2 == Operator.NOT_LIKE) {
                                        while (strValue.indexOf("%%") != -1) {
                                            strValue = strValue.replaceAll("%%", "%");
                                        }
                                        boolean not2 = op2 == Operator.NOT_LIKE;
                                        int p0 = strValue.indexOf(37);
                                        if (p0 == -1) {
                                            if (op2 == Operator.LIKE) {
                                                op = Operator.EQ;
                                            } else {
                                                op = Operator.NE;
                                            }
                                            filter2 = new StringOpSegement(propertyName, function, strValue, op);
                                        } else {
                                            String[] items = strValue.split("%");
                                            String startsWithValue = null;
                                            String endsWithValue = null;
                                            if (p0 == 0) {
                                                if (strValue.charAt(strValue.length() - 1) == '%') {
                                                    containsValues = new String[(items.length - 1)];
                                                    System.arraycopy(items, 1, containsValues, 0, containsValues.length);
                                                } else {
                                                    endsWithValue = items[items.length - 1];
                                                    if (items.length > 2) {
                                                        containsValues = new String[(items.length - 2)];
                                                        System.arraycopy(items, 1, containsValues, 0, containsValues.length);
                                                    } else {
                                                        containsValues = null;
                                                    }
                                                }
                                            } else if (strValue.charAt(strValue.length() - 1) == '%') {
                                                if (items.length == 1) {
                                                    startsWithValue = items[0];
                                                    containsValues = null;
                                                } else {
                                                    containsValues = items;
                                                }
                                            } else if (items.length == 1) {
                                                startsWithValue = items[0];
                                                containsValues = null;
                                            } else if (items.length == 2) {
                                                startsWithValue = items[0];
                                                endsWithValue = items[1];
                                                containsValues = null;
                                            } else {
                                                startsWithValue = items[0];
                                                endsWithValue = items[items.length - 1];
                                                String[] containsValues2 = new String[(items.length - 2)];
                                                System.arraycopy(items, 1, containsValues2, 0, containsValues2.length);
                                                containsValues = containsValues2;
                                            }
                                            filter2 = new MatchSegement(propertyName, function, startsWithValue, endsWithValue, containsValues, not2);
                                        }
                                    } else {
                                        filter2 = new StringOpSegement(propertyName, function, strValue, op2);
                                    }
                                    while (true) {
                                        c7 = this.ch;
                                        if (c7 != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (c7 == '&' || c7 == '|') {
                                        filter2 = filterRest(filter2);
                                    }
                                    if (predicateFlag) {
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter2;
                                } else if (isDigitFirst(c15)) {
                                    long value = readLongValue();
                                    double doubleValue = 0.0d;
                                    if (this.ch == '.') {
                                        doubleValue = readDoubleValue(value);
                                    }
                                    if (doubleValue == 0.0d) {
                                        filter3 = new IntOpSegement(propertyName, function, value, op2);
                                    } else {
                                        filter3 = new DoubleOpSegement(propertyName, function, doubleValue, op2);
                                    }
                                    while (true) {
                                        c11 = this.ch;
                                        if (c11 != ' ') {
                                            break;
                                        }
                                        next();
                                    }
                                    if (lparanCount > 1 && c11 == ')') {
                                        next();
                                        lparanCount--;
                                    }
                                    char c16 = this.ch;
                                    if (c16 == '&' || c16 == '|') {
                                        filter3 = filterRest(filter3);
                                    }
                                    if (predicateFlag) {
                                        int lparanCount2 = lparanCount - 1;
                                        accept(Operators.BRACKET_END);
                                    }
                                    if (acceptBracket) {
                                        accept(Operators.ARRAY_END);
                                    }
                                    return filter3;
                                } else {
                                    char c17 = this.ch;
                                    if (c17 == '$') {
                                        RefOpSegement filter10 = new RefOpSegement(propertyName, function, readSegement(), op2);
                                        this.hasRefSegment = true;
                                        while (this.ch == ' ') {
                                            next();
                                        }
                                        if (predicateFlag) {
                                            accept(Operators.BRACKET_END);
                                        }
                                        if (acceptBracket) {
                                            accept(Operators.ARRAY_END);
                                        }
                                        return filter10;
                                    } else if (c17 == '/') {
                                        int flags = 0;
                                        StringBuilder regBuf = new StringBuilder();
                                        while (true) {
                                            next();
                                            char c18 = this.ch;
                                            if (c18 == '/') {
                                                break;
                                            } else if (c18 == '\\') {
                                                next();
                                                regBuf.append(this.ch);
                                            } else {
                                                regBuf.append(c18);
                                            }
                                        }
                                        next();
                                        if (this.ch == 'i') {
                                            next();
                                            flags = 0 | 2;
                                        }
                                        RegMatchSegement filter11 = new RegMatchSegement(propertyName, function, Pattern.compile(regBuf.toString(), flags), op2);
                                        if (predicateFlag) {
                                            accept(Operators.BRACKET_END);
                                        }
                                        if (acceptBracket) {
                                            accept(Operators.ARRAY_END);
                                        }
                                        return filter11;
                                    } else {
                                        if (c17 == 'n') {
                                            if (b.m.equals(readName())) {
                                                Filter filter12 = null;
                                                if (op2 == Operator.EQ) {
                                                    filter12 = new NullSegement(propertyName, function);
                                                } else if (op2 == Operator.NE) {
                                                    filter12 = new NotNullSegement(propertyName, function);
                                                }
                                                if (filter12 != null) {
                                                    while (true) {
                                                        c10 = this.ch;
                                                        if (c10 != ' ') {
                                                            break;
                                                        }
                                                        next();
                                                    }
                                                    if (c10 == '&' || c10 == '|') {
                                                        filter12 = filterRest(filter12);
                                                    }
                                                }
                                                if (predicateFlag) {
                                                    accept(Operators.BRACKET_END);
                                                }
                                                accept(Operators.ARRAY_END);
                                                if (filter12 != null) {
                                                    return filter12;
                                                }
                                                throw new UnsupportedOperationException();
                                            }
                                        } else if (c17 == 't') {
                                            if (AbsoluteConst.TRUE.equals(readName())) {
                                                Filter filter13 = null;
                                                if (op2 == Operator.EQ) {
                                                    filter13 = new ValueSegment(propertyName, function, Boolean.TRUE, true);
                                                } else if (op2 == Operator.NE) {
                                                    filter13 = new ValueSegment(propertyName, function, Boolean.TRUE, false);
                                                }
                                                if (filter13 != null) {
                                                    while (true) {
                                                        c9 = this.ch;
                                                        if (c9 != ' ') {
                                                            break;
                                                        }
                                                        next();
                                                    }
                                                    if (c9 == '&' || c9 == '|') {
                                                        filter13 = filterRest(filter13);
                                                    }
                                                }
                                                if (predicateFlag) {
                                                    accept(Operators.BRACKET_END);
                                                }
                                                accept(Operators.ARRAY_END);
                                                if (filter13 != null) {
                                                    return filter13;
                                                }
                                                throw new UnsupportedOperationException();
                                            }
                                        } else if (c17 == 'f' && AbsoluteConst.FALSE.equals(readName())) {
                                            Filter filter14 = null;
                                            if (op2 == Operator.EQ) {
                                                filter14 = new ValueSegment(propertyName, function, Boolean.FALSE, true);
                                            } else if (op2 == Operator.NE) {
                                                filter14 = new ValueSegment(propertyName, function, Boolean.FALSE, false);
                                            }
                                            if (filter14 != null) {
                                                while (true) {
                                                    c8 = this.ch;
                                                    if (c8 != ' ') {
                                                        break;
                                                    }
                                                    next();
                                                }
                                                if (c8 == '&' || c8 == '|') {
                                                    filter14 = filterRest(filter14);
                                                }
                                            }
                                            if (predicateFlag) {
                                                accept(Operators.BRACKET_END);
                                            }
                                            accept(Operators.ARRAY_END);
                                            if (filter14 != null) {
                                                return filter14;
                                            }
                                            throw new UnsupportedOperationException();
                                        }
                                        throw new UnsupportedOperationException();
                                    }
                                }
                            }
                        }
                    }
                    boolean not3 = op2 == Operator.NOT_BETWEEN;
                    Object startValue = readValue();
                    if ("and".equalsIgnoreCase(readName())) {
                        Object endValue = readValue();
                        if (startValue == null || endValue == null) {
                            throw new JSONPathException(this.path);
                        } else if (JSONPath.isInt(startValue.getClass()) && JSONPath.isInt(endValue.getClass())) {
                            return new IntBetweenSegement(propertyName, function, TypeUtils.longExtractValue((Number) startValue), TypeUtils.longExtractValue((Number) endValue), not3);
                        } else {
                            throw new JSONPathException(this.path);
                        }
                    } else {
                        throw new JSONPathException(this.path);
                    }
                } else {
                    if (!isEOF()) {
                        z = false;
                    } else if (propertyName.equals("last")) {
                        return new MultiIndexSegment(new int[]{-1});
                    } else {
                        z = false;
                    }
                    next();
                    Filter filter15 = new NotNullSegement(propertyName, z);
                    while (true) {
                        c12 = this.ch;
                        if (c12 != ' ') {
                            break;
                        }
                        next();
                    }
                    if (c12 == '&' || c12 == '|') {
                        filter15 = filterRest(filter15);
                    }
                    accept(Operators.BRACKET_END);
                    if (predicateFlag) {
                        accept(Operators.BRACKET_END);
                    }
                    if (acceptBracket) {
                        accept(Operators.ARRAY_END);
                    }
                    return filter15;
                }
            } else {
                int start = this.pos - 1;
                char startCh = this.ch;
                while (true) {
                    char c19 = this.ch;
                    if (c19 != ']' && c19 != '/' && !isEOF() && (this.ch != '.' || predicateFlag || predicateFlag || startCh == '\'')) {
                        if (this.ch == '\\') {
                            next();
                        }
                        next();
                    } else if (!acceptBracket) {
                        end = this.pos - 1;
                    } else {
                        char c20 = this.ch;
                        if (c20 == '/' || c20 == '.') {
                            end = this.pos - 1;
                        } else {
                            end = this.pos;
                        }
                    }
                }
                if (!acceptBracket) {
                }
                String text = this.path.substring(start, end);
                if (text.indexOf(92) != 0) {
                    StringBuilder buf = new StringBuilder(text.length());
                    int i3 = 0;
                    while (i3 < text.length()) {
                        char ch2 = text.charAt(i3);
                        if (ch2 == '\\' && i3 < text.length() - 1 && ((c22 = text.charAt(i3 + 1)) == '@' || ch2 == '\\' || ch2 == '\"')) {
                            buf.append(c22);
                            i3++;
                        } else {
                            buf.append(ch2);
                        }
                        i3++;
                    }
                    text = buf.toString();
                }
                if (text.indexOf("\\.") != -1) {
                    if (startCh == '\'' && text.length() > 2 && text.charAt(text.length() - 1) == startCh) {
                        propName = text.substring(1, text.length() - 1);
                    } else {
                        propName = text.replaceAll("\\\\\\.", "\\.");
                        if (propName.indexOf("\\-") != -1) {
                            propName = propName.replaceAll("\\\\-", "-");
                        }
                    }
                    if (predicateFlag) {
                        accept(Operators.BRACKET_END);
                    }
                    return new PropertySegment(propName, false);
                }
                Segment segment = buildArraySegement(text);
                if (acceptBracket && !isEOF()) {
                    accept(Operators.ARRAY_END);
                }
                return segment;
            }
        }

        /* access modifiers changed from: package-private */
        public Filter filterRest(Filter filter) {
            boolean and = this.ch == '&';
            if ((this.ch == '&' && getNextChar() == '&') || (this.ch == '|' && getNextChar() == '|')) {
                next();
                next();
                boolean paren = false;
                if (this.ch == '(') {
                    paren = true;
                    next();
                }
                while (this.ch == ' ') {
                    next();
                }
                filter = new FilterGroup(filter, (Filter) parseArrayAccessFilter(false), and);
                if (paren && this.ch == ')') {
                    next();
                }
            }
            return filter;
        }

        /* access modifiers changed from: protected */
        public long readLongValue() {
            int beginIndex = this.pos - 1;
            char c = this.ch;
            if (c == '+' || c == '-') {
                next();
            }
            while (true) {
                char c2 = this.ch;
                if (c2 < '0' || c2 > '9') {
                } else {
                    next();
                }
            }
            return Long.parseLong(this.path.substring(beginIndex, this.pos - 1));
        }

        /* access modifiers changed from: protected */
        public double readDoubleValue(long longValue) {
            int beginIndex = this.pos - 1;
            next();
            while (true) {
                char c = this.ch;
                if (c < '0' || c > '9') {
                } else {
                    next();
                }
            }
            return Double.parseDouble(this.path.substring(beginIndex, this.pos - 1)) + ((double) longValue);
        }

        /* access modifiers changed from: protected */
        public Object readValue() {
            skipWhitespace();
            if (isDigitFirst(this.ch)) {
                return Long.valueOf(readLongValue());
            }
            char c = this.ch;
            if (c == '\"' || c == '\'') {
                return readString();
            }
            if (c != 'n') {
                throw new UnsupportedOperationException();
            } else if (b.m.equals(readName())) {
                return null;
            } else {
                throw new JSONPathException(this.path);
            }
        }

        static boolean isDigitFirst(char ch2) {
            return ch2 == '-' || ch2 == '+' || (ch2 >= '0' && ch2 <= '9');
        }

        /* access modifiers changed from: protected */
        public Operator readOp() {
            Operator op = null;
            char c = this.ch;
            if (c == '=') {
                next();
                char c2 = this.ch;
                if (c2 == '~') {
                    next();
                    op = Operator.REG_MATCH;
                } else if (c2 == '=') {
                    next();
                    op = Operator.EQ;
                } else {
                    op = Operator.EQ;
                }
            } else if (c == '!') {
                next();
                accept(a.h);
                op = Operator.NE;
            } else if (c == '<') {
                next();
                if (this.ch == '=') {
                    next();
                    op = Operator.LE;
                } else {
                    op = Operator.LT;
                }
            } else if (c == '>') {
                next();
                if (this.ch == '=') {
                    next();
                    op = Operator.GE;
                } else {
                    op = Operator.GT;
                }
            }
            if (op != null) {
                return op;
            }
            String name = readName();
            if ("not".equalsIgnoreCase(name)) {
                skipWhitespace();
                String name2 = readName();
                if ("like".equalsIgnoreCase(name2)) {
                    return Operator.NOT_LIKE;
                }
                if ("rlike".equalsIgnoreCase(name2)) {
                    return Operator.NOT_RLIKE;
                }
                if ("in".equalsIgnoreCase(name2)) {
                    return Operator.NOT_IN;
                }
                if ("between".equalsIgnoreCase(name2)) {
                    return Operator.NOT_BETWEEN;
                }
                throw new UnsupportedOperationException();
            } else if ("nin".equalsIgnoreCase(name)) {
                return Operator.NOT_IN;
            } else {
                if ("like".equalsIgnoreCase(name)) {
                    return Operator.LIKE;
                }
                if ("rlike".equalsIgnoreCase(name)) {
                    return Operator.RLIKE;
                }
                if ("in".equalsIgnoreCase(name)) {
                    return Operator.IN;
                }
                if ("between".equalsIgnoreCase(name)) {
                    return Operator.BETWEEN;
                }
                throw new UnsupportedOperationException();
            }
        }

        /* access modifiers changed from: package-private */
        public String readName() {
            skipWhitespace();
            char c = this.ch;
            if (c == '\\' || Character.isJavaIdentifierStart(c)) {
                StringBuilder buf = new StringBuilder();
                while (!isEOF()) {
                    char c2 = this.ch;
                    if (c2 == '\\') {
                        next();
                        buf.append(this.ch);
                        if (isEOF()) {
                            return buf.toString();
                        }
                        next();
                    } else if (!Character.isJavaIdentifierPart(c2)) {
                        break;
                    } else {
                        buf.append(this.ch);
                        next();
                    }
                }
                if (isEOF() && Character.isJavaIdentifierPart(this.ch)) {
                    buf.append(this.ch);
                }
                return buf.toString();
            }
            throw new JSONPathException("illeal jsonpath syntax. " + this.path);
        }

        /* access modifiers changed from: package-private */
        public String readString() {
            char quoate = this.ch;
            next();
            int beginIndex = this.pos - 1;
            while (this.ch != quoate && !isEOF()) {
                next();
            }
            String strValue = this.path.substring(beginIndex, isEOF() ? this.pos : this.pos - 1);
            accept(quoate);
            return strValue;
        }

        /* access modifiers changed from: package-private */
        public void accept(char expect) {
            if (this.ch == ' ') {
                next();
            }
            if (this.ch != expect) {
                throw new JSONPathException("expect '" + expect + ", but '" + this.ch + "'");
            } else if (!isEOF()) {
                next();
            }
        }

        public Segment[] explain() {
            String str = this.path;
            if (str == null || str.length() == 0) {
                throw new IllegalArgumentException();
            }
            Segment[] segments = new Segment[8];
            while (true) {
                Segment segment = readSegement();
                if (segment == null) {
                    break;
                }
                if (segment instanceof PropertySegment) {
                    PropertySegment propertySegment = (PropertySegment) segment;
                    if (!propertySegment.deep && propertySegment.propertyName.equals("*")) {
                    }
                }
                int i = this.level;
                if (i == segments.length) {
                    Segment[] t = new Segment[((i * 3) / 2)];
                    System.arraycopy(segments, 0, t, 0, i);
                    segments = t;
                }
                int i2 = this.level;
                this.level = i2 + 1;
                segments[i2] = segment;
            }
            int i3 = this.level;
            if (i3 == segments.length) {
                return segments;
            }
            Segment[] result = new Segment[i3];
            System.arraycopy(segments, 0, result, 0, i3);
            return result;
        }

        /* access modifiers changed from: package-private */
        public Segment buildArraySegement(String indexText) {
            int end;
            int step;
            int indexTextLen = indexText.length();
            char firstChar = indexText.charAt(0);
            char lastChar = indexText.charAt(indexTextLen - 1);
            int commaIndex = indexText.indexOf(44);
            if (indexText.length() > 2 && firstChar == '\'' && lastChar == '\'') {
                String propertyName = indexText.substring(1, indexTextLen - 1);
                if (commaIndex == -1 || !strArrayPatternx.matcher(indexText).find()) {
                    return new PropertySegment(propertyName, false);
                }
                return new MultiPropertySegment(propertyName.split(strArrayRegex));
            }
            int colonIndex = indexText.indexOf(58);
            if (commaIndex == -1 && colonIndex == -1) {
                if (TypeUtils.isNumber(indexText)) {
                    try {
                        return new ArrayAccessSegment(Integer.parseInt(indexText));
                    } catch (NumberFormatException e) {
                        return new PropertySegment(indexText, false);
                    }
                } else {
                    if (indexText.charAt(0) == '\"' && indexText.charAt(indexText.length() - 1) == '\"') {
                        indexText = indexText.substring(1, indexText.length() - 1);
                    }
                    return new PropertySegment(indexText, false);
                }
            } else if (commaIndex != -1) {
                String[] indexesText = indexText.split(",");
                int[] indexes = new int[indexesText.length];
                for (int i = 0; i < indexesText.length; i++) {
                    indexes[i] = Integer.parseInt(indexesText[i]);
                }
                return new MultiIndexSegment(indexes);
            } else if (colonIndex != -1) {
                String[] indexesText2 = indexText.split(com.xiaomi.mipush.sdk.Constants.COLON_SEPARATOR);
                int[] indexes2 = new int[indexesText2.length];
                for (int i2 = 0; i2 < indexesText2.length; i2++) {
                    String str = indexesText2[i2];
                    if (str.length() != 0) {
                        indexes2[i2] = Integer.parseInt(str);
                    } else if (i2 == 0) {
                        indexes2[i2] = 0;
                    } else {
                        throw new UnsupportedOperationException();
                    }
                }
                int start = indexes2[0];
                if (indexes2.length > 1) {
                    end = indexes2[1];
                } else {
                    end = -1;
                }
                if (indexes2.length == 3) {
                    step = indexes2[2];
                } else {
                    step = 1;
                }
                if (end >= 0 && end < start) {
                    throw new UnsupportedOperationException("end must greater than or equals start. start " + start + ",  end " + end);
                } else if (step > 0) {
                    return new RangeSegment(start, end, step);
                } else {
                    throw new UnsupportedOperationException("step must greater than zero : " + step);
                }
            } else {
                throw new UnsupportedOperationException();
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class SizeSegment implements Segment {
        public static final SizeSegment instance = new SizeSegment();

        SizeSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Integer eval(JSONPath path, Object rootObject, Object currentObject) {
            return Integer.valueOf(path.evalSize(currentObject));
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            context.object = Integer.valueOf(path.evalSize(parser.parse()));
        }
    }

    /* access modifiers changed from: package-private */
    public static class TypeSegment implements Segment {
        public static final TypeSegment instance = new TypeSegment();

        TypeSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public String eval(JSONPath path, Object rootObject, Object currentObject) {
            if (currentObject == null) {
                return b.m;
            }
            if (currentObject instanceof Collection) {
                return "array";
            }
            if (currentObject instanceof Number) {
                return "number";
            }
            if (currentObject instanceof Boolean) {
                return "boolean";
            }
            if ((currentObject instanceof String) || (currentObject instanceof UUID) || (currentObject instanceof Enum)) {
                return "string";
            }
            return "object";
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class FloorSegment implements Segment {
        public static final FloorSegment instance = new FloorSegment();

        FloorSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            if (!(currentObject instanceof JSONArray)) {
                return floor(currentObject);
            }
            JSONArray array = (JSONArray) ((JSONArray) currentObject).clone();
            for (int i = 0; i < array.size(); i++) {
                Object item = array.get(i);
                Object newItem = floor(item);
                if (newItem != item) {
                    array.set(i, newItem);
                }
            }
            return array;
        }

        private static Object floor(Object item) {
            if (item == null) {
                return null;
            }
            if (item instanceof Float) {
                return Double.valueOf(Math.floor((double) ((Float) item).floatValue()));
            }
            if (item instanceof Double) {
                return Double.valueOf(Math.floor(((Double) item).doubleValue()));
            }
            if (item instanceof BigDecimal) {
                return ((BigDecimal) item).setScale(0, RoundingMode.FLOOR);
            }
            if ((item instanceof Byte) || (item instanceof Short) || (item instanceof Integer) || (item instanceof Long) || (item instanceof BigInteger)) {
                return item;
            }
            throw new UnsupportedOperationException();
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class MaxSegment implements Segment {
        public static final MaxSegment instance = new MaxSegment();

        MaxSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            Object max = null;
            if (currentObject instanceof Collection) {
                for (Object next : (Collection) currentObject) {
                    if (next != null) {
                        if (max == null) {
                            max = next;
                        } else if (JSONPath.compare(max, next) < 0) {
                            max = next;
                        }
                    }
                }
                return max;
            }
            throw new UnsupportedOperationException();
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class MinSegment implements Segment {
        public static final MinSegment instance = new MinSegment();

        MinSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            Object min = null;
            if (currentObject instanceof Collection) {
                for (Object next : (Collection) currentObject) {
                    if (next != null) {
                        if (min == null) {
                            min = next;
                        } else if (JSONPath.compare(min, next) > 0) {
                            min = next;
                        }
                    }
                }
                return min;
            }
            throw new UnsupportedOperationException();
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    static int compare(Object a, Object b) {
        if (a.getClass() == b.getClass()) {
            return ((Comparable) a).compareTo(b);
        }
        Class typeA = a.getClass();
        Class typeB = b.getClass();
        if (typeA == BigDecimal.class) {
            if (typeB == Integer.class) {
                b = new BigDecimal(((Integer) b).intValue());
            } else if (typeB == Long.class) {
                b = new BigDecimal(((Long) b).longValue());
            } else if (typeB == Float.class) {
                b = new BigDecimal((double) ((Float) b).floatValue());
            } else if (typeB == Double.class) {
                b = new BigDecimal(((Double) b).doubleValue());
            }
        } else if (typeA == Long.class) {
            if (typeB == Integer.class) {
                b = new Long((long) ((Integer) b).intValue());
            } else if (typeB == BigDecimal.class) {
                a = new BigDecimal(((Long) a).longValue());
            } else if (typeB == Float.class) {
                a = new Float((float) ((Long) a).longValue());
            } else if (typeB == Double.class) {
                a = new Double((double) ((Long) a).longValue());
            }
        } else if (typeA == Integer.class) {
            if (typeB == Long.class) {
                a = new Long((long) ((Integer) a).intValue());
            } else if (typeB == BigDecimal.class) {
                a = new BigDecimal(((Integer) a).intValue());
            } else if (typeB == Float.class) {
                a = new Float((float) ((Integer) a).intValue());
            } else if (typeB == Double.class) {
                a = new Double((double) ((Integer) a).intValue());
            }
        } else if (typeA == Double.class) {
            if (typeB == Integer.class) {
                b = new Double((double) ((Integer) b).intValue());
            } else if (typeB == Long.class) {
                b = new Double((double) ((Long) b).longValue());
            } else if (typeB == Float.class) {
                b = new Double((double) ((Float) b).floatValue());
            }
        } else if (typeA == Float.class) {
            if (typeB == Integer.class) {
                b = new Float((float) ((Integer) b).intValue());
            } else if (typeB == Long.class) {
                b = new Float((float) ((Long) b).longValue());
            } else if (typeB == Double.class) {
                a = new Double((double) ((Float) a).floatValue());
            }
        }
        return ((Comparable) a).compareTo(b);
    }

    /* access modifiers changed from: package-private */
    public static class KeySetSegment implements Segment {
        public static final KeySetSegment instance = new KeySetSegment();

        KeySetSegment() {
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            return path.evalKeySet(currentObject);
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class PropertySegment implements Segment {
        private final boolean deep;
        private final String propertyName;
        private final long propertyNameHash;

        public PropertySegment(String propertyName2, boolean deep2) {
            this.propertyName = propertyName2;
            this.propertyNameHash = TypeUtils.fnv1a_64(propertyName2);
            this.deep = deep2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            if (!this.deep) {
                return path.getPropertyValue(currentObject, this.propertyName, this.propertyNameHash);
            }
            List<Object> results = new ArrayList<>();
            path.deepScan(currentObject, this.propertyName, results);
            return results;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            Object value;
            Object value2;
            JSONArray array;
            Object value3;
            JSONLexerBase lexer = (JSONLexerBase) parser.lexer;
            if (this.deep && context.object == null) {
                context.object = new JSONArray();
            }
            if (lexer.token() != 14) {
                boolean z = this.deep;
                if (z) {
                    while (true) {
                        int matchStat = lexer.seekObjectToField(this.propertyNameHash, this.deep);
                        if (matchStat != -1) {
                            if (matchStat == 3) {
                                if (context.eval) {
                                    int i = lexer.token();
                                    if (i == 2) {
                                        value = lexer.integerValue();
                                        lexer.nextToken(16);
                                    } else if (i == 3) {
                                        value = lexer.decimalValue();
                                        lexer.nextToken(16);
                                    } else if (i != 4) {
                                        value = parser.parse();
                                    } else {
                                        value = lexer.stringVal();
                                        lexer.nextToken(16);
                                    }
                                    if (context.eval) {
                                        if (context.object instanceof List) {
                                            List list = (List) context.object;
                                            if (list.size() != 0 || !(value instanceof List)) {
                                                list.add(value);
                                            } else {
                                                context.object = value;
                                            }
                                        } else {
                                            context.object = value;
                                        }
                                    }
                                }
                            } else if (matchStat == 1 || matchStat == 2) {
                                extract(path, parser, context);
                            }
                        } else {
                            return;
                        }
                    }
                } else if (lexer.seekObjectToField(this.propertyNameHash, z) == 3 && context.eval) {
                    int i2 = lexer.token();
                    if (i2 == 2) {
                        value2 = lexer.integerValue();
                        lexer.nextToken(16);
                    } else if (i2 == 3) {
                        value2 = lexer.decimalValue();
                        lexer.nextToken(16);
                    } else if (i2 != 4) {
                        value2 = parser.parse();
                    } else {
                        value2 = lexer.stringVal();
                        lexer.nextToken(16);
                    }
                    if (context.eval) {
                        context.object = value2;
                    }
                }
            } else if (!"*".equals(this.propertyName)) {
                lexer.nextToken();
                if (this.deep) {
                    array = (JSONArray) context.object;
                } else {
                    array = new JSONArray();
                }
                while (true) {
                    int i3 = lexer.token();
                    if (i3 == 12) {
                        boolean z2 = this.deep;
                        if (z2) {
                            extract(path, parser, context);
                        } else {
                            int matchStat2 = lexer.seekObjectToField(this.propertyNameHash, z2);
                            if (matchStat2 == 3) {
                                int i4 = lexer.token();
                                if (i4 == 2) {
                                    value3 = lexer.integerValue();
                                    lexer.nextToken();
                                } else if (i4 != 4) {
                                    value3 = parser.parse();
                                } else {
                                    value3 = lexer.stringVal();
                                    lexer.nextToken();
                                }
                                array.add(value3);
                                if (lexer.token() == 13) {
                                    lexer.nextToken();
                                } else {
                                    lexer.skipObject(false);
                                }
                            } else if (matchStat2 == -1) {
                                continue;
                            } else if (!this.deep) {
                                lexer.skipObject(false);
                            } else {
                                throw new UnsupportedOperationException(lexer.info());
                            }
                        }
                    } else if (i3 != 14) {
                        switch (i3) {
                            case 2:
                            case 3:
                            case 4:
                            case 5:
                            case 6:
                            case 7:
                            case 8:
                                lexer.nextToken();
                                break;
                        }
                    } else if (this.deep) {
                        extract(path, parser, context);
                    } else {
                        lexer.skipObject(false);
                    }
                    if (lexer.token() == 15) {
                        lexer.nextToken();
                        if (!this.deep && array.size() > 0) {
                            context.object = array;
                            return;
                        }
                        return;
                    } else if (lexer.token() == 16) {
                        lexer.nextToken();
                    } else {
                        throw new JSONException("illegal json : " + lexer.info());
                    }
                }
            }
        }

        public void setValue(JSONPath path, Object parent, Object value) {
            if (this.deep) {
                path.deepSet(parent, this.propertyName, this.propertyNameHash, value);
            } else {
                path.setPropertyValue(parent, this.propertyName, this.propertyNameHash, value);
            }
        }

        public boolean remove(JSONPath path, Object parent) {
            return path.removePropertyValue(parent, this.propertyName, this.deep);
        }
    }

    /* access modifiers changed from: package-private */
    public static class MultiPropertySegment implements Segment {
        private final String[] propertyNames;
        private final long[] propertyNamesHash;

        public MultiPropertySegment(String[] propertyNames2) {
            this.propertyNames = propertyNames2;
            this.propertyNamesHash = new long[propertyNames2.length];
            int i = 0;
            while (true) {
                long[] jArr = this.propertyNamesHash;
                if (i < jArr.length) {
                    jArr[i] = TypeUtils.fnv1a_64(propertyNames2[i]);
                    i++;
                } else {
                    return;
                }
            }
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            List<Object> fieldValues = new ArrayList<>(this.propertyNames.length);
            int i = 0;
            while (true) {
                String[] strArr = this.propertyNames;
                if (i >= strArr.length) {
                    return fieldValues;
                }
                fieldValues.add(path.getPropertyValue(currentObject, strArr[i], this.propertyNamesHash[i]));
                i++;
            }
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            JSONArray array;
            Object value;
            JSONLexerBase lexer = (JSONLexerBase) parser.lexer;
            if (context.object == null) {
                JSONArray jSONArray = new JSONArray();
                array = jSONArray;
                context.object = jSONArray;
            } else {
                array = (JSONArray) context.object;
            }
            for (int i = array.size(); i < this.propertyNamesHash.length; i++) {
                array.add(null);
            }
            do {
                int index = lexer.seekObjectToField(this.propertyNamesHash);
                if (lexer.matchStat == 3) {
                    int i2 = lexer.token();
                    if (i2 == 2) {
                        value = lexer.integerValue();
                        lexer.nextToken(16);
                    } else if (i2 == 3) {
                        value = lexer.decimalValue();
                        lexer.nextToken(16);
                    } else if (i2 != 4) {
                        value = parser.parse();
                    } else {
                        value = lexer.stringVal();
                        lexer.nextToken(16);
                    }
                    array.set(index, value);
                } else {
                    return;
                }
            } while (lexer.token() == 16);
        }
    }

    /* access modifiers changed from: package-private */
    public static class WildCardSegment implements Segment {
        public static final WildCardSegment instance = new WildCardSegment(false, false);
        public static final WildCardSegment instance_deep = new WildCardSegment(true, false);
        public static final WildCardSegment instance_deep_objectOnly = new WildCardSegment(true, true);
        private boolean deep;
        private boolean objectOnly;

        private WildCardSegment(boolean deep2, boolean objectOnly2) {
            this.deep = deep2;
            this.objectOnly = objectOnly2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            if (!this.deep) {
                return path.getPropertyValues(currentObject);
            }
            List<Object> values = new ArrayList<>();
            path.deepGetPropertyValues(currentObject, values);
            return values;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            if (context.eval) {
                Object object = parser.parse();
                if (this.deep) {
                    List<Object> values = new ArrayList<>();
                    if (this.objectOnly) {
                        path.deepGetObjects(object, values);
                    } else {
                        path.deepGetPropertyValues(object, values);
                    }
                    context.object = values;
                    return;
                } else if (object instanceof JSONObject) {
                    Collection<Object> values2 = ((JSONObject) object).values();
                    JSONArray array = new JSONArray(values2.size());
                    array.addAll(values2);
                    context.object = array;
                    return;
                } else if (object instanceof JSONArray) {
                    context.object = object;
                    return;
                }
            }
            throw new JSONException("TODO");
        }
    }

    /* access modifiers changed from: package-private */
    public static class ArrayAccessSegment implements Segment {
        private final int index;

        public ArrayAccessSegment(int index2) {
            this.index = index2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            return path.getArrayItem(currentObject, this.index);
        }

        public boolean setValue(JSONPath path, Object currentObject, Object value) {
            return path.setArrayItem(path, currentObject, this.index, value);
        }

        public boolean remove(JSONPath path, Object currentObject) {
            return path.removeArrayItem(path, currentObject, this.index);
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            if (((JSONLexerBase) parser.lexer).seekArrayToItem(this.index) && context.eval) {
                context.object = parser.parse();
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class MultiIndexSegment implements Segment {
        private final int[] indexes;

        public MultiIndexSegment(int[] indexes2) {
            this.indexes = indexes2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            List<Object> items = new JSONArray(this.indexes.length);
            int i = 0;
            while (true) {
                int[] iArr = this.indexes;
                if (i >= iArr.length) {
                    return items;
                }
                items.add(path.getArrayItem(currentObject, iArr[i]));
                i++;
            }
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            if (context.eval) {
                Object object = parser.parse();
                if (object instanceof List) {
                    int[] iArr = this.indexes;
                    int[] indexes2 = new int[iArr.length];
                    boolean noneNegative = false;
                    System.arraycopy(iArr, 0, indexes2, 0, indexes2.length);
                    if (indexes2[0] >= 0) {
                        noneNegative = true;
                    }
                    List list = (List) object;
                    if (noneNegative) {
                        for (int i = list.size() - 1; i >= 0; i--) {
                            if (Arrays.binarySearch(indexes2, i) < 0) {
                                list.remove(i);
                            }
                        }
                        context.object = list;
                        return;
                    }
                }
            }
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class RangeSegment implements Segment {
        private final int end;
        private final int start;
        private final int step;

        public RangeSegment(int start2, int end2, int step2) {
            this.start = start2;
            this.end = end2;
            this.step = step2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            int size = SizeSegment.instance.eval(path, rootObject, currentObject).intValue();
            int start2 = this.start;
            if (start2 < 0) {
                start2 += size;
            }
            int end2 = this.end;
            if (end2 < 0) {
                end2 += size;
            }
            int array_size = ((end2 - start2) / this.step) + 1;
            if (array_size == -1) {
                return null;
            }
            List<Object> items = new ArrayList<>(array_size);
            int i = start2;
            while (i <= end2 && i < size) {
                items.add(path.getArrayItem(currentObject, i));
                i += this.step;
            }
            return items;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class NotNullSegement extends PropertyFilter {
        public NotNullSegement(String propertyName, boolean function) {
            super(propertyName, function);
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            return path.getPropertyValue(item, this.propertyName, this.propertyNameHash) != null;
        }
    }

    /* access modifiers changed from: package-private */
    public static class NullSegement extends PropertyFilter {
        public NullSegement(String propertyName, boolean function) {
            super(propertyName, function);
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            return get(path, rootObject, item) == null;
        }
    }

    /* access modifiers changed from: package-private */
    public static class ValueSegment extends PropertyFilter {
        private boolean eq = true;
        private final Object value;

        public ValueSegment(String propertyName, boolean function, Object value2, boolean eq2) {
            super(propertyName, function);
            if (value2 != null) {
                this.value = value2;
                this.eq = eq2;
                return;
            }
            throw new IllegalArgumentException("value is null");
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            boolean result = this.value.equals(get(path, rootObject, item));
            if (!this.eq) {
                return !result;
            }
            return result;
        }
    }

    /* access modifiers changed from: package-private */
    public static class IntInSegement extends PropertyFilter {
        private final boolean not;
        private final long[] values;

        public IntInSegement(String propertyName, boolean function, long[] values2, boolean not2) {
            super(propertyName, function);
            this.values = values2;
            this.not = not2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null) {
                return false;
            }
            if (propertyValue instanceof Number) {
                long longPropertyValue = TypeUtils.longExtractValue((Number) propertyValue);
                for (long value : this.values) {
                    if (value == longPropertyValue) {
                        return !this.not;
                    }
                }
            }
            return this.not;
        }
    }

    /* access modifiers changed from: package-private */
    public static class IntBetweenSegement extends PropertyFilter {
        private final long endValue;
        private final boolean not;
        private final long startValue;

        public IntBetweenSegement(String propertyName, boolean function, long startValue2, long endValue2, boolean not2) {
            super(propertyName, function);
            this.startValue = startValue2;
            this.endValue = endValue2;
            this.not = not2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null) {
                return false;
            }
            if (propertyValue instanceof Number) {
                long longPropertyValue = TypeUtils.longExtractValue((Number) propertyValue);
                if (longPropertyValue >= this.startValue && longPropertyValue <= this.endValue) {
                    return !this.not;
                }
            }
            return this.not;
        }
    }

    /* access modifiers changed from: package-private */
    public static class IntObjInSegement extends PropertyFilter {
        private final boolean not;
        private final Long[] values;

        public IntObjInSegement(String propertyName, boolean function, Long[] values2, boolean not2) {
            super(propertyName, function);
            this.values = values2;
            this.not = not2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            int i = 0;
            if (propertyValue == null) {
                Long[] lArr = this.values;
                int length = lArr.length;
                while (i < length) {
                    if (lArr[i] == null) {
                        return !this.not;
                    }
                    i++;
                }
                return this.not;
            }
            if (propertyValue instanceof Number) {
                long longPropertyValue = TypeUtils.longExtractValue((Number) propertyValue);
                Long[] lArr2 = this.values;
                int length2 = lArr2.length;
                while (i < length2) {
                    Long value = lArr2[i];
                    if (value != null && value.longValue() == longPropertyValue) {
                        return !this.not;
                    }
                    i++;
                }
            }
            return this.not;
        }
    }

    /* access modifiers changed from: package-private */
    public static class StringInSegement extends PropertyFilter {
        private final boolean not;
        private final String[] values;

        public StringInSegement(String propertyName, boolean function, String[] values2, boolean not2) {
            super(propertyName, function);
            this.values = values2;
            this.not = not2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            String[] strArr = this.values;
            for (String value : strArr) {
                if (value == propertyValue) {
                    return !this.not;
                }
                if (value != null && value.equals(propertyValue)) {
                    return !this.not;
                }
            }
            return this.not;
        }
    }

    /* access modifiers changed from: package-private */
    public static class IntOpSegement extends PropertyFilter {
        private final Operator op;
        private final long value;
        private BigDecimal valueDecimal;
        private Double valueDouble;
        private Float valueFloat;

        public IntOpSegement(String propertyName, boolean function, long value2, Operator op2) {
            super(propertyName, function);
            this.value = value2;
            this.op = op2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null || !(propertyValue instanceof Number)) {
                return false;
            }
            if (propertyValue instanceof BigDecimal) {
                if (this.valueDecimal == null) {
                    this.valueDecimal = BigDecimal.valueOf(this.value);
                }
                int result = this.valueDecimal.compareTo((BigDecimal) propertyValue);
                switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                    case 1:
                        if (result == 0) {
                            return true;
                        }
                        return false;
                    case 2:
                        if (result != 0) {
                            return true;
                        }
                        return false;
                    case 3:
                        if (result <= 0) {
                            return true;
                        }
                        return false;
                    case 4:
                        if (result < 0) {
                            return true;
                        }
                        return false;
                    case 5:
                        if (result >= 0) {
                            return true;
                        }
                        return false;
                    case 6:
                        if (result > 0) {
                            return true;
                        }
                        return false;
                    default:
                        return false;
                }
            } else if (propertyValue instanceof Float) {
                if (this.valueFloat == null) {
                    this.valueFloat = Float.valueOf((float) this.value);
                }
                int result2 = this.valueFloat.compareTo((Float) propertyValue);
                switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                    case 1:
                        if (result2 == 0) {
                            return true;
                        }
                        return false;
                    case 2:
                        if (result2 != 0) {
                            return true;
                        }
                        return false;
                    case 3:
                        if (result2 <= 0) {
                            return true;
                        }
                        return false;
                    case 4:
                        if (result2 < 0) {
                            return true;
                        }
                        return false;
                    case 5:
                        if (result2 >= 0) {
                            return true;
                        }
                        return false;
                    case 6:
                        if (result2 > 0) {
                            return true;
                        }
                        return false;
                    default:
                        return false;
                }
            } else if (propertyValue instanceof Double) {
                if (this.valueDouble == null) {
                    this.valueDouble = Double.valueOf((double) this.value);
                }
                int result3 = this.valueDouble.compareTo((Double) propertyValue);
                switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                    case 1:
                        if (result3 == 0) {
                            return true;
                        }
                        return false;
                    case 2:
                        if (result3 != 0) {
                            return true;
                        }
                        return false;
                    case 3:
                        if (result3 <= 0) {
                            return true;
                        }
                        return false;
                    case 4:
                        if (result3 < 0) {
                            return true;
                        }
                        return false;
                    case 5:
                        if (result3 >= 0) {
                            return true;
                        }
                        return false;
                    case 6:
                        if (result3 > 0) {
                            return true;
                        }
                        return false;
                    default:
                        return false;
                }
            } else {
                long longValue = TypeUtils.longExtractValue((Number) propertyValue);
                switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                    case 1:
                        if (longValue == this.value) {
                            return true;
                        }
                        return false;
                    case 2:
                        if (longValue != this.value) {
                            return true;
                        }
                        return false;
                    case 3:
                        if (longValue >= this.value) {
                            return true;
                        }
                        return false;
                    case 4:
                        if (longValue > this.value) {
                            return true;
                        }
                        return false;
                    case 5:
                        if (longValue <= this.value) {
                            return true;
                        }
                        return false;
                    case 6:
                        if (longValue < this.value) {
                            return true;
                        }
                        return false;
                    default:
                        return false;
                }
            }
        }
    }

    /* renamed from: com.alibaba.fastjson.JSONPath$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$alibaba$fastjson$JSONPath$Operator;

        static {
            int[] iArr = new int[Operator.values().length];
            $SwitchMap$com$alibaba$fastjson$JSONPath$Operator = iArr;
            try {
                iArr[Operator.EQ.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$alibaba$fastjson$JSONPath$Operator[Operator.NE.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$alibaba$fastjson$JSONPath$Operator[Operator.GE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$alibaba$fastjson$JSONPath$Operator[Operator.GT.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$alibaba$fastjson$JSONPath$Operator[Operator.LE.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$com$alibaba$fastjson$JSONPath$Operator[Operator.LT.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
        }
    }

    static abstract class PropertyFilter implements Filter {
        static long TYPE = TypeUtils.fnv1a_64("type");
        protected final boolean function;
        protected Segment functionExpr;
        protected final String propertyName;
        protected final long propertyNameHash;

        protected PropertyFilter(String propertyName2, boolean function2) {
            this.propertyName = propertyName2;
            long fnv1a_64 = TypeUtils.fnv1a_64(propertyName2);
            this.propertyNameHash = fnv1a_64;
            this.function = function2;
            if (!function2) {
                return;
            }
            if (fnv1a_64 == TYPE) {
                this.functionExpr = TypeSegment.instance;
            } else if (fnv1a_64 == JSONPath.SIZE) {
                this.functionExpr = SizeSegment.instance;
            } else {
                throw new JSONPathException("unsupported funciton : " + propertyName2);
            }
        }

        /* access modifiers changed from: protected */
        public Object get(JSONPath path, Object rootObject, Object currentObject) {
            Segment segment = this.functionExpr;
            if (segment != null) {
                return segment.eval(path, rootObject, currentObject);
            }
            return path.getPropertyValue(currentObject, this.propertyName, this.propertyNameHash);
        }
    }

    /* access modifiers changed from: package-private */
    public static class DoubleOpSegement extends PropertyFilter {
        private final Operator op;
        private final double value;

        public DoubleOpSegement(String propertyName, boolean function, double value2, Operator op2) {
            super(propertyName, function);
            this.value = value2;
            this.op = op2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null || !(propertyValue instanceof Number)) {
                return false;
            }
            double doubleValue = ((Number) propertyValue).doubleValue();
            switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                case 1:
                    if (doubleValue == this.value) {
                        return true;
                    }
                    return false;
                case 2:
                    if (doubleValue != this.value) {
                        return true;
                    }
                    return false;
                case 3:
                    if (doubleValue >= this.value) {
                        return true;
                    }
                    return false;
                case 4:
                    if (doubleValue > this.value) {
                        return true;
                    }
                    return false;
                case 5:
                    if (doubleValue <= this.value) {
                        return true;
                    }
                    return false;
                case 6:
                    if (doubleValue < this.value) {
                        return true;
                    }
                    return false;
                default:
                    return false;
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class RefOpSegement extends PropertyFilter {
        private final Operator op;
        private final Segment refSgement;

        public RefOpSegement(String propertyName, boolean function, Segment refSgement2, Operator op2) {
            super(propertyName, function);
            this.refSgement = refSgement2;
            this.op = op2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null || !(propertyValue instanceof Number)) {
                return false;
            }
            Object refValue = this.refSgement.eval(path, rootObject, rootObject);
            if ((refValue instanceof Integer) || (refValue instanceof Long) || (refValue instanceof Short) || (refValue instanceof Byte)) {
                long value = TypeUtils.longExtractValue((Number) refValue);
                if ((propertyValue instanceof Integer) || (propertyValue instanceof Long) || (propertyValue instanceof Short) || (propertyValue instanceof Byte)) {
                    long longValue = TypeUtils.longExtractValue((Number) propertyValue);
                    switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                        case 1:
                            if (longValue == value) {
                                return true;
                            }
                            return false;
                        case 2:
                            if (longValue != value) {
                                return true;
                            }
                            return false;
                        case 3:
                            if (longValue >= value) {
                                return true;
                            }
                            return false;
                        case 4:
                            if (longValue > value) {
                                return true;
                            }
                            return false;
                        case 5:
                            if (longValue <= value) {
                                return true;
                            }
                            return false;
                        case 6:
                            if (longValue < value) {
                                return true;
                            }
                            return false;
                    }
                } else if (propertyValue instanceof BigDecimal) {
                    int result = BigDecimal.valueOf(value).compareTo((BigDecimal) propertyValue);
                    switch (AnonymousClass1.$SwitchMap$com$alibaba$fastjson$JSONPath$Operator[this.op.ordinal()]) {
                        case 1:
                            if (result == 0) {
                                return true;
                            }
                            return false;
                        case 2:
                            if (result != 0) {
                                return true;
                            }
                            return false;
                        case 3:
                            if (result <= 0) {
                                return true;
                            }
                            return false;
                        case 4:
                            if (result < 0) {
                                return true;
                            }
                            return false;
                        case 5:
                            if (result >= 0) {
                                return true;
                            }
                            return false;
                        case 6:
                            if (result > 0) {
                                return true;
                            }
                            return false;
                        default:
                            return false;
                    }
                }
            }
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: package-private */
    public static class MatchSegement extends PropertyFilter {
        private final String[] containsValues;
        private final String endsWithValue;
        private final int minLength;
        private final boolean not;
        private final String startsWithValue;

        public MatchSegement(String propertyName, boolean function, String startsWithValue2, String endsWithValue2, String[] containsValues2, boolean not2) {
            super(propertyName, function);
            this.startsWithValue = startsWithValue2;
            this.endsWithValue = endsWithValue2;
            this.containsValues = containsValues2;
            this.not = not2;
            int len = startsWithValue2 != null ? 0 + startsWithValue2.length() : 0;
            len = endsWithValue2 != null ? len + endsWithValue2.length() : len;
            if (containsValues2 != null) {
                for (String item : containsValues2) {
                    len += item.length();
                }
            }
            this.minLength = len;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null) {
                return false;
            }
            String strPropertyValue = propertyValue.toString();
            if (strPropertyValue.length() < this.minLength) {
                return this.not;
            }
            int start = 0;
            String str = this.startsWithValue;
            if (str != null) {
                if (!strPropertyValue.startsWith(str)) {
                    return this.not;
                }
                start = 0 + this.startsWithValue.length();
            }
            String[] strArr = this.containsValues;
            if (strArr != null) {
                for (String containsValue : strArr) {
                    int index = strPropertyValue.indexOf(containsValue, start);
                    if (index == -1) {
                        return this.not;
                    }
                    start = index + containsValue.length();
                }
            }
            String str2 = this.endsWithValue;
            if (str2 == null || strPropertyValue.endsWith(str2)) {
                return !this.not;
            }
            return this.not;
        }
    }

    /* access modifiers changed from: package-private */
    public static class RlikeSegement extends PropertyFilter {
        private final boolean not;
        private final Pattern pattern;

        public RlikeSegement(String propertyName, boolean function, String pattern2, boolean not2) {
            super(propertyName, function);
            this.pattern = Pattern.compile(pattern2);
            this.not = not2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null) {
                return false;
            }
            boolean match = this.pattern.matcher(propertyValue.toString()).matches();
            if (this.not) {
                return !match;
            }
            return match;
        }
    }

    /* access modifiers changed from: package-private */
    public static class StringOpSegement extends PropertyFilter {
        private final Operator op;
        private final String value;

        public StringOpSegement(String propertyName, boolean function, String value2, Operator op2) {
            super(propertyName, function);
            this.value = value2;
            this.op = op2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (this.op == Operator.EQ) {
                return this.value.equals(propertyValue);
            }
            if (this.op == Operator.NE) {
                return !this.value.equals(propertyValue);
            }
            if (propertyValue == null) {
                return false;
            }
            int compareResult = this.value.compareTo(propertyValue.toString());
            if (this.op == Operator.GE) {
                if (compareResult <= 0) {
                    return true;
                }
                return false;
            } else if (this.op == Operator.GT) {
                if (compareResult < 0) {
                    return true;
                }
                return false;
            } else if (this.op == Operator.LE) {
                if (compareResult >= 0) {
                    return true;
                }
                return false;
            } else if (this.op != Operator.LT || compareResult <= 0) {
                return false;
            } else {
                return true;
            }
        }
    }

    /* access modifiers changed from: package-private */
    public static class RegMatchSegement extends PropertyFilter {
        private final Operator op;
        private final Pattern pattern;

        public RegMatchSegement(String propertyName, boolean function, Pattern pattern2, Operator op2) {
            super(propertyName, function);
            this.pattern = pattern2;
            this.op = op2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            Object propertyValue = get(path, rootObject, item);
            if (propertyValue == null) {
                return false;
            }
            return this.pattern.matcher(propertyValue.toString()).matches();
        }
    }

    public static class FilterSegment implements Segment {
        private final Filter filter;

        public FilterSegment(Filter filter2) {
            this.filter = filter2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public Object eval(JSONPath path, Object rootObject, Object currentObject) {
            if (currentObject == null) {
                return null;
            }
            List<Object> items = new JSONArray();
            if (currentObject instanceof Iterable) {
                for (Object item : (Iterable) currentObject) {
                    if (this.filter.apply(path, rootObject, currentObject, item)) {
                        items.add(item);
                    }
                }
                return items;
            } else if (this.filter.apply(path, rootObject, currentObject, currentObject)) {
                return currentObject;
            } else {
                return null;
            }
        }

        @Override // com.alibaba.fastjson.JSONPath.Segment
        public void extract(JSONPath path, DefaultJSONParser parser, Context context) {
            Object object = parser.parse();
            context.object = eval(path, object, object);
        }

        public boolean remove(JSONPath path, Object rootObject, Object currentObject) {
            if (currentObject == null || !(currentObject instanceof Iterable)) {
                return false;
            }
            Iterator it = ((Iterable) currentObject).iterator();
            while (it.hasNext()) {
                if (this.filter.apply(path, rootObject, currentObject, it.next())) {
                    it.remove();
                }
            }
            return true;
        }
    }

    /* access modifiers changed from: package-private */
    public static class FilterGroup implements Filter {
        private boolean and;
        private List<Filter> fitlers;

        public FilterGroup(Filter left, Filter right, boolean and2) {
            ArrayList arrayList = new ArrayList(2);
            this.fitlers = arrayList;
            arrayList.add(left);
            this.fitlers.add(right);
            this.and = and2;
        }

        @Override // com.alibaba.fastjson.JSONPath.Filter
        public boolean apply(JSONPath path, Object rootObject, Object currentObject, Object item) {
            if (this.and) {
                for (Filter fitler : this.fitlers) {
                    if (!fitler.apply(path, rootObject, currentObject, item)) {
                        return false;
                    }
                }
                return true;
            }
            for (Filter fitler2 : this.fitlers) {
                if (fitler2.apply(path, rootObject, currentObject, item)) {
                    return true;
                }
            }
            return false;
        }
    }

    /* access modifiers changed from: protected */
    public Object getArrayItem(Object currentObject, int index) {
        if (currentObject == null) {
            return null;
        }
        if (currentObject instanceof List) {
            List list = (List) currentObject;
            if (index >= 0) {
                if (index < list.size()) {
                    return list.get(index);
                }
                return null;
            } else if (Math.abs(index) <= list.size()) {
                return list.get(list.size() + index);
            } else {
                return null;
            }
        } else if (currentObject.getClass().isArray()) {
            int arrayLenth = Array.getLength(currentObject);
            if (index >= 0) {
                if (index < arrayLenth) {
                    return Array.get(currentObject, index);
                }
                return null;
            } else if (Math.abs(index) <= arrayLenth) {
                return Array.get(currentObject, arrayLenth + index);
            } else {
                return null;
            }
        } else if (currentObject instanceof Map) {
            Map map = (Map) currentObject;
            Object value = map.get(Integer.valueOf(index));
            if (value == null) {
                return map.get(Integer.toString(index));
            }
            return value;
        } else if (currentObject instanceof Collection) {
            int i = 0;
            for (Object item : (Collection) currentObject) {
                if (i == index) {
                    return item;
                }
                i++;
            }
            return null;
        } else if (index == 0) {
            return currentObject;
        } else {
            throw new UnsupportedOperationException();
        }
    }

    public boolean setArrayItem(JSONPath path2, Object currentObject, int index, Object value) {
        if (currentObject instanceof List) {
            List list = (List) currentObject;
            if (index >= 0) {
                list.set(index, value);
            } else {
                list.set(list.size() + index, value);
            }
            return true;
        }
        Class<?> clazz = currentObject.getClass();
        if (clazz.isArray()) {
            int arrayLenth = Array.getLength(currentObject);
            if (index >= 0) {
                if (index < arrayLenth) {
                    Array.set(currentObject, index, value);
                }
            } else if (Math.abs(index) <= arrayLenth) {
                Array.set(currentObject, arrayLenth + index, value);
            }
            return true;
        }
        throw new JSONPathException("unsupported set operation." + clazz);
    }

    public boolean removeArrayItem(JSONPath path2, Object currentObject, int index) {
        if (currentObject instanceof List) {
            List list = (List) currentObject;
            if (index < 0) {
                int newIndex = list.size() + index;
                if (newIndex < 0) {
                    return false;
                }
                list.remove(newIndex);
                return true;
            } else if (index >= list.size()) {
                return false;
            } else {
                list.remove(index);
                return true;
            }
        } else {
            Class<?> clazz = currentObject.getClass();
            throw new JSONPathException("unsupported set operation." + clazz);
        }
    }

    /* access modifiers changed from: protected */
    public Collection<Object> getPropertyValues(Object currentObject) {
        if (currentObject == null) {
            return null;
        }
        JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentObject.getClass());
        if (beanSerializer != null) {
            try {
                return beanSerializer.getFieldValues(currentObject);
            } catch (Exception e) {
                throw new JSONPathException("jsonpath error, path " + this.path, e);
            }
        } else if (currentObject instanceof Map) {
            return ((Map) currentObject).values();
        } else {
            if (currentObject instanceof Collection) {
                return (Collection) currentObject;
            }
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: protected */
    public void deepGetObjects(Object currentObject, List<Object> outValues) {
        Class<?> currentClass = currentObject.getClass();
        JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentClass);
        Collection collection = null;
        if (beanSerializer != null) {
            try {
                collection = beanSerializer.getFieldValues(currentObject);
                outValues.add(currentObject);
            } catch (Exception e) {
                throw new JSONPathException("jsonpath error, path " + this.path, e);
            }
        } else if (currentObject instanceof Map) {
            outValues.add(currentObject);
            collection = ((Map) currentObject).values();
        } else if (currentObject instanceof Collection) {
            collection = (Collection) currentObject;
        }
        if (collection != null) {
            for (Object fieldValue : collection) {
                if (fieldValue != null && !ParserConfig.isPrimitive2(fieldValue.getClass())) {
                    deepGetObjects(fieldValue, outValues);
                }
            }
            return;
        }
        throw new UnsupportedOperationException(currentClass.getName());
    }

    /* access modifiers changed from: protected */
    public void deepGetPropertyValues(Object currentObject, List<Object> outValues) {
        Class<?> currentClass = currentObject.getClass();
        JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentClass);
        Collection collection = null;
        if (beanSerializer != null) {
            try {
                collection = beanSerializer.getFieldValues(currentObject);
            } catch (Exception e) {
                throw new JSONPathException("jsonpath error, path " + this.path, e);
            }
        } else if (currentObject instanceof Map) {
            collection = ((Map) currentObject).values();
        } else if (currentObject instanceof Collection) {
            collection = (Collection) currentObject;
        }
        if (collection != null) {
            for (Object fieldValue : collection) {
                if (fieldValue == null || ParserConfig.isPrimitive2(fieldValue.getClass())) {
                    outValues.add(fieldValue);
                } else {
                    deepGetPropertyValues(fieldValue, outValues);
                }
            }
            return;
        }
        throw new UnsupportedOperationException(currentClass.getName());
    }

    static boolean eq(Object a, Object b) {
        if (a == b) {
            return true;
        }
        if (a == null || b == null) {
            return false;
        }
        if (a.getClass() == b.getClass()) {
            return a.equals(b);
        }
        if (!(a instanceof Number)) {
            return a.equals(b);
        }
        if (b instanceof Number) {
            return eqNotNull((Number) a, (Number) b);
        }
        return false;
    }

    static boolean eqNotNull(Number a, Number b) {
        Class clazzA = a.getClass();
        boolean isIntA = isInt(clazzA);
        Class clazzB = b.getClass();
        boolean isIntB = isInt(clazzB);
        if (a instanceof BigDecimal) {
            BigDecimal decimalA = (BigDecimal) a;
            if (isIntB) {
                return decimalA.equals(BigDecimal.valueOf(TypeUtils.longExtractValue(b)));
            }
        }
        if (isIntA) {
            if (isIntB) {
                if (a.longValue() == b.longValue()) {
                    return true;
                }
                return false;
            } else if (b instanceof BigInteger) {
                return BigInteger.valueOf(a.longValue()).equals((BigInteger) a);
            }
        }
        if (isIntB && (a instanceof BigInteger)) {
            return ((BigInteger) a).equals(BigInteger.valueOf(TypeUtils.longExtractValue(b)));
        }
        boolean isDoubleA = isDouble(clazzA);
        boolean isDoubleB = isDouble(clazzB);
        if (((!isDoubleA || !isDoubleB) && ((!isDoubleA || !isIntB) && (!isDoubleB || !isIntA))) || a.doubleValue() != b.doubleValue()) {
            return false;
        }
        return true;
    }

    protected static boolean isDouble(Class<?> clazzA) {
        return clazzA == Float.class || clazzA == Double.class;
    }

    protected static boolean isInt(Class<?> clazzA) {
        return clazzA == Byte.class || clazzA == Short.class || clazzA == Integer.class || clazzA == Long.class;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x002e  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x0048  */
    public Object getPropertyValue(Object currentObject, String propertyName, long propertyNameHash) {
        Object currentObject2;
        if (currentObject == null) {
            return null;
        }
        if (currentObject instanceof String) {
            try {
                currentObject2 = (JSONObject) JSON.parse((String) currentObject, this.parserConfig);
            } catch (Exception e) {
            }
            if (!(currentObject2 instanceof Map)) {
                Map map = (Map) currentObject2;
                Object val = map.get(propertyName);
                if (val != null) {
                    return val;
                }
                if (SIZE == propertyNameHash || LENGTH == propertyNameHash) {
                    return Integer.valueOf(map.size());
                }
                return val;
            }
            JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentObject2.getClass());
            if (beanSerializer != null) {
                try {
                    return beanSerializer.getFieldValue(currentObject2, propertyName, propertyNameHash, false);
                } catch (Exception e2) {
                    throw new JSONPathException("jsonpath error, path " + this.path + ", segement " + propertyName, e2);
                }
            } else if (currentObject2 instanceof List) {
                List list = (List) currentObject2;
                if (SIZE == propertyNameHash || LENGTH == propertyNameHash) {
                    return Integer.valueOf(list.size());
                }
                List<Object> fieldValues = null;
                for (int i = 0; i < list.size(); i++) {
                    Object obj = list.get(i);
                    if (obj == list) {
                        if (fieldValues == null) {
                            fieldValues = new JSONArray(list.size());
                        }
                        fieldValues.add(obj);
                    } else {
                        Object itemValue = getPropertyValue(obj, propertyName, propertyNameHash);
                        if (itemValue instanceof Collection) {
                            Collection collection = (Collection) itemValue;
                            if (fieldValues == null) {
                                fieldValues = new JSONArray(list.size());
                            }
                            fieldValues.addAll(collection);
                        } else if (itemValue != null || !this.ignoreNullValue) {
                            if (fieldValues == null) {
                                fieldValues = new JSONArray(list.size());
                            }
                            fieldValues.add(itemValue);
                        }
                    }
                }
                if (fieldValues == null) {
                    return Collections.emptyList();
                }
                return fieldValues;
            } else if (currentObject2 instanceof Object[]) {
                Object[] array = (Object[]) currentObject2;
                if (SIZE == propertyNameHash || LENGTH == propertyNameHash) {
                    return Integer.valueOf(array.length);
                }
                List<Object> fieldValues2 = new JSONArray(array.length);
                for (Object obj2 : array) {
                    if (obj2 == array) {
                        fieldValues2.add(obj2);
                    } else {
                        Object itemValue2 = getPropertyValue(obj2, propertyName, propertyNameHash);
                        if (itemValue2 instanceof Collection) {
                            fieldValues2.addAll((Collection) itemValue2);
                        } else if (itemValue2 != null || !this.ignoreNullValue) {
                            fieldValues2.add(itemValue2);
                        }
                    }
                }
                return fieldValues2;
            } else {
                if (currentObject2 instanceof Enum) {
                    Enum e3 = (Enum) currentObject2;
                    if (-4270347329889690746L == propertyNameHash) {
                        return e3.name();
                    }
                    if (-1014497654951707614L == propertyNameHash) {
                        return Integer.valueOf(e3.ordinal());
                    }
                }
                if (currentObject2 instanceof Calendar) {
                    Calendar e4 = (Calendar) currentObject2;
                    if (8963398325558730460L == propertyNameHash) {
                        return Integer.valueOf(e4.get(1));
                    }
                    if (-811277319855450459L == propertyNameHash) {
                        return Integer.valueOf(e4.get(2));
                    }
                    if (-3851359326990528739L == propertyNameHash) {
                        return Integer.valueOf(e4.get(5));
                    }
                    if (4647432019745535567L == propertyNameHash) {
                        return Integer.valueOf(e4.get(11));
                    }
                    if (6607618197526598121L == propertyNameHash) {
                        return Integer.valueOf(e4.get(12));
                    }
                    if (-6586085717218287427L == propertyNameHash) {
                        return Integer.valueOf(e4.get(13));
                    }
                }
                return null;
            }
        }
        currentObject2 = currentObject;
        if (!(currentObject2 instanceof Map)) {
        }
    }

    /* access modifiers changed from: protected */
    public void deepScan(Object currentObject, String propertyName, List<Object> results) {
        if (currentObject != null) {
            if (currentObject instanceof Map) {
                for (Map.Entry entry : ((Map) currentObject).entrySet()) {
                    Object val = entry.getValue();
                    if (propertyName.equals(entry.getKey())) {
                        if (val instanceof Collection) {
                            results.addAll((Collection) val);
                        } else {
                            results.add(val);
                        }
                    } else if (val != null && !ParserConfig.isPrimitive2(val.getClass())) {
                        deepScan(val, propertyName, results);
                    }
                }
            } else if (currentObject instanceof Collection) {
                for (Object next : (Collection) currentObject) {
                    if (!ParserConfig.isPrimitive2(next.getClass())) {
                        deepScan(next, propertyName, results);
                    }
                }
            } else {
                JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentObject.getClass());
                if (beanSerializer != null) {
                    try {
                        FieldSerializer fieldDeser = beanSerializer.getFieldSerializer(propertyName);
                        if (fieldDeser != null) {
                            try {
                                results.add(fieldDeser.getPropertyValueDirect(currentObject));
                            } catch (InvocationTargetException ex) {
                                throw new JSONException("getFieldValue error." + propertyName, ex);
                            } catch (IllegalAccessException ex2) {
                                throw new JSONException("getFieldValue error." + propertyName, ex2);
                            }
                        } else {
                            for (Object val2 : beanSerializer.getFieldValues(currentObject)) {
                                deepScan(val2, propertyName, results);
                            }
                        }
                    } catch (Exception e) {
                        throw new JSONPathException("jsonpath error, path " + this.path + ", segement " + propertyName, e);
                    }
                } else if (currentObject instanceof List) {
                    List list = (List) currentObject;
                    for (int i = 0; i < list.size(); i++) {
                        deepScan(list.get(i), propertyName, results);
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public void deepSet(Object currentObject, String propertyName, long propertyNameHash, Object value) {
        if (currentObject != null) {
            if (currentObject instanceof Map) {
                Map map = (Map) currentObject;
                if (map.containsKey(propertyName)) {
                    map.get(propertyName);
                    map.put(propertyName, value);
                    return;
                }
                for (Object val : map.values()) {
                    deepSet(val, propertyName, propertyNameHash, value);
                }
                return;
            }
            Class<?> currentClass = currentObject.getClass();
            JavaBeanDeserializer beanDeserializer = getJavaBeanDeserializer(currentClass);
            if (beanDeserializer != null) {
                try {
                    FieldDeserializer fieldDeser = beanDeserializer.getFieldDeserializer(propertyName);
                    if (fieldDeser != null) {
                        fieldDeser.setValue(currentObject, value);
                        return;
                    }
                    for (Object val2 : getJavaBeanSerializer(currentClass).getObjectFieldValues(currentObject)) {
                        deepSet(val2, propertyName, propertyNameHash, value);
                    }
                } catch (Exception e) {
                    throw new JSONPathException("jsonpath error, path " + this.path + ", segement " + propertyName, e);
                }
            } else if (currentObject instanceof List) {
                List list = (List) currentObject;
                for (int i = 0; i < list.size(); i++) {
                    deepSet(list.get(i), propertyName, propertyNameHash, value);
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public boolean setPropertyValue(Object parent, String name, long propertyNameHash, Object value) {
        if (parent instanceof Map) {
            ((Map) parent).put(name, value);
            return true;
        } else if (parent instanceof List) {
            for (Object element : (List) parent) {
                if (element != null) {
                    setPropertyValue(element, name, propertyNameHash, value);
                }
            }
            return true;
        } else {
            ObjectDeserializer deserializer = this.parserConfig.getDeserializer(parent.getClass());
            JavaBeanDeserializer beanDeserializer = null;
            if (deserializer instanceof JavaBeanDeserializer) {
                beanDeserializer = (JavaBeanDeserializer) deserializer;
            }
            if (beanDeserializer != null) {
                FieldDeserializer fieldDeserializer = beanDeserializer.getFieldDeserializer(propertyNameHash);
                if (fieldDeserializer == null) {
                    return false;
                }
                if (!(value == null || value.getClass() == fieldDeserializer.fieldInfo.fieldClass)) {
                    value = TypeUtils.cast(value, fieldDeserializer.fieldInfo.fieldType, this.parserConfig);
                }
                fieldDeserializer.setValue(parent, value);
                return true;
            }
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: protected */
    public boolean removePropertyValue(Object parent, String name, boolean deep) {
        boolean found = false;
        if (parent instanceof Map) {
            if (((Map) parent).remove(name) != null) {
                found = true;
            }
            if (deep) {
                for (Object item : ((Map) parent).values()) {
                    removePropertyValue(item, name, deep);
                }
            }
            return found;
        }
        ObjectDeserializer deserializer = this.parserConfig.getDeserializer(parent.getClass());
        JavaBeanDeserializer beanDeserializer = null;
        if (deserializer instanceof JavaBeanDeserializer) {
            beanDeserializer = (JavaBeanDeserializer) deserializer;
        }
        if (beanDeserializer != null) {
            FieldDeserializer fieldDeserializer = beanDeserializer.getFieldDeserializer(name);
            boolean found2 = false;
            if (fieldDeserializer != null) {
                fieldDeserializer.setValue(parent, (String) null);
                found2 = true;
            }
            if (deep) {
                for (Object item2 : getPropertyValues(parent)) {
                    if (item2 != null) {
                        removePropertyValue(item2, name, deep);
                    }
                }
            }
            return found2;
        } else if (deep) {
            return false;
        } else {
            throw new UnsupportedOperationException();
        }
    }

    /* access modifiers changed from: protected */
    public JavaBeanSerializer getJavaBeanSerializer(Class<?> currentClass) {
        ObjectSerializer serializer = this.serializeConfig.getObjectWriter(currentClass);
        if (serializer instanceof JavaBeanSerializer) {
            return (JavaBeanSerializer) serializer;
        }
        return null;
    }

    /* access modifiers changed from: protected */
    public JavaBeanDeserializer getJavaBeanDeserializer(Class<?> currentClass) {
        ObjectDeserializer deserializer = this.parserConfig.getDeserializer(currentClass);
        if (deserializer instanceof JavaBeanDeserializer) {
            return (JavaBeanDeserializer) deserializer;
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public int evalSize(Object currentObject) {
        if (currentObject == null) {
            return -1;
        }
        if (currentObject instanceof Collection) {
            return ((Collection) currentObject).size();
        }
        if (currentObject instanceof Object[]) {
            return ((Object[]) currentObject).length;
        }
        if (currentObject.getClass().isArray()) {
            return Array.getLength(currentObject);
        }
        if (currentObject instanceof Map) {
            int count = 0;
            for (Object value : ((Map) currentObject).values()) {
                if (value != null) {
                    count++;
                }
            }
            return count;
        }
        JavaBeanSerializer beanSerializer = getJavaBeanSerializer(currentObject.getClass());
        if (beanSerializer == null) {
            return -1;
        }
        try {
            return beanSerializer.getSize(currentObject);
        } catch (Exception e) {
            throw new JSONPathException("evalSize error : " + this.path, e);
        }
    }

    /* access modifiers changed from: package-private */
    public Set<?> evalKeySet(Object currentObject) {
        JavaBeanSerializer beanSerializer;
        if (currentObject == null) {
            return null;
        }
        if (currentObject instanceof Map) {
            return ((Map) currentObject).keySet();
        }
        if ((currentObject instanceof Collection) || (currentObject instanceof Object[]) || currentObject.getClass().isArray() || (beanSerializer = getJavaBeanSerializer(currentObject.getClass())) == null) {
            return null;
        }
        try {
            return beanSerializer.getFieldNames(currentObject);
        } catch (Exception e) {
            throw new JSONPathException("evalKeySet error : " + this.path, e);
        }
    }

    @Override // com.alibaba.fastjson.JSONAware
    public String toJSONString() {
        return JSON.toJSONString(this.path);
    }

    public static Object reserveToArray(Object object, String... paths) {
        JSONArray reserved = new JSONArray();
        if (paths == null || paths.length == 0) {
            return reserved;
        }
        for (String item : paths) {
            JSONPath path2 = compile(item);
            path2.init();
            reserved.add(path2.eval(object));
        }
        return reserved;
    }

    public static Object reserveToObject(Object object, String... paths) {
        Object value;
        if (paths == null || paths.length == 0) {
            return object;
        }
        JSONObject reserved = new JSONObject(true);
        for (String item : paths) {
            JSONPath path2 = compile(item);
            path2.init();
            Segment[] segmentArr = path2.segments;
            if ((segmentArr[segmentArr.length - 1] instanceof PropertySegment) && (value = path2.eval(object)) != null) {
                path2.set(reserved, value);
            }
        }
        return reserved;
    }
}
