package com.alibaba.fastjson.asm;

import io.dcloud.common.DHInterface.IApp;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class ClassReader {
    public final byte[] b;
    public final int header;
    private final int[] items;
    private final int maxStringLength;
    private boolean readAnnotations;
    private final String[] strings;

    public ClassReader(InputStream is, boolean readAnnotations2) throws IOException {
        int size;
        this.readAnnotations = readAnnotations2;
        ByteArrayOutputStream out = new ByteArrayOutputStream();
        byte[] buf = new byte[1024];
        while (true) {
            int len = is.read(buf);
            if (len == -1) {
                break;
            } else if (len > 0) {
                out.write(buf, 0, len);
            }
        }
        is.close();
        this.b = out.toByteArray();
        int[] iArr = new int[readUnsignedShort(8)];
        this.items = iArr;
        int n = iArr.length;
        this.strings = new String[n];
        int max = 0;
        int index = 10;
        int i = 1;
        while (i < n) {
            this.items[i] = index + 1;
            byte b2 = this.b[index];
            if (b2 == 1) {
                size = readUnsignedShort(index + 1) + 3;
                if (size > max) {
                    max = size;
                }
            } else if (b2 != 15) {
                if (!(b2 == 18 || b2 == 3 || b2 == 4)) {
                    if (b2 != 5 && b2 != 6) {
                        switch (b2) {
                            case 9:
                            case 10:
                            case 11:
                            case 12:
                                break;
                            default:
                                size = 3;
                                break;
                        }
                    } else {
                        size = 9;
                        i++;
                    }
                }
                size = 5;
            } else {
                size = 4;
            }
            index += size;
            i++;
        }
        this.maxStringLength = max;
        this.header = index;
    }

    public void accept(TypeCollector classVisitor) {
        char[] c = new char[this.maxStringLength];
        int anns = 0;
        if (this.readAnnotations) {
            int u = getAttributes();
            int i = readUnsignedShort(u);
            while (true) {
                if (i <= 0) {
                    break;
                } else if ("RuntimeVisibleAnnotations".equals(readUTF8(u + 2, c))) {
                    anns = u + 8;
                    break;
                } else {
                    u += readInt(u + 4) + 6;
                    i--;
                }
            }
        }
        int u2 = this.header;
        int len = readUnsignedShort(u2 + 6);
        int u3 = u2 + 8;
        for (int i2 = 0; i2 < len; i2++) {
            u3 += 2;
        }
        int v = u3 + 2;
        for (int i3 = readUnsignedShort(u3); i3 > 0; i3--) {
            v += 8;
            for (int j = readUnsignedShort(v + 6); j > 0; j--) {
                v += readInt(v + 2) + 6;
            }
        }
        int v2 = v + 2;
        for (int i4 = readUnsignedShort(v); i4 > 0; i4--) {
            v2 += 8;
            for (int j2 = readUnsignedShort(v2 + 6); j2 > 0; j2--) {
                v2 += readInt(v2 + 2) + 6;
            }
        }
        int v3 = v2 + 2;
        for (int i5 = readUnsignedShort(v2); i5 > 0; i5--) {
            v3 += readInt(v3 + 2) + 6;
        }
        if (anns != 0) {
            int v4 = anns + 2;
            for (int i6 = readUnsignedShort(anns); i6 > 0; i6--) {
                classVisitor.visitAnnotation(readUTF8(v4, c));
            }
        }
        int u4 = u3 + 2;
        for (int i7 = readUnsignedShort(u3); i7 > 0; i7--) {
            u4 += 8;
            for (int j3 = readUnsignedShort(u4 + 6); j3 > 0; j3--) {
                u4 += readInt(u4 + 2) + 6;
            }
        }
        int u5 = u4 + 2;
        for (int i8 = readUnsignedShort(u4); i8 > 0; i8--) {
            u5 = readMethod(classVisitor, c, u5);
        }
    }

    private int getAttributes() {
        int i = this.header;
        int u = i + 8 + (readUnsignedShort(i + 6) * 2);
        for (int i2 = readUnsignedShort(u); i2 > 0; i2--) {
            for (int j = readUnsignedShort(u + 8); j > 0; j--) {
                u += readInt(u + 12) + 6;
            }
            u += 8;
        }
        int u2 = u + 2;
        for (int i3 = readUnsignedShort(u2); i3 > 0; i3--) {
            for (int j2 = readUnsignedShort(u2 + 8); j2 > 0; j2--) {
                u2 += readInt(u2 + 12) + 6;
            }
            u2 += 8;
        }
        return u2 + 2;
    }

    /* JADX INFO: Multiple debug info for r7v4 int[]: [D('w' int), D('typeTable' int[])] */
    private int readMethod(TypeCollector classVisitor, char[] c, int u) {
        int access = readUnsignedShort(u);
        String name = readUTF8(u + 2, c);
        String desc = readUTF8(u + 4, c);
        int v = 0;
        int u2 = u + 8;
        for (int j = readUnsignedShort(u + 6); j > 0; j--) {
            String attrName = readUTF8(u2, c);
            int attrSize = readInt(u2 + 2);
            int u3 = u2 + 6;
            if (attrName.equals("Code")) {
                v = u3;
            }
            u2 = u3 + attrSize;
        }
        if (0 != 0) {
            int w = 0 + 2;
            for (int j2 = 0; j2 < readUnsignedShort(w); j2++) {
                w += 2;
            }
        }
        MethodCollector mv = classVisitor.visitMethod(access, name, desc);
        if (mv != null && v != 0) {
            int codeEnd = v + 8 + readInt(v + 4);
            int v2 = codeEnd + 2;
            for (int j3 = readUnsignedShort(codeEnd); j3 > 0; j3--) {
                v2 += 8;
            }
            int varTable = 0;
            int varTypeTable = 0;
            int j4 = readUnsignedShort(v2);
            int v3 = v2 + 2;
            while (j4 > 0) {
                String attrName2 = readUTF8(v3, c);
                if (attrName2.equals("LocalVariableTable")) {
                    varTable = v3 + 6;
                } else if (attrName2.equals("LocalVariableTypeTable")) {
                    varTypeTable = v3 + 6;
                }
                v3 += readInt(v3 + 2) + 6;
                j4--;
                access = access;
                name = name;
            }
            if (varTable != 0) {
                if (varTypeTable != 0) {
                    int k = readUnsignedShort(varTypeTable) * 3;
                    int w2 = varTypeTable + 2;
                    int[] typeTable = new int[k];
                    while (k > 0) {
                        int k2 = k - 1;
                        typeTable[k2] = w2 + 6;
                        int k3 = k2 - 1;
                        typeTable[k3] = readUnsignedShort(w2 + 8);
                        k = k3 - 1;
                        typeTable[k] = readUnsignedShort(w2);
                        w2 += 10;
                        desc = desc;
                    }
                }
                int w3 = varTable + 2;
                for (int k4 = readUnsignedShort(varTable); k4 > 0; k4--) {
                    mv.visitLocalVariable(readUTF8(w3 + 4, c), readUnsignedShort(w3 + 8));
                    w3 += 10;
                }
            }
        }
        return u2;
    }

    private int readUnsignedShort(int index) {
        byte[] b2 = this.b;
        return ((b2[index] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (b2[index + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    private int readInt(int index) {
        byte[] b2 = this.b;
        return ((b2[index] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 24) | ((b2[index + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((b2[index + 2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (b2[index + 3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    private String readUTF8(int index, char[] buf) {
        int item = readUnsignedShort(index);
        String[] strArr = this.strings;
        String s = strArr[item];
        if (s != null) {
            return s;
        }
        int index2 = this.items[item];
        String readUTF = readUTF(index2 + 2, readUnsignedShort(index2), buf);
        strArr[item] = readUTF;
        return readUTF;
    }

    /* JADX INFO: Multiple debug info for r10v2 byte: [D('index' int), D('c' int)] */
    private String readUTF(int c, int utfLen, char[] buf) {
        int endIndex = c + utfLen;
        byte[] b2 = this.b;
        int st = 0;
        int st2 = 0;
        char cc = 0;
        while (c < endIndex) {
            int index = c + 1;
            byte b3 = b2[c];
            if (st2 == 0) {
                int c2 = b3 & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
                if (c2 < 128) {
                    buf[st] = (char) c2;
                    st++;
                } else if (c2 >= 224 || c2 <= 191) {
                    cc = (char) (c2 & 15);
                    st2 = 2;
                } else {
                    cc = (char) (c2 & 31);
                    st2 = 1;
                }
            } else if (st2 == 1) {
                buf[st] = (char) ((cc << 6) | (b3 & 63));
                st2 = 0;
                st++;
            } else if (st2 == 2) {
                cc = (char) ((cc << 6) | (b3 & 63));
                st2 = 1;
            }
            c = index;
        }
        return new String(buf, 0, st);
    }
}
