package com.alibaba.fastjson.parser;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPath;
import com.alibaba.fastjson.JSONPathException;
import com.alibaba.fastjson.parser.deserializer.ExtraProcessable;
import com.alibaba.fastjson.parser.deserializer.ExtraProcessor;
import com.alibaba.fastjson.parser.deserializer.ExtraTypeProvider;
import com.alibaba.fastjson.parser.deserializer.FieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.FieldTypeResolver;
import com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.deserializer.MapDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.parser.deserializer.PropertyProcessable;
import com.alibaba.fastjson.parser.deserializer.ResolveFieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.ThrowableDeserializer;
import com.alibaba.fastjson.serializer.BeanContext;
import com.alibaba.fastjson.serializer.IntegerCodec;
import com.alibaba.fastjson.serializer.LongCodec;
import com.alibaba.fastjson.serializer.SerializeConfig;
import com.alibaba.fastjson.serializer.StringCodec;
import com.alibaba.fastjson.util.TypeUtils;
import com.igexin.push.core.b;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.io.Closeable;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;

public class DefaultJSONParser implements Closeable {
    public static final int NONE = 0;
    public static final int NeedToResolve = 1;
    public static final int TypeNameRedirect = 2;
    private static final Set<Class<?>> primitiveClasses = new HashSet();
    private String[] autoTypeAccept;
    private boolean autoTypeEnable;
    protected ParserConfig config;
    protected ParseContext context;
    private ParseContext[] contextArray;
    private int contextArrayIndex;
    private DateFormat dateFormat;
    private String dateFormatPattern;
    private List<ExtraProcessor> extraProcessors;
    private List<ExtraTypeProvider> extraTypeProviders;
    protected FieldTypeResolver fieldTypeResolver;
    public final Object input;
    protected transient BeanContext lastBeanContext;
    public final JSONLexer lexer;
    private int objectKeyLevel;
    public int resolveStatus;
    private List<ResolveTask> resolveTaskList;
    public final SymbolTable symbolTable;

    static {
        primitiveClasses.addAll(Arrays.asList(Boolean.TYPE, Byte.TYPE, Short.TYPE, Integer.TYPE, Long.TYPE, Float.TYPE, Double.TYPE, Boolean.class, Byte.class, Short.class, Integer.class, Long.class, Float.class, Double.class, BigInteger.class, BigDecimal.class, String.class));
    }

    public String getDateFomartPattern() {
        return this.dateFormatPattern;
    }

    public DateFormat getDateFormat() {
        if (this.dateFormat == null) {
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat(this.dateFormatPattern, this.lexer.getLocale());
            this.dateFormat = simpleDateFormat;
            simpleDateFormat.setTimeZone(this.lexer.getTimeZone());
        }
        return this.dateFormat;
    }

    public void setDateFormat(String dateFormat2) {
        this.dateFormatPattern = dateFormat2;
        this.dateFormat = null;
    }

    public void setDateFomrat(DateFormat dateFormat2) {
        setDateFormat(dateFormat2);
    }

    public void setDateFormat(DateFormat dateFormat2) {
        this.dateFormat = dateFormat2;
    }

    public DefaultJSONParser(String input2) {
        this(input2, ParserConfig.getGlobalInstance(), JSON.DEFAULT_PARSER_FEATURE);
    }

    public DefaultJSONParser(String input2, ParserConfig config2) {
        this(input2, new JSONScanner(input2, JSON.DEFAULT_PARSER_FEATURE), config2);
    }

    public DefaultJSONParser(String input2, ParserConfig config2, int features) {
        this(input2, new JSONScanner(input2, features), config2);
    }

    public DefaultJSONParser(char[] input2, int length, ParserConfig config2, int features) {
        this(input2, new JSONScanner(input2, length, features), config2);
    }

    public DefaultJSONParser(JSONLexer lexer2) {
        this(lexer2, ParserConfig.getGlobalInstance());
    }

    public DefaultJSONParser(JSONLexer lexer2, ParserConfig config2) {
        this((Object) null, lexer2, config2);
    }

    public DefaultJSONParser(Object input2, JSONLexer lexer2, ParserConfig config2) {
        this.dateFormatPattern = JSON.DEFFAULT_DATE_FORMAT;
        this.contextArrayIndex = 0;
        this.resolveStatus = 0;
        this.extraTypeProviders = null;
        this.extraProcessors = null;
        this.fieldTypeResolver = null;
        this.objectKeyLevel = 0;
        this.autoTypeAccept = null;
        this.lexer = lexer2;
        this.input = input2;
        this.config = config2;
        this.symbolTable = config2.symbolTable;
        int ch = lexer2.getCurrent();
        if (ch == 123) {
            lexer2.next();
            ((JSONLexerBase) lexer2).token = 12;
        } else if (ch == 91) {
            lexer2.next();
            ((JSONLexerBase) lexer2).token = 14;
        } else {
            lexer2.nextToken();
        }
    }

    public SymbolTable getSymbolTable() {
        return this.symbolTable;
    }

    public String getInput() {
        Object obj = this.input;
        if (obj instanceof char[]) {
            return new String((char[]) this.input);
        }
        return obj.toString();
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:155:0x02f1 */
    /* JADX DEBUG: Multi-variable search result rejected for r3v12, resolved type: java.lang.Object */
    /* JADX DEBUG: Multi-variable search result rejected for r20v0, resolved type: java.lang.Object */
    /* JADX DEBUG: Multi-variable search result rejected for r0v115, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARNING: Removed duplicated region for block: B:407:0x019d A[SYNTHETIC] */
    public final Object parseObject(Map object, Object fieldName) {
        Throwable th;
        char ch;
        String str;
        String str2;
        Number number;
        Map input2;
        Map map;
        Object[] objArr;
        Class<?> clazz;
        Class<?> clazz2;
        String str3;
        Object obj = fieldName;
        String str4 = "parse number key error";
        JSONLexer lexer2 = this.lexer;
        if (lexer2.token() == 8) {
            lexer2.nextToken();
            return null;
        } else if (lexer2.token() == 13) {
            lexer2.nextToken();
            return object;
        } else if (lexer2.token() == 4 && lexer2.stringVal().length() == 0) {
            lexer2.nextToken();
            return object;
        } else if (lexer2.token() == 12 || lexer2.token() == 16) {
            ParseContext context2 = this.context;
            try {
                boolean isJsonObjectMap = object instanceof JSONObject;
                Map<String, Object> map2 = isJsonObjectMap ? ((JSONObject) object).getInnerMap() : object;
                ParseContext context3 = context2;
                boolean setContextFlag = false;
                while (true) {
                    try {
                        lexer2.skipWhitespace();
                        char ch2 = lexer2.getCurrent();
                        if (lexer2.isEnabled(Feature.AllowArbitraryCommas)) {
                            while (ch2 == ',') {
                                lexer2.next();
                                lexer2.skipWhitespace();
                                ch2 = lexer2.getCurrent();
                            }
                            ch = ch2;
                        } else {
                            ch = ch2;
                        }
                        boolean isObjectKey = false;
                        if (ch == '\"') {
                            str = lexer2.scanSymbol(this.symbolTable, Operators.QUOTE);
                            lexer2.skipWhitespace();
                            if (lexer2.getCurrent() != ':') {
                                throw new JSONException("expect ':' at " + lexer2.pos() + ", name " + ((Object) str));
                            }
                        } else if (ch == '}') {
                            lexer2.next();
                            lexer2.resetStringPosition();
                            lexer2.nextToken();
                            if (!setContextFlag) {
                                if (this.context != null && obj == this.context.fieldName && object == this.context.object) {
                                    context3 = this.context;
                                } else {
                                    ParseContext contextR = setContext(object, fieldName);
                                    if (context3 == null) {
                                        context3 = contextR;
                                    }
                                }
                            }
                            setContext(context3);
                            return object;
                        } else if (ch == '\'') {
                            if (lexer2.isEnabled(Feature.AllowSingleQuotes)) {
                                str = lexer2.scanSymbol(this.symbolTable, Operators.SINGLE_QUOTE);
                                lexer2.skipWhitespace();
                                if (lexer2.getCurrent() != ':') {
                                    throw new JSONException("expect ':' at " + lexer2.pos());
                                }
                            } else {
                                throw new JSONException("syntax error");
                            }
                        } else if (ch == 26) {
                            throw new JSONException("syntax error");
                        } else if (ch == ',') {
                            throw new JSONException("syntax error");
                        } else if ((ch >= '0' && ch <= '9') || ch == '-') {
                            lexer2.resetStringPosition();
                            lexer2.scanNumber();
                            try {
                                if (lexer2.token() == 2) {
                                    str3 = lexer2.integerValue();
                                } else {
                                    str3 = lexer2.decimalValue(true);
                                }
                                if (!lexer2.isEnabled(Feature.NonStringKeyAsString)) {
                                    if (!isJsonObjectMap) {
                                        str = str3;
                                        if (lexer2.getCurrent() != ':') {
                                            throw new JSONException(str4 + lexer2.info());
                                        }
                                    }
                                }
                                str = str3.toString();
                                if (lexer2.getCurrent() != ':') {
                                }
                            } catch (NumberFormatException e) {
                                throw new JSONException(str4 + lexer2.info());
                            }
                        } else if (ch == '{' || ch == '[') {
                            int i = this.objectKeyLevel;
                            this.objectKeyLevel = i + 1;
                            if (i <= 512) {
                                lexer2.nextToken();
                                str = parse();
                                isObjectKey = true;
                            } else {
                                throw new JSONException("object key level > 512");
                            }
                        } else if (lexer2.isEnabled(Feature.AllowUnQuotedFieldNames)) {
                            str = lexer2.scanSymbolUnQuoted(this.symbolTable);
                            lexer2.skipWhitespace();
                            char ch3 = lexer2.getCurrent();
                            if (ch3 != ':') {
                                throw new JSONException("expect ':' at " + lexer2.pos() + ", actual " + ch3);
                            }
                        } else {
                            throw new JSONException("syntax error");
                        }
                        if (!isObjectKey) {
                            lexer2.next();
                            lexer2.skipWhitespace();
                        }
                        char ch4 = lexer2.getCurrent();
                        lexer2.resetStringPosition();
                        if (str == JSON.DEFAULT_TYPE_KEY) {
                            if (!lexer2.isEnabled(Feature.DisableSpecialKeyDetect)) {
                                String typeName = lexer2.scanSymbol(this.symbolTable, Operators.QUOTE);
                                if (!lexer2.isEnabled(Feature.IgnoreAutoType)) {
                                    Class<?> clazz3 = null;
                                    if (object != null && object.getClass().getName().equals(typeName)) {
                                        clazz = object.getClass();
                                    } else if ("java.util.HashMap".equals(typeName)) {
                                        clazz = HashMap.class;
                                    } else if ("java.util.LinkedHashMap".equals(typeName)) {
                                        clazz = LinkedHashMap.class;
                                    } else {
                                        boolean allDigits = true;
                                        int i2 = 0;
                                        while (true) {
                                            if (i2 >= typeName.length()) {
                                                clazz2 = clazz3;
                                                break;
                                            }
                                            char c = typeName.charAt(i2);
                                            clazz2 = clazz3;
                                            if (c < '0' || c > '9') {
                                                allDigits = false;
                                            } else {
                                                i2++;
                                                clazz3 = clazz2;
                                            }
                                        }
                                        if (!allDigits) {
                                            clazz = this.config.checkAutoType(typeName, null, lexer2.getFeatures());
                                        } else {
                                            clazz = clazz2;
                                        }
                                    }
                                    if (clazz == null) {
                                        map2.put(JSON.DEFAULT_TYPE_KEY, typeName);
                                    } else {
                                        lexer2.nextToken(16);
                                        if (lexer2.token() == 13) {
                                            lexer2.nextToken(16);
                                            Object instance = null;
                                            try {
                                                if (this.config.getDeserializer(clazz) instanceof JavaBeanDeserializer) {
                                                    instance = TypeUtils.cast((Object) object, (Class) clazz, this.config);
                                                }
                                                if (instance == null) {
                                                    if (clazz == Cloneable.class) {
                                                        instance = new HashMap();
                                                    } else if ("java.util.Collections$EmptyMap".equals(typeName)) {
                                                        instance = Collections.emptyMap();
                                                    } else if ("java.util.Collections$UnmodifiableMap".equals(typeName)) {
                                                        instance = Collections.unmodifiableMap(new HashMap());
                                                    } else {
                                                        instance = clazz.newInstance();
                                                    }
                                                }
                                                setContext(context3);
                                                return instance;
                                            } catch (Exception e2) {
                                                throw new JSONException("create instance error", e2);
                                            }
                                        } else {
                                            setResolveStatus(2);
                                            if (this.context != null && obj != null && !(obj instanceof Integer) && !(this.context.fieldName instanceof Integer)) {
                                                popContext();
                                            }
                                            if (object.size() > 0) {
                                                Object newObj = TypeUtils.cast((Object) object, (Class) clazz, this.config);
                                                setResolveStatus(0);
                                                parseObject(newObj);
                                                setContext(context3);
                                                return newObj;
                                            }
                                            ObjectDeserializer deserializer = this.config.getDeserializer(clazz);
                                            Class deserClass = deserializer.getClass();
                                            if (JavaBeanDeserializer.class.isAssignableFrom(deserClass) && deserClass != JavaBeanDeserializer.class && deserClass != ThrowableDeserializer.class) {
                                                setResolveStatus(0);
                                            } else if (deserializer instanceof MapDeserializer) {
                                                setResolveStatus(0);
                                            }
                                            Object obj2 = deserializer.deserialze(this, clazz, obj);
                                            setContext(context3);
                                            return obj2;
                                        }
                                    }
                                }
                            }
                        }
                        if (str == "$ref" && context3 != null) {
                            if (object == null || object.size() == 0) {
                                if (!lexer2.isEnabled(Feature.DisableSpecialKeyDetect)) {
                                    lexer2.nextToken(4);
                                    if (lexer2.token() == 4) {
                                        String ref = lexer2.stringVal();
                                        lexer2.nextToken(13);
                                        if (lexer2.token() == 16) {
                                            map2.put(str, ref);
                                        } else {
                                            Object refValue = null;
                                            if ("@".equals(ref)) {
                                                if (this.context != null) {
                                                    ParseContext thisContext = this.context;
                                                    Object thisObj = thisContext.object;
                                                    if ((thisObj instanceof Object[]) || (thisObj instanceof Collection)) {
                                                        refValue = thisObj;
                                                    } else if (thisContext.parent != null) {
                                                        refValue = thisContext.parent.object;
                                                    }
                                                }
                                            } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(ref)) {
                                                if (context3.object != null) {
                                                    refValue = context3.object;
                                                } else {
                                                    addResolveTask(new ResolveTask(context3, ref));
                                                    setResolveStatus(1);
                                                }
                                            } else if (Operators.DOLLAR_STR.equals(ref)) {
                                                ParseContext rootContext = context3;
                                                while (rootContext.parent != null) {
                                                    rootContext = rootContext.parent;
                                                }
                                                if (rootContext.object != null) {
                                                    refValue = rootContext.object;
                                                } else {
                                                    addResolveTask(new ResolveTask(rootContext, ref));
                                                    setResolveStatus(1);
                                                }
                                            } else if (JSONPath.compile(ref).isRef()) {
                                                addResolveTask(new ResolveTask(context3, ref));
                                                setResolveStatus(1);
                                            } else {
                                                refValue = new JSONObject().fluentPut("$ref", ref);
                                            }
                                            if (lexer2.token() == 13) {
                                                lexer2.nextToken(16);
                                                setContext(context3);
                                                return refValue;
                                            }
                                            throw new JSONException("syntax error, " + lexer2.info());
                                        }
                                    } else {
                                        throw new JSONException("illegal ref, " + JSONToken.name(lexer2.token()));
                                    }
                                }
                            }
                        }
                        if (!setContextFlag) {
                            if (this.context != null && obj == this.context.fieldName && object == this.context.object) {
                                context3 = this.context;
                            } else {
                                ParseContext contextR2 = setContext(object, fieldName);
                                if (context3 == null) {
                                    context3 = contextR2;
                                }
                                setContextFlag = true;
                            }
                        }
                        if (object.getClass() == JSONObject.class && str == null) {
                            str = b.m;
                        }
                        if (ch4 == '\"') {
                            lexer2.scanString();
                            String strValue = lexer2.stringVal();
                            number = strValue;
                            if (lexer2.isEnabled(Feature.AllowISO8601DateFormat)) {
                                JSONScanner iso8601Lexer = new JSONScanner(strValue);
                                if (iso8601Lexer.scanISO8601DateIfMatch()) {
                                    number = iso8601Lexer.getCalendar().getTime();
                                }
                                iso8601Lexer.close();
                            }
                            map2.put(str, number);
                        } else if ((ch4 < '0' || ch4 > '9') && ch4 != '-') {
                            if (ch4 == '[') {
                                lexer2.nextToken();
                                JSONArray list = new JSONArray();
                                boolean z = obj != null && fieldName.getClass() == Integer.class;
                                if (obj == null) {
                                    setContext(context3);
                                }
                                parseArray(list, str);
                                if (lexer2.isEnabled(Feature.UseObjectArray)) {
                                    objArr = list.toArray();
                                } else {
                                    objArr = list;
                                }
                                map2.put(str, objArr);
                                if (lexer2.token() == 13) {
                                    lexer2.nextToken();
                                    setContext(context3);
                                    return object;
                                } else if (lexer2.token() == 16) {
                                    str2 = str4;
                                } else {
                                    throw new JSONException("syntax error");
                                }
                            } else if (ch4 == '{') {
                                lexer2.nextToken();
                                boolean parentIsArray = obj != null && fieldName.getClass() == Integer.class;
                                if (lexer2.isEnabled(Feature.CustomMapDeserializer)) {
                                    MapDeserializer mapDeserializer = (MapDeserializer) this.config.getDeserializer(Map.class);
                                    if ((lexer2.getFeatures() & Feature.OrderedField.mask) != 0) {
                                        map = mapDeserializer.createMap(Map.class, lexer2.getFeatures());
                                    } else {
                                        map = mapDeserializer.createMap(Map.class);
                                    }
                                    input2 = map;
                                } else {
                                    input2 = new JSONObject(lexer2.isEnabled(Feature.OrderedField));
                                }
                                ParseContext ctxLocal = null;
                                if (!parentIsArray) {
                                    ctxLocal = setContext(this.context, input2, str);
                                }
                                Map map3 = null;
                                boolean objParsed = false;
                                if (this.fieldTypeResolver != null) {
                                    str2 = str4;
                                    Type fieldType = this.fieldTypeResolver.resolve(object, str != null ? str.toString() : null);
                                    if (fieldType != null) {
                                        map3 = this.config.getDeserializer(fieldType).deserialze(this, fieldType, str);
                                        objParsed = true;
                                    }
                                } else {
                                    str2 = str4;
                                }
                                if (!objParsed) {
                                    map3 = parseObject(input2, str);
                                }
                                if (!(ctxLocal == null || input2 == map3)) {
                                    ctxLocal.object = object;
                                }
                                if (str != null) {
                                    checkMapResolve(object, str.toString());
                                }
                                map2.put(str, map3);
                                if (parentIsArray) {
                                    setContext(map3, str);
                                }
                                if (lexer2.token() == 13) {
                                    lexer2.nextToken();
                                    setContext(context3);
                                    setContext(context3);
                                    return object;
                                } else if (lexer2.token() != 16) {
                                    throw new JSONException("syntax error, " + lexer2.tokenName());
                                } else if (parentIsArray) {
                                    popContext();
                                } else {
                                    setContext(context3);
                                }
                            } else {
                                str2 = str4;
                                lexer2.nextToken();
                                map2.put(str, parse());
                                if (lexer2.token() == 13) {
                                    lexer2.nextToken();
                                    setContext(context3);
                                    return object;
                                } else if (lexer2.token() != 16) {
                                    throw new JSONException("syntax error, position at " + lexer2.pos() + ", name " + ((Object) str));
                                }
                            }
                            obj = fieldName;
                            str4 = str2;
                        } else {
                            lexer2.scanNumber();
                            if (lexer2.token() == 2) {
                                number = lexer2.integerValue();
                            } else {
                                number = lexer2.decimalValue(lexer2.isEnabled(Feature.UseBigDecimal));
                            }
                            map2.put(str, number);
                        }
                        lexer2.skipWhitespace();
                        char ch5 = lexer2.getCurrent();
                        if (ch5 == ',') {
                            lexer2.next();
                            str2 = str4;
                            obj = fieldName;
                            str4 = str2;
                        } else if (ch5 == '}') {
                            lexer2.next();
                            lexer2.resetStringPosition();
                            lexer2.nextToken();
                            setContext(number, str);
                            setContext(context3);
                            return object;
                        } else {
                            throw new JSONException("syntax error, position at " + lexer2.pos() + ", name " + ((Object) str));
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        context2 = context3;
                        setContext(context2);
                        throw th;
                    }
                }
            } catch (Throwable th3) {
                th = th3;
                setContext(context2);
                throw th;
            }
        } else {
            throw new JSONException("syntax error, expect {, actual " + lexer2.tokenName() + ", " + lexer2.info());
        }
    }

    public ParserConfig getConfig() {
        return this.config;
    }

    public void setConfig(ParserConfig config2) {
        this.config = config2;
    }

    public <T> T parseObject(Class<T> clazz) {
        return (T) parseObject(clazz, (Object) null);
    }

    public <T> T parseObject(Type type) {
        return (T) parseObject(type, (Object) null);
    }

    public <T> T parseObject(Type type, Object fieldName) {
        int token = this.lexer.token();
        if (token == 8) {
            this.lexer.nextToken();
            return (T) TypeUtils.optionalEmpty(type);
        }
        if (token == 4) {
            if (type == byte[].class) {
                T t = (T) this.lexer.bytesValue();
                this.lexer.nextToken();
                return t;
            } else if (type == char[].class) {
                String strVal = this.lexer.stringVal();
                this.lexer.nextToken();
                return (T) strVal.toCharArray();
            }
        }
        ObjectDeserializer deserializer = this.config.getDeserializer(type);
        try {
            if (deserializer.getClass() != JavaBeanDeserializer.class) {
                return (T) deserializer.deserialze(this, type, fieldName);
            }
            if (this.lexer.token() != 12) {
                if (this.lexer.token() != 14) {
                    throw new JSONException("syntax error,expect start with { or [,but actually start with " + this.lexer.tokenName());
                }
            }
            return (T) ((JavaBeanDeserializer) deserializer).deserialze(this, type, fieldName, 0);
        } catch (JSONException e) {
            throw e;
        } catch (Throwable e2) {
            throw new JSONException(e2.getMessage(), e2);
        }
    }

    public <T> List<T> parseArray(Class<T> clazz) {
        List<T> array = new ArrayList<>();
        parseArray((Class<?>) clazz, (Collection) array);
        return array;
    }

    public void parseArray(Class<?> clazz, Collection array) {
        parseArray((Type) clazz, array);
    }

    public void parseArray(Type type, Collection array) {
        parseArray(type, array, null);
    }

    /* JADX INFO: finally extract failed */
    public void parseArray(Type type, Collection array, Object fieldName) {
        ObjectDeserializer deserializer;
        Object val;
        String value;
        int token = this.lexer.token();
        if (token == 21 || token == 22) {
            this.lexer.nextToken();
            token = this.lexer.token();
        }
        if (token == 14) {
            if (Integer.TYPE == type) {
                deserializer = IntegerCodec.instance;
                this.lexer.nextToken(2);
            } else if (String.class == type) {
                deserializer = StringCodec.instance;
                this.lexer.nextToken(4);
            } else {
                deserializer = this.config.getDeserializer(type);
                this.lexer.nextToken(deserializer.getFastMatchToken());
            }
            ParseContext context2 = this.context;
            setContext(array, fieldName);
            int i = 0;
            while (true) {
                try {
                    if (this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                        while (this.lexer.token() == 16) {
                            this.lexer.nextToken();
                        }
                    }
                    if (this.lexer.token() == 15) {
                        setContext(context2);
                        this.lexer.nextToken(16);
                        return;
                    }
                    if (Integer.TYPE == type) {
                        array.add(IntegerCodec.instance.deserialze(this, null, null));
                    } else if (String.class == type) {
                        if (this.lexer.token() == 4) {
                            value = this.lexer.stringVal();
                            this.lexer.nextToken(16);
                        } else {
                            Object obj = parse();
                            if (obj == null) {
                                value = null;
                            } else {
                                value = obj.toString();
                            }
                        }
                        array.add(value);
                    } else {
                        if (this.lexer.token() == 8) {
                            this.lexer.nextToken();
                            val = null;
                        } else {
                            val = deserializer.deserialze(this, type, Integer.valueOf(i));
                        }
                        array.add(val);
                        checkListResolve(array);
                    }
                    if (this.lexer.token() == 16) {
                        this.lexer.nextToken(deserializer.getFastMatchToken());
                    }
                    i++;
                } catch (Throwable th) {
                    setContext(context2);
                    throw th;
                }
            }
        } else {
            throw new JSONException("field " + fieldName + " expect '[', but " + JSONToken.name(token) + ", " + this.lexer.info());
        }
    }

    /* JADX INFO: Multiple debug info for r11v4 java.lang.reflect.Type: [D('type' java.lang.reflect.Type), D('value' java.lang.Object)] */
    public Object[] parseArray(Type[] types) {
        String value;
        Class<?> clazz;
        Object obj = null;
        int i = 8;
        if (this.lexer.token() == 8) {
            this.lexer.nextToken(16);
            return null;
        }
        int i2 = 14;
        if (this.lexer.token() == 14) {
            Object[] list = new Object[types.length];
            if (types.length == 0) {
                this.lexer.nextToken(15);
                if (this.lexer.token() == 15) {
                    this.lexer.nextToken(16);
                    return new Object[0];
                }
                throw new JSONException("syntax error");
            }
            this.lexer.nextToken(2);
            int i3 = 0;
            while (i3 < types.length) {
                if (this.lexer.token() == i) {
                    value = null;
                    this.lexer.nextToken(16);
                } else {
                    Type type = types[i3];
                    if (type == Integer.TYPE || type == Integer.class) {
                        if (this.lexer.token() == 2) {
                            Integer valueOf = Integer.valueOf(this.lexer.intValue());
                            this.lexer.nextToken(16);
                            value = valueOf;
                        } else {
                            value = TypeUtils.cast(parse(), type, this.config);
                        }
                    } else if (type != String.class) {
                        boolean isArray = false;
                        Class<?> componentType = null;
                        if (i3 == types.length - 1 && (type instanceof Class) && !(((clazz = (Class) type) == byte[].class || clazz == char[].class) && this.lexer.token() == 4)) {
                            isArray = clazz.isArray();
                            componentType = clazz.getComponentType();
                        }
                        if (!isArray || this.lexer.token() == i2) {
                            value = this.config.getDeserializer(type).deserialze(this, type, Integer.valueOf(i3));
                        } else {
                            List<Object> varList = new ArrayList<>();
                            ObjectDeserializer deserializer = this.config.getDeserializer(componentType);
                            int fastMatch = deserializer.getFastMatchToken();
                            if (this.lexer.token() != 15) {
                                while (true) {
                                    varList.add(deserializer.deserialze(this, type, obj));
                                    if (this.lexer.token() != 16) {
                                        break;
                                    }
                                    this.lexer.nextToken(fastMatch);
                                    obj = null;
                                }
                                if (this.lexer.token() != 15) {
                                    throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
                                }
                            }
                            value = TypeUtils.cast(varList, type, this.config);
                        }
                    } else if (this.lexer.token() == 4) {
                        String stringVal = this.lexer.stringVal();
                        this.lexer.nextToken(16);
                        value = stringVal;
                    } else {
                        value = TypeUtils.cast(parse(), type, this.config);
                    }
                }
                list[i3] = value;
                if (this.lexer.token() == 15) {
                    break;
                } else if (this.lexer.token() == 16) {
                    if (i3 == types.length - 1) {
                        this.lexer.nextToken(15);
                    } else {
                        this.lexer.nextToken(2);
                    }
                    i3++;
                    obj = null;
                    i = 8;
                    i2 = 14;
                } else {
                    throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
                }
            }
            if (this.lexer.token() == 15) {
                this.lexer.nextToken(16);
                return list;
            }
            throw new JSONException("syntax error");
        }
        throw new JSONException("syntax error : " + this.lexer.tokenName());
    }

    public void parseObject(Object object) {
        Object fieldValue;
        Class<?> clazz = object.getClass();
        JavaBeanDeserializer beanDeser = null;
        ObjectDeserializer deserializer = this.config.getDeserializer(clazz);
        if (deserializer instanceof JavaBeanDeserializer) {
            beanDeser = (JavaBeanDeserializer) deserializer;
        }
        if (this.lexer.token() == 12 || this.lexer.token() == 16) {
            while (true) {
                String key = this.lexer.scanSymbol(this.symbolTable);
                if (key == null) {
                    if (this.lexer.token() == 13) {
                        this.lexer.nextToken(16);
                        return;
                    } else if (this.lexer.token() == 16 && this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                    }
                }
                FieldDeserializer fieldDeser = null;
                if (beanDeser != null) {
                    fieldDeser = beanDeser.getFieldDeserializer(key);
                }
                if (fieldDeser != null) {
                    Class<?> fieldClass = fieldDeser.fieldInfo.fieldClass;
                    Type fieldType = fieldDeser.fieldInfo.fieldType;
                    if (fieldClass == Integer.TYPE) {
                        this.lexer.nextTokenWithColon(2);
                        fieldValue = IntegerCodec.instance.deserialze(this, fieldType, null);
                    } else if (fieldClass == String.class) {
                        this.lexer.nextTokenWithColon(4);
                        fieldValue = StringCodec.deserialze(this);
                    } else if (fieldClass == Long.TYPE) {
                        this.lexer.nextTokenWithColon(2);
                        fieldValue = LongCodec.instance.deserialze(this, fieldType, null);
                    } else {
                        ObjectDeserializer fieldValueDeserializer = this.config.getDeserializer(fieldClass, fieldType);
                        this.lexer.nextTokenWithColon(fieldValueDeserializer.getFastMatchToken());
                        fieldValue = fieldValueDeserializer.deserialze(this, fieldType, null);
                    }
                    fieldDeser.setValue(object, fieldValue);
                    if (this.lexer.token() != 16 && this.lexer.token() == 13) {
                        this.lexer.nextToken(16);
                        return;
                    }
                } else if (this.lexer.isEnabled(Feature.IgnoreNotMatch)) {
                    this.lexer.nextTokenWithColon();
                    parse();
                    if (this.lexer.token() == 13) {
                        this.lexer.nextToken();
                        return;
                    }
                } else {
                    throw new JSONException("setter not found, class " + clazz.getName() + ", property " + key);
                }
            }
        } else {
            throw new JSONException("syntax error, expect {, actual " + this.lexer.tokenName());
        }
    }

    public Object parseArrayWithType(Type collectionType) {
        if (this.lexer.token() == 8) {
            this.lexer.nextToken();
            return null;
        }
        Type[] actualTypes = ((ParameterizedType) collectionType).getActualTypeArguments();
        if (actualTypes.length == 1) {
            Type actualTypeArgument = actualTypes[0];
            if (actualTypeArgument instanceof Class) {
                List<Object> array = new ArrayList<>();
                parseArray((Class) actualTypeArgument, (Collection) array);
                return array;
            } else if (actualTypeArgument instanceof WildcardType) {
                WildcardType wildcardType = (WildcardType) actualTypeArgument;
                Type upperBoundType = wildcardType.getUpperBounds()[0];
                if (!Object.class.equals(upperBoundType)) {
                    List<Object> array2 = new ArrayList<>();
                    parseArray((Class) upperBoundType, (Collection) array2);
                    return array2;
                } else if (wildcardType.getLowerBounds().length == 0) {
                    return parse();
                } else {
                    throw new JSONException("not support type : " + collectionType);
                }
            } else {
                if (actualTypeArgument instanceof TypeVariable) {
                    TypeVariable<?> typeVariable = (TypeVariable) actualTypeArgument;
                    Type[] bounds = typeVariable.getBounds();
                    if (bounds.length == 1) {
                        Type boundType = bounds[0];
                        if (boundType instanceof Class) {
                            List<Object> array3 = new ArrayList<>();
                            parseArray((Class) boundType, (Collection) array3);
                            return array3;
                        }
                    } else {
                        throw new JSONException("not support : " + typeVariable);
                    }
                }
                if (actualTypeArgument instanceof ParameterizedType) {
                    List<Object> array4 = new ArrayList<>();
                    parseArray((ParameterizedType) actualTypeArgument, array4);
                    return array4;
                }
                throw new JSONException("TODO : " + collectionType);
            }
        } else {
            throw new JSONException("not support type " + collectionType);
        }
    }

    public void acceptType(String typeName) {
        JSONLexer lexer2 = this.lexer;
        lexer2.nextTokenWithColon();
        if (lexer2.token() != 4) {
            throw new JSONException("type not match error");
        } else if (typeName.equals(lexer2.stringVal())) {
            lexer2.nextToken();
            if (lexer2.token() == 16) {
                lexer2.nextToken();
            }
        } else {
            throw new JSONException("type not match error");
        }
    }

    public int getResolveStatus() {
        return this.resolveStatus;
    }

    public void setResolveStatus(int resolveStatus2) {
        this.resolveStatus = resolveStatus2;
    }

    public Object getObject(String path) {
        for (int i = 0; i < this.contextArrayIndex; i++) {
            if (path.equals(this.contextArray[i].toString())) {
                return this.contextArray[i].object;
            }
        }
        return null;
    }

    public void checkListResolve(Collection array) {
        if (this.resolveStatus != 1) {
            return;
        }
        if (array instanceof List) {
            ResolveTask task = getLastResolveTask();
            task.fieldDeserializer = new ResolveFieldDeserializer(this, (List) array, array.size() - 1);
            task.ownerContext = this.context;
            setResolveStatus(0);
            return;
        }
        ResolveTask task2 = getLastResolveTask();
        task2.fieldDeserializer = new ResolveFieldDeserializer(array);
        task2.ownerContext = this.context;
        setResolveStatus(0);
    }

    public void checkMapResolve(Map object, Object fieldName) {
        if (this.resolveStatus == 1) {
            ResolveFieldDeserializer fieldResolver = new ResolveFieldDeserializer(object, fieldName);
            ResolveTask task = getLastResolveTask();
            task.fieldDeserializer = fieldResolver;
            task.ownerContext = this.context;
            setResolveStatus(0);
        }
    }

    public Object parseObject(Map object) {
        return parseObject(object, (Object) null);
    }

    public JSONObject parseObject() {
        Object parsedObject = parseObject((Map) new JSONObject(this.lexer.isEnabled(Feature.OrderedField)));
        if (parsedObject instanceof JSONObject) {
            return (JSONObject) parsedObject;
        }
        if (parsedObject == null) {
            return null;
        }
        return new JSONObject((Map) parsedObject);
    }

    public final void parseArray(Collection array) {
        parseArray(array, (Object) null);
    }

    public final void parseArray(Collection array, Object fieldName) {
        Object value;
        Object value2;
        Object value3;
        JSONLexer lexer2 = this.lexer;
        if (lexer2.token() == 21 || lexer2.token() == 22) {
            lexer2.nextToken();
        }
        if (lexer2.token() == 14) {
            lexer2.nextToken(4);
            ParseContext parseContext = this.context;
            if (parseContext == null || parseContext.level <= 512) {
                ParseContext context2 = this.context;
                setContext(array, fieldName);
                int i = 0;
                while (true) {
                    try {
                        if (lexer2.isEnabled(Feature.AllowArbitraryCommas)) {
                            while (lexer2.token() == 16) {
                                lexer2.nextToken();
                            }
                        }
                        int i2 = lexer2.token();
                        if (i2 == 2) {
                            Object value4 = lexer2.integerValue();
                            lexer2.nextToken(16);
                            value = value4;
                        } else if (i2 == 3) {
                            if (lexer2.isEnabled(Feature.UseBigDecimal)) {
                                value2 = lexer2.decimalValue(true);
                            } else {
                                value2 = lexer2.decimalValue(false);
                            }
                            lexer2.nextToken(16);
                            value = value2;
                        } else if (i2 == 4) {
                            String stringLiteral = lexer2.stringVal();
                            lexer2.nextToken(16);
                            if (lexer2.isEnabled(Feature.AllowISO8601DateFormat)) {
                                JSONScanner iso8601Lexer = new JSONScanner(stringLiteral);
                                if (iso8601Lexer.scanISO8601DateIfMatch()) {
                                    value3 = iso8601Lexer.getCalendar().getTime();
                                } else {
                                    value3 = stringLiteral;
                                }
                                iso8601Lexer.close();
                                value = value3;
                            } else {
                                value = stringLiteral;
                            }
                        } else if (i2 == 6) {
                            Object value5 = Boolean.TRUE;
                            lexer2.nextToken(16);
                            value = value5;
                        } else if (i2 == 7) {
                            Object value6 = Boolean.FALSE;
                            lexer2.nextToken(16);
                            value = value6;
                        } else if (i2 == 8) {
                            value = null;
                            lexer2.nextToken(4);
                        } else if (i2 == 12) {
                            value = parseObject(new JSONObject(lexer2.isEnabled(Feature.OrderedField)), Integer.valueOf(i));
                        } else if (i2 == 20) {
                            throw new JSONException("unclosed jsonArray");
                        } else if (i2 == 23) {
                            value = null;
                            lexer2.nextToken(4);
                        } else if (i2 == 14) {
                            Collection items = new JSONArray();
                            parseArray(items, Integer.valueOf(i));
                            value = lexer2.isEnabled(Feature.UseObjectArray) ? items.toArray() : items;
                        } else if (i2 != 15) {
                            value = parse();
                        } else {
                            lexer2.nextToken(16);
                            setContext(context2);
                            return;
                        }
                        array.add(value == 1 ? 1 : 0);
                        checkListResolve(array);
                        if (lexer2.token() == 16) {
                            lexer2.nextToken(4);
                        }
                        i++;
                    } catch (ClassCastException e) {
                        throw new JSONException("unkown error", e);
                    } catch (Throwable th) {
                        setContext(context2);
                        throw th;
                    }
                }
            } else {
                throw new JSONException("array level > 512");
            }
        } else {
            throw new JSONException("syntax error, expect [, actual " + JSONToken.name(lexer2.token()) + ", pos " + lexer2.pos() + ", fieldName " + fieldName);
        }
    }

    public ParseContext getContext() {
        return this.context;
    }

    public ParseContext getOwnerContext() {
        return this.context.parent;
    }

    public List<ResolveTask> getResolveTaskList() {
        if (this.resolveTaskList == null) {
            this.resolveTaskList = new ArrayList(2);
        }
        return this.resolveTaskList;
    }

    public void addResolveTask(ResolveTask task) {
        if (this.resolveTaskList == null) {
            this.resolveTaskList = new ArrayList(2);
        }
        this.resolveTaskList.add(task);
    }

    public ResolveTask getLastResolveTask() {
        List<ResolveTask> list = this.resolveTaskList;
        return list.get(list.size() - 1);
    }

    public List<ExtraProcessor> getExtraProcessors() {
        if (this.extraProcessors == null) {
            this.extraProcessors = new ArrayList(2);
        }
        return this.extraProcessors;
    }

    public List<ExtraTypeProvider> getExtraTypeProviders() {
        if (this.extraTypeProviders == null) {
            this.extraTypeProviders = new ArrayList(2);
        }
        return this.extraTypeProviders;
    }

    public FieldTypeResolver getFieldTypeResolver() {
        return this.fieldTypeResolver;
    }

    public void setFieldTypeResolver(FieldTypeResolver fieldTypeResolver2) {
        this.fieldTypeResolver = fieldTypeResolver2;
    }

    public void setContext(ParseContext context2) {
        if (!this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            this.context = context2;
        }
    }

    public void popContext() {
        if (!this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            this.context = this.context.parent;
            int i = this.contextArrayIndex;
            if (i > 0) {
                int i2 = i - 1;
                this.contextArrayIndex = i2;
                this.contextArray[i2] = null;
            }
        }
    }

    public ParseContext setContext(Object object, Object fieldName) {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        return setContext(this.context, object, fieldName);
    }

    public ParseContext setContext(ParseContext parent, Object object, Object fieldName) {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        ParseContext parseContext = new ParseContext(parent, object, fieldName);
        this.context = parseContext;
        addContext(parseContext);
        return this.context;
    }

    private void addContext(ParseContext context2) {
        int i = this.contextArrayIndex;
        this.contextArrayIndex = i + 1;
        ParseContext[] parseContextArr = this.contextArray;
        if (parseContextArr == null) {
            this.contextArray = new ParseContext[8];
        } else if (i >= parseContextArr.length) {
            ParseContext[] newArray = new ParseContext[((parseContextArr.length * 3) / 2)];
            System.arraycopy(parseContextArr, 0, newArray, 0, parseContextArr.length);
            this.contextArray = newArray;
        }
        this.contextArray[i] = context2;
    }

    public Object parse() {
        return parse(null);
    }

    public Object parseKey() {
        if (this.lexer.token() != 18) {
            return parse(null);
        }
        String value = this.lexer.stringVal();
        this.lexer.nextToken(16);
        return value;
    }

    public Object parse(Object fieldName) {
        Map object;
        JSONLexer lexer2 = this.lexer;
        int i = lexer2.token();
        if (i == 2) {
            Number intValue = lexer2.integerValue();
            lexer2.nextToken();
            return intValue;
        } else if (i == 3) {
            Object value = lexer2.decimalValue(lexer2.isEnabled(Feature.UseBigDecimal));
            lexer2.nextToken();
            return value;
        } else if (i == 4) {
            String stringLiteral = lexer2.stringVal();
            lexer2.nextToken(16);
            if (lexer2.isEnabled(Feature.AllowISO8601DateFormat)) {
                JSONScanner iso8601Lexer = new JSONScanner(stringLiteral);
                try {
                    if (iso8601Lexer.scanISO8601DateIfMatch()) {
                        return iso8601Lexer.getCalendar().getTime();
                    }
                    iso8601Lexer.close();
                } finally {
                    iso8601Lexer.close();
                }
            }
            return stringLiteral;
        } else if (i == 12) {
            if (isEnabled(Feature.UseNativeJavaObject)) {
                object = lexer2.isEnabled(Feature.OrderedField) ? new HashMap() : new LinkedHashMap();
            } else {
                object = new JSONObject(lexer2.isEnabled(Feature.OrderedField));
            }
            return parseObject(object, fieldName);
        } else if (i == 14) {
            Collection array = isEnabled(Feature.UseNativeJavaObject) ? new ArrayList() : new JSONArray();
            parseArray(array, fieldName);
            if (lexer2.isEnabled(Feature.UseObjectArray)) {
                return array.toArray();
            }
            return array;
        } else if (i != 18) {
            if (i != 26) {
                switch (i) {
                    case 6:
                        lexer2.nextToken();
                        return Boolean.TRUE;
                    case 7:
                        lexer2.nextToken();
                        return Boolean.FALSE;
                    case 8:
                        lexer2.nextToken();
                        return null;
                    case 9:
                        lexer2.nextToken(18);
                        if (lexer2.token() == 18) {
                            lexer2.nextToken(10);
                            accept(10);
                            long time = lexer2.integerValue().longValue();
                            accept(2);
                            accept(11);
                            return new Date(time);
                        }
                        throw new JSONException("syntax error");
                    default:
                        switch (i) {
                            case 20:
                                if (lexer2.isBlankInput()) {
                                    return null;
                                }
                                throw new JSONException("unterminated json string, " + lexer2.info());
                            case 21:
                                lexer2.nextToken();
                                HashSet<Object> set = new HashSet<>();
                                parseArray(set, fieldName);
                                return set;
                            case 22:
                                lexer2.nextToken();
                                TreeSet<Object> treeSet = new TreeSet<>();
                                parseArray(treeSet, fieldName);
                                return treeSet;
                            case 23:
                                lexer2.nextToken();
                                return null;
                            default:
                                throw new JSONException("syntax error, " + lexer2.info());
                        }
                }
            } else {
                byte[] bytes = lexer2.bytesValue();
                lexer2.nextToken();
                return bytes;
            }
        } else if ("NaN".equals(lexer2.stringVal())) {
            lexer2.nextToken();
            return null;
        } else {
            throw new JSONException("syntax error, " + lexer2.info());
        }
    }

    public void config(Feature feature, boolean state) {
        this.lexer.config(feature, state);
    }

    public boolean isEnabled(Feature feature) {
        return this.lexer.isEnabled(feature);
    }

    public JSONLexer getLexer() {
        return this.lexer;
    }

    public final void accept(int token) {
        JSONLexer lexer2 = this.lexer;
        if (lexer2.token() == token) {
            lexer2.nextToken();
            return;
        }
        throw new JSONException("syntax error, expect " + JSONToken.name(token) + ", actual " + JSONToken.name(lexer2.token()));
    }

    public final void accept(int token, int nextExpectToken) {
        JSONLexer lexer2 = this.lexer;
        if (lexer2.token() == token) {
            lexer2.nextToken(nextExpectToken);
        } else {
            throwException(token);
        }
    }

    public void throwException(int token) {
        throw new JSONException("syntax error, expect " + JSONToken.name(token) + ", actual " + JSONToken.name(this.lexer.token()));
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        JSONLexer lexer2 = this.lexer;
        try {
            if (lexer2.isEnabled(Feature.AutoCloseSource)) {
                if (lexer2.token() != 20) {
                    throw new JSONException("not close json text, token : " + JSONToken.name(lexer2.token()));
                }
            }
        } finally {
            lexer2.close();
        }
    }

    public Object resolveReference(String ref) {
        if (this.contextArray == null) {
            return null;
        }
        int i = 0;
        while (true) {
            ParseContext[] parseContextArr = this.contextArray;
            if (i >= parseContextArr.length || i >= this.contextArrayIndex) {
                return null;
            }
            ParseContext context2 = parseContextArr[i];
            if (context2.toString().equals(ref)) {
                return context2.object;
            }
            i++;
        }
        return null;
    }

    public void handleResovleTask(Object value) {
        Object refValue;
        List<ResolveTask> list = this.resolveTaskList;
        if (list != null) {
            int size = list.size();
            for (int i = 0; i < size; i++) {
                ResolveTask task = this.resolveTaskList.get(i);
                String ref = task.referenceValue;
                Object object = null;
                if (task.ownerContext != null) {
                    object = task.ownerContext.object;
                }
                if (ref.startsWith(Operators.DOLLAR_STR)) {
                    refValue = getObject(ref);
                    if (refValue == null) {
                        try {
                            JSONPath jsonpath = new JSONPath(ref, SerializeConfig.getGlobalInstance(), this.config, true);
                            if (jsonpath.isRef()) {
                                refValue = jsonpath.eval(value);
                            }
                        } catch (JSONPathException e) {
                        }
                    }
                } else {
                    refValue = task.context.object;
                }
                FieldDeserializer fieldDeser = task.fieldDeserializer;
                if (fieldDeser != null) {
                    if (refValue != null && refValue.getClass() == JSONObject.class && fieldDeser.fieldInfo != null && !Map.class.isAssignableFrom(fieldDeser.fieldInfo.fieldClass)) {
                        Object root = this.contextArray[0].object;
                        JSONPath jsonpath2 = JSONPath.compile(ref);
                        if (jsonpath2.isRef()) {
                            refValue = jsonpath2.eval(root);
                        }
                    }
                    if (fieldDeser.getOwnerClass() != null && !fieldDeser.getOwnerClass().isInstance(object) && task.ownerContext.parent != null) {
                        ParseContext ctx = task.ownerContext.parent;
                        while (true) {
                            if (ctx == null) {
                                break;
                            } else if (fieldDeser.getOwnerClass().isInstance(ctx.object)) {
                                object = ctx.object;
                                break;
                            } else {
                                ctx = ctx.parent;
                            }
                        }
                    }
                    fieldDeser.setValue(object, refValue);
                }
            }
        }
    }

    public static class ResolveTask {
        public final ParseContext context;
        public FieldDeserializer fieldDeserializer;
        public ParseContext ownerContext;
        public final String referenceValue;

        public ResolveTask(ParseContext context2, String referenceValue2) {
            this.context = context2;
            this.referenceValue = referenceValue2;
        }
    }

    public void parseExtra(Object object, String key) {
        Object value;
        this.lexer.nextTokenWithColon();
        Type type = null;
        List<ExtraTypeProvider> list = this.extraTypeProviders;
        if (list != null) {
            for (ExtraTypeProvider extraProvider : list) {
                type = extraProvider.getExtraType(object, key);
            }
        }
        if (type == null) {
            value = parse();
        } else {
            value = parseObject(type);
        }
        if (object instanceof ExtraProcessable) {
            ((ExtraProcessable) object).processExtra(key, value);
            return;
        }
        List<ExtraProcessor> list2 = this.extraProcessors;
        if (list2 != null) {
            for (ExtraProcessor process : list2) {
                process.processExtra(object, key, value);
            }
        }
        if (this.resolveStatus == 1) {
            this.resolveStatus = 0;
        }
    }

    /* JADX INFO: Multiple debug info for r0v2 com.alibaba.fastjson.parser.ParseContext: [D('msg' java.lang.String), D('context' com.alibaba.fastjson.parser.ParseContext)] */
    public Object parse(PropertyProcessable object, Object fieldName) {
        String key;
        Object value;
        if (this.lexer.token() != 12) {
            String msg = "syntax error, expect {, actual " + this.lexer.tokenName();
            if (fieldName instanceof String) {
                msg = (msg + ", fieldName ") + fieldName;
            }
            String msg2 = (msg + ", ") + this.lexer.info();
            JSONArray array = new JSONArray();
            parseArray(array, fieldName);
            if (array.size() == 1) {
                Object first = array.get(0);
                if (first instanceof JSONObject) {
                    return (JSONObject) first;
                }
            }
            throw new JSONException(msg2);
        }
        ParseContext context2 = this.context;
        int i = 0;
        while (true) {
            try {
                this.lexer.skipWhitespace();
                char ch = this.lexer.getCurrent();
                if (this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                    while (ch == ',') {
                        this.lexer.next();
                        this.lexer.skipWhitespace();
                        ch = this.lexer.getCurrent();
                    }
                }
                if (ch == '\"') {
                    key = this.lexer.scanSymbol(this.symbolTable, Operators.QUOTE);
                    this.lexer.skipWhitespace();
                    if (this.lexer.getCurrent() != ':') {
                        throw new JSONException("expect ':' at " + this.lexer.pos());
                    }
                } else if (ch == '}') {
                    this.lexer.next();
                    this.lexer.resetStringPosition();
                    this.lexer.nextToken(16);
                    setContext(context2);
                    return object;
                } else if (ch == '\'') {
                    if (this.lexer.isEnabled(Feature.AllowSingleQuotes)) {
                        key = this.lexer.scanSymbol(this.symbolTable, Operators.SINGLE_QUOTE);
                        this.lexer.skipWhitespace();
                        if (this.lexer.getCurrent() != ':') {
                            throw new JSONException("expect ':' at " + this.lexer.pos());
                        }
                    } else {
                        throw new JSONException("syntax error");
                    }
                } else if (this.lexer.isEnabled(Feature.AllowUnQuotedFieldNames)) {
                    key = this.lexer.scanSymbolUnQuoted(this.symbolTable);
                    this.lexer.skipWhitespace();
                    char ch2 = this.lexer.getCurrent();
                    if (ch2 != ':') {
                        throw new JSONException("expect ':' at " + this.lexer.pos() + ", actual " + ch2);
                    }
                } else {
                    throw new JSONException("syntax error");
                }
                this.lexer.next();
                this.lexer.skipWhitespace();
                this.lexer.getCurrent();
                this.lexer.resetStringPosition();
                if (key != JSON.DEFAULT_TYPE_KEY || this.lexer.isEnabled(Feature.DisableSpecialKeyDetect)) {
                    this.lexer.nextToken();
                    if (i != 0) {
                        setContext(context2);
                    }
                    Type valueType = object.getType(key);
                    if (this.lexer.token() == 8) {
                        value = null;
                        this.lexer.nextToken();
                    } else {
                        value = parseObject(valueType, key);
                    }
                    object.apply(key, value);
                    setContext(context2, value, key);
                    setContext(context2);
                    int tok = this.lexer.token();
                    if (tok == 20 || tok == 15) {
                        setContext(context2);
                    } else if (tok == 13) {
                        this.lexer.nextToken();
                        setContext(context2);
                        return object;
                    }
                } else {
                    Class<?> clazz = this.config.checkAutoType(this.lexer.scanSymbol(this.symbolTable, Operators.QUOTE), null, this.lexer.getFeatures());
                    if (Map.class.isAssignableFrom(clazz)) {
                        this.lexer.nextToken(16);
                        if (this.lexer.token() == 13) {
                            this.lexer.nextToken(16);
                            return object;
                        }
                    } else {
                        ObjectDeserializer deserializer = this.config.getDeserializer(clazz);
                        this.lexer.nextToken(16);
                        setResolveStatus(2);
                        if (context2 != null && !(fieldName instanceof Integer)) {
                            popContext();
                        }
                        Map map = (Map) deserializer.deserialze(this, clazz, fieldName);
                        setContext(context2);
                        return map;
                    }
                }
                i++;
            } finally {
                setContext(context2);
            }
        }
        setContext(context2);
        return object;
    }
}
