package com.alibaba.fastjson.parser;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.util.IOUtils;
import com.alibaba.fastjson.util.TypeUtils;
import com.igexin.push.core.b;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.Closeable;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.math.MathContext;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collection;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.Locale;
import java.util.TimeZone;
import java.util.UUID;

public abstract class JSONLexerBase implements JSONLexer, Closeable {
    protected static final int INT_MULTMIN_RADIX_TEN = -214748364;
    protected static final long MULTMIN_RADIX_TEN = -922337203685477580L;
    private static final ThreadLocal<char[]> SBUF_LOCAL = new ThreadLocal<>();
    protected static final int[] digits = new int[103];
    protected static final char[] typeFieldName = ("\"" + JSON.DEFAULT_TYPE_KEY + "\":\"").toCharArray();
    protected int bp;
    protected Calendar calendar = null;
    protected char ch;
    protected int eofPos;
    protected int features;
    protected boolean hasSpecial;
    protected Locale locale = JSON.defaultLocale;
    public int matchStat = 0;
    protected int nanos = 0;
    protected int np;
    protected int pos;
    protected char[] sbuf;
    protected int sp;
    protected String stringDefaultValue = null;
    protected TimeZone timeZone = JSON.defaultTimeZone;
    protected int token;

    public abstract String addSymbol(int i, int i2, int i3, SymbolTable symbolTable);

    /* access modifiers changed from: protected */
    public abstract void arrayCopy(int i, char[] cArr, int i2, int i3);

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public abstract byte[] bytesValue();

    /* access modifiers changed from: protected */
    public abstract boolean charArrayCompare(char[] cArr);

    public abstract char charAt(int i);

    /* access modifiers changed from: protected */
    public abstract void copyTo(int i, int i2, char[] cArr);

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public abstract BigDecimal decimalValue();

    public abstract int indexOf(char c, int i);

    public abstract boolean isEOF();

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public abstract char next();

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public abstract String numberString();

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public abstract String stringVal();

    public abstract String subString(int i, int i2);

    /* access modifiers changed from: protected */
    public abstract char[] sub_chars(int i, int i2);

    /* access modifiers changed from: protected */
    public void lexError(String key, Object... args) {
        this.token = 1;
    }

    static {
        for (int i = 48; i <= 57; i++) {
            digits[i] = i - 48;
        }
        for (int i2 = 97; i2 <= 102; i2++) {
            digits[i2] = (i2 - 97) + 10;
        }
        for (int i3 = 65; i3 <= 70; i3++) {
            digits[i3] = (i3 - 65) + 10;
        }
    }

    public JSONLexerBase(int features2) {
        this.features = features2;
        if ((Feature.InitStringFieldAsEmpty.mask & features2) != 0) {
            this.stringDefaultValue = "";
        }
        char[] cArr = SBUF_LOCAL.get();
        this.sbuf = cArr;
        if (cArr == null) {
            this.sbuf = new char[512];
        }
    }

    public final int matchStat() {
        return this.matchStat;
    }

    public void setToken(int token2) {
        this.token = token2;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void nextToken() {
        this.sp = 0;
        while (true) {
            this.pos = this.bp;
            char c = this.ch;
            if (c == '/') {
                skipComment();
            } else if (c == '\"') {
                scanString();
                return;
            } else if (c == ',') {
                next();
                this.token = 16;
                return;
            } else if (c < '0' || c > '9') {
                char c2 = this.ch;
                if (c2 == '-') {
                    scanNumber();
                    return;
                }
                switch (c2) {
                    case '\b':
                    case '\t':
                    case '\n':
                    case '\f':
                    case '\r':
                    case ' ':
                        next();
                        continue;
                    case '\'':
                        if (isEnabled(Feature.AllowSingleQuotes)) {
                            scanStringSingleQuote();
                            return;
                        }
                        throw new JSONException("Feature.AllowSingleQuotes is false");
                    case '(':
                        next();
                        this.token = 10;
                        return;
                    case ')':
                        next();
                        this.token = 11;
                        return;
                    case '+':
                        next();
                        scanNumber();
                        return;
                    case '.':
                        next();
                        this.token = 25;
                        return;
                    case ':':
                        next();
                        this.token = 17;
                        return;
                    case ';':
                        next();
                        this.token = 24;
                        return;
                    case 'N':
                    case 'S':
                    case 'T':
                    case 'u':
                        scanIdent();
                        return;
                    case '[':
                        next();
                        this.token = 14;
                        return;
                    case ']':
                        next();
                        this.token = 15;
                        return;
                    case 'f':
                        scanFalse();
                        return;
                    case 'n':
                        scanNullOrNew();
                        return;
                    case 't':
                        scanTrue();
                        return;
                    case 'x':
                        scanHex();
                        return;
                    case '{':
                        next();
                        this.token = 12;
                        return;
                    case '}':
                        next();
                        this.token = 13;
                        return;
                    default:
                        if (!isEOF()) {
                            char c3 = this.ch;
                            if (c3 <= 31 || c3 == 127) {
                                next();
                                continue;
                            } else {
                                lexError("illegal.char", String.valueOf((int) c3));
                                next();
                                return;
                            }
                        } else if (this.token != 20) {
                            this.token = 20;
                            int i = this.bp;
                            this.pos = i;
                            this.eofPos = i;
                            return;
                        } else {
                            throw new JSONException("EOF error");
                        }
                }
            } else {
                scanNumber();
                return;
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void nextToken(int expect) {
        this.sp = 0;
        while (true) {
            if (expect == 2) {
                char c = this.ch;
                if (c < '0' || c > '9') {
                    char c2 = this.ch;
                    if (c2 == '\"') {
                        this.pos = this.bp;
                        scanString();
                        return;
                    } else if (c2 == '[') {
                        this.token = 14;
                        next();
                        return;
                    } else if (c2 == '{') {
                        this.token = 12;
                        next();
                        return;
                    }
                } else {
                    this.pos = this.bp;
                    scanNumber();
                    return;
                }
            } else if (expect == 4) {
                char c3 = this.ch;
                if (c3 == '\"') {
                    this.pos = this.bp;
                    scanString();
                    return;
                } else if (c3 < '0' || c3 > '9') {
                    char c4 = this.ch;
                    if (c4 == '[') {
                        this.token = 14;
                        next();
                        return;
                    } else if (c4 == '{') {
                        this.token = 12;
                        next();
                        return;
                    }
                } else {
                    this.pos = this.bp;
                    scanNumber();
                    return;
                }
            } else if (expect == 12) {
                char c5 = this.ch;
                if (c5 == '{') {
                    this.token = 12;
                    next();
                    return;
                } else if (c5 == '[') {
                    this.token = 14;
                    next();
                    return;
                }
            } else if (expect != 18) {
                if (expect != 20) {
                    switch (expect) {
                        case 14:
                            char c6 = this.ch;
                            if (c6 == '[') {
                                this.token = 14;
                                next();
                                return;
                            } else if (c6 == '{') {
                                this.token = 12;
                                next();
                                return;
                            }
                            break;
                        case 15:
                            if (this.ch == ']') {
                                this.token = 15;
                                next();
                                return;
                            }
                            break;
                        case 16:
                            char c7 = this.ch;
                            if (c7 == ',') {
                                this.token = 16;
                                next();
                                return;
                            } else if (c7 == '}') {
                                this.token = 13;
                                next();
                                return;
                            } else if (c7 == ']') {
                                this.token = 15;
                                next();
                                return;
                            } else if (c7 == 26) {
                                this.token = 20;
                                return;
                            } else if (c7 == 'n') {
                                scanNullOrNew(false);
                                return;
                            }
                            break;
                    }
                }
                if (this.ch == 26) {
                    this.token = 20;
                    return;
                }
            } else {
                nextIdent();
                return;
            }
            char c8 = this.ch;
            if (c8 == ' ' || c8 == '\n' || c8 == '\r' || c8 == '\t' || c8 == '\f' || c8 == '\b') {
                next();
            } else {
                nextToken();
                return;
            }
        }
    }

    public final void nextIdent() {
        while (isWhitespace(this.ch)) {
            next();
        }
        char c = this.ch;
        if (c == '_' || c == '$' || Character.isLetter(c)) {
            scanIdent();
        } else {
            nextToken();
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void nextTokenWithColon() {
        nextTokenWithChar(Operators.CONDITION_IF_MIDDLE);
    }

    public final void nextTokenWithChar(char expect) {
        this.sp = 0;
        while (true) {
            char c = this.ch;
            if (c == expect) {
                next();
                nextToken();
                return;
            } else if (c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == '\f' || c == '\b') {
                next();
            } else {
                throw new JSONException("not match " + expect + " - " + this.ch + ", info : " + info());
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final int token() {
        return this.token;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final String tokenName() {
        return JSONToken.name(this.token);
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final int pos() {
        return this.pos;
    }

    public final String stringDefaultValue() {
        return this.stringDefaultValue;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final Number integerValue() throws NumberFormatException {
        long limit;
        long result = 0;
        boolean negative = false;
        if (this.np == -1) {
            this.np = 0;
        }
        int i = this.np;
        int max = this.np + this.sp;
        char type = ' ';
        char charAt = charAt(max - 1);
        if (charAt == 'B') {
            max--;
            type = 'B';
        } else if (charAt == 'L') {
            max--;
            type = 'L';
        } else if (charAt == 'S') {
            max--;
            type = 'S';
        }
        if (charAt(this.np) == '-') {
            negative = true;
            limit = Long.MIN_VALUE;
            i++;
        } else {
            limit = -9223372036854775807L;
        }
        if (i < max) {
            result = (long) (-(charAt(i) - 48));
            i++;
        }
        while (i < max) {
            int i2 = i + 1;
            int digit = charAt(i) - 48;
            if (result < MULTMIN_RADIX_TEN) {
                return new BigInteger(numberString(), 10);
            }
            long result2 = result * 10;
            if (result2 < ((long) digit) + limit) {
                return new BigInteger(numberString(), 10);
            }
            result = result2 - ((long) digit);
            i = i2;
        }
        if (!negative) {
            long result3 = -result;
            if (result3 > 2147483647L || type == 'L') {
                return Long.valueOf(result3);
            }
            if (type == 'S') {
                return Short.valueOf((short) ((int) result3));
            }
            if (type == 'B') {
                return Byte.valueOf((byte) ((int) result3));
            }
            return Integer.valueOf((int) result3);
        } else if (i <= this.np + 1) {
            throw new JSONException("illegal number format : " + numberString());
        } else if (result < -2147483648L || type == 'L') {
            return Long.valueOf(result);
        } else {
            if (type == 'S') {
                return Short.valueOf((short) ((int) result));
            }
            if (type == 'B') {
                return Byte.valueOf((byte) ((int) result));
            }
            return Integer.valueOf((int) result);
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void nextTokenWithColon(int expect) {
        nextTokenWithChar(Operators.CONDITION_IF_MIDDLE);
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public float floatValue() {
        char c0;
        String strVal = numberString();
        float floatValue = Float.parseFloat(strVal);
        if ((floatValue != 0.0f && floatValue != Float.POSITIVE_INFINITY) || (c0 = strVal.charAt(0)) <= '0' || c0 > '9') {
            return floatValue;
        }
        throw new JSONException("float overflow : " + strVal);
    }

    public double doubleValue() {
        return Double.parseDouble(numberString());
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public void config(Feature feature, boolean state) {
        int config = Feature.config(this.features, feature, state);
        this.features = config;
        if ((config & Feature.InitStringFieldAsEmpty.mask) != 0) {
            this.stringDefaultValue = "";
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final boolean isEnabled(Feature feature) {
        return isEnabled(feature.mask);
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final boolean isEnabled(int feature) {
        return (this.features & feature) != 0;
    }

    public final boolean isEnabled(int features2, int feature) {
        return ((this.features & feature) == 0 && (features2 & feature) == 0) ? false : true;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final char getCurrent() {
        return this.ch;
    }

    /* access modifiers changed from: protected */
    public void skipComment() {
        char c;
        next();
        char c2 = this.ch;
        if (c2 == '/') {
            do {
                next();
                c = this.ch;
                if (c == '\n') {
                    next();
                    return;
                }
            } while (c != 26);
        } else if (c2 == '*') {
            next();
            while (true) {
                char c3 = this.ch;
                if (c3 == 26) {
                    return;
                }
                if (c3 == '*') {
                    next();
                    if (this.ch == '/') {
                        next();
                        return;
                    }
                } else {
                    next();
                }
            }
        } else {
            throw new JSONException("invalid comment");
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final String scanSymbol(SymbolTable symbolTable) {
        skipWhitespace();
        char c = this.ch;
        if (c == '\"') {
            return scanSymbol(symbolTable, Operators.QUOTE);
        }
        if (c == '\'') {
            if (isEnabled(Feature.AllowSingleQuotes)) {
                return scanSymbol(symbolTable, Operators.SINGLE_QUOTE);
            }
            throw new JSONException("syntax error");
        } else if (c == '}') {
            next();
            this.token = 13;
            return null;
        } else if (c == ',') {
            next();
            this.token = 16;
            return null;
        } else if (c == 26) {
            this.token = 20;
            return null;
        } else if (isEnabled(Feature.AllowUnQuotedFieldNames)) {
            return scanSymbolUnQuoted(symbolTable);
        } else {
            throw new JSONException("syntax error");
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final String scanSymbol(SymbolTable symbolTable, char quote) {
        String value;
        int offset;
        int hash = 0;
        this.np = this.bp;
        this.sp = 0;
        boolean hasSpecial2 = false;
        while (true) {
            char chLocal = next();
            if (chLocal == quote) {
                this.token = 4;
                if (!hasSpecial2) {
                    int offset2 = this.np;
                    if (offset2 == -1) {
                        offset = 0;
                    } else {
                        offset = offset2 + 1;
                    }
                    value = addSymbol(offset, this.sp, hash, symbolTable);
                } else {
                    value = symbolTable.addSymbol(this.sbuf, 0, this.sp, hash);
                }
                this.sp = 0;
                next();
                return value;
            } else if (chLocal == 26) {
                throw new JSONException("unclosed.str");
            } else if (chLocal == '\\') {
                if (!hasSpecial2) {
                    hasSpecial2 = true;
                    int i = this.sp;
                    char[] cArr = this.sbuf;
                    if (i >= cArr.length) {
                        int newCapcity = cArr.length * 2;
                        if (i > newCapcity) {
                            newCapcity = this.sp;
                        }
                        char[] newsbuf = new char[newCapcity];
                        char[] cArr2 = this.sbuf;
                        System.arraycopy(cArr2, 0, newsbuf, 0, cArr2.length);
                        this.sbuf = newsbuf;
                    }
                    arrayCopy(this.np + 1, this.sbuf, 0, this.sp);
                }
                char chLocal2 = next();
                if (chLocal2 == '\"') {
                    hash = (hash * 31) + 34;
                    putChar(Operators.QUOTE);
                } else if (chLocal2 != '\'') {
                    if (chLocal2 != 'F') {
                        if (chLocal2 == '\\') {
                            hash = (hash * 31) + 92;
                            putChar('\\');
                        } else if (chLocal2 == 'b') {
                            hash = (hash * 31) + 8;
                            putChar('\b');
                        } else if (chLocal2 != 'f') {
                            if (chLocal2 == 'n') {
                                hash = (hash * 31) + 10;
                                putChar('\n');
                            } else if (chLocal2 == 'r') {
                                hash = (hash * 31) + 13;
                                putChar('\r');
                            } else if (chLocal2 != 'x') {
                                switch (chLocal2) {
                                    case '/':
                                        hash = (hash * 31) + 47;
                                        putChar('/');
                                        continue;
                                    case '0':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(0);
                                        continue;
                                    case '1':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(1);
                                        continue;
                                    case '2':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(2);
                                        continue;
                                    case '3':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(3);
                                        continue;
                                    case '4':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(4);
                                        continue;
                                    case '5':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(5);
                                        continue;
                                    case '6':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(6);
                                        continue;
                                    case '7':
                                        hash = (hash * 31) + chLocal2;
                                        putChar(7);
                                        continue;
                                    default:
                                        switch (chLocal2) {
                                            case 't':
                                                hash = (hash * 31) + 9;
                                                putChar('\t');
                                                continue;
                                            case 'u':
                                                int val = Integer.parseInt(new String(new char[]{next(), next(), next(), next()}), 16);
                                                hash = (hash * 31) + val;
                                                putChar((char) val);
                                                continue;
                                            case 'v':
                                                hash = (hash * 31) + 11;
                                                putChar(11);
                                                continue;
                                                continue;
                                            default:
                                                this.ch = chLocal2;
                                                throw new JSONException("unclosed.str.lit");
                                        }
                                }
                            } else {
                                char x1 = next();
                                this.ch = x1;
                                char x2 = next();
                                this.ch = x2;
                                int[] iArr = digits;
                                char x_char = (char) ((iArr[x1] * 16) + iArr[x2]);
                                hash = (hash * 31) + x_char;
                                putChar(x_char);
                            }
                        }
                    }
                    hash = (hash * 31) + 12;
                    putChar('\f');
                } else {
                    hash = (hash * 31) + 39;
                    putChar(Operators.SINGLE_QUOTE);
                }
            } else {
                hash = (hash * 31) + chLocal;
                if (!hasSpecial2) {
                    this.sp++;
                } else {
                    int i2 = this.sp;
                    char[] cArr3 = this.sbuf;
                    if (i2 == cArr3.length) {
                        putChar(chLocal);
                    } else {
                        this.sp = i2 + 1;
                        cArr3[i2] = chLocal;
                    }
                }
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void resetStringPosition() {
        this.sp = 0;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public String info() {
        return "";
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final String scanSymbolUnQuoted(SymbolTable symbolTable) {
        boolean firstFlag = false;
        if (this.token == 1 && this.pos == 0 && this.bp == 1) {
            this.bp = 0;
        }
        boolean[] firstIdentifierFlags = IOUtils.firstIdentifierFlags;
        char first = this.ch;
        if (this.ch >= firstIdentifierFlags.length || firstIdentifierFlags[first]) {
            firstFlag = true;
        }
        if (firstFlag) {
            boolean[] identifierFlags = IOUtils.identifierFlags;
            int hash = first;
            this.np = this.bp;
            this.sp = 1;
            while (true) {
                char chLocal = next();
                if (chLocal < identifierFlags.length && !identifierFlags[chLocal]) {
                    break;
                }
                hash = (hash * 31) + chLocal;
                this.sp++;
            }
            this.ch = charAt(this.bp);
            this.token = 18;
            if (this.sp == 4 && hash == 3392903 && charAt(this.np) == 'n' && charAt(this.np + 1) == 'u' && charAt(this.np + 2) == 'l' && charAt(this.np + 3) == 'l') {
                return null;
            }
            if (symbolTable == null) {
                return subString(this.np, this.sp);
            }
            return addSymbol(this.np, this.sp, hash, symbolTable);
        }
        throw new JSONException("illegal identifier : " + this.ch + info());
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void scanString() {
        char x1;
        char x2;
        this.np = this.bp;
        this.hasSpecial = false;
        while (true) {
            char ch2 = next();
            if (ch2 == '\"') {
                this.token = 4;
                this.ch = next();
                return;
            } else if (ch2 != 26) {
                boolean hex2 = true;
                if (ch2 == '\\') {
                    if (!this.hasSpecial) {
                        this.hasSpecial = true;
                        int i = this.sp;
                        char[] cArr = this.sbuf;
                        if (i >= cArr.length) {
                            int newCapcity = cArr.length * 2;
                            if (i > newCapcity) {
                                newCapcity = this.sp;
                            }
                            char[] newsbuf = new char[newCapcity];
                            char[] cArr2 = this.sbuf;
                            System.arraycopy(cArr2, 0, newsbuf, 0, cArr2.length);
                            this.sbuf = newsbuf;
                        }
                        copyTo(this.np + 1, this.sp, this.sbuf);
                    }
                    char ch3 = next();
                    if (ch3 == '\"') {
                        putChar(Operators.QUOTE);
                    } else if (ch3 != '\'') {
                        if (ch3 != 'F') {
                            if (ch3 == '\\') {
                                putChar('\\');
                            } else if (ch3 == 'b') {
                                putChar('\b');
                            } else if (ch3 != 'f') {
                                if (ch3 == 'n') {
                                    putChar('\n');
                                } else if (ch3 == 'r') {
                                    putChar('\r');
                                } else if (ch3 != 'x') {
                                    switch (ch3) {
                                        case '/':
                                            putChar('/');
                                            continue;
                                        case '0':
                                            putChar(0);
                                            continue;
                                        case '1':
                                            putChar(1);
                                            continue;
                                        case '2':
                                            putChar(2);
                                            continue;
                                        case '3':
                                            putChar(3);
                                            continue;
                                        case '4':
                                            putChar(4);
                                            continue;
                                        case '5':
                                            putChar(5);
                                            continue;
                                        case '6':
                                            putChar(6);
                                            continue;
                                        case '7':
                                            putChar(7);
                                            continue;
                                        default:
                                            switch (ch3) {
                                                case 't':
                                                    putChar('\t');
                                                    continue;
                                                case 'u':
                                                    putChar((char) Integer.parseInt(new String(new char[]{next(), next(), next(), next()}), 16));
                                                    continue;
                                                case 'v':
                                                    putChar(11);
                                                    continue;
                                                    continue;
                                                default:
                                                    this.ch = ch3;
                                                    throw new JSONException("unclosed string : " + ch3);
                                            }
                                    }
                                } else {
                                    x1 = next();
                                    x2 = next();
                                    boolean hex1 = (x1 >= '0' && x1 <= '9') || (x1 >= 'a' && x1 <= 'f') || (x1 >= 'A' && x1 <= 'F');
                                    if ((x2 < '0' || x2 > '9') && ((x2 < 'a' || x2 > 'f') && (x2 < 'A' || x2 > 'F'))) {
                                        hex2 = false;
                                    }
                                    if (!hex1 || !hex2) {
                                    } else {
                                        int[] iArr = digits;
                                        putChar((char) ((iArr[x1] * 16) + iArr[x2]));
                                    }
                                }
                            }
                        }
                        putChar('\f');
                    } else {
                        putChar(Operators.SINGLE_QUOTE);
                    }
                } else if (!this.hasSpecial) {
                    this.sp++;
                } else {
                    int i2 = this.sp;
                    char[] cArr3 = this.sbuf;
                    if (i2 == cArr3.length) {
                        putChar(ch2);
                    } else {
                        this.sp = i2 + 1;
                        cArr3[i2] = ch2;
                    }
                }
            } else if (!isEOF()) {
                putChar(JSONLexer.EOI);
            } else {
                throw new JSONException("unclosed string : " + ch2);
            }
        }
        throw new JSONException("invalid escape character \\x" + x1 + x2);
    }

    public Calendar getCalendar() {
        return this.calendar;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public TimeZone getTimeZone() {
        return this.timeZone;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public void setTimeZone(TimeZone timeZone2) {
        this.timeZone = timeZone2;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public Locale getLocale() {
        return this.locale;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public void setLocale(Locale locale2) {
        this.locale = locale2;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final int intValue() {
        int limit;
        int i;
        if (this.np == -1) {
            this.np = 0;
        }
        int result = 0;
        boolean negative = false;
        int i2 = this.np;
        int i3 = this.np;
        int max = this.sp + i3;
        if (charAt(i3) == '-') {
            negative = true;
            limit = Integer.MIN_VALUE;
            i2++;
        } else {
            limit = -2147483647;
        }
        if (i2 < max) {
            result = -(charAt(i2) - 48);
            i2++;
        }
        while (true) {
            if (i2 >= max) {
                break;
            }
            i = i2 + 1;
            char chLocal = charAt(i2);
            if (chLocal == 'L' || chLocal == 'S' || chLocal == 'B') {
                i2 = i;
            } else {
                int digit = chLocal - '0';
                if (((long) result) >= -214748364) {
                    int result2 = result * 10;
                    if (result2 >= limit + digit) {
                        result = result2 - digit;
                        i2 = i;
                    } else {
                        throw new NumberFormatException(numberString());
                    }
                } else {
                    throw new NumberFormatException(numberString());
                }
            }
        }
        i2 = i;
        if (!negative) {
            return -result;
        }
        if (i2 > this.np + 1) {
            return result;
        }
        throw new NumberFormatException(numberString());
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer, java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        char[] cArr = this.sbuf;
        if (cArr.length <= 8192) {
            SBUF_LOCAL.set(cArr);
        }
        this.sbuf = null;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final boolean isRef() {
        if (this.sp == 4 && charAt(this.np + 1) == '$' && charAt(this.np + 2) == 'r' && charAt(this.np + 3) == 'e' && charAt(this.np + 4) == 'f') {
            return true;
        }
        return false;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public String scanTypeName(SymbolTable symbolTable) {
        return null;
    }

    public final int scanType(String type) {
        this.matchStat = 0;
        if (!charArrayCompare(typeFieldName)) {
            return -2;
        }
        int bpLocal = this.bp + typeFieldName.length;
        int typeLength = type.length();
        for (int i = 0; i < typeLength; i++) {
            if (type.charAt(i) != charAt(bpLocal + i)) {
                return -1;
            }
        }
        int bpLocal2 = bpLocal + typeLength;
        if (charAt(bpLocal2) != '\"') {
            return -1;
        }
        int bpLocal3 = bpLocal2 + 1;
        char charAt = charAt(bpLocal3);
        this.ch = charAt;
        if (charAt == ',') {
            int bpLocal4 = bpLocal3 + 1;
            this.ch = charAt(bpLocal4);
            this.bp = bpLocal4;
            this.token = 16;
            return 3;
        }
        if (charAt == '}') {
            bpLocal3++;
            char charAt2 = charAt(bpLocal3);
            this.ch = charAt2;
            if (charAt2 == ',') {
                this.token = 16;
                bpLocal3++;
                this.ch = charAt(bpLocal3);
            } else if (charAt2 == ']') {
                this.token = 15;
                bpLocal3++;
                this.ch = charAt(bpLocal3);
            } else if (charAt2 == '}') {
                this.token = 13;
                bpLocal3++;
                this.ch = charAt(bpLocal3);
            } else if (charAt2 != 26) {
                return -1;
            } else {
                this.token = 20;
            }
            this.matchStat = 4;
        }
        this.bp = bpLocal3;
        return this.matchStat;
    }

    public final boolean matchField(char[] fieldName) {
        while (!charArrayCompare(fieldName)) {
            if (!isWhitespace(this.ch)) {
                return false;
            }
            next();
        }
        int length = this.bp + fieldName.length;
        this.bp = length;
        char charAt = charAt(length);
        this.ch = charAt;
        if (charAt == '{') {
            next();
            this.token = 12;
        } else if (charAt == '[') {
            next();
            this.token = 14;
        } else if (charAt == 'S' && charAt(this.bp + 1) == 'e' && charAt(this.bp + 2) == 't' && charAt(this.bp + 3) == '[') {
            int i = this.bp + 3;
            this.bp = i;
            this.ch = charAt(i);
            this.token = 21;
        } else {
            nextToken();
        }
        return true;
    }

    public int matchField(long fieldNameHash) {
        throw new UnsupportedOperationException();
    }

    public boolean seekArrayToItem(int index) {
        throw new UnsupportedOperationException();
    }

    public int seekObjectToField(long fieldNameHash, boolean deepScan) {
        throw new UnsupportedOperationException();
    }

    public int seekObjectToField(long[] fieldNameHash) {
        throw new UnsupportedOperationException();
    }

    public int seekObjectToFieldDeepScan(long fieldNameHash) {
        throw new UnsupportedOperationException();
    }

    public void skipObject() {
        throw new UnsupportedOperationException();
    }

    public void skipObject(boolean valid) {
        throw new UnsupportedOperationException();
    }

    public void skipArray() {
        throw new UnsupportedOperationException();
    }

    public String scanFieldString(char[] fieldName) {
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return stringDefaultValue();
        }
        int offset = fieldName.length;
        int offset2 = offset + 1;
        if (charAt(this.bp + offset) != '\"') {
            this.matchStat = -1;
            return stringDefaultValue();
        }
        int endIndex = indexOf(Operators.QUOTE, this.bp + fieldName.length + 1);
        if (endIndex != -1) {
            int startIndex2 = this.bp + fieldName.length + 1;
            String stringVal = subString(startIndex2, endIndex - startIndex2);
            if (stringVal.indexOf(92) != -1) {
                while (true) {
                    int slashCount = 0;
                    int i = endIndex - 1;
                    while (i >= 0 && charAt(i) == '\\') {
                        slashCount++;
                        i--;
                    }
                    if (slashCount % 2 == 0) {
                        break;
                    }
                    endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                }
                int i2 = this.bp;
                int chars_len = endIndex - ((fieldName.length + i2) + 1);
                stringVal = readString(sub_chars(i2 + fieldName.length + 1, chars_len), chars_len);
            }
            int i3 = this.bp;
            int offset3 = offset2 + (endIndex - ((fieldName.length + i3) + 1)) + 1;
            int offset4 = offset3 + 1;
            char chLocal = charAt(i3 + offset3);
            if (chLocal == ',') {
                int i4 = this.bp + offset4;
                this.bp = i4;
                this.ch = charAt(i4);
                this.matchStat = 3;
                return stringVal;
            } else if (chLocal == '}') {
                int offset5 = offset4 + 1;
                char chLocal2 = charAt(this.bp + offset4);
                if (chLocal2 == ',') {
                    this.token = 16;
                    int i5 = this.bp + offset5;
                    this.bp = i5;
                    this.ch = charAt(i5);
                } else if (chLocal2 == ']') {
                    this.token = 15;
                    int i6 = this.bp + offset5;
                    this.bp = i6;
                    this.ch = charAt(i6);
                } else if (chLocal2 == '}') {
                    this.token = 13;
                    int i7 = this.bp + offset5;
                    this.bp = i7;
                    this.ch = charAt(i7);
                } else if (chLocal2 == 26) {
                    this.token = 20;
                    this.bp += offset5 - 1;
                    this.ch = JSONLexer.EOI;
                } else {
                    this.matchStat = -1;
                    return stringDefaultValue();
                }
                this.matchStat = 4;
                return stringVal;
            } else {
                this.matchStat = -1;
                return stringDefaultValue();
            }
        } else {
            throw new JSONException("unclosed str");
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public String scanString(char expectNextChar) {
        this.matchStat = 0;
        int offset = 0 + 1;
        char chLocal = charAt(this.bp + 0);
        if (chLocal != 'n') {
            while (chLocal != '\"') {
                if (isWhitespace(chLocal)) {
                    chLocal = charAt(this.bp + offset);
                    offset++;
                } else {
                    this.matchStat = -1;
                    return stringDefaultValue();
                }
            }
            int startIndex = this.bp + offset;
            int endIndex = indexOf(Operators.QUOTE, startIndex);
            if (endIndex != -1) {
                String stringVal = subString(this.bp + offset, endIndex - startIndex);
                if (stringVal.indexOf(92) != -1) {
                    while (true) {
                        int slashCount = 0;
                        int i = endIndex - 1;
                        while (i >= 0 && charAt(i) == '\\') {
                            slashCount++;
                            i--;
                        }
                        if (slashCount % 2 == 0) {
                            break;
                        }
                        endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                    }
                    int chars_len = endIndex - startIndex;
                    stringVal = readString(sub_chars(this.bp + 1, chars_len), chars_len);
                }
                int offset2 = offset + (endIndex - startIndex) + 1;
                int offset3 = offset2 + 1;
                char chLocal2 = charAt(this.bp + offset2);
                while (chLocal2 != expectNextChar) {
                    if (isWhitespace(chLocal2)) {
                        chLocal2 = charAt(this.bp + offset3);
                        offset3++;
                    } else {
                        if (chLocal2 == ']') {
                            int i2 = this.bp + offset3;
                            this.bp = i2;
                            this.ch = charAt(i2);
                            this.matchStat = -1;
                        }
                        return stringVal;
                    }
                }
                int i3 = this.bp + offset3;
                this.bp = i3;
                this.ch = charAt(i3);
                this.matchStat = 3;
                this.token = 16;
                return stringVal;
            }
            throw new JSONException("unclosed str");
        } else if (charAt(this.bp + offset) == 'u' && charAt(this.bp + offset + 1) == 'l' && charAt(this.bp + offset + 2) == 'l') {
            int offset4 = offset + 3;
            int offset5 = offset4 + 1;
            if (charAt(this.bp + offset4) == expectNextChar) {
                int i4 = this.bp + offset5;
                this.bp = i4;
                this.ch = charAt(i4);
                this.matchStat = 3;
                return null;
            }
            this.matchStat = -1;
            return null;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public long scanFieldSymbol(char[] fieldName) {
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0;
        }
        int offset = fieldName.length;
        int offset2 = offset + 1;
        if (charAt(this.bp + offset) != '\"') {
            this.matchStat = -1;
            return 0;
        }
        long hash = TypeUtils.fnv1a_64_magic_hashcode;
        while (true) {
            int offset3 = offset2 + 1;
            char chLocal = charAt(this.bp + offset2);
            if (chLocal == '\"') {
                int offset4 = offset3 + 1;
                char chLocal2 = charAt(this.bp + offset3);
                if (chLocal2 == ',') {
                    int i = this.bp + offset4;
                    this.bp = i;
                    this.ch = charAt(i);
                    this.matchStat = 3;
                    return hash;
                } else if (chLocal2 == '}') {
                    int offset5 = offset4 + 1;
                    char chLocal3 = charAt(this.bp + offset4);
                    if (chLocal3 == ',') {
                        this.token = 16;
                        int i2 = this.bp + offset5;
                        this.bp = i2;
                        this.ch = charAt(i2);
                    } else if (chLocal3 == ']') {
                        this.token = 15;
                        int i3 = this.bp + offset5;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal3 == '}') {
                        this.token = 13;
                        int i4 = this.bp + offset5;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal3 == 26) {
                        this.token = 20;
                        this.bp += offset5 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return 0;
                    }
                    this.matchStat = 4;
                    return hash;
                } else {
                    this.matchStat = -1;
                    return 0;
                }
            } else {
                hash = (hash ^ ((long) chLocal)) * TypeUtils.fnv1a_64_magic_prime;
                if (chLocal == '\\') {
                    this.matchStat = -1;
                    return 0;
                }
                offset2 = offset3;
            }
        }
    }

    public long scanEnumSymbol(char[] fieldName) {
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0;
        }
        int offset = fieldName.length;
        int offset2 = offset + 1;
        if (charAt(this.bp + offset) != '\"') {
            this.matchStat = -1;
            return 0;
        }
        long hash = TypeUtils.fnv1a_64_magic_hashcode;
        while (true) {
            int offset3 = offset2 + 1;
            char chLocal = charAt(this.bp + offset2);
            if (chLocal == '\"') {
                int offset4 = offset3 + 1;
                char chLocal2 = charAt(this.bp + offset3);
                if (chLocal2 == ',') {
                    int i = this.bp + offset4;
                    this.bp = i;
                    this.ch = charAt(i);
                    this.matchStat = 3;
                    return hash;
                } else if (chLocal2 == '}') {
                    int offset5 = offset4 + 1;
                    char chLocal3 = charAt(this.bp + offset4);
                    if (chLocal3 == ',') {
                        this.token = 16;
                        int i2 = this.bp + offset5;
                        this.bp = i2;
                        this.ch = charAt(i2);
                    } else if (chLocal3 == ']') {
                        this.token = 15;
                        int i3 = this.bp + offset5;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal3 == '}') {
                        this.token = 13;
                        int i4 = this.bp + offset5;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal3 == 26) {
                        this.token = 20;
                        this.bp += offset5 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return 0;
                    }
                    this.matchStat = 4;
                    return hash;
                } else {
                    this.matchStat = -1;
                    return 0;
                }
            } else {
                hash = (hash ^ ((long) ((chLocal < 'A' || chLocal > 'Z') ? chLocal : chLocal + ' '))) * TypeUtils.fnv1a_64_magic_prime;
                if (chLocal == '\\') {
                    this.matchStat = -1;
                    return 0;
                }
                offset2 = offset3;
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public Enum<?> scanEnum(Class<?> enumClass, SymbolTable symbolTable, char serperator) {
        String name = scanSymbolWithSeperator(symbolTable, serperator);
        if (name == null) {
            return null;
        }
        return Enum.valueOf(enumClass, name);
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public String scanSymbolWithSeperator(SymbolTable symbolTable, char serperator) {
        this.matchStat = 0;
        int offset = 0 + 1;
        char chLocal = charAt(this.bp + 0);
        if (chLocal == 'n') {
            if (charAt(this.bp + offset) == 'u' && charAt(this.bp + offset + 1) == 'l' && charAt(this.bp + offset + 2) == 'l') {
                int offset2 = offset + 3;
                int offset3 = offset2 + 1;
                if (charAt(this.bp + offset2) == serperator) {
                    int i = this.bp + offset3;
                    this.bp = i;
                    this.ch = charAt(i);
                    this.matchStat = 3;
                    return null;
                }
                this.matchStat = -1;
                return null;
            }
            this.matchStat = -1;
            return null;
        } else if (chLocal != '\"') {
            this.matchStat = -1;
            return null;
        } else {
            int hash = 0;
            while (true) {
                int offset4 = offset + 1;
                char chLocal2 = charAt(this.bp + offset);
                if (chLocal2 == '\"') {
                    int i2 = this.bp;
                    int start = i2 + 0 + 1;
                    String strVal = addSymbol(start, ((i2 + offset4) - start) - 1, hash, symbolTable);
                    int offset5 = offset4 + 1;
                    char chLocal3 = charAt(this.bp + offset4);
                    while (chLocal3 != serperator) {
                        if (isWhitespace(chLocal3)) {
                            chLocal3 = charAt(this.bp + offset5);
                            offset5++;
                        } else {
                            this.matchStat = -1;
                            return strVal;
                        }
                    }
                    int i3 = this.bp + offset5;
                    this.bp = i3;
                    this.ch = charAt(i3);
                    this.matchStat = 3;
                    return strVal;
                }
                hash = (hash * 31) + chLocal2;
                if (chLocal2 == '\\') {
                    this.matchStat = -1;
                    return null;
                }
                offset = offset4;
            }
        }
    }

    public Collection<String> newCollectionByType(Class<?> type) {
        if (type.isAssignableFrom(HashSet.class)) {
            return new HashSet();
        }
        if (type.isAssignableFrom(ArrayList.class)) {
            return new ArrayList();
        }
        if (type.isAssignableFrom(LinkedList.class)) {
            return new LinkedList();
        }
        try {
            return (Collection) type.newInstance();
        } catch (Exception e) {
            throw new JSONException(e.getMessage(), e);
        }
    }

    public Collection<String> scanFieldStringArray(char[] fieldName, Class<?> type) {
        int offset;
        char chLocal;
        int offset2;
        char chLocal2;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        Collection<String> list = newCollectionByType(type);
        int offset3 = fieldName.length;
        int offset4 = offset3 + 1;
        int i = -1;
        if (charAt(this.bp + offset3) != '[') {
            this.matchStat = -1;
            return null;
        }
        int offset5 = offset4 + 1;
        char chLocal3 = charAt(this.bp + offset4);
        while (true) {
            if (chLocal3 == '\"') {
                int endIndex = indexOf(Operators.QUOTE, this.bp + offset5);
                if (endIndex != i) {
                    int startIndex2 = this.bp + offset5;
                    String stringVal = subString(startIndex2, endIndex - startIndex2);
                    if (stringVal.indexOf(92) != i) {
                        while (true) {
                            int slashCount = 0;
                            int i2 = endIndex - 1;
                            while (i2 >= 0 && charAt(i2) == '\\') {
                                slashCount++;
                                i2--;
                            }
                            if (slashCount % 2 == 0) {
                                break;
                            }
                            endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                        }
                        int i3 = this.bp;
                        int chars_len = endIndex - (i3 + offset5);
                        stringVal = readString(sub_chars(i3 + offset5, chars_len), chars_len);
                    }
                    int i4 = this.bp;
                    int offset6 = offset5 + (endIndex - (i4 + offset5)) + 1;
                    offset2 = offset6 + 1;
                    chLocal2 = charAt(i4 + offset6);
                    list.add(stringVal);
                } else {
                    throw new JSONException("unclosed str");
                }
            } else if (chLocal3 == 'n' && charAt(this.bp + offset5) == 'u' && charAt(this.bp + offset5 + 1) == 'l' && charAt(this.bp + offset5 + 2) == 'l') {
                int offset7 = offset5 + 3;
                offset2 = offset7 + 1;
                chLocal2 = charAt(this.bp + offset7);
                list.add(null);
            }
            if (chLocal2 == ',') {
                offset5 = offset2 + 1;
                chLocal3 = charAt(this.bp + offset2);
                i = -1;
            } else if (chLocal2 == ']') {
                offset = offset2 + 1;
                chLocal = charAt(this.bp + offset2);
            } else {
                this.matchStat = -1;
                return null;
            }
        }
        if (chLocal3 == ']' && list.size() == 0) {
            offset = offset5 + 1;
            chLocal = charAt(this.bp + offset5);
            if (chLocal == ',') {
                int i5 = this.bp + offset;
                this.bp = i5;
                this.ch = charAt(i5);
                this.matchStat = 3;
                return list;
            } else if (chLocal == '}') {
                int offset8 = offset + 1;
                char chLocal4 = charAt(this.bp + offset);
                if (chLocal4 == ',') {
                    this.token = 16;
                    int i6 = this.bp + offset8;
                    this.bp = i6;
                    this.ch = charAt(i6);
                } else if (chLocal4 == ']') {
                    this.token = 15;
                    int i7 = this.bp + offset8;
                    this.bp = i7;
                    this.ch = charAt(i7);
                } else if (chLocal4 == '}') {
                    this.token = 13;
                    int i8 = this.bp + offset8;
                    this.bp = i8;
                    this.ch = charAt(i8);
                } else if (chLocal4 == 26) {
                    this.bp += offset8 - 1;
                    this.token = 20;
                    this.ch = JSONLexer.EOI;
                } else {
                    this.matchStat = -1;
                    return null;
                }
                this.matchStat = 4;
                return list;
            } else {
                this.matchStat = -1;
                return null;
            }
        } else {
            throw new JSONException("illega str");
        }
    }

    /* JADX INFO: Multiple debug info for r4v19 int: [D('slashCount' int), D('chars_len' int)] */
    @Override // com.alibaba.fastjson.parser.JSONLexer
    public void scanStringArray(Collection<String> list, char seperator) {
        int offset;
        char chLocal;
        int startIndex;
        char chLocal2;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal3 = charAt(this.bp + 0);
        char c = 'u';
        char c2 = 'n';
        char c3 = 'l';
        if (chLocal3 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l' && charAt(this.bp + offset2 + 3) == seperator) {
            int i = this.bp + 5;
            this.bp = i;
            this.ch = charAt(i);
            this.matchStat = 5;
        } else if (chLocal3 != '[') {
            this.matchStat = -1;
        } else {
            int offset3 = offset2 + 1;
            char chLocal4 = charAt(this.bp + offset2);
            while (true) {
                if (chLocal4 != c2 || charAt(this.bp + offset3) != c || charAt(this.bp + offset3 + 1) != c3 || charAt(this.bp + offset3 + 2) != c3) {
                    if (chLocal4 == ']' && list.size() == 0) {
                        offset = offset3 + 1;
                        chLocal = charAt(this.bp + offset3);
                        break;
                    } else if (chLocal4 != '\"') {
                        this.matchStat = -1;
                        return;
                    } else {
                        int startIndex2 = this.bp + offset3;
                        int endIndex = indexOf(Operators.QUOTE, startIndex2);
                        if (endIndex != -1) {
                            String stringVal = subString(this.bp + offset3, endIndex - startIndex2);
                            if (stringVal.indexOf(92) != -1) {
                                while (true) {
                                    int slashCount = 0;
                                    int i2 = endIndex - 1;
                                    while (i2 >= 0 && charAt(i2) == '\\') {
                                        slashCount++;
                                        i2--;
                                    }
                                    if (slashCount % 2 == 0) {
                                        break;
                                    }
                                    endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                                }
                                int chars_len = endIndex - startIndex2;
                                stringVal = readString(sub_chars(this.bp + offset3, chars_len), chars_len);
                            }
                            int i3 = this.bp;
                            int offset4 = offset3 + (endIndex - (i3 + offset3)) + 1;
                            chLocal2 = charAt(i3 + offset4);
                            list.add(stringVal);
                            startIndex = offset4 + 1;
                        } else {
                            throw new JSONException("unclosed str");
                        }
                    }
                } else {
                    int offset5 = offset3 + 3;
                    startIndex = offset5 + 1;
                    chLocal2 = charAt(this.bp + offset5);
                    list.add(null);
                }
                if (chLocal2 == ',') {
                    offset3 = startIndex + 1;
                    chLocal4 = charAt(this.bp + startIndex);
                    c = 'u';
                    c2 = 'n';
                    c3 = 'l';
                } else if (chLocal2 == ']') {
                    offset = startIndex + 1;
                    chLocal = charAt(this.bp + startIndex);
                } else {
                    this.matchStat = -1;
                    return;
                }
            }
            if (chLocal == seperator) {
                int i4 = this.bp + offset;
                this.bp = i4;
                this.ch = charAt(i4);
                this.matchStat = 3;
                return;
            }
            this.matchStat = -1;
        }
    }

    public int scanFieldInt(char[] fieldName) {
        int offset;
        char chLocal;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal2 = charAt(this.bp + offset2);
        boolean negative = chLocal2 == '-';
        if (negative) {
            chLocal2 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal2 < '0' || chLocal2 > '9') {
            this.matchStat = -1;
            return 0;
        }
        int value = chLocal2 - '0';
        while (true) {
            offset = offset3 + 1;
            chLocal = charAt(this.bp + offset3);
            if (chLocal >= '0' && chLocal <= '9') {
                value = (value * 10) + (chLocal - '0');
                offset3 = offset;
            }
        }
        if (chLocal == '.') {
            this.matchStat = -1;
            return 0;
        } else if ((value < 0 || offset > fieldName.length + 14) && !(value == Integer.MIN_VALUE && offset == 17 && negative)) {
            this.matchStat = -1;
            return 0;
        } else if (chLocal == ',') {
            int i = this.bp + offset;
            this.bp = i;
            this.ch = charAt(i);
            this.matchStat = 3;
            this.token = 16;
            return negative ? -value : value;
        } else if (chLocal == '}') {
            int offset4 = offset + 1;
            char chLocal3 = charAt(this.bp + offset);
            if (chLocal3 == ',') {
                this.token = 16;
                int i2 = this.bp + offset4;
                this.bp = i2;
                this.ch = charAt(i2);
            } else if (chLocal3 == ']') {
                this.token = 15;
                int i3 = this.bp + offset4;
                this.bp = i3;
                this.ch = charAt(i3);
            } else if (chLocal3 == '}') {
                this.token = 13;
                int i4 = this.bp + offset4;
                this.bp = i4;
                this.ch = charAt(i4);
            } else if (chLocal3 == 26) {
                this.token = 20;
                this.bp += offset4 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return 0;
            }
            this.matchStat = 4;
            return negative ? -value : value;
        } else {
            this.matchStat = -1;
            return 0;
        }
    }

    /* JADX INFO: Multiple debug info for r6v9 int: [D('tmp' int[]), D('arrayIndex' int)] */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x012b, code lost:
        return null;
     */
    public final int[] scanFieldIntArray(char[] fieldName) {
        int offset;
        char chLocal;
        int offset2;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset3 = fieldName.length;
        int offset4 = offset3 + 1;
        if (charAt(this.bp + offset3) != '[') {
            this.matchStat = -2;
            return null;
        }
        int offset5 = offset4 + 1;
        char chLocal2 = charAt(this.bp + offset4);
        int[] array = new int[16];
        int arrayIndex = 0;
        if (chLocal2 == ']') {
            offset = offset5 + 1;
            chLocal = charAt(this.bp + offset5);
        } else {
            while (true) {
                boolean nagative = false;
                if (chLocal2 == '-') {
                    chLocal2 = charAt(this.bp + offset5);
                    nagative = true;
                    offset5++;
                }
                if (chLocal2 < '0' || chLocal2 > '9') {
                    this.matchStat = -1;
                } else {
                    int value = chLocal2 - '0';
                    while (true) {
                        offset2 = offset5 + 1;
                        chLocal2 = charAt(this.bp + offset5);
                        if (chLocal2 >= '0' && chLocal2 <= '9') {
                            value = (value * 10) + (chLocal2 - '0');
                            offset5 = offset2;
                        }
                    }
                    if (arrayIndex >= array.length) {
                        int[] tmp = new int[((array.length * 3) / 2)];
                        System.arraycopy(array, 0, tmp, 0, arrayIndex);
                        array = tmp;
                    }
                    int arrayIndex2 = arrayIndex + 1;
                    array[arrayIndex] = nagative ? -value : value;
                    if (chLocal2 == ',') {
                        chLocal2 = charAt(this.bp + offset2);
                        offset2++;
                    } else if (chLocal2 == ']') {
                        offset = offset2 + 1;
                        chLocal = charAt(this.bp + offset2);
                        arrayIndex = arrayIndex2;
                        break;
                    }
                    arrayIndex = arrayIndex2;
                    offset5 = offset2;
                }
            }
        }
        if (arrayIndex != array.length) {
            int[] tmp2 = new int[arrayIndex];
            System.arraycopy(array, 0, tmp2, 0, arrayIndex);
            array = tmp2;
        }
        if (chLocal == ',') {
            this.bp += offset - 1;
            next();
            this.matchStat = 3;
            this.token = 16;
            return array;
        } else if (chLocal == '}') {
            int offset6 = offset + 1;
            char chLocal3 = charAt(this.bp + offset);
            if (chLocal3 == ',') {
                this.token = 16;
                this.bp += offset6 - 1;
                next();
            } else if (chLocal3 == ']') {
                this.token = 15;
                this.bp += offset6 - 1;
                next();
            } else if (chLocal3 == '}') {
                this.token = 13;
                this.bp += offset6 - 1;
                next();
            } else if (chLocal3 == 26) {
                this.bp += offset6 - 1;
                this.token = 20;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return null;
            }
            this.matchStat = 4;
            return array;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public boolean scanBoolean(char expectNext) {
        this.matchStat = 0;
        int offset = 0 + 1;
        char chLocal = charAt(this.bp + 0);
        boolean value = false;
        if (chLocal == 't') {
            if (charAt(this.bp + offset) == 'r' && charAt(this.bp + offset + 1) == 'u' && charAt(this.bp + offset + 2) == 'e') {
                int offset2 = offset + 3;
                chLocal = charAt(this.bp + offset2);
                value = true;
                offset = offset2 + 1;
            } else {
                this.matchStat = -1;
                return false;
            }
        } else if (chLocal == 'f') {
            if (charAt(this.bp + offset) == 'a' && charAt(this.bp + offset + 1) == 'l' && charAt(this.bp + offset + 2) == 's' && charAt(this.bp + offset + 3) == 'e') {
                int offset3 = offset + 4;
                chLocal = charAt(this.bp + offset3);
                value = false;
                offset = offset3 + 1;
            } else {
                this.matchStat = -1;
                return false;
            }
        } else if (chLocal == '1') {
            chLocal = charAt(this.bp + offset);
            value = true;
            offset++;
        } else if (chLocal == '0') {
            chLocal = charAt(this.bp + offset);
            value = false;
            offset++;
        }
        while (chLocal != expectNext) {
            if (isWhitespace(chLocal)) {
                chLocal = charAt(this.bp + offset);
                offset++;
            } else {
                this.matchStat = -1;
                return value;
            }
        }
        int i = this.bp + offset;
        this.bp = i;
        this.ch = charAt(i);
        this.matchStat = 3;
        return value;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public int scanInt(char expectNext) {
        int offset;
        char chLocal;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        boolean negative = chLocal2 == '-';
        if (negative) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        if (chLocal2 >= '0' && chLocal2 <= '9') {
            int value = chLocal2 - '0';
            while (true) {
                offset = offset2 + 1;
                chLocal = charAt(this.bp + offset2);
                if (chLocal >= '0' && chLocal <= '9') {
                    value = (value * 10) + (chLocal - '0');
                    offset2 = offset;
                }
            }
            if (chLocal == '.') {
                this.matchStat = -1;
                return 0;
            } else if (value < 0) {
                this.matchStat = -1;
                return 0;
            } else {
                while (chLocal != expectNext) {
                    if (isWhitespace(chLocal)) {
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    } else {
                        this.matchStat = -1;
                        return negative ? -value : value;
                    }
                }
                int i = this.bp + offset;
                this.bp = i;
                this.ch = charAt(i);
                this.matchStat = 3;
                this.token = 16;
                return negative ? -value : value;
            }
        } else if (chLocal2 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
            this.matchStat = 5;
            int offset3 = offset2 + 3;
            int offset4 = offset3 + 1;
            char chLocal3 = charAt(this.bp + offset3);
            if (quote && chLocal3 == '\"') {
                chLocal3 = charAt(this.bp + offset4);
                offset4++;
            }
            while (chLocal3 != ',') {
                if (chLocal3 == ']') {
                    int i2 = this.bp + offset4;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 5;
                    this.token = 15;
                    return 0;
                } else if (isWhitespace(chLocal3)) {
                    chLocal3 = charAt(this.bp + offset4);
                    offset4++;
                } else {
                    this.matchStat = -1;
                    return 0;
                }
            }
            int i3 = this.bp + offset4;
            this.bp = i3;
            this.ch = charAt(i3);
            this.matchStat = 5;
            this.token = 16;
            return 0;
        } else {
            this.matchStat = -1;
            return 0;
        }
    }

    public boolean scanFieldBoolean(char[] fieldName) {
        int offset;
        boolean value;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return false;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal = charAt(this.bp + offset2);
        if (chLocal == 't') {
            int offset4 = offset3 + 1;
            if (charAt(this.bp + offset3) != 'r') {
                this.matchStat = -1;
                return false;
            }
            int offset5 = offset4 + 1;
            if (charAt(this.bp + offset4) != 'u') {
                this.matchStat = -1;
                return false;
            }
            offset = offset5 + 1;
            if (charAt(this.bp + offset5) != 'e') {
                this.matchStat = -1;
                return false;
            }
            value = true;
        } else if (chLocal == 'f') {
            int offset6 = offset3 + 1;
            if (charAt(this.bp + offset3) != 'a') {
                this.matchStat = -1;
                return false;
            }
            int offset7 = offset6 + 1;
            if (charAt(this.bp + offset6) != 'l') {
                this.matchStat = -1;
                return false;
            }
            int offset8 = offset7 + 1;
            if (charAt(this.bp + offset7) != 's') {
                this.matchStat = -1;
                return false;
            }
            int offset9 = offset8 + 1;
            if (charAt(this.bp + offset8) != 'e') {
                this.matchStat = -1;
                return false;
            }
            value = false;
            offset = offset9;
        } else {
            this.matchStat = -1;
            return false;
        }
        int offset10 = offset + 1;
        char chLocal2 = charAt(this.bp + offset);
        if (chLocal2 == ',') {
            int i = this.bp + offset10;
            this.bp = i;
            this.ch = charAt(i);
            this.matchStat = 3;
            this.token = 16;
            return value;
        } else if (chLocal2 == '}') {
            int offset11 = offset10 + 1;
            char chLocal3 = charAt(this.bp + offset10);
            if (chLocal3 == ',') {
                this.token = 16;
                int i2 = this.bp + offset11;
                this.bp = i2;
                this.ch = charAt(i2);
            } else if (chLocal3 == ']') {
                this.token = 15;
                int i3 = this.bp + offset11;
                this.bp = i3;
                this.ch = charAt(i3);
            } else if (chLocal3 == '}') {
                this.token = 13;
                int i4 = this.bp + offset11;
                this.bp = i4;
                this.ch = charAt(i4);
            } else if (chLocal3 == 26) {
                this.token = 20;
                this.bp += offset11 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return false;
            }
            this.matchStat = 4;
            return value;
        } else {
            this.matchStat = -1;
            return false;
        }
    }

    public long scanFieldLong(char[] fieldName) {
        int offset;
        char chLocal;
        boolean valid = false;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal2 = charAt(this.bp + offset2);
        boolean negative = false;
        if (chLocal2 == '-') {
            chLocal2 = charAt(this.bp + offset3);
            negative = true;
            offset3++;
        }
        if (chLocal2 >= '0') {
            char c = '9';
            if (chLocal2 <= '9') {
                long value = (long) (chLocal2 - '0');
                while (true) {
                    offset = offset3 + 1;
                    chLocal = charAt(this.bp + offset3);
                    if (chLocal >= '0' && chLocal <= c) {
                        value = (10 * value) + ((long) (chLocal - '0'));
                        offset3 = offset;
                        c = '9';
                    }
                }
                if (chLocal == '.') {
                    this.matchStat = -1;
                    return 0;
                }
                if (offset - fieldName.length < 21 && (value >= 0 || (value == Long.MIN_VALUE && negative))) {
                    valid = true;
                }
                if (!valid) {
                    this.matchStat = -1;
                    return 0;
                } else if (chLocal == ',') {
                    int i = this.bp + offset;
                    this.bp = i;
                    this.ch = charAt(i);
                    this.matchStat = 3;
                    this.token = 16;
                    return negative ? -value : value;
                } else if (chLocal == '}') {
                    int offset4 = offset + 1;
                    char chLocal3 = charAt(this.bp + offset);
                    if (chLocal3 == ',') {
                        this.token = 16;
                        int i2 = this.bp + offset4;
                        this.bp = i2;
                        this.ch = charAt(i2);
                    } else if (chLocal3 == ']') {
                        this.token = 15;
                        int i3 = this.bp + offset4;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal3 == '}') {
                        this.token = 13;
                        int i4 = this.bp + offset4;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal3 == 26) {
                        this.token = 20;
                        this.bp += offset4 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return 0;
                    }
                    this.matchStat = 4;
                    return negative ? -value : value;
                } else {
                    this.matchStat = -1;
                    return 0;
                }
            }
        }
        this.matchStat = -1;
        return 0;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public long scanLong(char expectNextChar) {
        int offset;
        char chLocal;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        boolean negative = chLocal2 == '-';
        if (negative) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        if (chLocal2 >= '0') {
            char c = '9';
            if (chLocal2 <= '9') {
                long value = (long) (chLocal2 - '0');
                while (true) {
                    offset = offset2 + 1;
                    chLocal = charAt(this.bp + offset2);
                    if (chLocal >= '0' && chLocal <= c) {
                        value = (10 * value) + ((long) (chLocal - '0'));
                        offset2 = offset;
                        c = '9';
                    }
                }
                if (chLocal == '.') {
                    this.matchStat = -1;
                    return 0;
                }
                if (value >= 0 || (value == Long.MIN_VALUE && negative)) {
                    if (quote) {
                        if (chLocal != '\"') {
                            this.matchStat = -1;
                            return 0;
                        }
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    }
                    while (chLocal != expectNextChar) {
                        if (isWhitespace(chLocal)) {
                            chLocal = charAt(this.bp + offset);
                            offset++;
                        } else {
                            this.matchStat = -1;
                            return value;
                        }
                    }
                    int i = this.bp + offset;
                    this.bp = i;
                    this.ch = charAt(i);
                    this.matchStat = 3;
                    this.token = 16;
                    return negative ? -value : value;
                }
                throw new NumberFormatException(subString(this.bp, offset - 1));
            }
        }
        if (chLocal2 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
            this.matchStat = 5;
            int offset3 = offset2 + 3;
            int offset4 = offset3 + 1;
            char chLocal3 = charAt(this.bp + offset3);
            if (quote && chLocal3 == '\"') {
                chLocal3 = charAt(this.bp + offset4);
                offset4++;
            }
            while (chLocal3 != ',') {
                if (chLocal3 == ']') {
                    int i2 = this.bp + offset4;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 5;
                    this.token = 15;
                    return 0;
                } else if (isWhitespace(chLocal3)) {
                    chLocal3 = charAt(this.bp + offset4);
                    offset4++;
                } else {
                    this.matchStat = -1;
                    return 0;
                }
            }
            int i3 = this.bp + offset4;
            this.bp = i3;
            this.ch = charAt(i3);
            this.matchStat = 5;
            this.token = 16;
            return 0;
        }
        this.matchStat = -1;
        return 0;
    }

    public final float scanFieldFloat(char[] fieldName) {
        int offset;
        char chLocal;
        boolean negative;
        int start;
        int count;
        char chLocal2;
        float value;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0.0f;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal3 = charAt(this.bp + offset2);
        boolean quote = chLocal3 == '\"';
        if (quote) {
            chLocal3 = charAt(this.bp + offset3);
            offset3++;
        }
        boolean negative2 = chLocal3 == '-';
        if (negative2) {
            chLocal3 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal3 >= '0') {
            char c = '9';
            if (chLocal3 <= '9') {
                long intVal = (long) (chLocal3 - '0');
                while (true) {
                    offset = offset3 + 1;
                    chLocal = charAt(this.bp + offset3);
                    if (chLocal < '0' || chLocal > '9') {
                        long power = 1;
                    } else {
                        intVal = (10 * intVal) + ((long) (chLocal - '0'));
                        offset3 = offset;
                    }
                }
                long power2 = 1;
                boolean small = chLocal == '.';
                if (small) {
                    int offset4 = offset + 1;
                    char chLocal4 = charAt(this.bp + offset);
                    if (chLocal4 < '0' || chLocal4 > '9') {
                        this.matchStat = -1;
                        return 0.0f;
                    }
                    negative = negative2;
                    power2 = 10;
                    intVal = (intVal * 10) + ((long) (chLocal4 - '0'));
                    while (true) {
                        offset = offset4 + 1;
                        chLocal = charAt(this.bp + offset4);
                        if (chLocal >= '0' && chLocal <= c) {
                            intVal = (intVal * 10) + ((long) (chLocal - '0'));
                            power2 *= 10;
                            offset4 = offset;
                            small = small;
                            c = '9';
                        }
                    }
                } else {
                    negative = negative2;
                }
                boolean exp = chLocal == 'e' || chLocal == 'E';
                if (exp) {
                    int offset5 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    if (chLocal == '+' || chLocal == '-') {
                        chLocal = charAt(this.bp + offset5);
                        offset = offset5 + 1;
                    } else {
                        offset = offset5;
                    }
                    while (chLocal >= '0' && chLocal <= '9') {
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    }
                }
                if (!quote) {
                    int count2 = this.bp;
                    start = count2 + fieldName.length;
                    count = ((count2 + offset) - start) - 1;
                } else if (chLocal != '\"') {
                    this.matchStat = -1;
                    return 0.0f;
                } else {
                    int offset6 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    int i = this.bp;
                    start = fieldName.length + i + 1;
                    count = ((i + offset6) - start) - 2;
                    offset = offset6;
                }
                if (exp || count >= 17) {
                    chLocal2 = chLocal;
                    value = Float.parseFloat(subString(start, count));
                } else {
                    chLocal2 = chLocal;
                    value = (float) (((double) intVal) / ((double) power2));
                    if (negative) {
                        value = -value;
                    }
                }
                if (chLocal2 == ',') {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                } else if (chLocal2 == '}') {
                    int offset7 = offset + 1;
                    char chLocal5 = charAt(this.bp + offset);
                    if (chLocal5 == ',') {
                        this.token = 16;
                        int i3 = this.bp + offset7;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal5 == ']') {
                        this.token = 15;
                        int i4 = this.bp + offset7;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal5 == '}') {
                        this.token = 13;
                        int i5 = this.bp + offset7;
                        this.bp = i5;
                        this.ch = charAt(i5);
                    } else if (chLocal5 == 26) {
                        this.bp += offset7 - 1;
                        this.token = 20;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return 0.0f;
                    }
                    this.matchStat = 4;
                    return value;
                } else {
                    this.matchStat = -1;
                    return 0.0f;
                }
            }
        }
        if (chLocal3 == 'n' && charAt(this.bp + offset3) == 'u' && charAt(this.bp + offset3 + 1) == 'l' && charAt(this.bp + offset3 + 2) == 'l') {
            this.matchStat = 5;
            int offset8 = offset3 + 3;
            int offset9 = offset8 + 1;
            char chLocal6 = charAt(this.bp + offset8);
            if (quote && chLocal6 == '\"') {
                chLocal6 = charAt(this.bp + offset9);
                offset9++;
            }
            while (chLocal6 != ',') {
                if (chLocal6 == '}') {
                    int i6 = this.bp + offset9;
                    this.bp = i6;
                    this.ch = charAt(i6);
                    this.matchStat = 5;
                    this.token = 13;
                    return 0.0f;
                } else if (isWhitespace(chLocal6)) {
                    chLocal6 = charAt(this.bp + offset9);
                    offset9++;
                } else {
                    this.matchStat = -1;
                    return 0.0f;
                }
            }
            int i7 = this.bp + offset9;
            this.bp = i7;
            this.ch = charAt(i7);
            this.matchStat = 5;
            this.token = 16;
            return 0.0f;
        }
        this.matchStat = -1;
        return 0.0f;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final float scanFloat(char seperator) {
        int offset;
        char chLocal;
        int start;
        int count;
        float value;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        boolean negative = chLocal2 == '-';
        if (negative) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        if (chLocal2 >= '0') {
            char c = '9';
            if (chLocal2 <= '9') {
                long intVal = (long) (chLocal2 - '0');
                while (true) {
                    offset = offset2 + 1;
                    chLocal = charAt(this.bp + offset2);
                    if (chLocal < '0' || chLocal > '9') {
                        long power = 1;
                    } else {
                        intVal = (10 * intVal) + ((long) (chLocal - '0'));
                        offset2 = offset;
                    }
                }
                long power2 = 1;
                boolean small = chLocal == '.';
                if (small) {
                    int offset3 = offset + 1;
                    char chLocal3 = charAt(this.bp + offset);
                    if (chLocal3 < '0' || chLocal3 > '9') {
                        this.matchStat = -1;
                        return 0.0f;
                    }
                    power2 = 10;
                    intVal = (intVal * 10) + ((long) (chLocal3 - '0'));
                    while (true) {
                        offset = offset3 + 1;
                        chLocal = charAt(this.bp + offset3);
                        if (chLocal >= '0' && chLocal <= c) {
                            intVal = (intVal * 10) + ((long) (chLocal - '0'));
                            power2 *= 10;
                            offset3 = offset;
                            small = small;
                            c = '9';
                        }
                    }
                }
                boolean exp = chLocal == 'e' || chLocal == 'E';
                if (exp) {
                    int offset4 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    if (chLocal == '+' || chLocal == '-') {
                        chLocal = charAt(this.bp + offset4);
                        offset = offset4 + 1;
                    } else {
                        offset = offset4;
                    }
                    while (chLocal >= '0' && chLocal <= '9') {
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    }
                }
                if (!quote) {
                    start = this.bp;
                    count = ((this.bp + offset) - start) - 1;
                } else if (chLocal != '\"') {
                    this.matchStat = -1;
                    return 0.0f;
                } else {
                    int offset5 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    int i = this.bp;
                    start = i + 1;
                    count = ((i + offset5) - start) - 2;
                    offset = offset5;
                }
                if (exp || count >= 17) {
                    value = Float.parseFloat(subString(start, count));
                } else {
                    value = (float) (((double) intVal) / ((double) power2));
                    if (negative) {
                        value = -value;
                    }
                }
                if (chLocal == seperator) {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                }
                this.matchStat = -1;
                return value;
            }
        }
        if (chLocal2 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
            this.matchStat = 5;
            int offset6 = offset2 + 3;
            int offset7 = offset6 + 1;
            char chLocal4 = charAt(this.bp + offset6);
            if (quote && chLocal4 == '\"') {
                chLocal4 = charAt(this.bp + offset7);
                offset7++;
            }
            while (chLocal4 != ',') {
                if (chLocal4 == ']') {
                    int i3 = this.bp + offset7;
                    this.bp = i3;
                    this.ch = charAt(i3);
                    this.matchStat = 5;
                    this.token = 15;
                    return 0.0f;
                } else if (isWhitespace(chLocal4)) {
                    chLocal4 = charAt(this.bp + offset7);
                    offset7++;
                } else {
                    this.matchStat = -1;
                    return 0.0f;
                }
            }
            int i4 = this.bp + offset7;
            this.bp = i4;
            this.ch = charAt(i4);
            this.matchStat = 5;
            this.token = 16;
            return 0.0f;
        }
        this.matchStat = -1;
        return 0.0f;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public double scanDouble(char seperator) {
        int offset;
        char chLocal;
        boolean negative;
        int start;
        int count;
        double value;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        boolean negative2 = chLocal2 == '-';
        if (negative2) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        char c = '0';
        if (chLocal2 >= '0') {
            char c2 = '9';
            if (chLocal2 <= '9') {
                long intVal = (long) (chLocal2 - '0');
                while (true) {
                    offset = offset2 + 1;
                    chLocal = charAt(this.bp + offset2);
                    if (chLocal < '0' || chLocal > '9') {
                        long power = 1;
                    } else {
                        intVal = (10 * intVal) + ((long) (chLocal - '0'));
                        offset2 = offset;
                    }
                }
                long power2 = 1;
                if (chLocal == '.') {
                    int offset3 = offset + 1;
                    char chLocal3 = charAt(this.bp + offset);
                    if (chLocal3 >= '0' && chLocal3 <= '9') {
                        negative = negative2;
                        power2 = 10;
                        intVal = (intVal * 10) + ((long) (chLocal3 - '0'));
                        while (true) {
                            offset = offset3 + 1;
                            chLocal = charAt(this.bp + offset3);
                            if (chLocal < c || chLocal > c2) {
                                break;
                            }
                            intVal = (intVal * 10) + ((long) (chLocal - '0'));
                            power2 *= 10;
                            offset3 = offset;
                            c = '0';
                            c2 = '9';
                        }
                    } else {
                        this.matchStat = -1;
                        return 0.0d;
                    }
                } else {
                    negative = negative2;
                }
                boolean exp = chLocal == 'e' || chLocal == 'E';
                if (exp) {
                    int offset4 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    if (chLocal == '+' || chLocal == '-') {
                        chLocal = charAt(this.bp + offset4);
                        offset = offset4 + 1;
                    } else {
                        offset = offset4;
                    }
                    while (chLocal >= '0' && chLocal <= '9') {
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    }
                }
                if (!quote) {
                    start = this.bp;
                    count = ((this.bp + offset) - start) - 1;
                } else if (chLocal != '\"') {
                    this.matchStat = -1;
                    return 0.0d;
                } else {
                    int offset5 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    int i = this.bp;
                    start = i + 1;
                    count = ((i + offset5) - start) - 2;
                    offset = offset5;
                }
                if (exp || count >= 17) {
                    value = Double.parseDouble(subString(start, count));
                } else {
                    value = ((double) intVal) / ((double) power2);
                    if (negative) {
                        value = -value;
                    }
                }
                if (chLocal == seperator) {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                }
                this.matchStat = -1;
                return value;
            }
        }
        if (chLocal2 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
            this.matchStat = 5;
            int offset6 = offset2 + 3;
            int offset7 = offset6 + 1;
            char chLocal4 = charAt(this.bp + offset6);
            if (quote && chLocal4 == '\"') {
                chLocal4 = charAt(this.bp + offset7);
                offset7++;
            }
            while (chLocal4 != ',') {
                if (chLocal4 == ']') {
                    int i3 = this.bp + offset7;
                    this.bp = i3;
                    this.ch = charAt(i3);
                    this.matchStat = 5;
                    this.token = 15;
                    return 0.0d;
                } else if (isWhitespace(chLocal4)) {
                    chLocal4 = charAt(this.bp + offset7);
                    offset7++;
                } else {
                    this.matchStat = -1;
                    return 0.0d;
                }
            }
            int i4 = this.bp + offset7;
            this.bp = i4;
            this.ch = charAt(i4);
            this.matchStat = 5;
            this.token = 16;
            return 0.0d;
        }
        this.matchStat = -1;
        return 0.0d;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public BigDecimal scanDecimal(char seperator) {
        int offset;
        char chLocal;
        int start;
        int count;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        if (chLocal2 == '-') {
            chLocal2 = charAt(this.bp + offset2);
            offset2++;
        }
        if (chLocal2 >= '0' && chLocal2 <= '9') {
            while (true) {
                offset = offset2 + 1;
                chLocal = charAt(this.bp + offset2);
                if (chLocal >= '0' && chLocal <= '9') {
                    offset2 = offset;
                }
            }
            if (chLocal == '.') {
                int offset3 = offset + 1;
                char chLocal3 = charAt(this.bp + offset);
                if (chLocal3 >= '0' && chLocal3 <= '9') {
                    while (true) {
                        offset = offset3 + 1;
                        chLocal = charAt(this.bp + offset3);
                        if (chLocal < '0' || chLocal > '9') {
                            break;
                        }
                        offset3 = offset;
                    }
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
            if (chLocal == 'e' || chLocal == 'E') {
                int offset4 = offset + 1;
                chLocal = charAt(this.bp + offset);
                if (chLocal == '+' || chLocal == '-') {
                    chLocal = charAt(this.bp + offset4);
                    offset = offset4 + 1;
                } else {
                    offset = offset4;
                }
                while (chLocal >= '0' && chLocal <= '9') {
                    chLocal = charAt(this.bp + offset);
                    offset++;
                }
            }
            if (!quote) {
                start = this.bp;
                count = ((this.bp + offset) - start) - 1;
            } else if (chLocal != '\"') {
                this.matchStat = -1;
                return null;
            } else {
                int offset5 = offset + 1;
                chLocal = charAt(this.bp + offset);
                int i = this.bp;
                start = i + 1;
                count = ((i + offset5) - start) - 2;
                offset = offset5;
            }
            if (count <= 65535) {
                char[] chars = sub_chars(start, count);
                BigDecimal value = new BigDecimal(chars, 0, chars.length, MathContext.UNLIMITED);
                if (chLocal == ',') {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                } else if (chLocal == ']') {
                    int offset6 = offset + 1;
                    char chLocal4 = charAt(this.bp + offset);
                    if (chLocal4 == ',') {
                        this.token = 16;
                        int i3 = this.bp + offset6;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal4 == ']') {
                        this.token = 15;
                        int i4 = this.bp + offset6;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal4 == '}') {
                        this.token = 13;
                        int i5 = this.bp + offset6;
                        this.bp = i5;
                        this.ch = charAt(i5);
                    } else if (chLocal4 == 26) {
                        this.token = 20;
                        this.bp += offset6 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                    this.matchStat = 4;
                    return value;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            } else {
                throw new JSONException("decimal overflow");
            }
        } else if (chLocal2 == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
            this.matchStat = 5;
            int offset7 = offset2 + 3;
            int offset8 = offset7 + 1;
            char chLocal5 = charAt(this.bp + offset7);
            if (quote && chLocal5 == '\"') {
                chLocal5 = charAt(this.bp + offset8);
                offset8++;
            }
            while (chLocal5 != ',') {
                if (chLocal5 == '}') {
                    int i6 = this.bp + offset8;
                    this.bp = i6;
                    this.ch = charAt(i6);
                    this.matchStat = 5;
                    this.token = 13;
                    return null;
                } else if (isWhitespace(chLocal5)) {
                    chLocal5 = charAt(this.bp + offset8);
                    offset8++;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
            int i7 = this.bp + offset8;
            this.bp = i7;
            this.ch = charAt(i7);
            this.matchStat = 5;
            this.token = 16;
            return null;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    /* JADX INFO: Multiple debug info for r13v2 int: [D('arrayIndex' int), D('tmp' float[])] */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x00ae, code lost:
        return r4;
     */
    public final float[] scanFieldFloatArray(char[] fieldName) {
        int offset;
        int intVal;
        float value;
        char chLocal;
        this.matchStat = 0;
        float[] fArr = null;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        if (charAt(this.bp + offset2) != '[') {
            this.matchStat = -2;
            return null;
        }
        int offset4 = offset3 + 1;
        char chLocal2 = charAt(this.bp + offset3);
        float[] array = new float[16];
        int arrayIndex = 0;
        while (true) {
            int start = (this.bp + offset4) - 1;
            boolean negative = chLocal2 == '-';
            if (negative) {
                chLocal2 = charAt(this.bp + offset4);
                offset4++;
            }
            if (chLocal2 < '0' || chLocal2 > '9') {
                this.matchStat = -1;
            } else {
                int intVal2 = chLocal2 - '0';
                while (true) {
                    offset = offset4 + 1;
                    chLocal2 = charAt(this.bp + offset4);
                    if (chLocal2 < '0' || chLocal2 > '9') {
                        int power = 1;
                    } else {
                        intVal2 = (intVal2 * 10) + (chLocal2 - '0');
                        offset4 = offset;
                    }
                }
                int power2 = 1;
                if (chLocal2 == '.') {
                    int offset5 = offset + 1;
                    char chLocal3 = charAt(this.bp + offset);
                    if (chLocal3 < '0' || chLocal3 > '9') {
                        this.matchStat = -1;
                    } else {
                        int intVal3 = (intVal2 * 10) + (chLocal3 - '0');
                        power2 = 10;
                        while (true) {
                            offset = offset5 + 1;
                            chLocal = charAt(this.bp + offset5);
                            if (chLocal < '0' || chLocal > '9') {
                                chLocal2 = chLocal;
                                intVal = intVal3;
                            } else {
                                intVal3 = (intVal3 * 10) + (chLocal - '0');
                                power2 *= 10;
                                offset5 = offset;
                            }
                        }
                        chLocal2 = chLocal;
                        intVal = intVal3;
                    }
                } else {
                    intVal = intVal2;
                }
                boolean exp = chLocal2 == 'e' || chLocal2 == 'E';
                if (exp) {
                    int offset6 = offset + 1;
                    chLocal2 = charAt(this.bp + offset);
                    if (chLocal2 == '+' || chLocal2 == '-') {
                        chLocal2 = charAt(this.bp + offset6);
                        offset = offset6 + 1;
                    } else {
                        offset = offset6;
                    }
                    while (chLocal2 >= '0' && chLocal2 <= '9') {
                        chLocal2 = charAt(this.bp + offset);
                        offset++;
                    }
                }
                int count = ((this.bp + offset) - start) - 1;
                if (exp || count >= 10) {
                    value = Float.parseFloat(subString(start, count));
                } else {
                    value = ((float) intVal) / ((float) power2);
                    if (negative) {
                        value = -value;
                    }
                }
                if (arrayIndex >= array.length) {
                    float[] tmp = new float[((array.length * 3) / 2)];
                    System.arraycopy(array, 0, tmp, 0, arrayIndex);
                    array = tmp;
                }
                int arrayIndex2 = arrayIndex + 1;
                array[arrayIndex] = value;
                if (chLocal2 == ',') {
                    chLocal2 = charAt(this.bp + offset);
                    offset4 = offset + 1;
                } else if (chLocal2 == ']') {
                    int offset7 = offset + 1;
                    char chLocal4 = charAt(this.bp + offset);
                    if (arrayIndex2 != array.length) {
                        float[] tmp2 = new float[arrayIndex2];
                        System.arraycopy(array, 0, tmp2, 0, arrayIndex2);
                        array = tmp2;
                    }
                    if (chLocal4 == ',') {
                        this.bp += offset7 - 1;
                        next();
                        this.matchStat = 3;
                        this.token = 16;
                        return array;
                    } else if (chLocal4 == '}') {
                        int offset8 = offset7 + 1;
                        char chLocal5 = charAt(this.bp + offset7);
                        if (chLocal5 == ',') {
                            this.token = 16;
                            this.bp += offset8 - 1;
                            next();
                        } else if (chLocal5 == ']') {
                            this.token = 15;
                            this.bp += offset8 - 1;
                            next();
                        } else if (chLocal5 == '}') {
                            this.token = 13;
                            this.bp += offset8 - 1;
                            next();
                        } else if (chLocal5 == 26) {
                            this.bp += offset8 - 1;
                            this.token = 20;
                            this.ch = JSONLexer.EOI;
                        } else {
                            this.matchStat = -1;
                            return null;
                        }
                        this.matchStat = 4;
                        return array;
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                } else {
                    offset4 = offset;
                }
                arrayIndex = arrayIndex2;
                fArr = null;
            }
        }
        this.matchStat = -1;
        return null;
    }

    /* JADX INFO: Multiple debug info for r12v3 int: [D('arrayIndex' int), D('tmp' float[])] */
    /* JADX INFO: Multiple debug info for r1v30 int: [D('arrayarrayIndex' int), D('tmp' float[][])] */
    /* JADX WARNING: Code restructure failed: missing block: B:100:0x01db, code lost:
        if (r3 != ',') goto L_0x01ec;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:101:0x01dd, code lost:
        r23.token = 16;
        r23.bp += r5 - 1;
        next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:103:0x01ee, code lost:
        if (r3 != ']') goto L_0x01ff;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:104:0x01f0, code lost:
        r23.token = 15;
        r23.bp += r5 - 1;
        next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:105:0x01ff, code lost:
        if (r3 != '}') goto L_0x0210;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:106:0x0201, code lost:
        r23.token = 13;
        r23.bp += r5 - 1;
        next();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:108:0x0212, code lost:
        if (r3 != 26) goto L_0x0225;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:109:0x0214, code lost:
        r23.bp += r5 - 1;
        r23.token = 20;
        r23.ch = com.alibaba.fastjson.parser.JSONLexer.EOI;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:110:0x0221, code lost:
        r23.matchStat = 4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:111:0x0224, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:112:0x0225, code lost:
        r23.matchStat = -1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:113:0x022b, code lost:
        return null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:114:0x022c, code lost:
        r23.matchStat = -1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:115:0x0232, code lost:
        return null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x00c0, code lost:
        return r4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:72:0x0146, code lost:
        r14 = r20 + 1;
        r3 = charAt(r23.bp + r20);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:73:0x0152, code lost:
        if (r12 == r8.length) goto L_0x015b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:0x0154, code lost:
        r1 = new float[r12];
        java.lang.System.arraycopy(r8, 0, r1, 0, r12);
        r8 = r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x015c, code lost:
        if (r9 < r7.length) goto L_0x016b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:77:0x015e, code lost:
        r1 = new float[((r7.length * 3) / 2)][];
        java.lang.System.arraycopy(r8, 0, r1, 0, r12);
        r7 = r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:0x016b, code lost:
        r1 = r9 + 1;
        r7[r9] = r8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x0171, code lost:
        if (r3 != ',') goto L_0x017e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:80:0x0173, code lost:
        r3 = charAt(r23.bp + r14);
        r8 = r14 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x0180, code lost:
        if (r3 != ']') goto L_0x018e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:83:0x0182, code lost:
        r3 = charAt(r23.bp + r14);
        r9 = r1;
        r8 = r14 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:84:0x018e, code lost:
        r8 = r14;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:91:0x01ae, code lost:
        if (r9 == r7.length) goto L_0x01b7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:92:0x01b0, code lost:
        r1 = new float[r9][];
        java.lang.System.arraycopy(r7, 0, r1, 0, r9);
        r7 = r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:94:0x01b9, code lost:
        if (r3 != ',') goto L_0x01cc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:95:0x01bb, code lost:
        r23.bp += r8 - 1;
        next();
        r23.matchStat = 3;
        r23.token = 16;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:96:0x01cb, code lost:
        return r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:98:0x01ce, code lost:
        if (r3 != '}') goto L_0x022c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:99:0x01d0, code lost:
        r5 = r8 + 1;
        r3 = charAt(r23.bp + r8);
     */
    public final float[][] scanFieldFloatArray2(char[] fieldName) {
        int offset;
        int intVal;
        float value;
        int arrayarrayIndex;
        this.matchStat = 0;
        float[][] fArr = null;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal = charAt(this.bp + offset2);
        char c = Operators.ARRAY_START;
        if (chLocal != '[') {
            this.matchStat = -2;
            return null;
        }
        int offset4 = offset3 + 1;
        char chLocal2 = charAt(this.bp + offset3);
        int i = 16;
        float[][] arrayarray = new float[16][];
        int arrayarrayIndex2 = 0;
        loop0:
        while (true) {
            int arrayIndex = -1;
            if (chLocal2 != c) {
                break;
            }
            int offset5 = offset4 + 1;
            char chLocal3 = charAt(this.bp + offset4);
            float[] array = new float[i];
            int arrayIndex2 = 0;
            while (true) {
                int start = (this.bp + offset5) - 1;
                boolean negative = chLocal3 == '-';
                if (negative) {
                    chLocal3 = charAt(this.bp + offset5);
                    offset5++;
                }
                if (chLocal3 < '0' || chLocal3 > '9') {
                    this.matchStat = -1;
                } else {
                    int intVal2 = chLocal3 - '0';
                    while (true) {
                        offset = offset5 + 1;
                        chLocal3 = charAt(this.bp + offset5);
                        if (chLocal3 < '0' || chLocal3 > '9') {
                            int power = 1;
                        } else {
                            intVal2 = (intVal2 * 10) + (chLocal3 - '0');
                            offset5 = offset;
                        }
                    }
                    int power2 = 1;
                    if (chLocal3 == '.') {
                        int offset6 = offset + 1;
                        char chLocal4 = charAt(this.bp + offset);
                        if (chLocal4 < '0' || chLocal4 > '9') {
                            this.matchStat = arrayIndex;
                        } else {
                            power2 = 10;
                            int intVal3 = (intVal2 * 10) + (chLocal4 - '0');
                            while (true) {
                                offset = offset6 + 1;
                                chLocal3 = charAt(this.bp + offset6);
                                if (chLocal3 < '0' || chLocal3 > '9') {
                                    intVal = intVal3;
                                } else {
                                    intVal3 = (intVal3 * 10) + (chLocal3 - '0');
                                    power2 *= 10;
                                    offset6 = offset;
                                }
                            }
                            intVal = intVal3;
                        }
                    } else {
                        intVal = intVal2;
                    }
                    boolean exp = chLocal3 == 'e' || chLocal3 == 'E';
                    if (exp) {
                        int offset7 = offset + 1;
                        chLocal3 = charAt(this.bp + offset);
                        if (chLocal3 == '+' || chLocal3 == '-') {
                            chLocal3 = charAt(this.bp + offset7);
                            offset = offset7 + 1;
                        } else {
                            offset = offset7;
                        }
                        while (chLocal3 >= '0' && chLocal3 <= '9') {
                            chLocal3 = charAt(this.bp + offset);
                            offset++;
                        }
                    }
                    int count = ((this.bp + offset) - start) - 1;
                    if (exp || count >= 10) {
                        value = Float.parseFloat(subString(start, count));
                    } else {
                        value = ((float) intVal) / ((float) power2);
                        if (negative) {
                            value = -value;
                        }
                    }
                    if (arrayIndex2 >= array.length) {
                        float[] tmp = new float[((array.length * 3) / 2)];
                        System.arraycopy(array, 0, tmp, 0, arrayIndex2);
                        array = tmp;
                    }
                    int arrayIndex3 = arrayIndex2 + 1;
                    array[arrayIndex2] = value;
                    if (chLocal3 == ',') {
                        chLocal3 = charAt(this.bp + offset);
                        offset5 = offset + 1;
                    } else if (chLocal3 == ']') {
                        break;
                    } else {
                        offset5 = offset;
                    }
                    arrayIndex2 = arrayIndex3;
                    fArr = null;
                    arrayIndex = -1;
                }
            }
            arrayarrayIndex2 = arrayarrayIndex;
            fArr = null;
            i = 16;
            c = Operators.ARRAY_START;
        }
        this.matchStat = -1;
        return null;
    }

    public final double scanFieldDouble(char[] fieldName) {
        int offset;
        char chLocal;
        boolean negative;
        int start;
        int count;
        double value;
        char chLocal2;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return 0.0d;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal3 = charAt(this.bp + offset2);
        boolean quote = chLocal3 == '\"';
        if (quote) {
            chLocal3 = charAt(this.bp + offset3);
            offset3++;
        }
        boolean negative2 = chLocal3 == '-';
        if (negative2) {
            chLocal3 = charAt(this.bp + offset3);
            offset3++;
        }
        char c = '0';
        if (chLocal3 >= '0') {
            char c2 = '9';
            if (chLocal3 <= '9') {
                long intVal = (long) (chLocal3 - '0');
                while (true) {
                    offset = offset3 + 1;
                    chLocal = charAt(this.bp + offset3);
                    if (chLocal < '0' || chLocal > '9') {
                        long power = 1;
                    } else {
                        intVal = (10 * intVal) + ((long) (chLocal - '0'));
                        offset3 = offset;
                        quote = quote;
                    }
                }
                long power2 = 1;
                if (chLocal == '.') {
                    int offset4 = offset + 1;
                    char chLocal4 = charAt(this.bp + offset);
                    if (chLocal4 < '0' || chLocal4 > '9') {
                        this.matchStat = -1;
                        return 0.0d;
                    }
                    negative = negative2;
                    power2 = 10;
                    intVal = (intVal * 10) + ((long) (chLocal4 - '0'));
                    while (true) {
                        offset = offset4 + 1;
                        chLocal2 = charAt(this.bp + offset4);
                        if (chLocal2 < c || chLocal2 > c2) {
                            chLocal = chLocal2;
                        } else {
                            intVal = (intVal * 10) + ((long) (chLocal2 - '0'));
                            power2 *= 10;
                            offset4 = offset;
                            c2 = '9';
                            c = '0';
                        }
                    }
                    chLocal = chLocal2;
                } else {
                    negative = negative2;
                }
                boolean exp = chLocal == 'e' || chLocal == 'E';
                if (exp) {
                    int offset5 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    if (chLocal == '+' || chLocal == '-') {
                        chLocal = charAt(this.bp + offset5);
                        offset = offset5 + 1;
                    } else {
                        offset = offset5;
                    }
                    while (chLocal >= '0' && chLocal <= '9') {
                        chLocal = charAt(this.bp + offset);
                        offset++;
                    }
                }
                if (!quote) {
                    int count2 = this.bp;
                    start = count2 + fieldName.length;
                    count = ((count2 + offset) - start) - 1;
                } else if (chLocal != '\"') {
                    this.matchStat = -1;
                    return 0.0d;
                } else {
                    int offset6 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    int i = this.bp;
                    start = fieldName.length + i + 1;
                    count = ((i + offset6) - start) - 2;
                    offset = offset6;
                }
                if (exp || count >= 17) {
                    value = Double.parseDouble(subString(start, count));
                } else {
                    value = ((double) intVal) / ((double) power2);
                    if (negative) {
                        value = -value;
                    }
                }
                if (chLocal == ',') {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                } else if (chLocal == '}') {
                    int offset7 = offset + 1;
                    char chLocal5 = charAt(this.bp + offset);
                    if (chLocal5 == ',') {
                        this.token = 16;
                        int i3 = this.bp + offset7;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal5 == ']') {
                        this.token = 15;
                        int i4 = this.bp + offset7;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal5 == '}') {
                        this.token = 13;
                        int i5 = this.bp + offset7;
                        this.bp = i5;
                        this.ch = charAt(i5);
                    } else if (chLocal5 == 26) {
                        this.token = 20;
                        this.bp += offset7 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return 0.0d;
                    }
                    this.matchStat = 4;
                    return value;
                } else {
                    this.matchStat = -1;
                    return 0.0d;
                }
            }
        }
        if (chLocal3 == 'n' && charAt(this.bp + offset3) == 'u' && charAt(this.bp + offset3 + 1) == 'l' && charAt(this.bp + offset3 + 2) == 'l') {
            this.matchStat = 5;
            int offset8 = offset3 + 3;
            int offset9 = offset8 + 1;
            char chLocal6 = charAt(this.bp + offset8);
            if (quote && chLocal6 == '\"') {
                chLocal6 = charAt(this.bp + offset9);
                offset9++;
            }
            while (chLocal6 != ',') {
                if (chLocal6 == '}') {
                    int i6 = this.bp + offset9;
                    this.bp = i6;
                    this.ch = charAt(i6);
                    this.matchStat = 5;
                    this.token = 13;
                    return 0.0d;
                } else if (isWhitespace(chLocal6)) {
                    chLocal6 = charAt(this.bp + offset9);
                    offset9++;
                } else {
                    this.matchStat = -1;
                    return 0.0d;
                }
            }
            int i7 = this.bp + offset9;
            this.bp = i7;
            this.ch = charAt(i7);
            this.matchStat = 5;
            this.token = 16;
            return 0.0d;
        }
        this.matchStat = -1;
        return 0.0d;
    }

    public BigDecimal scanFieldDecimal(char[] fieldName) {
        int offset;
        char chLocal;
        int start;
        int count;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal2 = charAt(this.bp + offset2);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal2 == '-') {
            chLocal2 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal2 >= '0' && chLocal2 <= '9') {
            while (true) {
                offset = offset3 + 1;
                chLocal = charAt(this.bp + offset3);
                if (chLocal >= '0' && chLocal <= '9') {
                    offset3 = offset;
                }
            }
            if (chLocal == '.') {
                int offset4 = offset + 1;
                char chLocal3 = charAt(this.bp + offset);
                if (chLocal3 >= '0' && chLocal3 <= '9') {
                    while (true) {
                        offset = offset4 + 1;
                        chLocal = charAt(this.bp + offset4);
                        if (chLocal < '0' || chLocal > '9') {
                            break;
                        }
                        offset4 = offset;
                    }
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
            if (chLocal == 'e' || chLocal == 'E') {
                int offset5 = offset + 1;
                chLocal = charAt(this.bp + offset);
                if (chLocal == '+' || chLocal == '-') {
                    chLocal = charAt(this.bp + offset5);
                    offset = offset5 + 1;
                } else {
                    offset = offset5;
                }
                while (chLocal >= '0' && chLocal <= '9') {
                    chLocal = charAt(this.bp + offset);
                    offset++;
                }
            }
            if (!quote) {
                int count2 = this.bp;
                start = count2 + fieldName.length;
                count = ((count2 + offset) - start) - 1;
            } else if (chLocal != '\"') {
                this.matchStat = -1;
                return null;
            } else {
                int offset6 = offset + 1;
                chLocal = charAt(this.bp + offset);
                int i = this.bp;
                start = fieldName.length + i + 1;
                count = ((i + offset6) - start) - 2;
                offset = offset6;
            }
            if (count <= 65535) {
                char[] chars = sub_chars(start, count);
                BigDecimal value = new BigDecimal(chars, 0, chars.length, MathContext.UNLIMITED);
                if (chLocal == ',') {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                } else if (chLocal == '}') {
                    int offset7 = offset + 1;
                    char chLocal4 = charAt(this.bp + offset);
                    if (chLocal4 == ',') {
                        this.token = 16;
                        int i3 = this.bp + offset7;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal4 == ']') {
                        this.token = 15;
                        int i4 = this.bp + offset7;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal4 == '}') {
                        this.token = 13;
                        int i5 = this.bp + offset7;
                        this.bp = i5;
                        this.ch = charAt(i5);
                    } else if (chLocal4 == 26) {
                        this.token = 20;
                        this.bp += offset7 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                    this.matchStat = 4;
                    return value;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            } else {
                throw new JSONException("scan decimal overflow");
            }
        } else if (chLocal2 == 'n' && charAt(this.bp + offset3) == 'u' && charAt(this.bp + offset3 + 1) == 'l' && charAt(this.bp + offset3 + 2) == 'l') {
            this.matchStat = 5;
            int offset8 = offset3 + 3;
            int offset9 = offset8 + 1;
            char chLocal5 = charAt(this.bp + offset8);
            if (quote && chLocal5 == '\"') {
                chLocal5 = charAt(this.bp + offset9);
                offset9++;
            }
            while (chLocal5 != ',') {
                if (chLocal5 == '}') {
                    int i6 = this.bp + offset9;
                    this.bp = i6;
                    this.ch = charAt(i6);
                    this.matchStat = 5;
                    this.token = 13;
                    return null;
                } else if (isWhitespace(chLocal5)) {
                    chLocal5 = charAt(this.bp + offset9);
                    offset9++;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
            int i7 = this.bp + offset9;
            this.bp = i7;
            this.ch = charAt(i7);
            this.matchStat = 5;
            this.token = 16;
            return null;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public BigInteger scanFieldBigInteger(char[] fieldName) {
        int offset;
        char chLocal;
        int start;
        int count;
        BigInteger value;
        boolean negative = false;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal2 = charAt(this.bp + offset2);
        boolean quote = chLocal2 == '\"';
        if (quote) {
            chLocal2 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal2 == '-') {
            negative = true;
        }
        if (negative) {
            chLocal2 = charAt(this.bp + offset3);
            offset3++;
        }
        if (chLocal2 >= '0') {
            char c = '9';
            if (chLocal2 <= '9') {
                long intVal = (long) (chLocal2 - '0');
                boolean overflow = false;
                while (true) {
                    offset = offset3 + 1;
                    chLocal = charAt(this.bp + offset3);
                    if (chLocal < '0' || chLocal > c) {
                        break;
                    }
                    long temp = (10 * intVal) + ((long) (chLocal - '0'));
                    if (temp < intVal) {
                        overflow = true;
                        break;
                    }
                    intVal = temp;
                    offset3 = offset;
                    c = '9';
                }
                if (!quote) {
                    int count2 = this.bp;
                    start = count2 + fieldName.length;
                    count = ((count2 + offset) - start) - 1;
                } else if (chLocal != '\"') {
                    this.matchStat = -1;
                    return null;
                } else {
                    int offset4 = offset + 1;
                    chLocal = charAt(this.bp + offset);
                    int i = this.bp;
                    start = fieldName.length + i + 1;
                    count = ((i + offset4) - start) - 2;
                    offset = offset4;
                }
                if (!overflow && (count < 20 || (negative && count < 21))) {
                    value = BigInteger.valueOf(negative ? -intVal : intVal);
                } else if (count <= 65535) {
                    value = new BigInteger(subString(start, count), 10);
                } else {
                    throw new JSONException("scanInteger overflow");
                }
                if (chLocal == ',') {
                    int i2 = this.bp + offset;
                    this.bp = i2;
                    this.ch = charAt(i2);
                    this.matchStat = 3;
                    this.token = 16;
                    return value;
                } else if (chLocal == '}') {
                    int offset5 = offset + 1;
                    char chLocal3 = charAt(this.bp + offset);
                    if (chLocal3 == ',') {
                        this.token = 16;
                        int i3 = this.bp + offset5;
                        this.bp = i3;
                        this.ch = charAt(i3);
                    } else if (chLocal3 == ']') {
                        this.token = 15;
                        int i4 = this.bp + offset5;
                        this.bp = i4;
                        this.ch = charAt(i4);
                    } else if (chLocal3 == '}') {
                        this.token = 13;
                        int i5 = this.bp + offset5;
                        this.bp = i5;
                        this.ch = charAt(i5);
                    } else if (chLocal3 == 26) {
                        this.token = 20;
                        this.bp += offset5 - 1;
                        this.ch = JSONLexer.EOI;
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                    this.matchStat = 4;
                    return value;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
        }
        if (chLocal2 == 'n' && charAt(this.bp + offset3) == 'u' && charAt(this.bp + offset3 + 1) == 'l' && charAt(this.bp + offset3 + 2) == 'l') {
            this.matchStat = 5;
            int offset6 = offset3 + 3;
            int offset7 = offset6 + 1;
            char chLocal4 = charAt(this.bp + offset6);
            if (quote && chLocal4 == '\"') {
                chLocal4 = charAt(this.bp + offset7);
                offset7++;
            }
            while (chLocal4 != ',') {
                if (chLocal4 == '}') {
                    int i6 = this.bp + offset7;
                    this.bp = i6;
                    this.ch = charAt(i6);
                    this.matchStat = 5;
                    this.token = 13;
                    return null;
                } else if (isWhitespace(chLocal4)) {
                    chLocal4 = charAt(this.bp + offset7);
                    offset7++;
                } else {
                    this.matchStat = -1;
                    return null;
                }
            }
            int i7 = this.bp + offset7;
            this.bp = i7;
            this.ch = charAt(i7);
            this.matchStat = 5;
            this.token = 16;
            return null;
        }
        this.matchStat = -1;
        return null;
    }

    public Date scanFieldDate(char[] fieldName) {
        int offset;
        Date dateVal;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal = charAt(this.bp + offset2);
        if (chLocal == '\"') {
            int endIndex = indexOf(Operators.QUOTE, this.bp + fieldName.length + 1);
            if (endIndex != -1) {
                int startIndex2 = this.bp + fieldName.length + 1;
                String stringVal = subString(startIndex2, endIndex - startIndex2);
                if (stringVal.indexOf(92) != -1) {
                    while (true) {
                        int slashCount = 0;
                        int i = endIndex - 1;
                        while (i >= 0 && charAt(i) == '\\') {
                            slashCount++;
                            i--;
                        }
                        if (slashCount % 2 == 0) {
                            break;
                        }
                        endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                    }
                    int i2 = this.bp;
                    int chars_len = endIndex - ((fieldName.length + i2) + 1);
                    stringVal = readString(sub_chars(i2 + fieldName.length + 1, chars_len), chars_len);
                }
                int i3 = this.bp;
                int offset4 = offset3 + (endIndex - ((fieldName.length + i3) + 1)) + 1;
                offset = offset4 + 1;
                chLocal = charAt(i3 + offset4);
                JSONScanner dateLexer = new JSONScanner(stringVal);
                try {
                    if (dateLexer.scanISO8601DateIfMatch(false)) {
                        dateVal = dateLexer.getCalendar().getTime();
                    } else {
                        this.matchStat = -1;
                        dateLexer.close();
                        return null;
                    }
                } finally {
                    dateLexer.close();
                }
            } else {
                throw new JSONException("unclosed str");
            }
        } else {
            char c = '9';
            if (chLocal == '-' || (chLocal >= '0' && chLocal <= '9')) {
                long millis = 0;
                boolean negative = false;
                if (chLocal == '-') {
                    chLocal = charAt(this.bp + offset3);
                    negative = true;
                    offset3++;
                }
                if (chLocal >= '0' && chLocal <= '9') {
                    millis = (long) (chLocal - '0');
                    while (true) {
                        offset = offset3 + 1;
                        chLocal = charAt(this.bp + offset3);
                        if (chLocal < '0' || chLocal > c) {
                            break;
                        }
                        millis = (10 * millis) + ((long) (chLocal - '0'));
                        offset3 = offset;
                        c = '9';
                    }
                } else {
                    offset = offset3;
                }
                if (millis < 0) {
                    this.matchStat = -1;
                    return null;
                }
                if (negative) {
                    millis = -millis;
                }
                dateVal = new Date(millis);
            } else {
                this.matchStat = -1;
                return null;
            }
        }
        if (chLocal == ',') {
            int i4 = this.bp + offset;
            this.bp = i4;
            this.ch = charAt(i4);
            this.matchStat = 3;
            return dateVal;
        } else if (chLocal == '}') {
            int offset5 = offset + 1;
            char chLocal2 = charAt(this.bp + offset);
            if (chLocal2 == ',') {
                this.token = 16;
                int i5 = this.bp + offset5;
                this.bp = i5;
                this.ch = charAt(i5);
            } else if (chLocal2 == ']') {
                this.token = 15;
                int i6 = this.bp + offset5;
                this.bp = i6;
                this.ch = charAt(i6);
            } else if (chLocal2 == '}') {
                this.token = 13;
                int i7 = this.bp + offset5;
                this.bp = i7;
                this.ch = charAt(i7);
            } else if (chLocal2 == 26) {
                this.token = 20;
                this.bp += offset5 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return null;
            }
            this.matchStat = 4;
            return dateVal;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public Date scanDate(char seperator) {
        int offset;
        Date dateVal;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal = charAt(this.bp + 0);
        if (chLocal == '\"') {
            int endIndex = indexOf(Operators.QUOTE, this.bp + 1);
            if (endIndex != -1) {
                int startIndex2 = this.bp + 1;
                String stringVal = subString(startIndex2, endIndex - startIndex2);
                if (stringVal.indexOf(92) != -1) {
                    while (true) {
                        int slashCount = 0;
                        int i = endIndex - 1;
                        while (i >= 0 && charAt(i) == '\\') {
                            slashCount++;
                            i--;
                        }
                        if (slashCount % 2 == 0) {
                            break;
                        }
                        endIndex = indexOf(Operators.QUOTE, endIndex + 1);
                    }
                    int i2 = this.bp;
                    int chars_len = endIndex - (i2 + 1);
                    stringVal = readString(sub_chars(i2 + 1, chars_len), chars_len);
                }
                int i3 = this.bp;
                int offset3 = offset2 + (endIndex - (i3 + 1)) + 1;
                offset = offset3 + 1;
                chLocal = charAt(i3 + offset3);
                JSONScanner dateLexer = new JSONScanner(stringVal);
                try {
                    if (dateLexer.scanISO8601DateIfMatch(false)) {
                        dateVal = dateLexer.getCalendar().getTime();
                    } else {
                        this.matchStat = -1;
                        dateLexer.close();
                        return null;
                    }
                } finally {
                    dateLexer.close();
                }
            } else {
                throw new JSONException("unclosed str");
            }
        } else {
            char c = '0';
            if (chLocal == '-' || (chLocal >= '0' && chLocal <= '9')) {
                long millis = 0;
                boolean negative = false;
                if (chLocal == '-') {
                    chLocal = charAt(this.bp + offset2);
                    negative = true;
                    offset2++;
                }
                if (chLocal < '0' || chLocal > '9') {
                    offset = offset2;
                } else {
                    long millis2 = (long) (chLocal - '0');
                    while (true) {
                        offset = offset2 + 1;
                        chLocal = charAt(this.bp + offset2);
                        if (chLocal < c || chLocal > '9') {
                            millis = millis2;
                        } else {
                            millis2 = (10 * millis2) + ((long) (chLocal - '0'));
                            offset2 = offset;
                            c = '0';
                        }
                    }
                    millis = millis2;
                }
                if (millis < 0) {
                    this.matchStat = -1;
                    return null;
                }
                if (negative) {
                    millis = -millis;
                }
                dateVal = new Date(millis);
            } else if (chLocal == 'n' && charAt(this.bp + offset2) == 'u' && charAt(this.bp + offset2 + 1) == 'l' && charAt(this.bp + offset2 + 2) == 'l') {
                this.matchStat = 5;
                dateVal = null;
                int offset4 = offset2 + 3;
                offset = offset4 + 1;
                chLocal = charAt(this.bp + offset4);
            } else {
                this.matchStat = -1;
                return null;
            }
        }
        if (chLocal == ',') {
            int i4 = this.bp + offset;
            this.bp = i4;
            this.ch = charAt(i4);
            this.matchStat = 3;
            this.token = 16;
            return dateVal;
        } else if (chLocal == ']') {
            int offset5 = offset + 1;
            char chLocal2 = charAt(this.bp + offset);
            if (chLocal2 == ',') {
                this.token = 16;
                int i5 = this.bp + offset5;
                this.bp = i5;
                this.ch = charAt(i5);
            } else if (chLocal2 == ']') {
                this.token = 15;
                int i6 = this.bp + offset5;
                this.bp = i6;
                this.ch = charAt(i6);
            } else if (chLocal2 == '}') {
                this.token = 13;
                int i7 = this.bp + offset5;
                this.bp = i7;
                this.ch = charAt(i7);
            } else if (chLocal2 == 26) {
                this.token = 20;
                this.bp += offset5 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return null;
            }
            this.matchStat = 4;
            return dateVal;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public UUID scanFieldUUID(char[] fieldName) {
        int offset;
        UUID uuid;
        char chLocal;
        int num;
        int num2;
        int num3;
        int num4;
        int num5;
        int num6;
        int num7;
        this.matchStat = 0;
        if (!charArrayCompare(fieldName)) {
            this.matchStat = -2;
            return null;
        }
        int offset2 = fieldName.length;
        int offset3 = offset2 + 1;
        char chLocal2 = charAt(this.bp + offset2);
        if (chLocal2 == '\"') {
            int endIndex = indexOf(Operators.QUOTE, this.bp + fieldName.length + 1);
            if (endIndex != -1) {
                int startIndex2 = this.bp + fieldName.length + 1;
                int len = endIndex - startIndex2;
                char c = 'F';
                char c2 = 'f';
                char c3 = '9';
                char c4 = 'A';
                char c5 = 'a';
                char c6 = '0';
                if (len == 36) {
                    long mostSigBits = 0;
                    long leastSigBits = 0;
                    int i = 0;
                    while (i < 8) {
                        char ch2 = charAt(startIndex2 + i);
                        if (ch2 >= '0' && ch2 <= '9') {
                            num7 = ch2 - '0';
                        } else if (ch2 >= 'a' && ch2 <= 'f') {
                            num7 = (ch2 - 'a') + 10;
                        } else if (ch2 < c4 || ch2 > c) {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num7 = (ch2 - 'A') + 10;
                        }
                        mostSigBits = (mostSigBits << 4) | ((long) num7);
                        i++;
                        offset3 = offset3;
                        c4 = 'A';
                        c = 'F';
                    }
                    for (int i2 = 9; i2 < 13; i2++) {
                        char ch3 = charAt(startIndex2 + i2);
                        if (ch3 >= '0' && ch3 <= '9') {
                            num6 = ch3 - '0';
                        } else if (ch3 >= 'a' && ch3 <= 'f') {
                            num6 = (ch3 - 'a') + 10;
                        } else if (ch3 < 'A' || ch3 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num6 = (ch3 - 'A') + 10;
                        }
                        mostSigBits = (mostSigBits << 4) | ((long) num6);
                    }
                    int i3 = 14;
                    long mostSigBits2 = mostSigBits;
                    while (i3 < 18) {
                        char ch4 = charAt(startIndex2 + i3);
                        if (ch4 >= '0' && ch4 <= c3) {
                            num5 = ch4 - '0';
                        } else if (ch4 >= 'a' && ch4 <= 'f') {
                            num5 = (ch4 - 'a') + 10;
                        } else if (ch4 < 'A' || ch4 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num5 = (ch4 - 'A') + 10;
                        }
                        mostSigBits2 = (mostSigBits2 << 4) | ((long) num5);
                        i3++;
                        endIndex = endIndex;
                        c3 = '9';
                    }
                    int i4 = 19;
                    while (i4 < 23) {
                        char ch5 = charAt(startIndex2 + i4);
                        if (ch5 >= '0' && ch5 <= '9') {
                            num4 = ch5 - '0';
                        } else if (ch5 >= 'a' && ch5 <= c2) {
                            num4 = (ch5 - 'a') + 10;
                        } else if (ch5 < 'A' || ch5 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num4 = (ch5 - 'A') + 10;
                        }
                        leastSigBits = (leastSigBits << 4) | ((long) num4);
                        i4++;
                        c2 = 'f';
                    }
                    long leastSigBits2 = leastSigBits;
                    for (int i5 = 24; i5 < 36; i5++) {
                        char ch6 = charAt(startIndex2 + i5);
                        if (ch6 >= '0' && ch6 <= '9') {
                            num3 = ch6 - '0';
                        } else if (ch6 >= 'a' && ch6 <= 'f') {
                            num3 = (ch6 - 'a') + 10;
                        } else if (ch6 < 'A' || ch6 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num3 = (ch6 - 'A') + 10;
                        }
                        leastSigBits2 = (leastSigBits2 << 4) | ((long) num3);
                    }
                    uuid = new UUID(mostSigBits2, leastSigBits2);
                    int i6 = this.bp;
                    int offset4 = offset3 + (endIndex - ((fieldName.length + i6) + 1)) + 1;
                    offset = offset4 + 1;
                    chLocal = charAt(i6 + offset4);
                } else {
                    if (len == 32) {
                        long mostSigBits3 = 0;
                        long leastSigBits3 = 0;
                        int i7 = 0;
                        while (i7 < 16) {
                            char ch7 = charAt(startIndex2 + i7);
                            if (ch7 >= c6 && ch7 <= '9') {
                                num2 = ch7 - '0';
                            } else if (ch7 >= c5 && ch7 <= 'f') {
                                num2 = (ch7 - 'a') + 10;
                            } else if (ch7 < 'A' || ch7 > 'F') {
                                this.matchStat = -2;
                                return null;
                            } else {
                                num2 = (ch7 - 'A') + 10;
                            }
                            mostSigBits3 = (mostSigBits3 << 4) | ((long) num2);
                            i7++;
                            c6 = '0';
                            c5 = 'a';
                        }
                        int i8 = 16;
                        for (int i9 = 32; i8 < i9; i9 = 32) {
                            char ch8 = charAt(startIndex2 + i8);
                            if (ch8 >= '0') {
                                if (ch8 <= '9') {
                                    num = ch8 - '0';
                                    leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                                    i8++;
                                }
                            }
                            if (ch8 >= 'a') {
                                if (ch8 <= 'f') {
                                    num = (ch8 - 'a') + 10;
                                    leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                                    i8++;
                                }
                            }
                            if (ch8 < 'A' || ch8 > 'F') {
                                this.matchStat = -2;
                                return null;
                            }
                            num = (ch8 - 'A') + 10;
                            leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                            i8++;
                        }
                        uuid = new UUID(mostSigBits3, leastSigBits3);
                        int i10 = this.bp;
                        int offset5 = offset3 + (endIndex - ((fieldName.length + i10) + 1)) + 1;
                        offset = offset5 + 1;
                        chLocal = charAt(i10 + offset5);
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                }
            } else {
                throw new JSONException("unclosed str");
            }
        } else {
            if (chLocal2 == 'n') {
                int offset6 = offset3 + 1;
                if (charAt(this.bp + offset3) == 'u') {
                    int offset7 = offset6 + 1;
                    if (charAt(this.bp + offset6) == 'l') {
                        int offset8 = offset7 + 1;
                        if (charAt(this.bp + offset7) == 'l') {
                            uuid = null;
                            offset = offset8 + 1;
                            chLocal = charAt(this.bp + offset8);
                        }
                    }
                }
            }
            this.matchStat = -1;
            return null;
        }
        if (chLocal == ',') {
            int i11 = this.bp + offset;
            this.bp = i11;
            this.ch = charAt(i11);
            this.matchStat = 3;
            return uuid;
        } else if (chLocal == '}') {
            int offset9 = offset + 1;
            char chLocal3 = charAt(this.bp + offset);
            if (chLocal3 == ',') {
                this.token = 16;
                int i12 = this.bp + offset9;
                this.bp = i12;
                this.ch = charAt(i12);
            } else if (chLocal3 == ']') {
                this.token = 15;
                int i13 = this.bp + offset9;
                this.bp = i13;
                this.ch = charAt(i13);
            } else if (chLocal3 == '}') {
                this.token = 13;
                int i14 = this.bp + offset9;
                this.bp = i14;
                this.ch = charAt(i14);
            } else if (chLocal3 == 26) {
                this.token = 20;
                this.bp += offset9 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return null;
            }
            this.matchStat = 4;
            return uuid;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public UUID scanUUID(char seperator) {
        int offset;
        UUID uuid;
        char chLocal;
        int num;
        int num2;
        int num3;
        int num4;
        int num5;
        int num6;
        int num7;
        this.matchStat = 0;
        int offset2 = 0 + 1;
        char chLocal2 = charAt(this.bp + 0);
        char c = 4;
        if (chLocal2 == '\"') {
            int endIndex = indexOf(Operators.QUOTE, this.bp + 1);
            if (endIndex != -1) {
                int startIndex2 = this.bp + 1;
                int len = endIndex - startIndex2;
                char c2 = 'F';
                char c3 = 'f';
                char c4 = '9';
                char c5 = 'A';
                char c6 = 'a';
                char c7 = '0';
                if (len == 36) {
                    long mostSigBits = 0;
                    long leastSigBits = 0;
                    int i = 0;
                    while (i < 8) {
                        char ch2 = charAt(startIndex2 + i);
                        if (ch2 >= '0' && ch2 <= '9') {
                            num7 = ch2 - '0';
                        } else if (ch2 >= 'a' && ch2 <= 'f') {
                            num7 = (ch2 - 'a') + 10;
                        } else if (ch2 < c5 || ch2 > c2) {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num7 = (ch2 - 'A') + 10;
                        }
                        mostSigBits = (mostSigBits << 4) | ((long) num7);
                        i++;
                        endIndex = endIndex;
                        c5 = 'A';
                        c2 = 'F';
                    }
                    int i2 = 9;
                    while (i2 < 13) {
                        char ch3 = charAt(startIndex2 + i2);
                        if (ch3 >= '0' && ch3 <= '9') {
                            num6 = ch3 - '0';
                        } else if (ch3 >= c6 && ch3 <= 'f') {
                            num6 = (ch3 - 'a') + 10;
                        } else if (ch3 < 'A' || ch3 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num6 = (ch3 - 'A') + 10;
                        }
                        mostSigBits = (mostSigBits << 4) | ((long) num6);
                        i2++;
                        offset2 = offset2;
                        c6 = 'a';
                    }
                    long mostSigBits2 = mostSigBits;
                    for (int i3 = 14; i3 < 18; i3++) {
                        char ch4 = charAt(startIndex2 + i3);
                        if (ch4 >= '0' && ch4 <= '9') {
                            num5 = ch4 - '0';
                        } else if (ch4 >= 'a' && ch4 <= 'f') {
                            num5 = (ch4 - 'a') + 10;
                        } else if (ch4 < 'A' || ch4 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num5 = (ch4 - 'A') + 10;
                        }
                        mostSigBits2 = (mostSigBits2 << 4) | ((long) num5);
                    }
                    int i4 = 19;
                    while (i4 < 23) {
                        char ch5 = charAt(startIndex2 + i4);
                        if (ch5 >= '0' && ch5 <= c4) {
                            num4 = ch5 - '0';
                        } else if (ch5 >= 'a' && ch5 <= 'f') {
                            num4 = (ch5 - 'a') + 10;
                        } else if (ch5 < 'A' || ch5 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num4 = (ch5 - 'A') + 10;
                        }
                        leastSigBits = (leastSigBits << c) | ((long) num4);
                        i4++;
                        c4 = '9';
                        c = 4;
                    }
                    int i5 = 24;
                    long leastSigBits2 = leastSigBits;
                    while (i5 < 36) {
                        char ch6 = charAt(startIndex2 + i5);
                        if (ch6 >= c7 && ch6 <= '9') {
                            num3 = ch6 - '0';
                        } else if (ch6 >= 'a' && ch6 <= 'f') {
                            num3 = (ch6 - 'a') + 10;
                        } else if (ch6 < 'A' || ch6 > 'F') {
                            this.matchStat = -2;
                            return null;
                        } else {
                            num3 = (ch6 - 'A') + 10;
                        }
                        leastSigBits2 = (leastSigBits2 << 4) | ((long) num3);
                        i5++;
                        c7 = '0';
                    }
                    uuid = new UUID(mostSigBits2, leastSigBits2);
                    int i6 = this.bp;
                    int offset3 = offset2 + (endIndex - (i6 + 1)) + 1;
                    offset = offset3 + 1;
                    chLocal = charAt(i6 + offset3);
                } else {
                    if (len == 32) {
                        long mostSigBits3 = 0;
                        long leastSigBits3 = 0;
                        int i7 = 0;
                        while (i7 < 16) {
                            char ch7 = charAt(startIndex2 + i7);
                            if (ch7 >= '0' && ch7 <= '9') {
                                num2 = ch7 - '0';
                            } else if (ch7 >= 'a' && ch7 <= c3) {
                                num2 = (ch7 - 'a') + 10;
                            } else if (ch7 < 'A' || ch7 > 'F') {
                                this.matchStat = -2;
                                return null;
                            } else {
                                num2 = (ch7 - 'A') + 10;
                            }
                            mostSigBits3 = (mostSigBits3 << 4) | ((long) num2);
                            i7++;
                            c3 = 'f';
                        }
                        int i8 = 16;
                        for (int i9 = 32; i8 < i9; i9 = 32) {
                            char ch8 = charAt(startIndex2 + i8);
                            if (ch8 >= '0') {
                                if (ch8 <= '9') {
                                    num = ch8 - '0';
                                    leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                                    i8++;
                                }
                            }
                            if (ch8 >= 'a') {
                                if (ch8 <= 'f') {
                                    num = (ch8 - 'a') + 10;
                                    leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                                    i8++;
                                }
                            }
                            if (ch8 < 'A' || ch8 > 'F') {
                                this.matchStat = -2;
                                return null;
                            }
                            num = (ch8 - 'A') + 10;
                            leastSigBits3 = (leastSigBits3 << 4) | ((long) num);
                            i8++;
                        }
                        uuid = new UUID(mostSigBits3, leastSigBits3);
                        int i10 = this.bp;
                        int offset4 = offset2 + (endIndex - (i10 + 1)) + 1;
                        offset = offset4 + 1;
                        chLocal = charAt(i10 + offset4);
                    } else {
                        this.matchStat = -1;
                        return null;
                    }
                }
            } else {
                throw new JSONException("unclosed str");
            }
        } else {
            if (chLocal2 == 'n') {
                int offset5 = offset2 + 1;
                if (charAt(this.bp + offset2) == 'u') {
                    int offset6 = offset5 + 1;
                    if (charAt(this.bp + offset5) == 'l') {
                        int offset7 = offset6 + 1;
                        if (charAt(this.bp + offset6) == 'l') {
                            uuid = null;
                            offset = offset7 + 1;
                            chLocal = charAt(this.bp + offset7);
                        }
                    }
                }
            }
            this.matchStat = -1;
            return null;
        }
        if (chLocal == ',') {
            int i11 = this.bp + offset;
            this.bp = i11;
            this.ch = charAt(i11);
            this.matchStat = 3;
            return uuid;
        } else if (chLocal == ']') {
            int offset8 = offset + 1;
            char chLocal3 = charAt(this.bp + offset);
            if (chLocal3 == ',') {
                this.token = 16;
                int i12 = this.bp + offset8;
                this.bp = i12;
                this.ch = charAt(i12);
            } else if (chLocal3 == ']') {
                this.token = 15;
                int i13 = this.bp + offset8;
                this.bp = i13;
                this.ch = charAt(i13);
            } else if (chLocal3 == '}') {
                this.token = 13;
                int i14 = this.bp + offset8;
                this.bp = i14;
                this.ch = charAt(i14);
            } else if (chLocal3 == 26) {
                this.token = 20;
                this.bp += offset8 - 1;
                this.ch = JSONLexer.EOI;
            } else {
                this.matchStat = -1;
                return null;
            }
            this.matchStat = 4;
            return uuid;
        } else {
            this.matchStat = -1;
            return null;
        }
    }

    public final void scanTrue() {
        if (this.ch == 't') {
            next();
            if (this.ch == 'r') {
                next();
                if (this.ch == 'u') {
                    next();
                    if (this.ch == 'e') {
                        next();
                        char c = this.ch;
                        if (c == ' ' || c == ',' || c == '}' || c == ']' || c == '\n' || c == '\r' || c == '\t' || c == 26 || c == '\f' || c == '\b' || c == ':' || c == '/') {
                            this.token = 6;
                            return;
                        }
                        throw new JSONException("scan true error");
                    }
                    throw new JSONException("error parse true");
                }
                throw new JSONException("error parse true");
            }
            throw new JSONException("error parse true");
        }
        throw new JSONException("error parse true");
    }

    public final void scanNullOrNew() {
        scanNullOrNew(true);
    }

    public final void scanNullOrNew(boolean acceptColon) {
        char c;
        if (this.ch == 'n') {
            next();
            char c2 = this.ch;
            if (c2 == 'u') {
                next();
                if (this.ch == 'l') {
                    next();
                    if (this.ch == 'l') {
                        next();
                        char c3 = this.ch;
                        if (c3 == ' ' || c3 == ',' || c3 == '}' || c3 == ']' || c3 == '\n' || c3 == '\r' || c3 == '\t' || c3 == 26 || ((c3 == ':' && acceptColon) || (c = this.ch) == '\f' || c == '\b')) {
                            this.token = 8;
                            return;
                        }
                        throw new JSONException("scan null error");
                    }
                    throw new JSONException("error parse null");
                }
                throw new JSONException("error parse null");
            } else if (c2 == 'e') {
                next();
                if (this.ch == 'w') {
                    next();
                    char c4 = this.ch;
                    if (c4 == ' ' || c4 == ',' || c4 == '}' || c4 == ']' || c4 == '\n' || c4 == '\r' || c4 == '\t' || c4 == 26 || c4 == '\f' || c4 == '\b') {
                        this.token = 9;
                        return;
                    }
                    throw new JSONException("scan new error");
                }
                throw new JSONException("error parse new");
            } else {
                throw new JSONException("error parse new");
            }
        } else {
            throw new JSONException("error parse null or new");
        }
    }

    public final void scanFalse() {
        if (this.ch == 'f') {
            next();
            if (this.ch == 'a') {
                next();
                if (this.ch == 'l') {
                    next();
                    if (this.ch == 's') {
                        next();
                        if (this.ch == 'e') {
                            next();
                            char c = this.ch;
                            if (c == ' ' || c == ',' || c == '}' || c == ']' || c == '\n' || c == '\r' || c == '\t' || c == 26 || c == '\f' || c == '\b' || c == ':' || c == '/') {
                                this.token = 7;
                                return;
                            }
                            throw new JSONException("scan false error");
                        }
                        throw new JSONException("error parse false");
                    }
                    throw new JSONException("error parse false");
                }
                throw new JSONException("error parse false");
            }
            throw new JSONException("error parse false");
        }
        throw new JSONException("error parse false");
    }

    public final void scanIdent() {
        this.np = this.bp - 1;
        this.hasSpecial = false;
        do {
            this.sp++;
            next();
        } while (Character.isLetterOrDigit(this.ch));
        String ident = stringVal();
        if (b.m.equalsIgnoreCase(ident)) {
            this.token = 8;
        } else if ("new".equals(ident)) {
            this.token = 9;
        } else if (AbsoluteConst.TRUE.equals(ident)) {
            this.token = 6;
        } else if (AbsoluteConst.FALSE.equals(ident)) {
            this.token = 7;
        } else if (Constants.Name.UNDEFINED.equals(ident)) {
            this.token = 23;
        } else if ("Set".equals(ident)) {
            this.token = 21;
        } else if ("TreeSet".equals(ident)) {
            this.token = 22;
        } else {
            this.token = 18;
        }
    }

    public static String readString(char[] chars, int chars_len) {
        char[] sbuf2 = new char[chars_len];
        int len = 0;
        int i = 0;
        while (i < chars_len) {
            char ch2 = chars[i];
            if (ch2 != '\\') {
                sbuf2[len] = ch2;
                len++;
            } else {
                i++;
                char ch3 = chars[i];
                if (ch3 == '\"') {
                    sbuf2[len] = Operators.QUOTE;
                    len++;
                } else if (ch3 != '\'') {
                    if (ch3 != 'F') {
                        if (ch3 == '\\') {
                            sbuf2[len] = '\\';
                            len++;
                        } else if (ch3 == 'b') {
                            sbuf2[len] = '\b';
                            len++;
                        } else if (ch3 != 'f') {
                            if (ch3 == 'n') {
                                sbuf2[len] = '\n';
                                len++;
                            } else if (ch3 == 'r') {
                                sbuf2[len] = '\r';
                                len++;
                            } else if (ch3 != 'x') {
                                switch (ch3) {
                                    case '/':
                                        sbuf2[len] = '/';
                                        len++;
                                        continue;
                                    case '0':
                                        sbuf2[len] = 0;
                                        len++;
                                        continue;
                                    case '1':
                                        sbuf2[len] = 1;
                                        len++;
                                        continue;
                                    case '2':
                                        sbuf2[len] = 2;
                                        len++;
                                        continue;
                                    case '3':
                                        sbuf2[len] = 3;
                                        len++;
                                        continue;
                                    case '4':
                                        sbuf2[len] = 4;
                                        len++;
                                        continue;
                                    case '5':
                                        sbuf2[len] = 5;
                                        len++;
                                        continue;
                                    case '6':
                                        sbuf2[len] = 6;
                                        len++;
                                        continue;
                                    case '7':
                                        sbuf2[len] = 7;
                                        len++;
                                        continue;
                                    default:
                                        switch (ch3) {
                                            case 't':
                                                sbuf2[len] = '\t';
                                                len++;
                                                continue;
                                            case 'u':
                                                int i2 = i + 1;
                                                int i3 = i2 + 1;
                                                int i4 = i3 + 1;
                                                i = i4 + 1;
                                                sbuf2[len] = (char) Integer.parseInt(new String(new char[]{chars[i2], chars[i3], chars[i4], chars[i]}), 16);
                                                len++;
                                                continue;
                                            case 'v':
                                                sbuf2[len] = 11;
                                                len++;
                                                continue;
                                                continue;
                                            default:
                                                throw new JSONException("unclosed.str.lit");
                                        }
                                }
                            } else {
                                int[] iArr = digits;
                                int i5 = i + 1;
                                i = i5 + 1;
                                sbuf2[len] = (char) ((iArr[chars[i5]] * 16) + iArr[chars[i]]);
                                len++;
                            }
                        }
                    }
                    sbuf2[len] = '\f';
                    len++;
                } else {
                    sbuf2[len] = Operators.SINGLE_QUOTE;
                    len++;
                }
            }
            i++;
        }
        return new String(sbuf2, 0, len);
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public boolean isBlankInput() {
        int i = 0;
        while (true) {
            char chLocal = charAt(i);
            if (chLocal == 26) {
                this.token = 20;
                return true;
            } else if (!isWhitespace(chLocal)) {
                return false;
            } else {
                i++;
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void skipWhitespace() {
        while (true) {
            char c = this.ch;
            if (c > '/') {
                return;
            }
            if (c == ' ' || c == '\r' || c == '\n' || c == '\t' || c == '\f' || c == '\b') {
                next();
            } else if (c == '/') {
                skipComment();
            } else {
                return;
            }
        }
    }

    private void scanStringSingleQuote() {
        char x1;
        char x2;
        this.np = this.bp;
        this.hasSpecial = false;
        while (true) {
            char chLocal = next();
            if (chLocal == '\'') {
                this.token = 4;
                next();
                return;
            } else if (chLocal != 26) {
                boolean hex2 = true;
                if (chLocal == '\\') {
                    if (!this.hasSpecial) {
                        this.hasSpecial = true;
                        int i = this.sp;
                        char[] cArr = this.sbuf;
                        if (i > cArr.length) {
                            char[] newsbuf = new char[(i * 2)];
                            System.arraycopy(cArr, 0, newsbuf, 0, cArr.length);
                            this.sbuf = newsbuf;
                        }
                        copyTo(this.np + 1, this.sp, this.sbuf);
                    }
                    char chLocal2 = next();
                    if (chLocal2 == '\"') {
                        putChar(Operators.QUOTE);
                    } else if (chLocal2 != '\'') {
                        if (chLocal2 != 'F') {
                            if (chLocal2 == '\\') {
                                putChar('\\');
                            } else if (chLocal2 == 'b') {
                                putChar('\b');
                            } else if (chLocal2 != 'f') {
                                if (chLocal2 == 'n') {
                                    putChar('\n');
                                } else if (chLocal2 == 'r') {
                                    putChar('\r');
                                } else if (chLocal2 != 'x') {
                                    switch (chLocal2) {
                                        case '/':
                                            putChar('/');
                                            continue;
                                        case '0':
                                            putChar(0);
                                            continue;
                                        case '1':
                                            putChar(1);
                                            continue;
                                        case '2':
                                            putChar(2);
                                            continue;
                                        case '3':
                                            putChar(3);
                                            continue;
                                        case '4':
                                            putChar(4);
                                            continue;
                                        case '5':
                                            putChar(5);
                                            continue;
                                        case '6':
                                            putChar(6);
                                            continue;
                                        case '7':
                                            putChar(7);
                                            continue;
                                        default:
                                            switch (chLocal2) {
                                                case 't':
                                                    putChar('\t');
                                                    continue;
                                                case 'u':
                                                    putChar((char) Integer.parseInt(new String(new char[]{next(), next(), next(), next()}), 16));
                                                    continue;
                                                case 'v':
                                                    putChar(11);
                                                    continue;
                                                    continue;
                                                default:
                                                    this.ch = chLocal2;
                                                    throw new JSONException("unclosed single-quote string");
                                            }
                                    }
                                } else {
                                    x1 = next();
                                    x2 = next();
                                    boolean hex1 = (x1 >= '0' && x1 <= '9') || (x1 >= 'a' && x1 <= 'f') || (x1 >= 'A' && x1 <= 'F');
                                    if ((x2 < '0' || x2 > '9') && ((x2 < 'a' || x2 > 'f') && (x2 < 'A' || x2 > 'F'))) {
                                        hex2 = false;
                                    }
                                    if (!hex1 || !hex2) {
                                    } else {
                                        int[] iArr = digits;
                                        putChar((char) ((iArr[x1] * 16) + iArr[x2]));
                                    }
                                }
                            }
                        }
                        putChar('\f');
                    } else {
                        putChar(Operators.SINGLE_QUOTE);
                    }
                } else if (!this.hasSpecial) {
                    this.sp++;
                } else {
                    int i2 = this.sp;
                    char[] cArr2 = this.sbuf;
                    if (i2 == cArr2.length) {
                        putChar(chLocal);
                    } else {
                        this.sp = i2 + 1;
                        cArr2[i2] = chLocal;
                    }
                }
            } else if (!isEOF()) {
                putChar(JSONLexer.EOI);
            } else {
                throw new JSONException("unclosed single-quote string");
            }
        }
        throw new JSONException("invalid escape character \\x" + x1 + x2);
    }

    /* access modifiers changed from: protected */
    public final void putChar(char ch2) {
        int i = this.sp;
        char[] cArr = this.sbuf;
        if (i >= cArr.length) {
            int len = cArr.length * 2;
            if (len < i) {
                len = i + 1;
            }
            char[] newsbuf = new char[len];
            char[] cArr2 = this.sbuf;
            System.arraycopy(cArr2, 0, newsbuf, 0, cArr2.length);
            this.sbuf = newsbuf;
        }
        char[] newsbuf2 = this.sbuf;
        int i2 = this.sp;
        this.sp = i2 + 1;
        newsbuf2[i2] = ch2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0045  */
    /* JADX WARNING: Removed duplicated region for block: B:21:0x0052  */
    public final void scanHex() {
        char ch2;
        if (this.ch == 'x') {
            next();
            if (this.ch == '\'') {
                this.np = this.bp;
                next();
                if (this.ch == '\'') {
                    next();
                    this.token = 26;
                    return;
                }
                int i = 0;
                while (true) {
                    ch2 = next();
                    if ((ch2 >= '0' && ch2 <= '9') || (ch2 >= 'A' && ch2 <= 'F')) {
                        this.sp++;
                        i++;
                    } else if (ch2 != '\'') {
                        this.sp++;
                        next();
                        this.token = 26;
                        return;
                    } else {
                        throw new JSONException("illegal state. " + ch2);
                    }
                }
                if (ch2 != '\'') {
                }
            } else {
                throw new JSONException("illegal state. " + this.ch);
            }
        } else {
            throw new JSONException("illegal state. " + this.ch);
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final void scanNumber() {
        this.np = this.bp;
        if (this.ch == '-') {
            this.sp++;
            next();
        }
        while (true) {
            char c = this.ch;
            if (c < '0' || c > '9') {
                boolean isDouble = false;
            } else {
                this.sp++;
                next();
            }
        }
        boolean isDouble2 = false;
        if (this.ch == '.') {
            this.sp++;
            next();
            isDouble2 = true;
            while (true) {
                char c2 = this.ch;
                if (c2 < '0' || c2 > '9') {
                    break;
                }
                this.sp++;
                next();
            }
        }
        int i = this.sp;
        if (i <= 65535) {
            char c3 = this.ch;
            if (c3 == 'L') {
                this.sp = i + 1;
                next();
            } else if (c3 == 'S') {
                this.sp = i + 1;
                next();
            } else if (c3 == 'B') {
                this.sp = i + 1;
                next();
            } else if (c3 == 'F') {
                this.sp = i + 1;
                next();
                isDouble2 = true;
            } else if (c3 == 'D') {
                this.sp = i + 1;
                next();
                isDouble2 = true;
            } else if (c3 == 'e' || c3 == 'E') {
                this.sp++;
                next();
                char c4 = this.ch;
                if (c4 == '+' || c4 == '-') {
                    this.sp++;
                    next();
                }
                while (true) {
                    char c5 = this.ch;
                    if (c5 < '0' || c5 > '9') {
                        char c6 = this.ch;
                    } else {
                        this.sp++;
                        next();
                    }
                }
                char c62 = this.ch;
                if (c62 == 'D' || c62 == 'F') {
                    this.sp++;
                    next();
                }
                isDouble2 = true;
            }
            if (isDouble2) {
                this.token = 3;
            } else {
                this.token = 2;
            }
        } else {
            throw new JSONException("scanNumber overflow");
        }
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final long longValue() throws NumberFormatException {
        long limit;
        int i;
        long result = 0;
        boolean negative = false;
        if (this.np == -1) {
            this.np = 0;
        }
        int i2 = this.np;
        int i3 = this.np;
        int max = this.sp + i3;
        if (charAt(i3) == '-') {
            negative = true;
            limit = Long.MIN_VALUE;
            i2++;
        } else {
            limit = -9223372036854775807L;
        }
        if (i2 < max) {
            result = (long) (-(charAt(i2) - 48));
            i2++;
        }
        while (true) {
            if (i2 >= max) {
                break;
            }
            i = i2 + 1;
            char chLocal = charAt(i2);
            if (chLocal == 'L' || chLocal == 'S' || chLocal == 'B') {
                i2 = i;
            } else {
                int digit = chLocal - '0';
                if (result >= MULTMIN_RADIX_TEN) {
                    long result2 = result * 10;
                    if (result2 >= ((long) digit) + limit) {
                        result = result2 - ((long) digit);
                        i2 = i;
                    } else {
                        throw new NumberFormatException(numberString());
                    }
                } else {
                    throw new NumberFormatException(numberString());
                }
            }
        }
        i2 = i;
        if (!negative) {
            return -result;
        }
        if (i2 > this.np + 1) {
            return result;
        }
        throw new NumberFormatException(numberString());
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public final Number decimalValue(boolean decimal) {
        char chLocal = charAt((this.np + this.sp) - 1);
        if (chLocal == 'F') {
            try {
                return Float.valueOf(Float.parseFloat(numberString()));
            } catch (NumberFormatException ex) {
                throw new JSONException(ex.getMessage() + ", " + info());
            }
        } else if (chLocal == 'D') {
            return Double.valueOf(Double.parseDouble(numberString()));
        } else {
            if (decimal) {
                return decimalValue();
            }
            return Double.valueOf(doubleValue());
        }
    }

    public static boolean isWhitespace(char ch2) {
        return ch2 <= ' ' && (ch2 == ' ' || ch2 == '\n' || ch2 == '\r' || ch2 == '\t' || ch2 == '\f' || ch2 == '\b');
    }

    public String[] scanFieldStringArray(char[] fieldName, int argTypesCount, SymbolTable typeSymbolTable) {
        throw new UnsupportedOperationException();
    }

    public boolean matchField2(char[] fieldName) {
        throw new UnsupportedOperationException();
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public int getFeatures() {
        return this.features;
    }

    @Override // com.alibaba.fastjson.parser.JSONLexer
    public void setFeatures(int features2) {
        this.features = features2;
    }
}
