package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.asm.ClassWriter;
import com.alibaba.fastjson.asm.FieldWriter;
import com.alibaba.fastjson.asm.Label;
import com.alibaba.fastjson.asm.MethodVisitor;
import com.alibaba.fastjson.asm.MethodWriter;
import com.alibaba.fastjson.asm.Opcodes;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JSONLexerBase;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.parser.SymbolTable;
import com.alibaba.fastjson.util.ASMClassLoader;
import com.alibaba.fastjson.util.ASMUtils;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.IOUtils;
import com.alibaba.fastjson.util.JavaBeanInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.el.parse.Operators;
import com.umeng.analytics.pro.d;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.TreeSet;
import java.util.UUID;
import java.util.concurrent.atomic.AtomicLong;

public class ASMDeserializerFactory implements Opcodes {
    static final String DefaultJSONParser = ASMUtils.type(DefaultJSONParser.class);
    static final String JSONLexerBase = ASMUtils.type(JSONLexerBase.class);
    public final ASMClassLoader classLoader;
    protected final AtomicLong seed = new AtomicLong();

    public ASMDeserializerFactory(ClassLoader parentClassLoader) {
        this.classLoader = parentClassLoader instanceof ASMClassLoader ? (ASMClassLoader) parentClassLoader : new ASMClassLoader(parentClassLoader);
    }

    public ObjectDeserializer createJavaBeanDeserializer(ParserConfig config, JavaBeanInfo beanInfo) throws Exception {
        String classNameType;
        String packageName;
        Class<?> clazz = beanInfo.clazz;
        if (!clazz.isPrimitive()) {
            String className = "FastjsonASMDeserializer_" + this.seed.incrementAndGet() + "_" + clazz.getSimpleName();
            Package pkg = ASMDeserializerFactory.class.getPackage();
            if (pkg != null) {
                String packageName2 = pkg.getName();
                String classNameType2 = packageName2.replace(Operators.DOT, '/') + "/" + className;
                packageName = packageName2 + Operators.DOT_STR + className;
                classNameType = classNameType2;
            } else {
                packageName = className;
                classNameType = className;
            }
            ClassWriter cw = new ClassWriter();
            cw.visit(49, 33, classNameType, ASMUtils.type(JavaBeanDeserializer.class), null);
            _init(cw, new Context(classNameType, config, beanInfo, 3));
            _createInstance(cw, new Context(classNameType, config, beanInfo, 3));
            _deserialze(cw, new Context(classNameType, config, beanInfo, 5));
            _deserialzeArrayMapping(cw, new Context(classNameType, config, beanInfo, 4));
            byte[] code = cw.toByteArray();
            return (ObjectDeserializer) this.classLoader.defineClassPublic(packageName, code, 0, code.length).getConstructor(ParserConfig.class, JavaBeanInfo.class).newInstance(config, beanInfo);
        }
        throw new IllegalArgumentException("not support type :" + clazz.getName());
    }

    private void _setFlag(MethodVisitor mw, Context context, int i) {
        String varName = "_asm_flag_" + (i / 32);
        mw.visitVarInsn(21, context.var(varName));
        mw.visitLdcInsn(Integer.valueOf(1 << i));
        mw.visitInsn(128);
        mw.visitVarInsn(54, context.var(varName));
    }

    private void _isFlag(MethodVisitor mw, Context context, int i, Label label) {
        mw.visitVarInsn(21, context.var("_asm_flag_" + (i / 32)));
        mw.visitLdcInsn(Integer.valueOf(1 << i));
        mw.visitInsn(126);
        mw.visitJumpInsn(153, label);
    }

    private void _deserialzeArrayMapping(ClassWriter cw, Context context) {
        Label typeNameNotNull_;
        FieldInfo[] sortedFieldInfoList;
        int fieldListSize;
        int i;
        FieldInfo fieldInfo;
        char seperator;
        int i2;
        MethodVisitor mw = new MethodWriter(cw, 1, "deserialzeArrayMapping", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;", null, null);
        defineVarLexer(context, mw);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitVarInsn(25, 1);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getSymbolTable", "()" + ASMUtils.desc(SymbolTable.class));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanTypeName", Operators.BRACKET_START_STR + ASMUtils.desc(SymbolTable.class) + ")Ljava/lang/String;");
        mw.visitVarInsn(58, context.var("typeName"));
        Label typeNameNotNull_2 = new Label();
        mw.visitVarInsn(25, context.var("typeName"));
        mw.visitJumpInsn(Opcodes.IFNULL, typeNameNotNull_2);
        mw.visitVarInsn(25, 1);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getConfig", "()" + ASMUtils.desc(ParserConfig.class));
        mw.visitVarInsn(25, 0);
        mw.visitFieldInsn(180, ASMUtils.type(JavaBeanDeserializer.class), "beanInfo", ASMUtils.desc(JavaBeanInfo.class));
        mw.visitVarInsn(25, context.var("typeName"));
        mw.visitMethodInsn(Opcodes.INVOKESTATIC, ASMUtils.type(JavaBeanDeserializer.class), "getSeeAlso", Operators.BRACKET_START_STR + ASMUtils.desc(ParserConfig.class) + ASMUtils.desc(JavaBeanInfo.class) + "Ljava/lang/String;)" + ASMUtils.desc(JavaBeanDeserializer.class));
        mw.visitVarInsn(58, context.var("userTypeDeser"));
        mw.visitVarInsn(25, context.var("userTypeDeser"));
        mw.visitTypeInsn(Opcodes.INSTANCEOF, ASMUtils.type(JavaBeanDeserializer.class));
        mw.visitJumpInsn(153, typeNameNotNull_2);
        mw.visitVarInsn(25, context.var("userTypeDeser"));
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(25, 3);
        mw.visitVarInsn(25, 4);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "deserialzeArrayMapping", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;");
        mw.visitInsn(176);
        mw.visitLabel(typeNameNotNull_2);
        _createInstance(context, mw);
        FieldInfo[] sortedFieldInfoList2 = context.beanInfo.sortedFields;
        int fieldListSize2 = sortedFieldInfoList2.length;
        int i3 = 0;
        while (i3 < fieldListSize2) {
            boolean last = i3 == fieldListSize2 + -1;
            char seperator2 = last ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
            FieldInfo fieldInfo2 = sortedFieldInfoList2[i3];
            Class<?> fieldClass = fieldInfo2.fieldClass;
            Type fieldType = fieldInfo2.fieldType;
            if (fieldClass == Byte.TYPE || fieldClass == Short.TYPE) {
                i = i3;
                fieldInfo = fieldInfo2;
                typeNameNotNull_ = typeNameNotNull_2;
                seperator = seperator2;
                fieldListSize = fieldListSize2;
                sortedFieldInfoList = sortedFieldInfoList2;
            } else if (fieldClass == Integer.TYPE) {
                i = i3;
                fieldInfo = fieldInfo2;
                typeNameNotNull_ = typeNameNotNull_2;
                seperator = seperator2;
                fieldListSize = fieldListSize2;
                sortedFieldInfoList = sortedFieldInfoList2;
            } else {
                typeNameNotNull_ = typeNameNotNull_2;
                if (fieldClass == Byte.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanInt", "(C)I");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Byte", "valueOf", "(B)Ljava/lang/Byte;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_ = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Short.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanInt", "(C)I");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Short", "valueOf", "(S)Ljava/lang/Short;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_2 = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_2);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_2);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Integer.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanInt", "(C)I");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_3 = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_3);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_3);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Long.TYPE) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanLong", "(C)J");
                    mw.visitVarInsn(55, context.var_asm(fieldInfo2, 2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Long.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanLong", "(C)J");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Long", "valueOf", "(J)Ljava/lang/Long;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_4 = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_4);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_4);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Boolean.TYPE) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanBoolean", "(C)Z");
                    mw.visitVarInsn(54, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Float.TYPE) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFloat", "(C)F");
                    mw.visitVarInsn(56, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Float.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFloat", "(C)F");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Float", "valueOf", "(F)Ljava/lang/Float;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_5 = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_5);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_5);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Double.TYPE) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanDouble", "(C)D");
                    mw.visitVarInsn(57, context.var_asm(fieldInfo2, 2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Double.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanDouble", "(C)D");
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Double", "valueOf", "(D)Ljava/lang/Double;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    Label valueNullEnd_6 = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                    mw.visitLdcInsn(5);
                    mw.visitJumpInsn(160, valueNullEnd_6);
                    mw.visitInsn(1);
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    mw.visitLabel(valueNullEnd_6);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Character.TYPE) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanString", "(C)Ljava/lang/String;");
                    mw.visitInsn(3);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/String", "charAt", "(I)C");
                    mw.visitVarInsn(54, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == String.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanString", "(C)Ljava/lang/String;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == BigDecimal.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanDecimal", "(C)Ljava/math/BigDecimal;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == Date.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanDate", "(C)Ljava/util/Date;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass == UUID.class) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanUUID", "(C)Ljava/util/UUID;");
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass.isEnum()) {
                    Label enumNumIf_ = new Label();
                    Label enumNumErr_ = new Label();
                    Label enumStore_ = new Label();
                    Label enumQuote_ = new Label();
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
                    mw.visitInsn(89);
                    mw.visitVarInsn(54, context.var("ch"));
                    mw.visitLdcInsn(110);
                    mw.visitJumpInsn(159, enumQuote_);
                    mw.visitVarInsn(21, context.var("ch"));
                    mw.visitLdcInsn(34);
                    mw.visitJumpInsn(160, enumNumIf_);
                    mw.visitLabel(enumQuote_);
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldClass)));
                    mw.visitVarInsn(25, 1);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getSymbolTable", "()" + ASMUtils.desc(SymbolTable.class));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanEnum", "(Ljava/lang/Class;" + ASMUtils.desc(SymbolTable.class) + "C)Ljava/lang/Enum;");
                    mw.visitJumpInsn(Opcodes.GOTO, enumStore_);
                    mw.visitLabel(enumNumIf_);
                    mw.visitVarInsn(21, context.var("ch"));
                    mw.visitLdcInsn(48);
                    mw.visitJumpInsn(161, enumNumErr_);
                    mw.visitVarInsn(21, context.var("ch"));
                    mw.visitLdcInsn(57);
                    mw.visitJumpInsn(Opcodes.IF_ICMPGT, enumNumErr_);
                    _getFieldDeser(context, mw, fieldInfo2);
                    mw.visitTypeInsn(192, ASMUtils.type(EnumDeserializer.class));
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanInt", "(C)I");
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(EnumDeserializer.class), "valueOf", "(I)Ljava/lang/Enum;");
                    mw.visitJumpInsn(Opcodes.GOTO, enumStore_);
                    mw.visitLabel(enumNumErr_);
                    mw.visitVarInsn(25, 0);
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "scanEnum", "(L" + JSONLexerBase + ";C)Ljava/lang/Enum;");
                    mw.visitLabel(enumStore_);
                    mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                    i = i3;
                } else if (Collection.class.isAssignableFrom(fieldClass)) {
                    Class<?> itemClass = TypeUtils.getCollectionItemClass(fieldType);
                    if (itemClass == String.class) {
                        if (fieldClass == List.class || fieldClass == Collections.class || fieldClass == ArrayList.class) {
                            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(ArrayList.class));
                            mw.visitInsn(89);
                            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(ArrayList.class), "<init>", "()V");
                        } else {
                            mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldClass)));
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, ASMUtils.type(TypeUtils.class), "createCollection", "(Ljava/lang/Class;)Ljava/util/Collection;");
                        }
                        mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitVarInsn(25, context.var_asm(fieldInfo2));
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanStringArray", "(Ljava/util/Collection;C)V");
                        Label valueNullEnd_7 = new Label();
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitFieldInsn(180, JSONLexerBase, "matchStat", "I");
                        mw.visitLdcInsn(5);
                        mw.visitJumpInsn(160, valueNullEnd_7);
                        mw.visitInsn(1);
                        mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                        mw.visitLabel(valueNullEnd_7);
                        i2 = i3;
                    } else {
                        Label notError_ = new Label();
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
                        mw.visitVarInsn(54, context.var("token"));
                        mw.visitVarInsn(21, context.var("token"));
                        int token = i3 == 0 ? 14 : 16;
                        mw.visitLdcInsn(Integer.valueOf(token));
                        mw.visitJumpInsn(159, notError_);
                        mw.visitVarInsn(25, 1);
                        mw.visitLdcInsn(Integer.valueOf(token));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "throwException", "(I)V");
                        mw.visitLabel(notError_);
                        Label quickElse_ = new Label();
                        Label quickEnd_ = new Label();
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
                        mw.visitVarInsn(16, 91);
                        mw.visitJumpInsn(160, quickElse_);
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
                        mw.visitInsn(87);
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitLdcInsn(14);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
                        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
                        mw.visitLabel(quickElse_);
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitLdcInsn(14);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
                        mw.visitLabel(quickEnd_);
                        i2 = i3;
                        _newCollection(mw, fieldClass, i2, false);
                        mw.visitInsn(89);
                        mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                        _getCollectionFieldItemDeser(context, mw, fieldInfo2, itemClass);
                        mw.visitVarInsn(25, 1);
                        mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(itemClass)));
                        mw.visitVarInsn(25, 3);
                        mw.visitMethodInsn(Opcodes.INVOKESTATIC, ASMUtils.type(JavaBeanDeserializer.class), "parseArray", "(Ljava/util/Collection;" + ASMUtils.desc(ObjectDeserializer.class) + "L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;)V");
                    }
                    i = i2;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else if (fieldClass.isArray()) {
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitLdcInsn(14);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
                    mw.visitVarInsn(25, 1);
                    mw.visitVarInsn(25, 0);
                    mw.visitLdcInsn(Integer.valueOf(i3));
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "getFieldType", "(I)Ljava/lang/reflect/Type;");
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "parseObject", "(Ljava/lang/reflect/Type;)Ljava/lang/Object;");
                    mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
                    mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                } else {
                    Label objElseIf_ = new Label();
                    Label objEndIf_ = new Label();
                    if (fieldClass == Date.class) {
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
                        mw.visitLdcInsn(49);
                        mw.visitJumpInsn(160, objElseIf_);
                        mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(Date.class));
                        mw.visitInsn(89);
                        mw.visitVarInsn(25, context.var("lexer"));
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanLong", "(C)J");
                        mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(Date.class), "<init>", "(J)V");
                        mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                        mw.visitJumpInsn(Opcodes.GOTO, objEndIf_);
                    }
                    mw.visitLabel(objElseIf_);
                    _quickNextToken(context, mw, 14);
                    i = i3;
                    fieldListSize = fieldListSize2;
                    sortedFieldInfoList = sortedFieldInfoList2;
                    _deserObject(context, mw, fieldInfo2, fieldClass, i);
                    mw.visitVarInsn(25, context.var("lexer"));
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
                    mw.visitLdcInsn(15);
                    mw.visitJumpInsn(159, objEndIf_);
                    mw.visitVarInsn(25, 0);
                    mw.visitVarInsn(25, context.var("lexer"));
                    if (!last) {
                        mw.visitLdcInsn(16);
                    } else {
                        mw.visitLdcInsn(15);
                    }
                    mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(JavaBeanDeserializer.class), "check", Operators.BRACKET_START_STR + ASMUtils.desc(JSONLexer.class) + "I)V");
                    mw.visitLabel(objEndIf_);
                }
                i3 = i + 1;
                fieldListSize2 = fieldListSize;
                sortedFieldInfoList2 = sortedFieldInfoList;
                typeNameNotNull_2 = typeNameNotNull_;
            }
            mw.visitVarInsn(25, context.var("lexer"));
            mw.visitVarInsn(16, seperator);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanInt", "(C)I");
            mw.visitVarInsn(54, context.var_asm(fieldInfo));
            i3 = i + 1;
            fieldListSize2 = fieldListSize;
            sortedFieldInfoList2 = sortedFieldInfoList;
            typeNameNotNull_2 = typeNameNotNull_;
        }
        _batchSet(context, mw, false);
        Label quickElse_2 = new Label();
        Label quickElseIf_ = new Label();
        Label quickElseIfEOI_ = new Label();
        Label quickEnd_2 = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
        mw.visitInsn(89);
        mw.visitVarInsn(54, context.var("ch"));
        mw.visitVarInsn(16, 44);
        mw.visitJumpInsn(160, quickElseIf_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(16);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_2);
        mw.visitLabel(quickElseIf_);
        mw.visitVarInsn(21, context.var("ch"));
        mw.visitVarInsn(16, 93);
        mw.visitJumpInsn(160, quickElseIfEOI_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(15);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_2);
        mw.visitLabel(quickElseIfEOI_);
        mw.visitVarInsn(21, context.var("ch"));
        mw.visitVarInsn(16, 26);
        mw.visitJumpInsn(160, quickElse_2);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(20);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_2);
        mw.visitLabel(quickElse_2);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(16);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
        mw.visitLabel(quickEnd_2);
        mw.visitVarInsn(25, context.var("instance"));
        mw.visitInsn(176);
        mw.visitMaxs(5, context.variantIndex);
        mw.visitEnd();
    }

    /* JADX INFO: Multiple debug info for r24v7 'fieldListSize'  int: [D('continue_2' com.alibaba.fastjson.asm.Label), D('fieldListSize' int)] */
    /* JADX INFO: Multiple debug info for r11v7 'reset_'  com.alibaba.fastjson.asm.Label: [D('fieldInfo' com.alibaba.fastjson.util.FieldInfo), D('reset_' com.alibaba.fastjson.asm.Label)] */
    /* JADX INFO: Multiple debug info for r24v8 'fieldListSize'  int: [D('continue_2' com.alibaba.fastjson.asm.Label), D('fieldListSize' int)] */
    /* JADX INFO: Multiple debug info for r7v18 'i'  int: [D('i' int), D('end_' com.alibaba.fastjson.asm.Label)] */
    private void _deserialze(ClassWriter cw, Context context) {
        String str;
        int fieldListSize;
        String str2;
        Label continue_3;
        Label continue_2;
        String str3;
        Label end_;
        Label return_;
        Label reset_;
        String str4;
        int i;
        int i2;
        Label notMatch_;
        int fieldListSize2;
        String str5;
        Label reset_2;
        Label end_2;
        Label super_;
        JavaBeanInfo beanInfo;
        if (context.fieldInfoList.length != 0) {
            FieldInfo[] fieldInfoArr = context.fieldInfoList;
            for (FieldInfo fieldInfo : fieldInfoArr) {
                Class<?> fieldClass = fieldInfo.fieldClass;
                Type fieldType = fieldInfo.fieldType;
                if (fieldClass == Character.TYPE) {
                    return;
                }
                if (Collection.class.isAssignableFrom(fieldClass) && (!(fieldType instanceof ParameterizedType) || !(((ParameterizedType) fieldType).getActualTypeArguments()[0] instanceof Class))) {
                    return;
                }
            }
            JavaBeanInfo beanInfo2 = context.beanInfo;
            context.fieldInfoList = beanInfo2.sortedFields;
            StringBuilder sb = new StringBuilder();
            String str6 = "(L";
            sb.append(str6);
            sb.append(DefaultJSONParser);
            sb.append(";Ljava/lang/reflect/Type;Ljava/lang/Object;I)Ljava/lang/Object;");
            MethodVisitor mw = new MethodWriter(cw, 1, "deserialze", sb.toString(), null, null);
            Label reset_3 = new Label();
            Label super_2 = new Label();
            Label return_2 = new Label();
            Label end_3 = new Label();
            defineVarLexer(context, mw);
            Label next_ = new Label();
            String str7 = "lexer";
            mw.visitVarInsn(25, context.var(str7));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
            mw.visitLdcInsn(14);
            mw.visitJumpInsn(160, next_);
            if ((beanInfo2.parserFeatures & Feature.SupportArrayToBean.mask) == 0) {
                mw.visitVarInsn(25, context.var(str7));
                mw.visitVarInsn(21, 4);
                mw.visitLdcInsn(Integer.valueOf(Feature.SupportArrayToBean.mask));
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "isEnabled", "(II)Z");
                mw.visitJumpInsn(153, next_);
            }
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitInsn(1);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, context.className, "deserialzeArrayMapping", str6 + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;Ljava/lang/Object;)Ljava/lang/Object;");
            mw.visitInsn(176);
            mw.visitLabel(next_);
            mw.visitVarInsn(25, context.var(str7));
            mw.visitLdcInsn(Integer.valueOf(Feature.SortFeidFastMatch.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "isEnabled", "(I)Z");
            Label continue_ = new Label();
            mw.visitJumpInsn(154, continue_);
            mw.visitJumpInsn(200, super_2);
            mw.visitLabel(continue_);
            mw.visitVarInsn(25, context.var(str7));
            mw.visitLdcInsn(context.clazz.getName());
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanType", "(Ljava/lang/String;)I");
            mw.visitLdcInsn(-1);
            Label continue_22 = new Label();
            mw.visitJumpInsn(160, continue_22);
            mw.visitJumpInsn(200, super_2);
            mw.visitLabel(continue_22);
            mw.visitVarInsn(25, 1);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getContext", "()" + ASMUtils.desc(ParseContext.class));
            mw.visitVarInsn(58, context.var("mark_context"));
            mw.visitInsn(3);
            mw.visitVarInsn(54, context.var("matchedCount"));
            _createInstance(context, mw);
            mw.visitVarInsn(25, 1);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getContext", "()" + ASMUtils.desc(ParseContext.class));
            mw.visitVarInsn(58, context.var(d.R));
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var(d.R));
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(25, 3);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "setContext", Operators.BRACKET_START_STR + ASMUtils.desc(ParseContext.class) + "Ljava/lang/Object;Ljava/lang/Object;)" + ASMUtils.desc(ParseContext.class));
            mw.visitVarInsn(58, context.var("childContext"));
            mw.visitVarInsn(25, context.var(str7));
            String str8 = "matchStat";
            String str9 = "I";
            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
            mw.visitLdcInsn(4);
            Label continue_32 = new Label();
            mw.visitJumpInsn(160, continue_32);
            mw.visitJumpInsn(200, return_2);
            mw.visitLabel(continue_32);
            mw.visitInsn(3);
            Label continue_23 = continue_22;
            mw.visitIntInsn(54, context.var(str8));
            int fieldListSize3 = context.fieldInfoList.length;
            int i3 = 0;
            while (i3 < fieldListSize3) {
                mw.visitInsn(3);
                mw.visitVarInsn(54, context.var("_asm_flag_" + (i3 / 32)));
                i3 += 32;
                continue_32 = continue_32;
                return_2 = return_2;
            }
            Label continue_33 = continue_32;
            Label return_3 = return_2;
            mw.visitVarInsn(25, context.var(str7));
            mw.visitLdcInsn(Integer.valueOf(Feature.InitStringFieldAsEmpty.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "isEnabled", "(I)Z");
            mw.visitIntInsn(54, context.var("initStringFieldAsEmpty"));
            int i4 = 0;
            while (i4 < fieldListSize3) {
                FieldInfo fieldInfo2 = context.fieldInfoList[i4];
                Class<?> fieldClass2 = fieldInfo2.fieldClass;
                if (fieldClass2 == Boolean.TYPE || fieldClass2 == Byte.TYPE || fieldClass2 == Short.TYPE) {
                    end_2 = end_3;
                    beanInfo = beanInfo2;
                    str5 = str6;
                    reset_2 = reset_3;
                    super_ = super_2;
                } else if (fieldClass2 == Integer.TYPE) {
                    end_2 = end_3;
                    beanInfo = beanInfo2;
                    str5 = str6;
                    reset_2 = reset_3;
                    super_ = super_2;
                } else {
                    if (fieldClass2 == Long.TYPE) {
                        mw.visitInsn(9);
                        beanInfo = beanInfo2;
                        super_ = super_2;
                        mw.visitVarInsn(55, context.var_asm(fieldInfo2, 2));
                        end_2 = end_3;
                        str5 = str6;
                        reset_2 = reset_3;
                    } else {
                        beanInfo = beanInfo2;
                        super_ = super_2;
                        if (fieldClass2 == Float.TYPE) {
                            mw.visitInsn(11);
                            mw.visitVarInsn(56, context.var_asm(fieldInfo2));
                            end_2 = end_3;
                            str5 = str6;
                            reset_2 = reset_3;
                        } else if (fieldClass2 == Double.TYPE) {
                            mw.visitInsn(14);
                            mw.visitVarInsn(57, context.var_asm(fieldInfo2, 2));
                            end_2 = end_3;
                            str5 = str6;
                            reset_2 = reset_3;
                        } else {
                            if (fieldClass2 == String.class) {
                                Label flagEnd_ = new Label();
                                Label flagElse_ = new Label();
                                end_2 = end_3;
                                mw.visitVarInsn(21, context.var("initStringFieldAsEmpty"));
                                mw.visitJumpInsn(153, flagElse_);
                                _setFlag(mw, context, i4);
                                mw.visitVarInsn(25, context.var(str7));
                                reset_2 = reset_3;
                                str5 = str6;
                                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "stringDefaultValue", "()Ljava/lang/String;");
                                mw.visitJumpInsn(Opcodes.GOTO, flagEnd_);
                                mw.visitLabel(flagElse_);
                                mw.visitInsn(1);
                                mw.visitLabel(flagEnd_);
                            } else {
                                end_2 = end_3;
                                str5 = str6;
                                reset_2 = reset_3;
                                mw.visitInsn(1);
                            }
                            mw.visitTypeInsn(192, ASMUtils.type(fieldClass2));
                            mw.visitVarInsn(58, context.var_asm(fieldInfo2));
                        }
                    }
                    i4++;
                    beanInfo2 = beanInfo;
                    super_2 = super_;
                    end_3 = end_2;
                    reset_3 = reset_2;
                    str6 = str5;
                }
                mw.visitInsn(3);
                mw.visitVarInsn(54, context.var_asm(fieldInfo2));
                i4++;
                beanInfo2 = beanInfo;
                super_2 = super_;
                end_3 = end_2;
                reset_3 = reset_2;
                str6 = str5;
            }
            Label end_4 = end_3;
            String str10 = str6;
            Label reset_4 = reset_3;
            int i5 = 0;
            while (i5 < fieldListSize3) {
                FieldInfo fieldInfo3 = context.fieldInfoList[i5];
                Class<?> fieldClass3 = fieldInfo3.fieldClass;
                Type fieldType2 = fieldInfo3.fieldType;
                Label notMatch_2 = new Label();
                if (fieldClass3 == Boolean.TYPE) {
                    mw.visitVarInsn(25, context.var(str7));
                    mw.visitVarInsn(25, 0);
                    mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldBoolean", "([C)Z");
                    mw.visitVarInsn(54, context.var_asm(fieldInfo3));
                    fieldListSize2 = fieldListSize3;
                    i2 = i5;
                    notMatch_ = notMatch_2;
                    str4 = str10;
                } else if (fieldClass3 == Byte.TYPE) {
                    fieldListSize2 = fieldListSize3;
                    mw.visitVarInsn(25, context.var(str7));
                    mw.visitVarInsn(25, 0);
                    notMatch_ = notMatch_2;
                    mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                    mw.visitVarInsn(54, context.var_asm(fieldInfo3));
                    i2 = i5;
                    str4 = str10;
                } else {
                    fieldListSize2 = fieldListSize3;
                    notMatch_ = notMatch_2;
                    if (fieldClass3 == Byte.class) {
                        mw.visitVarInsn(25, context.var(str7));
                        mw.visitVarInsn(25, 0);
                        i2 = i5;
                        mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Byte", "valueOf", "(B)Ljava/lang/Byte;");
                        mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                        Label valueNullEnd_ = new Label();
                        mw.visitVarInsn(25, context.var(str7));
                        mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                        mw.visitLdcInsn(5);
                        mw.visitJumpInsn(160, valueNullEnd_);
                        mw.visitInsn(1);
                        mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                        mw.visitLabel(valueNullEnd_);
                        str4 = str10;
                    } else {
                        i2 = i5;
                        if (fieldClass3 == Short.TYPE) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                            mw.visitVarInsn(54, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == Short.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Short", "valueOf", "(S)Ljava/lang/Short;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            Label valueNullEnd_2 = new Label();
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                            mw.visitLdcInsn(5);
                            mw.visitJumpInsn(160, valueNullEnd_2);
                            mw.visitInsn(1);
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            mw.visitLabel(valueNullEnd_2);
                            str4 = str10;
                        } else if (fieldClass3 == Integer.TYPE) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                            mw.visitVarInsn(54, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == Integer.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldInt", "([C)I");
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            Label valueNullEnd_3 = new Label();
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                            mw.visitLdcInsn(5);
                            mw.visitJumpInsn(160, valueNullEnd_3);
                            mw.visitInsn(1);
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            mw.visitLabel(valueNullEnd_3);
                            str4 = str10;
                        } else if (fieldClass3 == Long.TYPE) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldLong", "([C)J");
                            mw.visitVarInsn(55, context.var_asm(fieldInfo3, 2));
                            str4 = str10;
                        } else if (fieldClass3 == Long.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldLong", "([C)J");
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Long", "valueOf", "(J)Ljava/lang/Long;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            Label valueNullEnd_4 = new Label();
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                            mw.visitLdcInsn(5);
                            mw.visitJumpInsn(160, valueNullEnd_4);
                            mw.visitInsn(1);
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            mw.visitLabel(valueNullEnd_4);
                            str4 = str10;
                        } else if (fieldClass3 == Float.TYPE) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldFloat", "([C)F");
                            mw.visitVarInsn(56, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == Float.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldFloat", "([C)F");
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Float", "valueOf", "(F)Ljava/lang/Float;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            Label valueNullEnd_5 = new Label();
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                            mw.visitLdcInsn(5);
                            mw.visitJumpInsn(160, valueNullEnd_5);
                            mw.visitInsn(1);
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            mw.visitLabel(valueNullEnd_5);
                            str4 = str10;
                        } else if (fieldClass3 == Double.TYPE) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldDouble", "([C)D");
                            mw.visitVarInsn(57, context.var_asm(fieldInfo3, 2));
                            str4 = str10;
                        } else if (fieldClass3 == Double.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldDouble", "([C)D");
                            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Double", "valueOf", "(D)Ljava/lang/Double;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            Label valueNullEnd_6 = new Label();
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                            mw.visitLdcInsn(5);
                            mw.visitJumpInsn(160, valueNullEnd_6);
                            mw.visitInsn(1);
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            mw.visitLabel(valueNullEnd_6);
                            str4 = str10;
                        } else if (fieldClass3 == String.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldString", "([C)Ljava/lang/String;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == Date.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldDate", "([C)Ljava/util/Date;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == UUID.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldUUID", "([C)Ljava/util/UUID;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == BigDecimal.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldDecimal", "([C)Ljava/math/BigDecimal;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == BigInteger.class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldBigInteger", "([C)Ljava/math/BigInteger;");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == int[].class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldIntArray", "([C)[I");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == float[].class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldFloatArray", "([C)[F");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3 == float[][].class) {
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldFloatArray2", "([C)[[F");
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                            str4 = str10;
                        } else if (fieldClass3.isEnum()) {
                            mw.visitVarInsn(25, 0);
                            mw.visitVarInsn(25, context.var(str7));
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                            _getFieldDeser(context, mw, fieldInfo3);
                            String type = ASMUtils.type(JavaBeanDeserializer.class);
                            StringBuilder sb2 = new StringBuilder();
                            str4 = str10;
                            sb2.append(str4);
                            sb2.append(JSONLexerBase);
                            sb2.append(";[C");
                            sb2.append(ASMUtils.desc(ObjectDeserializer.class));
                            sb2.append(")Ljava/lang/Enum;");
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, type, "scanEnum", sb2.toString());
                            mw.visitTypeInsn(192, ASMUtils.type(fieldClass3));
                            mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                        } else {
                            str4 = str10;
                            if (Collection.class.isAssignableFrom(fieldClass3)) {
                                mw.visitVarInsn(25, context.var(str7));
                                mw.visitVarInsn(25, 0);
                                mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo3), "[C");
                                Class<?> itemClass = TypeUtils.getCollectionItemClass(fieldType2);
                                if (itemClass == String.class) {
                                    mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldClass3)));
                                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "scanFieldStringArray", "([CLjava/lang/Class;)" + ASMUtils.desc(Collection.class));
                                    mw.visitVarInsn(58, context.var_asm(fieldInfo3));
                                } else {
                                    str3 = str9;
                                    str2 = str8;
                                    continue_2 = continue_23;
                                    fieldListSize = fieldListSize2;
                                    continue_3 = continue_33;
                                    str = str7;
                                    return_ = return_3;
                                    end_ = end_4;
                                    i = i2;
                                    _deserialze_list_obj(context, mw, reset_4, fieldInfo3, fieldClass3, itemClass, i);
                                    if (i == fieldListSize - 1) {
                                        _deserialize_endCheck(context, mw, reset_4);
                                        reset_ = reset_4;
                                    } else {
                                        reset_ = reset_4;
                                    }
                                }
                            } else {
                                str3 = str9;
                                str2 = str8;
                                continue_2 = continue_23;
                                continue_3 = continue_33;
                                return_ = return_3;
                                end_ = end_4;
                                fieldListSize = fieldListSize2;
                                i = i2;
                                str = str7;
                                reset_ = reset_4;
                                _deserialze_obj(context, mw, reset_4, fieldInfo3, fieldClass3, i);
                                if (i == fieldListSize - 1) {
                                    _deserialize_endCheck(context, mw, reset_);
                                }
                            }
                            str10 = str4;
                            reset_4 = reset_;
                            return_3 = return_;
                            end_4 = end_;
                            str9 = str3;
                            continue_33 = continue_3;
                            str8 = str2;
                            fieldListSize3 = fieldListSize;
                            str7 = str;
                            i5 = i + 1;
                            continue_23 = continue_2;
                        }
                    }
                }
                mw.visitVarInsn(25, context.var(str7));
                mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                Label flag_ = new Label();
                mw.visitJumpInsn(Opcodes.IFLE, flag_);
                _setFlag(mw, context, i2);
                mw.visitLabel(flag_);
                mw.visitVarInsn(25, context.var(str7));
                mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                mw.visitInsn(89);
                mw.visitVarInsn(54, context.var(str8));
                mw.visitLdcInsn(-1);
                mw.visitJumpInsn(159, reset_4);
                mw.visitVarInsn(25, context.var(str7));
                mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                mw.visitJumpInsn(Opcodes.IFLE, notMatch_);
                mw.visitVarInsn(21, context.var("matchedCount"));
                mw.visitInsn(4);
                mw.visitInsn(96);
                mw.visitVarInsn(54, context.var("matchedCount"));
                mw.visitVarInsn(25, context.var(str7));
                mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                mw.visitLdcInsn(4);
                mw.visitJumpInsn(159, end_4);
                mw.visitLabel(notMatch_);
                if (i2 == fieldListSize2 - 1) {
                    mw.visitVarInsn(25, context.var(str7));
                    mw.visitFieldInsn(180, JSONLexerBase, str8, str9);
                    mw.visitLdcInsn(4);
                    mw.visitJumpInsn(160, reset_4);
                    str3 = str9;
                    str2 = str8;
                    str = str7;
                    reset_ = reset_4;
                    continue_2 = continue_23;
                    continue_3 = continue_33;
                    return_ = return_3;
                    fieldListSize = fieldListSize2;
                    end_ = end_4;
                    i = i2;
                } else {
                    str3 = str9;
                    str2 = str8;
                    str = str7;
                    reset_ = reset_4;
                    continue_2 = continue_23;
                    continue_3 = continue_33;
                    return_ = return_3;
                    fieldListSize = fieldListSize2;
                    end_ = end_4;
                    i = i2;
                }
                str10 = str4;
                reset_4 = reset_;
                return_3 = return_;
                end_4 = end_;
                str9 = str3;
                continue_33 = continue_3;
                str8 = str2;
                fieldListSize3 = fieldListSize;
                str7 = str;
                i5 = i + 1;
                continue_23 = continue_2;
            }
            mw.visitLabel(end_4);
            if (!context.clazz.isInterface() && !Modifier.isAbstract(context.clazz.getModifiers())) {
                _batchSet(context, mw);
            }
            mw.visitLabel(return_3);
            _setContext(context, mw);
            mw.visitVarInsn(25, context.var("instance"));
            Method buildMethod = context.beanInfo.buildMethod;
            if (buildMethod != null) {
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(context.getInstClass()), buildMethod.getName(), "()" + ASMUtils.desc(buildMethod.getReturnType()));
            }
            mw.visitInsn(176);
            mw.visitLabel(reset_4);
            _batchSet(context, mw);
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(21, 4);
            int flagSize = fieldListSize3 / 32;
            if (!(fieldListSize3 == 0 || fieldListSize3 % 32 == 0)) {
                flagSize++;
            }
            if (flagSize == 1) {
                mw.visitInsn(4);
            } else {
                mw.visitIntInsn(16, flagSize);
            }
            mw.visitIntInsn(Opcodes.NEWARRAY, 10);
            for (int i6 = 0; i6 < flagSize; i6++) {
                mw.visitInsn(89);
                if (i6 == 0) {
                    mw.visitInsn(3);
                } else if (i6 == 1) {
                    mw.visitInsn(4);
                } else {
                    mw.visitIntInsn(16, i6);
                }
                mw.visitVarInsn(21, context.var("_asm_flag_" + i6));
                mw.visitInsn(79);
            }
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "parseRest", str10 + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;Ljava/lang/Object;I[I)Ljava/lang/Object;");
            mw.visitTypeInsn(192, ASMUtils.type(context.clazz));
            mw.visitInsn(176);
            mw.visitLabel(super_2);
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitVarInsn(21, 4);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(JavaBeanDeserializer.class), "deserialze", str10 + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;I)Ljava/lang/Object;");
            mw.visitInsn(176);
            mw.visitMaxs(10, context.variantIndex);
            mw.visitEnd();
        }
    }

    private void defineVarLexer(Context context, MethodVisitor mw) {
        mw.visitVarInsn(25, 1);
        mw.visitFieldInsn(180, DefaultJSONParser, "lexer", ASMUtils.desc(JSONLexer.class));
        mw.visitTypeInsn(192, JSONLexerBase);
        mw.visitVarInsn(58, context.var("lexer"));
    }

    private void _createInstance(Context context, MethodVisitor mw) {
        Constructor<?> defaultConstructor = context.beanInfo.defaultConstructor;
        if (Modifier.isPublic(defaultConstructor.getModifiers())) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(context.getInstClass()));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(defaultConstructor.getDeclaringClass()), "<init>", "()V");
        } else {
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 0);
            mw.visitFieldInsn(180, ASMUtils.type(JavaBeanDeserializer.class), "clazz", "Ljava/lang/Class;");
            String type = ASMUtils.type(JavaBeanDeserializer.class);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, type, WXBridgeManager.METHOD_CREATE_INSTANCE, "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;)Ljava/lang/Object;");
            mw.visitTypeInsn(192, ASMUtils.type(context.getInstClass()));
        }
        mw.visitVarInsn(58, context.var("instance"));
    }

    private void _batchSet(Context context, MethodVisitor mw) {
        _batchSet(context, mw, true);
    }

    private void _batchSet(Context context, MethodVisitor mw, boolean flag) {
        int size = context.fieldInfoList.length;
        for (int i = 0; i < size; i++) {
            Label notSet_ = new Label();
            if (flag) {
                _isFlag(mw, context, i, notSet_);
            }
            _loadAndSet(context, mw, context.fieldInfoList[i]);
            if (flag) {
                mw.visitLabel(notSet_);
            }
        }
    }

    private void _loadAndSet(Context context, MethodVisitor mw, FieldInfo fieldInfo) {
        Class<?> fieldClass = fieldInfo.fieldClass;
        Type fieldType = fieldInfo.fieldType;
        if (fieldClass == Boolean.TYPE) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(21, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        } else if (fieldClass == Byte.TYPE || fieldClass == Short.TYPE || fieldClass == Integer.TYPE || fieldClass == Character.TYPE) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(21, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        } else if (fieldClass == Long.TYPE) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(22, context.var_asm(fieldInfo, 2));
            if (fieldInfo.method != null) {
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(context.getInstClass()), fieldInfo.method.getName(), ASMUtils.desc(fieldInfo.method));
                if (!fieldInfo.method.getReturnType().equals(Void.TYPE)) {
                    mw.visitInsn(87);
                    return;
                }
                return;
            }
            mw.visitFieldInsn(Opcodes.PUTFIELD, ASMUtils.type(fieldInfo.declaringClass), fieldInfo.field.getName(), ASMUtils.desc(fieldInfo.fieldClass));
        } else if (fieldClass == Float.TYPE) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(23, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        } else if (fieldClass == Double.TYPE) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(24, context.var_asm(fieldInfo, 2));
            _set(context, mw, fieldInfo);
        } else if (fieldClass == String.class) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(25, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        } else if (fieldClass.isEnum()) {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(25, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        } else if (Collection.class.isAssignableFrom(fieldClass)) {
            mw.visitVarInsn(25, context.var("instance"));
            if (TypeUtils.getCollectionItemClass(fieldType) == String.class) {
                mw.visitVarInsn(25, context.var_asm(fieldInfo));
                mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
            } else {
                mw.visitVarInsn(25, context.var_asm(fieldInfo));
            }
            _set(context, mw, fieldInfo);
        } else {
            mw.visitVarInsn(25, context.var("instance"));
            mw.visitVarInsn(25, context.var_asm(fieldInfo));
            _set(context, mw, fieldInfo);
        }
    }

    private void _set(Context context, MethodVisitor mw, FieldInfo fieldInfo) {
        Method method = fieldInfo.method;
        if (method != null) {
            mw.visitMethodInsn(method.getDeclaringClass().isInterface() ? Opcodes.INVOKEINTERFACE : Opcodes.INVOKEVIRTUAL, ASMUtils.type(fieldInfo.declaringClass), method.getName(), ASMUtils.desc(method));
            if (!fieldInfo.method.getReturnType().equals(Void.TYPE)) {
                mw.visitInsn(87);
                return;
            }
            return;
        }
        mw.visitFieldInsn(Opcodes.PUTFIELD, ASMUtils.type(fieldInfo.declaringClass), fieldInfo.field.getName(), ASMUtils.desc(fieldInfo.fieldClass));
    }

    private void _setContext(Context context, MethodVisitor mw) {
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, context.var(d.R));
        String str = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "setContext", Operators.BRACKET_START_STR + ASMUtils.desc(ParseContext.class) + ")V");
        Label endIf_ = new Label();
        mw.visitVarInsn(25, context.var("childContext"));
        mw.visitJumpInsn(Opcodes.IFNULL, endIf_);
        mw.visitVarInsn(25, context.var("childContext"));
        mw.visitVarInsn(25, context.var("instance"));
        mw.visitFieldInsn(Opcodes.PUTFIELD, ASMUtils.type(ParseContext.class), "object", "Ljava/lang/Object;");
        mw.visitLabel(endIf_);
    }

    private void _deserialize_endCheck(Context context, MethodVisitor mw, Label reset_) {
        mw.visitIntInsn(21, context.var("matchedCount"));
        mw.visitJumpInsn(Opcodes.IFLE, reset_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(13);
        mw.visitJumpInsn(160, reset_);
        _quickNextTokenComma(context, mw);
    }

    private void _deserialze_list_obj(Context context, MethodVisitor mw, Label reset_, FieldInfo fieldInfo, Class<?> fieldClass, Class<?> itemType, int i) {
        String str;
        String str2;
        String str3;
        Label _end_if = new Label();
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "matchField", "([C)Z");
        mw.visitJumpInsn(153, _end_if);
        _setFlag(mw, context, i);
        Label valueNotNull_ = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(8);
        mw.visitJumpInsn(160, valueNotNull_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(16);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, _end_if);
        mw.visitLabel(valueNotNull_);
        Label storeCollection_ = new Label();
        Label endSet_ = new Label();
        Label lbacketNormal_ = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(21);
        mw.visitJumpInsn(160, endSet_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(14);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
        _newCollection(mw, fieldClass, i, true);
        mw.visitJumpInsn(Opcodes.GOTO, storeCollection_);
        mw.visitLabel(endSet_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(14);
        mw.visitJumpInsn(159, lbacketNormal_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(12);
        mw.visitJumpInsn(160, reset_);
        _newCollection(mw, fieldClass, i, false);
        mw.visitVarInsn(58, context.var_asm(fieldInfo));
        _getCollectionFieldItemDeser(context, mw, fieldInfo, itemType);
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(itemType)));
        mw.visitInsn(3);
        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
        String type = ASMUtils.type(ObjectDeserializer.class);
        mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, type, "deserialze", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;)Ljava/lang/Object;");
        mw.visitVarInsn(58, context.var("list_item_value"));
        mw.visitVarInsn(25, context.var_asm(fieldInfo));
        mw.visitVarInsn(25, context.var("list_item_value"));
        if (fieldClass.isInterface()) {
            str = "list_item_value";
            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, ASMUtils.type(fieldClass), "add", "(Ljava/lang/Object;)Z");
        } else {
            str = "list_item_value";
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(fieldClass), "add", "(Ljava/lang/Object;)Z");
        }
        mw.visitInsn(87);
        mw.visitJumpInsn(Opcodes.GOTO, _end_if);
        mw.visitLabel(lbacketNormal_);
        _newCollection(mw, fieldClass, i, false);
        mw.visitLabel(storeCollection_);
        mw.visitVarInsn(58, context.var_asm(fieldInfo));
        boolean isPrimitive = ParserConfig.isPrimitive2(fieldInfo.fieldClass);
        _getCollectionFieldItemDeser(context, mw, fieldInfo, itemType);
        if (isPrimitive) {
            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, ASMUtils.type(ObjectDeserializer.class), "getFastMatchToken", "()I");
            mw.visitVarInsn(54, context.var("fastMatchToken"));
            mw.visitVarInsn(25, context.var("lexer"));
            mw.visitVarInsn(21, context.var("fastMatchToken"));
            str3 = "(I)V";
            str2 = "nextToken";
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, str2, str3);
        } else {
            str3 = "(I)V";
            str2 = "nextToken";
            mw.visitInsn(87);
            mw.visitLdcInsn(12);
            mw.visitVarInsn(54, context.var("fastMatchToken"));
            _quickNextToken(context, mw, 12);
        }
        mw.visitVarInsn(25, 1);
        String str4 = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str4, "getContext", "()" + ASMUtils.desc(ParseContext.class));
        mw.visitVarInsn(58, context.var("listContext"));
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, context.var_asm(fieldInfo));
        mw.visitLdcInsn(fieldInfo.name);
        String str5 = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str5, "setContext", "(Ljava/lang/Object;Ljava/lang/Object;)" + ASMUtils.desc(ParseContext.class));
        mw.visitInsn(87);
        Label loop_ = new Label();
        Label loop_end_ = new Label();
        mw.visitInsn(3);
        mw.visitVarInsn(54, context.var("i"));
        mw.visitLabel(loop_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(15);
        mw.visitJumpInsn(159, loop_end_);
        mw.visitVarInsn(25, 0);
        String str6 = context.className;
        mw.visitFieldInsn(180, str6, fieldInfo.name + "_asm_list_item_deser__", ASMUtils.desc(ObjectDeserializer.class));
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(itemType)));
        mw.visitVarInsn(21, context.var("i"));
        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
        String type2 = ASMUtils.type(ObjectDeserializer.class);
        mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, type2, "deserialze", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;)Ljava/lang/Object;");
        mw.visitVarInsn(58, context.var(str));
        mw.visitIincInsn(context.var("i"), 1);
        mw.visitVarInsn(25, context.var_asm(fieldInfo));
        mw.visitVarInsn(25, context.var(str));
        if (fieldClass.isInterface()) {
            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, ASMUtils.type(fieldClass), "add", "(Ljava/lang/Object;)Z");
        } else {
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(fieldClass), "add", "(Ljava/lang/Object;)Z");
        }
        mw.visitInsn(87);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, context.var_asm(fieldInfo));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "checkListResolve", "(Ljava/util/Collection;)V");
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(16);
        mw.visitJumpInsn(160, loop_);
        if (isPrimitive) {
            mw.visitVarInsn(25, context.var("lexer"));
            mw.visitVarInsn(21, context.var("fastMatchToken"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, str2, str3);
        } else {
            _quickNextToken(context, mw, 12);
        }
        mw.visitJumpInsn(Opcodes.GOTO, loop_);
        mw.visitLabel(loop_end_);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, context.var("listContext"));
        String str7 = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str7, "setContext", Operators.BRACKET_START_STR + ASMUtils.desc(ParseContext.class) + ")V");
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "token", "()I");
        mw.visitLdcInsn(15);
        mw.visitJumpInsn(160, reset_);
        _quickNextTokenComma(context, mw);
        mw.visitLabel(_end_if);
    }

    private void _quickNextToken(Context context, MethodVisitor mw, int token) {
        Label quickElse_ = new Label();
        Label quickEnd_ = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
        if (token == 12) {
            mw.visitVarInsn(16, 123);
        } else if (token == 14) {
            mw.visitVarInsn(16, 91);
        } else {
            throw new IllegalStateException();
        }
        mw.visitJumpInsn(160, quickElse_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(Integer.valueOf(token));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
        mw.visitLabel(quickElse_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(Integer.valueOf(token));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "(I)V");
        mw.visitLabel(quickEnd_);
    }

    private void _quickNextTokenComma(Context context, MethodVisitor mw) {
        Label quickElse_ = new Label();
        Label quickElseIf0_ = new Label();
        Label quickElseIf1_ = new Label();
        Label quickElseIf2_ = new Label();
        Label quickEnd_ = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "getCurrent", "()C");
        mw.visitInsn(89);
        mw.visitVarInsn(54, context.var("ch"));
        mw.visitVarInsn(16, 44);
        mw.visitJumpInsn(160, quickElseIf0_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(16);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
        mw.visitLabel(quickElseIf0_);
        mw.visitVarInsn(21, context.var("ch"));
        mw.visitVarInsn(16, 125);
        mw.visitJumpInsn(160, quickElseIf1_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(13);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
        mw.visitLabel(quickElseIf1_);
        mw.visitVarInsn(21, context.var("ch"));
        mw.visitVarInsn(16, 93);
        mw.visitJumpInsn(160, quickElseIf2_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "next", "()C");
        mw.visitInsn(87);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(15);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
        mw.visitLabel(quickElseIf2_);
        mw.visitVarInsn(21, context.var("ch"));
        mw.visitVarInsn(16, 26);
        mw.visitJumpInsn(160, quickElse_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitLdcInsn(20);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "setToken", "(I)V");
        mw.visitJumpInsn(Opcodes.GOTO, quickEnd_);
        mw.visitLabel(quickElse_);
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "nextToken", "()V");
        mw.visitLabel(quickEnd_);
    }

    private void _getCollectionFieldItemDeser(Context context, MethodVisitor mw, FieldInfo fieldInfo, Class<?> itemType) {
        Label notNull_ = new Label();
        mw.visitVarInsn(25, 0);
        String str = context.className;
        mw.visitFieldInsn(180, str, fieldInfo.name + "_asm_list_item_deser__", ASMUtils.desc(ObjectDeserializer.class));
        mw.visitJumpInsn(Opcodes.IFNONNULL, notNull_);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        String str2 = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, "getConfig", "()" + ASMUtils.desc(ParserConfig.class));
        mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(itemType)));
        String type = ASMUtils.type(ParserConfig.class);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, type, "getDeserializer", "(Ljava/lang/reflect/Type;)" + ASMUtils.desc(ObjectDeserializer.class));
        String str3 = context.className;
        mw.visitFieldInsn(Opcodes.PUTFIELD, str3, fieldInfo.name + "_asm_list_item_deser__", ASMUtils.desc(ObjectDeserializer.class));
        mw.visitLabel(notNull_);
        mw.visitVarInsn(25, 0);
        String str4 = context.className;
        mw.visitFieldInsn(180, str4, fieldInfo.name + "_asm_list_item_deser__", ASMUtils.desc(ObjectDeserializer.class));
    }

    private void _newCollection(MethodVisitor mw, Class<?> fieldClass, int i, boolean set) {
        if (fieldClass.isAssignableFrom(ArrayList.class) && !set) {
            mw.visitTypeInsn(Opcodes.NEW, "java/util/ArrayList");
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, "java/util/ArrayList", "<init>", "()V");
        } else if (fieldClass.isAssignableFrom(LinkedList.class) && !set) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(LinkedList.class));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(LinkedList.class), "<init>", "()V");
        } else if (fieldClass.isAssignableFrom(HashSet.class)) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(HashSet.class));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(HashSet.class), "<init>", "()V");
        } else if (fieldClass.isAssignableFrom(TreeSet.class)) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(TreeSet.class));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(TreeSet.class), "<init>", "()V");
        } else if (fieldClass.isAssignableFrom(LinkedHashSet.class)) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(LinkedHashSet.class));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(LinkedHashSet.class), "<init>", "()V");
        } else if (set) {
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(HashSet.class));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(HashSet.class), "<init>", "()V");
        } else {
            mw.visitVarInsn(25, 0);
            mw.visitLdcInsn(Integer.valueOf(i));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "getFieldType", "(I)Ljava/lang/reflect/Type;");
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, ASMUtils.type(TypeUtils.class), "createCollection", "(Ljava/lang/reflect/Type;)Ljava/util/Collection;");
        }
        mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
    }

    private void _deserialze_obj(Context context, MethodVisitor mw, Label reset_, FieldInfo fieldInfo, Class<?> fieldClass, int i) {
        Label matched_ = new Label();
        Label _end_if = new Label();
        mw.visitVarInsn(25, context.var("lexer"));
        mw.visitVarInsn(25, 0);
        mw.visitFieldInsn(180, context.className, context.fieldName(fieldInfo), "[C");
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONLexerBase, "matchField", "([C)Z");
        mw.visitJumpInsn(154, matched_);
        mw.visitInsn(1);
        mw.visitVarInsn(58, context.var_asm(fieldInfo));
        mw.visitJumpInsn(Opcodes.GOTO, _end_if);
        mw.visitLabel(matched_);
        _setFlag(mw, context, i);
        mw.visitVarInsn(21, context.var("matchedCount"));
        mw.visitInsn(4);
        mw.visitInsn(96);
        mw.visitVarInsn(54, context.var("matchedCount"));
        _deserObject(context, mw, fieldInfo, fieldClass, i);
        mw.visitVarInsn(25, 1);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "getResolveStatus", "()I");
        mw.visitLdcInsn(1);
        mw.visitJumpInsn(160, _end_if);
        mw.visitVarInsn(25, 1);
        String str = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "getLastResolveTask", "()" + ASMUtils.desc(DefaultJSONParser.ResolveTask.class));
        mw.visitVarInsn(58, context.var("resolveTask"));
        mw.visitVarInsn(25, context.var("resolveTask"));
        mw.visitVarInsn(25, 1);
        String str2 = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, "getContext", "()" + ASMUtils.desc(ParseContext.class));
        mw.visitFieldInsn(Opcodes.PUTFIELD, ASMUtils.type(DefaultJSONParser.ResolveTask.class), "ownerContext", ASMUtils.desc(ParseContext.class));
        mw.visitVarInsn(25, context.var("resolveTask"));
        mw.visitVarInsn(25, 0);
        mw.visitLdcInsn(fieldInfo.name);
        String type = ASMUtils.type(JavaBeanDeserializer.class);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, type, "getFieldDeserializer", "(Ljava/lang/String;)" + ASMUtils.desc(FieldDeserializer.class));
        mw.visitFieldInsn(Opcodes.PUTFIELD, ASMUtils.type(DefaultJSONParser.ResolveTask.class), "fieldDeserializer", ASMUtils.desc(FieldDeserializer.class));
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(0);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, DefaultJSONParser, "setResolveStatus", "(I)V");
        mw.visitLabel(_end_if);
    }

    private void _deserObject(Context context, MethodVisitor mw, FieldInfo fieldInfo, Class<?> fieldClass, int i) {
        _getFieldDeser(context, mw, fieldInfo);
        Label instanceOfElse_ = new Label();
        Label instanceOfEnd_ = new Label();
        if ((fieldInfo.parserFeatures & Feature.SupportArrayToBean.mask) != 0) {
            mw.visitInsn(89);
            mw.visitTypeInsn(Opcodes.INSTANCEOF, ASMUtils.type(JavaBeanDeserializer.class));
            mw.visitJumpInsn(153, instanceOfElse_);
            mw.visitTypeInsn(192, ASMUtils.type(JavaBeanDeserializer.class));
            mw.visitVarInsn(25, 1);
            if (fieldInfo.fieldType instanceof Class) {
                mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldInfo.fieldClass)));
            } else {
                mw.visitVarInsn(25, 0);
                mw.visitLdcInsn(Integer.valueOf(i));
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "getFieldType", "(I)Ljava/lang/reflect/Type;");
            }
            mw.visitLdcInsn(fieldInfo.name);
            mw.visitLdcInsn(Integer.valueOf(fieldInfo.parserFeatures));
            String type = ASMUtils.type(JavaBeanDeserializer.class);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, type, "deserialze", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;I)Ljava/lang/Object;");
            mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
            mw.visitVarInsn(58, context.var_asm(fieldInfo));
            mw.visitJumpInsn(Opcodes.GOTO, instanceOfEnd_);
            mw.visitLabel(instanceOfElse_);
        }
        mw.visitVarInsn(25, 1);
        if (fieldInfo.fieldType instanceof Class) {
            mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldInfo.fieldClass)));
        } else {
            mw.visitVarInsn(25, 0);
            mw.visitLdcInsn(Integer.valueOf(i));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, ASMUtils.type(JavaBeanDeserializer.class), "getFieldType", "(I)Ljava/lang/reflect/Type;");
        }
        mw.visitLdcInsn(fieldInfo.name);
        String type2 = ASMUtils.type(ObjectDeserializer.class);
        mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, type2, "deserialze", "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;Ljava/lang/Object;)Ljava/lang/Object;");
        mw.visitTypeInsn(192, ASMUtils.type(fieldClass));
        mw.visitVarInsn(58, context.var_asm(fieldInfo));
        mw.visitLabel(instanceOfEnd_);
    }

    private void _getFieldDeser(Context context, MethodVisitor mw, FieldInfo fieldInfo) {
        Label notNull_ = new Label();
        mw.visitVarInsn(25, 0);
        mw.visitFieldInsn(180, context.className, context.fieldDeserName(fieldInfo), ASMUtils.desc(ObjectDeserializer.class));
        mw.visitJumpInsn(Opcodes.IFNONNULL, notNull_);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        String str = DefaultJSONParser;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "getConfig", "()" + ASMUtils.desc(ParserConfig.class));
        mw.visitLdcInsn(com.alibaba.fastjson.asm.Type.getType(ASMUtils.desc(fieldInfo.fieldClass)));
        String type = ASMUtils.type(ParserConfig.class);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, type, "getDeserializer", "(Ljava/lang/reflect/Type;)" + ASMUtils.desc(ObjectDeserializer.class));
        mw.visitFieldInsn(Opcodes.PUTFIELD, context.className, context.fieldDeserName(fieldInfo), ASMUtils.desc(ObjectDeserializer.class));
        mw.visitLabel(notNull_);
        mw.visitVarInsn(25, 0);
        mw.visitFieldInsn(180, context.className, context.fieldDeserName(fieldInfo), ASMUtils.desc(ObjectDeserializer.class));
    }

    /* access modifiers changed from: package-private */
    public static class Context {
        static final int fieldName = 3;
        static final int parser = 1;
        static final int type = 2;
        private final JavaBeanInfo beanInfo;
        private final String className;
        private final Class<?> clazz;
        private FieldInfo[] fieldInfoList;
        private int variantIndex = -1;
        private final Map<String, Integer> variants = new HashMap();

        public Context(String className2, ParserConfig config, JavaBeanInfo beanInfo2, int initVariantIndex) {
            this.className = className2;
            this.clazz = beanInfo2.clazz;
            this.variantIndex = initVariantIndex;
            this.beanInfo = beanInfo2;
            this.fieldInfoList = beanInfo2.fields;
        }

        public Class<?> getInstClass() {
            Class<?> instClass = this.beanInfo.builderClass;
            if (instClass == null) {
                return this.clazz;
            }
            return instClass;
        }

        public int var(String name, int increment) {
            if (this.variants.get(name) == null) {
                this.variants.put(name, Integer.valueOf(this.variantIndex));
                this.variantIndex += increment;
            }
            return this.variants.get(name).intValue();
        }

        public int var(String name) {
            if (this.variants.get(name) == null) {
                Map<String, Integer> map = this.variants;
                int i = this.variantIndex;
                this.variantIndex = i + 1;
                map.put(name, Integer.valueOf(i));
            }
            return this.variants.get(name).intValue();
        }

        public int var_asm(FieldInfo fieldInfo) {
            return var(fieldInfo.name + "_asm");
        }

        public int var_asm(FieldInfo fieldInfo, int increment) {
            return var(fieldInfo.name + "_asm", increment);
        }

        public String fieldName(FieldInfo fieldInfo) {
            if (validIdent(fieldInfo.name)) {
                return fieldInfo.name + "_asm_prefix__";
            }
            return "asm_field_" + TypeUtils.fnv1a_64_extract(fieldInfo.name);
        }

        public String fieldDeserName(FieldInfo fieldInfo) {
            if (validIdent(fieldInfo.name)) {
                return fieldInfo.name + "_asm_deser__";
            }
            return "_asm_deser__" + TypeUtils.fnv1a_64_extract(fieldInfo.name);
        }

        /* access modifiers changed from: package-private */
        public boolean validIdent(String name) {
            for (int i = 0; i < name.length(); i++) {
                char ch = name.charAt(i);
                if (ch == 0) {
                    if (!IOUtils.firstIdentifier(ch)) {
                        return false;
                    }
                } else if (!IOUtils.isIdent(ch)) {
                    return false;
                }
            }
            return true;
        }
    }

    private void _init(ClassWriter cw, Context context) {
        int size = context.fieldInfoList.length;
        for (int i = 0; i < size; i++) {
            new FieldWriter(cw, 1, context.fieldName(context.fieldInfoList[i]), "[C").visitEnd();
        }
        int size2 = context.fieldInfoList.length;
        for (int i2 = 0; i2 < size2; i2++) {
            FieldInfo fieldInfo = context.fieldInfoList[i2];
            Class<?> fieldClass = fieldInfo.fieldClass;
            if (!fieldClass.isPrimitive()) {
                if (Collection.class.isAssignableFrom(fieldClass)) {
                    new FieldWriter(cw, 1, fieldInfo.name + "_asm_list_item_deser__", ASMUtils.desc(ObjectDeserializer.class)).visitEnd();
                } else {
                    new FieldWriter(cw, 1, context.fieldDeserName(fieldInfo), ASMUtils.desc(ObjectDeserializer.class)).visitEnd();
                }
            }
        }
        MethodVisitor mw = new MethodWriter(cw, 1, "<init>", Operators.BRACKET_START_STR + ASMUtils.desc(ParserConfig.class) + ASMUtils.desc(JavaBeanInfo.class) + ")V", null, null);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        String type = ASMUtils.type(JavaBeanDeserializer.class);
        mw.visitMethodInsn(Opcodes.INVOKESPECIAL, type, "<init>", Operators.BRACKET_START_STR + ASMUtils.desc(ParserConfig.class) + ASMUtils.desc(JavaBeanInfo.class) + ")V");
        int size3 = context.fieldInfoList.length;
        for (int i3 = 0; i3 < size3; i3++) {
            FieldInfo fieldInfo2 = context.fieldInfoList[i3];
            mw.visitVarInsn(25, 0);
            mw.visitLdcInsn("\"" + fieldInfo2.name + "\":");
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/String", "toCharArray", "()[C");
            mw.visitFieldInsn(Opcodes.PUTFIELD, context.className, context.fieldName(fieldInfo2), "[C");
        }
        mw.visitInsn(177);
        mw.visitMaxs(4, 4);
        mw.visitEnd();
    }

    private void _createInstance(ClassWriter cw, Context context) {
        if (Modifier.isPublic(context.beanInfo.defaultConstructor.getModifiers())) {
            MethodVisitor mw = new MethodWriter(cw, 1, WXBridgeManager.METHOD_CREATE_INSTANCE, "(L" + DefaultJSONParser + ";Ljava/lang/reflect/Type;)Ljava/lang/Object;", null, null);
            mw.visitTypeInsn(Opcodes.NEW, ASMUtils.type(context.getInstClass()));
            mw.visitInsn(89);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, ASMUtils.type(context.getInstClass()), "<init>", "()V");
            mw.visitInsn(176);
            mw.visitMaxs(3, 3);
            mw.visitEnd();
        }
    }
}
