package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.util.TypeUtils;
import java.lang.reflect.Type;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

public class EnumDeserializer implements ObjectDeserializer {
    protected final Class<?> enumClass;
    protected long[] enumNameHashCodes;
    protected final Enum[] enums;
    protected final Enum[] ordinalEnums;

    public EnumDeserializer(Class<?> enumClass2) {
        String jsonFieldName;
        this.enumClass = enumClass2;
        this.ordinalEnums = (Enum[]) enumClass2.getEnumConstants();
        Map<Long, Enum> enumMap = new HashMap<>();
        int i = 0;
        while (true) {
            Enum[] enumArr = this.ordinalEnums;
            if (i >= enumArr.length) {
                break;
            }
            Enum e = enumArr[i];
            String name = e.name();
            JSONField jsonField = null;
            try {
                jsonField = (JSONField) TypeUtils.getAnnotation(enumClass2.getField(name), JSONField.class);
                if (!(jsonField == null || (jsonFieldName = jsonField.name()) == null || jsonFieldName.length() <= 0)) {
                    name = jsonFieldName;
                }
            } catch (Exception e2) {
            }
            long hash = TypeUtils.fnv1a_64_magic_hashcode;
            long hash_lower = TypeUtils.fnv1a_64_magic_hashcode;
            for (int j = 0; j < name.length(); j++) {
                char ch = name.charAt(j);
                long hash2 = hash ^ ((long) ch);
                int i2 = (ch < 'A' || ch > 'Z') ? ch : ch + ' ';
                hash = hash2 * TypeUtils.fnv1a_64_magic_prime;
                hash_lower = (hash_lower ^ ((long) i2)) * TypeUtils.fnv1a_64_magic_prime;
            }
            enumMap.put(Long.valueOf(hash), e);
            if (hash != hash_lower) {
                enumMap.put(Long.valueOf(hash_lower), e);
            }
            if (jsonField != null) {
                String[] alternateNames = jsonField.alternateNames();
                int length = alternateNames.length;
                int i3 = 0;
                while (i3 < length) {
                    String alterName = alternateNames[i3];
                    long alterNameHash = TypeUtils.fnv1a_64_magic_hashcode;
                    int j2 = 0;
                    while (j2 < alterName.length()) {
                        alterNameHash = (alterNameHash ^ ((long) alterName.charAt(j2))) * TypeUtils.fnv1a_64_magic_prime;
                        j2++;
                        alternateNames = alternateNames;
                        name = name;
                        jsonField = jsonField;
                    }
                    if (!(alterNameHash == hash || alterNameHash == hash_lower)) {
                        enumMap.put(Long.valueOf(alterNameHash), e);
                    }
                    i3++;
                    alternateNames = alternateNames;
                    name = name;
                    jsonField = jsonField;
                }
            }
            i++;
        }
        this.enumNameHashCodes = new long[enumMap.size()];
        int i4 = 0;
        for (Long h : enumMap.keySet()) {
            this.enumNameHashCodes[i4] = h.longValue();
            i4++;
        }
        Arrays.sort(this.enumNameHashCodes);
        this.enums = new Enum[this.enumNameHashCodes.length];
        int i5 = 0;
        while (true) {
            long[] jArr = this.enumNameHashCodes;
            if (i5 < jArr.length) {
                this.enums[i5] = enumMap.get(Long.valueOf(jArr[i5]));
                i5++;
            } else {
                return;
            }
        }
    }

    public Enum getEnumByHashCode(long hashCode) {
        int enumIndex;
        if (this.enums != null && (enumIndex = Arrays.binarySearch(this.enumNameHashCodes, hashCode)) >= 0) {
            return this.enums[enumIndex];
        }
        return null;
    }

    public Enum<?> valueOf(int ordinal) {
        return this.ordinalEnums[ordinal];
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
        try {
            JSONLexer lexer = parser.lexer;
            int token = lexer.token();
            if (token == 2) {
                int intValue = lexer.intValue();
                lexer.nextToken(16);
                if (intValue >= 0 && intValue < this.ordinalEnums.length) {
                    return (T) this.ordinalEnums[intValue];
                }
                throw new JSONException("parse enum " + this.enumClass.getName() + " error, value : " + intValue);
            } else if (token == 4) {
                String name = lexer.stringVal();
                lexer.nextToken(16);
                if (name.length() == 0) {
                    return null;
                }
                long hash = TypeUtils.fnv1a_64_magic_hashcode;
                long hash_lower = TypeUtils.fnv1a_64_magic_hashcode;
                for (int j = 0; j < name.length(); j++) {
                    char ch = name.charAt(j);
                    long hash2 = hash ^ ((long) ch);
                    int i = (ch < 'A' || ch > 'Z') ? ch : ch + ' ';
                    hash = hash2 * TypeUtils.fnv1a_64_magic_prime;
                    hash_lower = (hash_lower ^ ((long) i)) * TypeUtils.fnv1a_64_magic_prime;
                }
                Enum e = (T) getEnumByHashCode(hash);
                if (e == null && hash_lower != hash) {
                    e = (T) getEnumByHashCode(hash_lower);
                }
                if (e != null || !lexer.isEnabled(Feature.ErrorOnEnumNotMatch)) {
                    return (T) e;
                }
                throw new JSONException("not match enum value, " + this.enumClass.getName() + " : " + name);
            } else if (token == 8) {
                lexer.nextToken(16);
                return null;
            } else {
                Object value = parser.parse();
                throw new JSONException("parse enum " + this.enumClass.getName() + " error, value : " + value);
            }
        } catch (JSONException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new JSONException(e3.getMessage(), e3);
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 2;
    }
}
