package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.serializer.BeanContext;
import com.alibaba.fastjson.util.FieldInfo;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.Collections;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;

public abstract class FieldDeserializer {
    protected BeanContext beanContext;
    protected final Class<?> clazz;
    public final FieldInfo fieldInfo;

    public abstract void parseField(DefaultJSONParser defaultJSONParser, Object obj, Type type, Map<String, Object> map);

    public FieldDeserializer(Class<?> clazz2, FieldInfo fieldInfo2) {
        this.clazz = clazz2;
        this.fieldInfo = fieldInfo2;
    }

    public Class<?> getOwnerClass() {
        return this.clazz;
    }

    public int getFastMatchToken() {
        return 0;
    }

    public void setValue(Object object, boolean value) {
        setValue(object, Boolean.valueOf(value));
    }

    public void setValue(Object object, int value) {
        setValue(object, Integer.valueOf(value));
    }

    public void setValue(Object object, long value) {
        setValue(object, Long.valueOf(value));
    }

    public void setValue(Object object, String value) {
        setValue(object, (Object) value);
    }

    public void setValue(Object object, Object value) {
        if (value != null || !this.fieldInfo.fieldClass.isPrimitive()) {
            if (this.fieldInfo.fieldClass == String.class && this.fieldInfo.format != null && this.fieldInfo.format.equals(AbsoluteConst.XML_TRIM)) {
                value = ((String) value).trim();
            }
            try {
                Method method = this.fieldInfo.method;
                if (method == null) {
                    Field field = this.fieldInfo.field;
                    if (this.fieldInfo.getOnly) {
                        if (this.fieldInfo.fieldClass == AtomicInteger.class) {
                            AtomicInteger atomic = (AtomicInteger) field.get(object);
                            if (atomic != null) {
                                atomic.set(((AtomicInteger) value).get());
                            }
                        } else if (this.fieldInfo.fieldClass == AtomicLong.class) {
                            AtomicLong atomic2 = (AtomicLong) field.get(object);
                            if (atomic2 != null) {
                                atomic2.set(((AtomicLong) value).get());
                            }
                        } else if (this.fieldInfo.fieldClass == AtomicBoolean.class) {
                            AtomicBoolean atomic3 = (AtomicBoolean) field.get(object);
                            if (atomic3 != null) {
                                atomic3.set(((AtomicBoolean) value).get());
                            }
                        } else if (Map.class.isAssignableFrom(this.fieldInfo.fieldClass)) {
                            Map map = (Map) field.get(object);
                            if (map != null && map != Collections.emptyMap() && !map.getClass().getName().startsWith("java.util.Collections$Unmodifiable")) {
                                map.putAll((Map) value);
                            }
                        } else {
                            Collection collection = (Collection) field.get(object);
                            if (collection != null && value != null && collection != Collections.emptySet() && collection != Collections.emptyList() && !collection.getClass().getName().startsWith("java.util.Collections$Unmodifiable")) {
                                collection.clear();
                                collection.addAll((Collection) value);
                            }
                        }
                    } else if (field != null) {
                        field.set(object, value);
                    }
                } else if (!this.fieldInfo.getOnly) {
                    method.invoke(object, value);
                } else if (this.fieldInfo.fieldClass == AtomicInteger.class) {
                    AtomicInteger atomic4 = (AtomicInteger) method.invoke(object, new Object[0]);
                    if (atomic4 != null) {
                        atomic4.set(((AtomicInteger) value).get());
                    } else {
                        degradeValueAssignment(this.fieldInfo.field, method, object, value);
                    }
                } else if (this.fieldInfo.fieldClass == AtomicLong.class) {
                    AtomicLong atomic5 = (AtomicLong) method.invoke(object, new Object[0]);
                    if (atomic5 != null) {
                        atomic5.set(((AtomicLong) value).get());
                    } else {
                        degradeValueAssignment(this.fieldInfo.field, method, object, value);
                    }
                } else if (this.fieldInfo.fieldClass == AtomicBoolean.class) {
                    AtomicBoolean atomic6 = (AtomicBoolean) method.invoke(object, new Object[0]);
                    if (atomic6 != null) {
                        atomic6.set(((AtomicBoolean) value).get());
                    } else {
                        degradeValueAssignment(this.fieldInfo.field, method, object, value);
                    }
                } else if (Map.class.isAssignableFrom(method.getReturnType())) {
                    try {
                        Map map2 = (Map) method.invoke(object, new Object[0]);
                        if (map2 != null) {
                            if (map2 != Collections.emptyMap()) {
                                if (!map2.isEmpty() || !((Map) value).isEmpty()) {
                                    String mapClassName = map2.getClass().getName();
                                    if (!mapClassName.equals("java.util.ImmutableCollections$Map1") && !mapClassName.equals("java.util.ImmutableCollections$MapN") && !mapClassName.startsWith("java.util.Collections$Unmodifiable")) {
                                        if (map2.getClass().getName().equals("kotlin.collections.EmptyMap")) {
                                            degradeValueAssignment(this.fieldInfo.field, method, object, value);
                                        } else {
                                            map2.putAll((Map) value);
                                        }
                                    }
                                }
                            }
                        } else if (value != null) {
                            degradeValueAssignment(this.fieldInfo.field, method, object, value);
                        }
                    } catch (InvocationTargetException e) {
                        degradeValueAssignment(this.fieldInfo.field, method, object, value);
                    }
                } else {
                    try {
                        Collection collection2 = (Collection) method.invoke(object, new Object[0]);
                        if (collection2 != null && value != null) {
                            String collectionClassName = collection2.getClass().getName();
                            if (collection2 != Collections.emptySet() && collection2 != Collections.emptyList() && collectionClassName != "java.util.ImmutableCollections$ListN" && collectionClassName != "java.util.ImmutableCollections$List12" && !collectionClassName.startsWith("java.util.Collections$Unmodifiable")) {
                                if (!collection2.isEmpty()) {
                                    collection2.clear();
                                } else if (((Collection) value).isEmpty()) {
                                    return;
                                }
                                if (collectionClassName.equals("kotlin.collections.EmptyList") || collectionClassName.equals("kotlin.collections.EmptySet")) {
                                    degradeValueAssignment(this.fieldInfo.field, method, object, value);
                                } else {
                                    collection2.addAll((Collection) value);
                                }
                            }
                        } else if (collection2 == null && value != null) {
                            degradeValueAssignment(this.fieldInfo.field, method, object, value);
                        }
                    } catch (InvocationTargetException e2) {
                        degradeValueAssignment(this.fieldInfo.field, method, object, value);
                    }
                }
            } catch (Exception e3) {
                throw new JSONException("set property error, " + this.clazz.getName() + "#" + this.fieldInfo.name, e3);
            }
        }
    }

    private static boolean degradeValueAssignment(Field field, Method getMethod, Object object, Object value) throws InvocationTargetException, IllegalAccessException {
        if (setFieldValue(field, object, value)) {
            return true;
        }
        try {
            Class<?> cls = object.getClass();
            cls.getDeclaredMethod("set" + getMethod.getName().substring(3), getMethod.getReturnType()).invoke(object, value);
            return true;
        } catch (IllegalAccessException | NoSuchMethodException | InvocationTargetException e) {
            return false;
        }
    }

    private static boolean setFieldValue(Field field, Object object, Object value) throws IllegalAccessException {
        if (field == null || Modifier.isFinal(field.getModifiers())) {
            return false;
        }
        field.set(object, value);
        return true;
    }

    public void setWrappedValue(String key, Object value) {
        throw new JSONException("TODO");
    }
}
