package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONValidator;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JSONLexerBase;
import com.alibaba.fastjson.parser.JSONToken;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.JavaBeanInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

public class JavaBeanDeserializer implements ObjectDeserializer {
    private final Map<String, FieldDeserializer> alterNameFieldDeserializers;
    private final ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler;
    public final JavaBeanInfo beanInfo;
    protected final Class<?> clazz;
    private ConcurrentMap<String, Object> extraFieldDeserializers;
    private Map<String, FieldDeserializer> fieldDeserializerMap;
    private final FieldDeserializer[] fieldDeserializers;
    private transient long[] hashArray;
    private transient short[] hashArrayMapping;
    private transient long[] smartMatchHashArray;
    private transient short[] smartMatchHashArrayMapping;
    protected final FieldDeserializer[] sortedFieldDeserializers;

    public JavaBeanDeserializer(ParserConfig config, Class<?> clazz2) {
        this(config, clazz2, clazz2);
    }

    public JavaBeanDeserializer(ParserConfig config, Class<?> clazz2, Type type) {
        this(config, JavaBeanInfo.build(clazz2, type, config.propertyNamingStrategy, config.fieldBased, config.compatibleWithJavaBean, config.isJacksonCompatible()));
    }

    public JavaBeanDeserializer(ParserConfig config, JavaBeanInfo beanInfo2) {
        this.clazz = beanInfo2.clazz;
        this.beanInfo = beanInfo2;
        ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler2 = null;
        if (!(beanInfo2.jsonType == null || beanInfo2.jsonType.autoTypeCheckHandler() == ParserConfig.AutoTypeCheckHandler.class)) {
            try {
                autoTypeCheckHandler2 = (ParserConfig.AutoTypeCheckHandler) beanInfo2.jsonType.autoTypeCheckHandler().newInstance();
            } catch (Exception e) {
            }
        }
        this.autoTypeCheckHandler = autoTypeCheckHandler2;
        Map<String, FieldDeserializer> alterNameFieldDeserializers2 = null;
        this.sortedFieldDeserializers = new FieldDeserializer[beanInfo2.sortedFields.length];
        int size = beanInfo2.sortedFields.length;
        for (int i = 0; i < size; i++) {
            FieldInfo fieldInfo = beanInfo2.sortedFields[i];
            FieldDeserializer fieldDeserializer = config.createFieldDeserializer(config, beanInfo2, fieldInfo);
            this.sortedFieldDeserializers[i] = fieldDeserializer;
            if (size > 128) {
                if (this.fieldDeserializerMap == null) {
                    this.fieldDeserializerMap = new HashMap();
                }
                this.fieldDeserializerMap.put(fieldInfo.name, fieldDeserializer);
            }
            String[] strArr = fieldInfo.alternateNames;
            for (String name : strArr) {
                if (alterNameFieldDeserializers2 == null) {
                    alterNameFieldDeserializers2 = new HashMap<>();
                }
                alterNameFieldDeserializers2.put(name, fieldDeserializer);
            }
        }
        this.alterNameFieldDeserializers = alterNameFieldDeserializers2;
        this.fieldDeserializers = new FieldDeserializer[beanInfo2.fields.length];
        int size2 = beanInfo2.fields.length;
        for (int i2 = 0; i2 < size2; i2++) {
            this.fieldDeserializers[i2] = getFieldDeserializer(beanInfo2.fields[i2].name);
        }
    }

    public FieldDeserializer getFieldDeserializer(String key) {
        return getFieldDeserializer(key, null);
    }

    public FieldDeserializer getFieldDeserializer(String key, int[] setFlags) {
        FieldDeserializer fieldDeserializer;
        if (key == null) {
            return null;
        }
        Map<String, FieldDeserializer> map = this.fieldDeserializerMap;
        if (map != null && (fieldDeserializer = map.get(key)) != null) {
            return fieldDeserializer;
        }
        int low = 0;
        int high = this.sortedFieldDeserializers.length - 1;
        while (low <= high) {
            int mid = (low + high) >>> 1;
            int cmp = this.sortedFieldDeserializers[mid].fieldInfo.name.compareTo(key);
            if (cmp < 0) {
                low = mid + 1;
            } else if (cmp > 0) {
                high = mid - 1;
            } else if (isSetFlag(mid, setFlags)) {
                return null;
            } else {
                return this.sortedFieldDeserializers[mid];
            }
        }
        Map<String, FieldDeserializer> map2 = this.alterNameFieldDeserializers;
        if (map2 != null) {
            return map2.get(key);
        }
        return null;
    }

    public FieldDeserializer getFieldDeserializer(long hash) {
        if (this.hashArray == null) {
            long[] hashArray2 = new long[this.sortedFieldDeserializers.length];
            int i = 0;
            while (true) {
                FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                if (i >= fieldDeserializerArr.length) {
                    break;
                }
                hashArray2[i] = TypeUtils.fnv1a_64(fieldDeserializerArr[i].fieldInfo.name);
                i++;
            }
            Arrays.sort(hashArray2);
            this.hashArray = hashArray2;
        }
        int pos = Arrays.binarySearch(this.hashArray, hash);
        if (pos < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            short[] mapping = new short[this.hashArray.length];
            Arrays.fill(mapping, (short) -1);
            int i2 = 0;
            while (true) {
                FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                if (i2 >= fieldDeserializerArr2.length) {
                    break;
                }
                int p = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(fieldDeserializerArr2[i2].fieldInfo.name));
                if (p >= 0) {
                    mapping[p] = (short) i2;
                }
                i2++;
            }
            this.hashArrayMapping = mapping;
        }
        short s = this.hashArrayMapping[pos];
        if (s != -1) {
            return this.sortedFieldDeserializers[s];
        }
        return null;
    }

    static boolean isSetFlag(int i, int[] setFlags) {
        int flagIndex;
        if (setFlags == null || (flagIndex = i / 32) >= setFlags.length || (setFlags[flagIndex] & (1 << (i % 32))) == 0) {
            return false;
        }
        return true;
    }

    public Object createInstance(DefaultJSONParser parser, Type type) {
        Object object;
        int i = 0;
        if ((type instanceof Class) && this.clazz.isInterface()) {
            return Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{(Class) type}, new JSONObject());
        } else if (this.beanInfo.defaultConstructor == null && this.beanInfo.factoryMethod == null) {
            return null;
        } else {
            if (this.beanInfo.factoryMethod != null && this.beanInfo.defaultConstructorParameterSize > 0) {
                return null;
            }
            try {
                Constructor<?> constructor = this.beanInfo.defaultConstructor;
                if (this.beanInfo.defaultConstructorParameterSize != 0) {
                    ParseContext context = parser.getContext();
                    if (context == null || context.object == null) {
                        throw new JSONException("can't create non-static inner class instance.");
                    } else if (type instanceof Class) {
                        String typeName = ((Class) type).getName();
                        String parentClassName = typeName.substring(0, typeName.lastIndexOf(36));
                        Object ctxObj = context.object;
                        String parentName = ctxObj.getClass().getName();
                        Object param = null;
                        if (!parentName.equals(parentClassName)) {
                            ParseContext parentContext = context.parent;
                            if (parentContext == null || parentContext.object == null || (!"java.util.ArrayList".equals(parentName) && !"java.util.List".equals(parentName) && !"java.util.Collection".equals(parentName) && !"java.util.Map".equals(parentName) && !"java.util.HashMap".equals(parentName))) {
                                param = ctxObj;
                            } else if (parentContext.object.getClass().getName().equals(parentClassName)) {
                                param = parentContext.object;
                            }
                        } else {
                            param = ctxObj;
                        }
                        if (param == null || ((param instanceof Collection) && ((Collection) param).isEmpty())) {
                            throw new JSONException("can't create non-static inner class instance.");
                        }
                        i = 0;
                        object = constructor.newInstance(param);
                    } else {
                        throw new JSONException("can't create non-static inner class instance.");
                    }
                } else if (constructor != null) {
                    object = constructor.newInstance(new Object[0]);
                } else {
                    object = this.beanInfo.factoryMethod.invoke(null, new Object[0]);
                }
                if (parser != null && parser.lexer.isEnabled(Feature.InitStringFieldAsEmpty)) {
                    FieldInfo[] fieldInfoArr = this.beanInfo.fields;
                    int length = fieldInfoArr.length;
                    while (i < length) {
                        FieldInfo fieldInfo = fieldInfoArr[i];
                        if (fieldInfo.fieldClass == String.class) {
                            try {
                                fieldInfo.set(object, "");
                            } catch (Exception e) {
                                throw new JSONException("create instance error, class " + this.clazz.getName(), e);
                            }
                        }
                        i++;
                    }
                }
                return object;
            } catch (JSONException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new JSONException("create instance error, class " + this.clazz.getName(), e3);
            }
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
        return (T) deserialze(parser, type, fieldName, 0);
    }

    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName, int features) {
        return (T) deserialze(parser, type, fieldName, null, features, null);
    }

    public <T> T deserialzeArrayMapping(DefaultJSONParser parser, Type type, Object fieldName, Object object) {
        Object value;
        JSONLexer lexer = parser.lexer;
        if (lexer.token() == 14) {
            String typeName = lexer.scanTypeName(parser.symbolTable);
            if (typeName != null) {
                ObjectDeserializer deserializer = getSeeAlso(parser.getConfig(), this.beanInfo, typeName);
                if (deserializer == null) {
                    deserializer = parser.getConfig().getDeserializer(parser.getConfig().checkAutoType(typeName, TypeUtils.getClass(type), lexer.getFeatures()));
                }
                if (deserializer instanceof JavaBeanDeserializer) {
                    return (T) ((JavaBeanDeserializer) deserializer).deserialzeArrayMapping(parser, type, fieldName, object);
                }
            }
            T t = (T) createInstance(parser, type);
            int i = 0;
            int size = this.sortedFieldDeserializers.length;
            while (true) {
                int i2 = 16;
                if (i >= size) {
                    break;
                }
                char seperator = i == size + -1 ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
                FieldDeserializer fieldDeser = this.sortedFieldDeserializers[i];
                Class<?> fieldClass = fieldDeser.fieldInfo.fieldClass;
                if (fieldClass == Integer.TYPE) {
                    fieldDeser.setValue((Object) t, lexer.scanInt(seperator));
                } else if (fieldClass == String.class) {
                    fieldDeser.setValue((Object) t, lexer.scanString(seperator));
                } else if (fieldClass == Long.TYPE) {
                    fieldDeser.setValue(t, lexer.scanLong(seperator));
                } else if (fieldClass.isEnum()) {
                    char ch = lexer.getCurrent();
                    if (ch == '\"' || ch == 'n') {
                        value = lexer.scanEnum(fieldClass, parser.getSymbolTable(), seperator);
                    } else if (ch < '0' || ch > '9') {
                        value = scanEnum(lexer, seperator);
                    } else {
                        value = ((EnumDeserializer) ((DefaultFieldDeserializer) fieldDeser).getFieldValueDeserilizer(parser.getConfig())).valueOf(lexer.scanInt(seperator));
                    }
                    fieldDeser.setValue(t, value);
                } else if (fieldClass == Boolean.TYPE) {
                    fieldDeser.setValue(t, lexer.scanBoolean(seperator));
                } else if (fieldClass == Float.TYPE) {
                    fieldDeser.setValue(t, Float.valueOf(lexer.scanFloat(seperator)));
                } else if (fieldClass == Double.TYPE) {
                    fieldDeser.setValue(t, Double.valueOf(lexer.scanDouble(seperator)));
                } else if (fieldClass == Date.class && lexer.getCurrent() == '1') {
                    fieldDeser.setValue(t, new Date(lexer.scanLong(seperator)));
                } else if (fieldClass == BigDecimal.class) {
                    fieldDeser.setValue(t, lexer.scanDecimal(seperator));
                } else {
                    lexer.nextToken(14);
                    fieldDeser.setValue(t, parser.parseObject(fieldDeser.fieldInfo.fieldType, fieldDeser.fieldInfo.name));
                    if (lexer.token() == 15) {
                        break;
                    }
                    if (seperator == ']') {
                        i2 = 15;
                    }
                    check(lexer, i2);
                }
                i++;
            }
            lexer.nextToken(16);
            return t;
        }
        throw new JSONException("error");
    }

    /* access modifiers changed from: protected */
    public void check(JSONLexer lexer, int token) {
        if (lexer.token() != token) {
            throw new JSONException("syntax error");
        }
    }

    /* access modifiers changed from: protected */
    public Enum<?> scanEnum(JSONLexer lexer, char seperator) {
        throw new JSONException("illegal enum. " + lexer.info());
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:861:0x0ccc */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:726:0x0d0f */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:593:0x0b0a */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX INFO: Multiple debug info for r3v2 com.alibaba.fastjson.parser.ParseContext: [D('childContext' com.alibaba.fastjson.parser.ParseContext), D('context' com.alibaba.fastjson.parser.ParseContext)] */
    /* JADX INFO: Multiple debug info for r2v37 'object'  T: [D('token' int), D('param' java.lang.Object)] */
    /* JADX INFO: Multiple debug info for r13v24 java.lang.Object: [D('fieldValue' java.lang.Object), D('config' com.alibaba.fastjson.parser.ParserConfig)] */
    /* JADX INFO: Multiple debug info for r3v100 com.alibaba.fastjson.util.FieldInfo: [D('fieldInfo' com.alibaba.fastjson.util.FieldInfo), D('token' int)] */
    /* JADX INFO: Multiple debug info for r5v102 java.lang.Class<?>: [D('fieldClass' java.lang.Class<?>), D('fieldIndex' int)] */
    /* JADX WARN: Type inference failed for: r6v14, types: [boolean] */
    /* JADX WARN: Type inference failed for: r6v15 */
    /* JADX WARN: Type inference failed for: r6v27 */
    /* JADX WARN: Type inference failed for: r6v28 */
    /* JADX WARN: Type inference failed for: r6v101 */
    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:352:?, code lost:
        r12.nextToken(16);
        r3 = r4;
        r40 = r7;
        r1 = r23;
        r10 = r34;
        r45 = 0;
        r2 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:353:0x0693, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:354:0x0694, code lost:
        r3 = r4;
        r5 = r7;
        r1 = (T) r34;
        r4 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:366:0x06d4, code lost:
        r12.nextTokenWithColon(4);
        r5 = r12.token();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:367:0x06dd, code lost:
        if (r5 != 4) goto L_0x07cd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:368:0x06df, code lost:
        r3 = r12.stringVal();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:369:0x06e9, code lost:
        if ("@".equals(r3) == false) goto L_0x06f6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:370:0x06eb, code lost:
        r15 = (T) r7.object;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:372:0x06fc, code lost:
        if (io.dcloud.common.util.PdrUtil.FILE_PATH_ENTRY_BACK.equals(r3) == false) goto L_0x071c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:373:0x06fe, code lost:
        r5 = r7.parent;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:374:0x0704, code lost:
        if (r5.object == null) goto L_0x0709;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:375:0x0706, code lost:
        r15 = (T) r5.object;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:376:0x0709, code lost:
        r42.addResolveTask(new com.alibaba.fastjson.parser.DefaultJSONParser.ResolveTask(r5, r3));
        r42.resolveStatus = 1;
        r15 = (T) r34;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:379:0x0724, code lost:
        if (com.taobao.weex.el.parse.Operators.DOLLAR_STR.equals(r3) == false) goto L_0x0748;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:380:0x0726, code lost:
        r5 = r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:382:0x0729, code lost:
        if (r5.parent == null) goto L_0x072f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:383:0x072b, code lost:
        r5 = r5.parent;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:385:0x0731, code lost:
        if (r5.object == null) goto L_0x0736;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:386:0x0733, code lost:
        r15 = (T) r5.object;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:387:0x0736, code lost:
        r42.addResolveTask(new com.alibaba.fastjson.parser.DefaultJSONParser.ResolveTask(r5, r3));
        r42.resolveStatus = 1;
        r15 = (T) r34;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:390:0x074e, code lost:
        if (r3.indexOf(92) <= 0) goto L_0x0785;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:391:0x0750, code lost:
        r15 = new java.lang.StringBuilder();
        r5 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:393:0x075f, code lost:
        if (r5 >= r3.length()) goto L_0x077d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:394:0x0761, code lost:
        r10 = r3.charAt(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:395:0x0769, code lost:
        if (r10 != '\\') goto L_0x0773;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:396:0x076b, code lost:
        r5 = r5 + 1;
        r10 = r3.charAt(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:397:0x0773, code lost:
        r15.append(r10);
        r5 = r5 + 1;
        r10 = r10;
        r6 = r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:398:0x077d, code lost:
        r3 = r15.toString();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:400:0x0789, code lost:
        r5 = r42.resolveReference(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:401:0x078d, code lost:
        if (r5 == null) goto L_0x0792;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:402:0x078f, code lost:
        r15 = (T) r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:403:0x0792, code lost:
        r42.addResolveTask(new com.alibaba.fastjson.parser.DefaultJSONParser.ResolveTask(r7, r3));
        r42.resolveStatus = 1;
        r15 = (T) r34;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:406:?, code lost:
        r12.nextToken(13);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:407:0x07a9, code lost:
        if (r12.token() != 13) goto L_0x07bc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:408:0x07ab, code lost:
        r12.nextToken(16);
        r42.setContext(r7, r15, r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:409:0x07b4, code lost:
        if (r4 == null) goto L_0x07b8;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:410:0x07b6, code lost:
        r4.object = r15;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:411:0x07b8, code lost:
        r42.setContext(r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:412:0x07bb, code lost:
        return (T) r15;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:414:0x07c3, code lost:
        throw new com.alibaba.fastjson.JSONException("illegal ref");
     */
    /* JADX WARNING: Code restructure failed: missing block: B:415:0x07c4, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:416:0x07c5, code lost:
        r3 = r4;
        r5 = r7;
        r1 = (T) r15;
        r4 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:418:0x07ed, code lost:
        throw new com.alibaba.fastjson.JSONException("illegal ref, " + com.alibaba.fastjson.parser.JSONToken.name(r5));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:449:0x087c, code lost:
        r5 = r42.getConfig().getDeserializer(r6);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:451:0x0888, code lost:
        r1 = (T) r5.deserialze(r42, r6, r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:452:0x088e, code lost:
        if ((r5 instanceof com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) == false) goto L_0x089f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:453:0x0890, code lost:
        r10 = (com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) r5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:454:0x0893, code lost:
        if (r14 == null) goto L_0x089f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:455:0x0895, code lost:
        r15 = r10.getFieldDeserializer(r14);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:456:0x0899, code lost:
        if (r15 == null) goto L_0x089f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:457:0x089b, code lost:
        r15.setValue((java.lang.Object) r1, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:458:0x089f, code lost:
        if (r4 == null) goto L_0x08a6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:459:0x08a1, code lost:
        r4.object = r34;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:461:0x08a8, code lost:
        r42.setContext(r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:462:0x08ab, code lost:
        return r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:468:0x08bc, code lost:
        r3 = r4;
        r40 = r7;
        r1 = r23;
        r45 = 0;
        r2 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:537:0x09fd, code lost:
        if ((r2.parserFeatures & com.alibaba.fastjson.parser.Feature.TrimStringFieldValue.mask) != 0) goto L_0x09ff;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:573:0x0ad8, code lost:
        r2 = r15;
        r3 = r16;
        r10 = r27;
        r1 = r39;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:574:0x0adf, code lost:
        if (r10 != null) goto L_0x0db5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:575:0x0ae1, code lost:
        if (r1 != null) goto L_0x0b08;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:577:?, code lost:
        r4 = (T) createInstance(r42, r43);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:578:0x0ae7, code lost:
        if (r3 != null) goto L_0x0af6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:579:0x0ae9, code lost:
        r5 = r40;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:582:0x0aef, code lost:
        r3 = r42.setContext(r5, r4, r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:583:0x0af1, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:584:0x0af2, code lost:
        r1 = r4;
        r4 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:585:0x0af6, code lost:
        r5 = r40;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:586:0x0af9, code lost:
        if (r3 == null) goto L_0x0afd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:587:0x0afb, code lost:
        r3.object = r4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:588:0x0afd, code lost:
        r42.setContext(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:589:0x0b00, code lost:
        return r4;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:590:0x0b01, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:591:0x0b02, code lost:
        r5 = r40;
        r4 = r0;
        r1 = (T) r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:592:0x0b08, code lost:
        r5 = r40;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:594:?, code lost:
        r4 = r41.beanInfo.creatorConstructorParameters;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:596:0x0b10, code lost:
        if (r4 == null) goto L_0x0c0f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:597:0x0b12, code lost:
        r7 = new java.lang.Object[r4.length];
        r13 = 0;
        r2 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:599:0x0b17, code lost:
        if (r13 >= r4.length) goto L_0x0c06;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:600:0x0b19, code lost:
        r16 = r2;
        r2 = (T) r1.remove(r4[r13]);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:601:0x0b25, code lost:
        if (r2 != null) goto L_0x0b93;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:602:0x0b27, code lost:
        r47 = r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:604:?, code lost:
        r10 = r41.beanInfo.creatorConstructorParameterTypes[r13];
        r11 = r41.beanInfo.fields[r13];
        r17 = r14;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:605:0x0b39, code lost:
        if (r10 != java.lang.Byte.TYPE) goto L_0x0b41;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:606:0x0b3b, code lost:
        r2 = (T) java.lang.Byte.valueOf(r45);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:608:0x0b43, code lost:
        if (r10 != java.lang.Short.TYPE) goto L_0x0b4b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:609:0x0b45, code lost:
        r2 = (T) java.lang.Short.valueOf(r45);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:611:0x0b4d, code lost:
        if (r10 != java.lang.Integer.TYPE) goto L_0x0b55;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:612:0x0b4f, code lost:
        r2 = (T) java.lang.Integer.valueOf(r45);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:614:0x0b57, code lost:
        if (r10 != java.lang.Long.TYPE) goto L_0x0b5f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:615:0x0b59, code lost:
        r2 = (T) null;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:617:0x0b61, code lost:
        if (r10 != java.lang.Float.TYPE) goto L_0x0b69;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:618:0x0b63, code lost:
        r2 = (T) java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:620:0x0b6b, code lost:
        if (r10 != java.lang.Double.TYPE) goto L_0x0b73;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:621:0x0b6d, code lost:
        r2 = (T) java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:623:0x0b75, code lost:
        if (r10 != java.lang.Boolean.TYPE) goto L_0x0b7b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:624:0x0b77, code lost:
        r2 = (T) java.lang.Boolean.FALSE;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:626:0x0b7d, code lost:
        if (r10 != java.lang.String.class) goto L_0x0b8c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:627:0x0b7f, code lost:
        r2 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:628:0x0b88, code lost:
        if ((com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask & r11.parserFeatures) == 0) goto L_0x0b8e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:629:0x0b8a, code lost:
        r2 = "";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:630:0x0b8c, code lost:
        r2 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:631:0x0b8e, code lost:
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:632:0x0b93, code lost:
        r47 = r10;
        r17 = r14;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:633:0x0b9b, code lost:
        if (r41.beanInfo.creatorConstructorParameterTypes == null) goto L_0x0bf3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:635:0x0ba2, code lost:
        if (r13 >= r41.beanInfo.creatorConstructorParameterTypes.length) goto L_0x0bf3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:636:0x0ba4, code lost:
        r10 = r41.beanInfo.creatorConstructorParameterTypes[r13];
     */
    /* JADX WARNING: Code restructure failed: missing block: B:637:0x0bac, code lost:
        if ((r10 instanceof java.lang.Class) == false) goto L_0x0bed;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:638:0x0bae, code lost:
        r11 = (java.lang.Class) r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:639:0x0bb5, code lost:
        if (r11.isInstance(r2) != false) goto L_0x0be7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:641:0x0bb9, code lost:
        if ((r2 instanceof java.util.List) == false) goto L_0x0be1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:642:0x0bbb, code lost:
        r14 = (java.util.List) r2;
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:643:0x0bc7, code lost:
        if (r14.size() != 1) goto L_0x0bdf;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:645:0x0bd6, code lost:
        if (r11.isInstance(r14.get(0)) == false) goto L_0x0bf6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:646:0x0bd8, code lost:
        r18 = r14.get(0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:648:0x0be1, code lost:
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:649:0x0be7, code lost:
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:650:0x0bed, code lost:
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:651:0x0bf3, code lost:
        r18 = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:652:0x0bf6, code lost:
        r7[r13] = r18;
        r13 = r13 + 1;
        r10 = r47;
        r2 = r16;
        r14 = r17;
        r45 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:653:0x0c06, code lost:
        r16 = r2 == 1 ? 1 : 0;
        r47 = r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:654:0x0c0f, code lost:
        r16 = r2;
        r47 = r10;
        r7 = r41.beanInfo.fields;
        r10 = r7.length;
        r11 = new java.lang.Object[r10];
        r13 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:655:0x0c1e, code lost:
        if (r13 >= r10) goto L_0x0c96;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:656:0x0c20, code lost:
        r14 = r7[r13];
        r15 = r1.get(r14.name);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:657:0x0c28, code lost:
        if (r15 != null) goto L_0x0c8c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:658:0x0c2a, code lost:
        r2 = r14.fieldType;
        r18 = r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:659:0x0c30, code lost:
        if (r2 != java.lang.Byte.TYPE) goto L_0x0c3a;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:660:0x0c32, code lost:
        r15 = (byte) 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:662:0x0c3c, code lost:
        if (r2 != java.lang.Short.TYPE) goto L_0x0c46;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:663:0x0c3e, code lost:
        r15 = (short) 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:665:0x0c48, code lost:
        if (r2 != java.lang.Integer.TYPE) goto L_0x0c52;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:666:0x0c4a, code lost:
        r15 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:668:0x0c54, code lost:
        if (r2 != java.lang.Long.TYPE) goto L_0x0c5c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:669:0x0c56, code lost:
        r15 = 0L;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:671:0x0c5e, code lost:
        if (r2 != java.lang.Float.TYPE) goto L_0x0c66;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:672:0x0c60, code lost:
        r15 = java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:674:0x0c68, code lost:
        if (r2 != java.lang.Double.TYPE) goto L_0x0c70;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:675:0x0c6a, code lost:
        r15 = java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:677:0x0c72, code lost:
        if (r2 != java.lang.Boolean.TYPE) goto L_0x0c78;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:678:0x0c74, code lost:
        r15 = java.lang.Boolean.FALSE;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:680:0x0c7a, code lost:
        if (r2 != java.lang.String.class) goto L_0x0c89;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:682:0x0c85, code lost:
        if ((com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask & r14.parserFeatures) == 0) goto L_0x0c8e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:683:0x0c87, code lost:
        r15 = "";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:685:0x0c8c, code lost:
        r18 = r7;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:686:0x0c8e, code lost:
        r11[r13] = r15;
        r13 = r13 + 1;
        r7 = r18;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:687:0x0c96, code lost:
        r7 = r11;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:689:0x0c9d, code lost:
        if (r41.beanInfo.creatorConstructor == null) goto L_0x0d6b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:690:0x0c9f, code lost:
        r2 = false;
        r6 = r41.beanInfo.f80kotlin;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:691:0x0ca4, code lost:
        if (r6 == 0) goto L_0x0ccc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:692:0x0ca6, code lost:
        r6 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:694:0x0ca8, code lost:
        if (r6 >= r7.length) goto L_0x0ccc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:696:0x0cac, code lost:
        if (r7[r6 == true ? 1 : 0] != null) goto L_0x0cc9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:698:0x0cb2, code lost:
        if (r41.beanInfo.fields == null) goto L_0x0cc9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:700:0x0cb9, code lost:
        if (r6 >= r41.beanInfo.fields.length) goto L_0x0cc9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:702:0x0cc5, code lost:
        if (r41.beanInfo.fields[r6].fieldClass != java.lang.String.class) goto L_0x0ccc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:703:0x0cc7, code lost:
        r2 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:704:0x0cc9, code lost:
        r6 = (r6 == true ? 1 : 0) + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:705:0x0ccc, code lost:
        if (r2 == false) goto L_0x0d04;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:708:0x0cd2, code lost:
        if (r41.beanInfo.kotlinDefaultConstructor == null) goto L_0x0d04;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:709:0x0cd4, code lost:
        r6 = r41.beanInfo.kotlinDefaultConstructor.newInstance(new java.lang.Object[0]);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:710:0x0cdf, code lost:
        r10 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:713:0x0ce1, code lost:
        if (r10 >= r7.length) goto L_0x0d0d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:714:0x0ce3, code lost:
        r11 = r7[r10];
     */
    /* JADX WARNING: Code restructure failed: missing block: B:715:0x0ce5, code lost:
        if (r11 == null) goto L_0x0cfd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:717:0x0ceb, code lost:
        if (r41.beanInfo.fields == null) goto L_0x0cfd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:719:0x0cf2, code lost:
        if (r10 >= r41.beanInfo.fields.length) goto L_0x0cfd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:720:0x0cf4, code lost:
        r41.beanInfo.fields[r10].set(r6, r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:721:0x0cfd, code lost:
        r10 = r10 + 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:722:0x0d01, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:723:0x0d02, code lost:
        r10 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:724:0x0d04, code lost:
        r6 = r41.beanInfo.creatorConstructor.newInstance(r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:725:0x0d0d, code lost:
        if (r4 == null) goto L_0x0d37;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:727:?, code lost:
        r10 = r1.entrySet().iterator();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:729:0x0d1b, code lost:
        if (r10.hasNext() == false) goto L_0x0d37;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:730:0x0d1d, code lost:
        r11 = r10.next();
        r13 = getFieldDeserializer(r11.getKey());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:731:0x0d2d, code lost:
        if (r13 == null) goto L_0x0d36;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:732:0x0d2f, code lost:
        r13.setValue(r6, r11.getValue());
     */
    /* JADX WARNING: Code restructure failed: missing block: B:734:0x0d37, code lost:
        r2 = (T) r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:735:0x0d39, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:736:0x0d3a, code lost:
        r10 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:738:0x0d63, code lost:
        throw new com.alibaba.fastjson.JSONException("create instance error, " + r4 + ", " + r41.beanInfo.creatorConstructor.toGenericString(), r10);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:739:0x0d64, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:740:0x0d65, code lost:
        r4 = r0;
        r1 = (T) r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:742:0x0d6f, code lost:
        if (r41.beanInfo.factoryMethod == null) goto L_0x0d9c;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:744:?, code lost:
        r2 = (T) r41.beanInfo.factoryMethod.invoke(null, r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:745:0x0d7b, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:747:0x0d9b, code lost:
        throw new com.alibaba.fastjson.JSONException("create factory method error, " + r41.beanInfo.factoryMethod.toString(), r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:748:0x0d9c, code lost:
        r2 = (T) r47;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:749:0x0d9e, code lost:
        if (r3 == null) goto L_0x0dbf;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:751:?, code lost:
        r3.object = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:752:0x0da3, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:753:0x0da4, code lost:
        r1 = (T) r47;
        r4 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:754:0x0dab, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:755:0x0dac, code lost:
        r1 = (T) r10;
        r4 = r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:756:0x0db5, code lost:
        r5 = r40;
        r2 = (T) r10;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:757:0x0dbf, code lost:
        r4 = r41.beanInfo.buildMethod;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:758:0x0dc3, code lost:
        if (r4 != null) goto L_0x0dce;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:759:0x0dc6, code lost:
        if (r3 == null) goto L_0x0dca;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:760:0x0dc8, code lost:
        r3.object = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:761:0x0dca, code lost:
        r42.setContext(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:762:0x0dcd, code lost:
        return (T) r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:765:?, code lost:
        r6 = (T) r4.invoke(r2, new java.lang.Object[0]);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:766:0x0dd7, code lost:
        if (r3 == null) goto L_0x0ddb;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:767:0x0dd9, code lost:
        r3.object = r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:768:0x0ddb, code lost:
        r42.setContext(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:769:0x0dde, code lost:
        return r6;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:770:0x0ddf, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:772:0x0de8, code lost:
        throw new com.alibaba.fastjson.JSONException("build object error", r0);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:773:0x0de9, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:774:0x0dea, code lost:
        r4 = r0;
        r1 = (T) r2;
     */
    /* JADX WARNING: Removed duplicated region for block: B:278:0x050e A[Catch:{ all -> 0x06c0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:279:0x0513 A[Catch:{ all -> 0x06c0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:345:0x0671 A[SYNTHETIC, Splitter:B:345:0x0671] */
    /* JADX WARNING: Removed duplicated region for block: B:477:0x0913  */
    /* JADX WARNING: Removed duplicated region for block: B:479:0x0921 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:500:0x0972  */
    /* JADX WARNING: Removed duplicated region for block: B:547:0x0a42 A[Catch:{ all -> 0x09b0, all -> 0x0a5c }] */
    /* JADX WARNING: Removed duplicated region for block: B:569:0x0ac3  */
    /* JADX WARNING: Removed duplicated region for block: B:570:0x0ace  */
    /* JADX WARNING: Removed duplicated region for block: B:796:0x0e77  */
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName, Object object, int features, int[] setFlags) {
        ParseContext context;
        ParseContext context2;
        Throwable th;
        int fieldIndex;
        int token;
        FieldDeserializer fieldDeserializer;
        FieldInfo fieldInfo;
        Class<?> fieldClass;
        Map<String, Object> fieldValues;
        int fieldIndex2;
        Object object2;
        int[] setFlags2;
        int notMatchCount;
        ParserConfig config;
        String typeKey;
        ParseContext childContext;
        int notMatchCount2;
        FieldInfo fieldInfo2;
        Class<?> fieldClass2;
        Object fieldValue;
        byte b;
        ParseContext context3;
        Object fieldValue2;
        FieldDeserializer fieldDeserializer2;
        Object fieldValue3;
        Object object3;
        Map<String, Object> fieldValues2;
        Object object4;
        int i;
        Map<String, Object> map;
        Class<?> fieldClass3;
        FieldInfo fieldInfo3;
        int token2;
        Object fieldValue4;
        Object fieldValue5;
        Object fieldValue6;
        Object fieldValue7;
        Object fieldValue8;
        Object obj = fieldName;
        Object object5 = (T) object;
        if (type == JSON.class || type == JSONObject.class) {
            return (T) parser.parse();
        }
        JSONLexerBase lexer = (JSONLexerBase) parser.lexer;
        ParserConfig config2 = parser.getConfig();
        int token3 = lexer.token();
        if (token3 == 8) {
            lexer.nextToken(16);
            return null;
        }
        ParseContext context4 = parser.getContext();
        if (object5 == null || context4 == null) {
            context = context4;
        } else {
            context = context4.parent;
        }
        ParseContext childContext2 = null;
        Object obj2 = null;
        if (token3 == 13) {
            try {
                lexer.nextToken(16);
                if (object5 == null) {
                    object5 = (T) createInstance(parser, type);
                }
                if (0 != 0) {
                    childContext2.object = object5;
                }
                parser.setContext(context);
                return (T) object5;
            } catch (Throwable th2) {
                th = th2;
                context2 = context;
                if (childContext2 != null) {
                }
                parser.setContext(context2);
                throw th;
            }
        } else {
            if (token3 == 14) {
                int mask = Feature.SupportArrayToBean.mask;
                if (((this.beanInfo.parserFeatures & mask) == 0 && !lexer.isEnabled(Feature.SupportArrayToBean) && (features & mask) == 0) ? false : true) {
                    T t = (T) deserialzeArrayMapping(parser, type, fieldName, object);
                    if (0 != 0) {
                        childContext2.object = object5;
                    }
                    parser.setContext(context);
                    return t;
                }
            }
            if (token3 == 12 || token3 == 16) {
                Map<String, Object> fieldValues3 = null;
                try {
                    if (parser.resolveStatus == 2) {
                        parser.resolveStatus = 0;
                    }
                    String typeKey2 = this.beanInfo.typeKey;
                    int token4 = 0;
                    int fieldIndex3 = 0;
                    ParseContext childContext3 = null;
                    int token5 = token3;
                    int[] setFlags3 = setFlags;
                    while (true) {
                        String key = null;
                        JSONField fieldAnnotation = null;
                        boolean customDeserializer = false;
                        try {
                            if (fieldIndex3 >= this.sortedFieldDeserializers.length || token4 >= 16) {
                                token = token5;
                                fieldIndex = fieldIndex3;
                                fieldDeserializer = null;
                                fieldInfo = null;
                                fieldClass = null;
                            } else {
                                try {
                                    FieldDeserializer fieldDeserializer3 = this.sortedFieldDeserializers[fieldIndex3];
                                    token = token5;
                                    try {
                                        FieldInfo fieldInfo4 = fieldDeserializer3.fieldInfo;
                                        fieldIndex = fieldIndex3;
                                        Class<?> fieldClass4 = fieldInfo4.fieldClass;
                                        fieldAnnotation = fieldInfo4.getAnnotation();
                                        if (fieldAnnotation == null || !(fieldDeserializer3 instanceof DefaultFieldDeserializer)) {
                                            fieldInfo = fieldInfo4;
                                            fieldClass = fieldClass4;
                                            fieldDeserializer = fieldDeserializer3;
                                        } else {
                                            customDeserializer = ((DefaultFieldDeserializer) fieldDeserializer3).customDeserilizer;
                                            fieldInfo = fieldInfo4;
                                            fieldClass = fieldClass4;
                                            fieldDeserializer = fieldDeserializer3;
                                        }
                                    } catch (Throwable th3) {
                                        childContext2 = childContext3;
                                        context2 = context;
                                        th = th3;
                                        if (childContext2 != null) {
                                        }
                                        parser.setContext(context2);
                                        throw th;
                                    }
                                } catch (Throwable th4) {
                                    childContext2 = childContext3;
                                    context2 = context;
                                    th = th4;
                                    if (childContext2 != null) {
                                    }
                                    parser.setContext(context2);
                                    throw th;
                                }
                            }
                            boolean matchField = false;
                            boolean valueParsed = false;
                            if (fieldDeserializer != null) {
                                try {
                                    char[] name_chars = fieldInfo.name_chars;
                                    if (!customDeserializer || !lexer.matchField(name_chars)) {
                                        setFlags2 = setFlags3;
                                        try {
                                            object2 = object5;
                                            if (fieldClass == Integer.TYPE) {
                                                fieldClass2 = fieldClass;
                                                fieldInfo2 = fieldInfo;
                                            } else if (fieldClass == Integer.class) {
                                                fieldClass2 = fieldClass;
                                                fieldInfo2 = fieldInfo;
                                            } else {
                                                try {
                                                    if (fieldClass == Long.TYPE) {
                                                        fieldClass2 = fieldClass;
                                                        fieldInfo2 = fieldInfo;
                                                    } else if (fieldClass == Long.class) {
                                                        fieldClass2 = fieldClass;
                                                        fieldInfo2 = fieldInfo;
                                                    } else if (fieldClass == String.class) {
                                                        Object fieldValue9 = lexer.scanFieldString(name_chars);
                                                        if (lexer.matchStat > 0) {
                                                            matchField = true;
                                                            valueParsed = true;
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue9;
                                                        } else if (lexer.matchStat == -2) {
                                                            fieldIndex2 = fieldIndex;
                                                            context2 = context;
                                                            typeKey = typeKey2;
                                                            notMatchCount = token4 + 1;
                                                            fieldValues = fieldValues3;
                                                            notMatchCount2 = token;
                                                            config = config2;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        } else {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue9;
                                                        }
                                                        if (!matchField) {
                                                            try {
                                                                String key2 = lexer.scanSymbol(parser.symbolTable);
                                                                if (key2 == null) {
                                                                    int token6 = lexer.token();
                                                                    if (token6 == 13) {
                                                                        break;
                                                                    }
                                                                    token2 = token6;
                                                                    if (token6 == 16) {
                                                                        token2 = token6;
                                                                        if (lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                                                                            fieldIndex2 = fieldIndex;
                                                                            context2 = context;
                                                                            typeKey = typeKey2;
                                                                            notMatchCount = token4;
                                                                            fieldValues = fieldValues3;
                                                                            notMatchCount2 = token6;
                                                                            config = config2;
                                                                            obj = fieldName;
                                                                            context = context2;
                                                                            fieldIndex3 = fieldIndex2 + 1;
                                                                            token5 = notMatchCount2;
                                                                            typeKey2 = typeKey;
                                                                            config2 = config;
                                                                            token4 = notMatchCount;
                                                                            setFlags3 = setFlags2;
                                                                            object5 = (T) object2;
                                                                            fieldValues3 = fieldValues;
                                                                        }
                                                                    }
                                                                } else {
                                                                    token2 = token;
                                                                }
                                                                if ("$ref" == key2 && context != null) {
                                                                    break;
                                                                }
                                                                fieldDeserializer2 = fieldDeserializer;
                                                                fieldValue3 = fieldValue;
                                                                notMatchCount = token4;
                                                                if ((typeKey2 == null || !typeKey2.equals(key2)) && JSON.DEFAULT_TYPE_KEY != key2) {
                                                                    key = key2;
                                                                    object3 = object2;
                                                                    notMatchCount2 = token2;
                                                                } else {
                                                                    lexer.nextTokenWithColon(4);
                                                                    if (lexer.token() == 4) {
                                                                        String typeName = lexer.stringVal();
                                                                        lexer.nextToken(16);
                                                                        if (!typeName.equals(this.beanInfo.typeName)) {
                                                                            if (!parser.isEnabled(Feature.IgnoreAutoType)) {
                                                                                ObjectDeserializer deserializer = getSeeAlso(config2, this.beanInfo, typeName);
                                                                                Class<?> userType = null;
                                                                                if (deserializer != null) {
                                                                                    break;
                                                                                }
                                                                                Class<?> expectClass = TypeUtils.getClass(type);
                                                                                if (this.autoTypeCheckHandler != null) {
                                                                                    userType = this.autoTypeCheckHandler.handler(typeName, expectClass, lexer.getFeatures());
                                                                                }
                                                                                if (userType != null || (!typeName.equals("java.util.HashMap") && !typeName.equals("java.util.LinkedHashMap"))) {
                                                                                    if (userType == null) {
                                                                                        userType = config2.checkAutoType(typeName, expectClass, lexer.getFeatures());
                                                                                    }
                                                                                } else if (lexer.token() == 13) {
                                                                                    lexer.nextToken();
                                                                                    fieldValue2 = object2;
                                                                                    break;
                                                                                } else {
                                                                                    fieldValue2 = object2;
                                                                                    fieldIndex2 = fieldIndex;
                                                                                    notMatchCount2 = token2;
                                                                                    context2 = context;
                                                                                    object2 = fieldValue2;
                                                                                    typeKey = typeKey2;
                                                                                    fieldValues = fieldValues3;
                                                                                    config = config2;
                                                                                    obj = fieldName;
                                                                                    context = context2;
                                                                                    fieldIndex3 = fieldIndex2 + 1;
                                                                                    token5 = notMatchCount2;
                                                                                    typeKey2 = typeKey;
                                                                                    config2 = config;
                                                                                    token4 = notMatchCount;
                                                                                    setFlags3 = setFlags2;
                                                                                    object5 = (T) object2;
                                                                                    fieldValues3 = fieldValues;
                                                                                }
                                                                            } else {
                                                                                fieldValue2 = object2;
                                                                            }
                                                                        } else {
                                                                            fieldValue2 = object2;
                                                                        }
                                                                        try {
                                                                            if (lexer.token() == 13) {
                                                                                lexer.nextToken();
                                                                                break;
                                                                            }
                                                                            fieldIndex2 = fieldIndex;
                                                                            notMatchCount2 = token2;
                                                                            context2 = context;
                                                                            object2 = fieldValue2;
                                                                            typeKey = typeKey2;
                                                                            fieldValues = fieldValues3;
                                                                            config = config2;
                                                                            obj = fieldName;
                                                                            context = context2;
                                                                            fieldIndex3 = fieldIndex2 + 1;
                                                                            token5 = notMatchCount2;
                                                                            typeKey2 = typeKey;
                                                                            config2 = config;
                                                                            token4 = notMatchCount;
                                                                            setFlags3 = setFlags2;
                                                                            object5 = (T) object2;
                                                                            fieldValues3 = fieldValues;
                                                                        } catch (Throwable th5) {
                                                                            childContext2 = childContext3;
                                                                            context2 = context;
                                                                            object5 = (T) fieldValue2;
                                                                            th = th5;
                                                                            if (childContext2 != null) {
                                                                            }
                                                                            parser.setContext(context2);
                                                                            throw th;
                                                                        }
                                                                    } else {
                                                                        throw new JSONException("syntax error");
                                                                    }
                                                                }
                                                            } catch (Throwable th6) {
                                                                childContext2 = childContext3;
                                                                context2 = context;
                                                                object5 = (T) object2;
                                                                th = th6;
                                                                if (childContext2 != null) {
                                                                }
                                                                parser.setContext(context2);
                                                                throw th;
                                                            }
                                                        } else {
                                                            fieldDeserializer2 = fieldDeserializer;
                                                            fieldValue3 = fieldValue;
                                                            notMatchCount = token4;
                                                            object3 = object2;
                                                            notMatchCount2 = token;
                                                        }
                                                        if (object3 == null || fieldValues3 != null) {
                                                            childContext = childContext3;
                                                            fieldValues2 = fieldValues3;
                                                        } else {
                                                            try {
                                                                object5 = (T) createInstance(parser, type);
                                                                if (object5 == null) {
                                                                    try {
                                                                        fieldValues3 = new HashMap<>(this.fieldDeserializers.length);
                                                                    } catch (Throwable th7) {
                                                                        childContext2 = childContext3;
                                                                        context2 = context;
                                                                        th = th7;
                                                                        if (childContext2 != null) {
                                                                        }
                                                                        parser.setContext(context2);
                                                                        throw th;
                                                                    }
                                                                }
                                                                childContext2 = parser.setContext(context, object5, obj);
                                                                if (setFlags2 == null) {
                                                                    try {
                                                                        object3 = object5;
                                                                        setFlags2 = new int[((this.fieldDeserializers.length / 32) + 1)];
                                                                        childContext = childContext2;
                                                                        fieldValues2 = fieldValues3;
                                                                    } catch (Throwable th8) {
                                                                        th = th8;
                                                                        context2 = context;
                                                                        if (childContext2 != null) {
                                                                        }
                                                                        parser.setContext(context2);
                                                                        throw th;
                                                                    }
                                                                } else {
                                                                    object3 = object5;
                                                                    childContext = childContext2;
                                                                    fieldValues2 = fieldValues3;
                                                                }
                                                            } catch (Throwable th9) {
                                                                childContext2 = childContext3;
                                                                context2 = context;
                                                                object5 = (T) object3;
                                                                th = th9;
                                                                if (childContext2 != null) {
                                                                }
                                                                parser.setContext(context2);
                                                                throw th;
                                                            }
                                                        }
                                                        if (!matchField) {
                                                            config = config2;
                                                            if (fieldValues2 == null) {
                                                                map = new HashMap<>(this.fieldDeserializers.length);
                                                            } else {
                                                                map = fieldValues2;
                                                            }
                                                            fieldValues = fieldValues2;
                                                            fieldIndex2 = fieldIndex;
                                                            object4 = object3;
                                                            b = 0;
                                                            i = 13;
                                                            context3 = context;
                                                            try {
                                                                if (!parseField(parser, key, object3, type, map, setFlags2)) {
                                                                    try {
                                                                        if (lexer.token() == 13) {
                                                                            lexer.nextToken();
                                                                            break;
                                                                        }
                                                                        typeKey = typeKey2;
                                                                        context2 = context3;
                                                                        childContext3 = childContext;
                                                                        object2 = object4;
                                                                        obj = fieldName;
                                                                        context = context2;
                                                                        fieldIndex3 = fieldIndex2 + 1;
                                                                        token5 = notMatchCount2;
                                                                        typeKey2 = typeKey;
                                                                        config2 = config;
                                                                        token4 = notMatchCount;
                                                                        setFlags3 = setFlags2;
                                                                        object5 = (T) object2;
                                                                        fieldValues3 = fieldValues;
                                                                    } catch (Throwable th10) {
                                                                        th = th10;
                                                                        childContext2 = childContext;
                                                                        object5 = (T) object4;
                                                                        context2 = context3;
                                                                        if (childContext2 != null) {
                                                                        }
                                                                        parser.setContext(context2);
                                                                        throw th;
                                                                    }
                                                                } else if (lexer.token() == 17) {
                                                                    throw new JSONException("syntax error, unexpect token ':'");
                                                                }
                                                            } catch (Throwable th11) {
                                                                context2 = context3;
                                                                th = th11;
                                                                childContext2 = childContext;
                                                                object5 = (T) object4;
                                                                if (childContext2 != null) {
                                                                }
                                                                parser.setContext(context2);
                                                                throw th;
                                                            }
                                                        } else if (!valueParsed) {
                                                            try {
                                                                fieldDeserializer2.parseField(parser, object3, type, fieldValues2);
                                                                fieldIndex2 = fieldIndex;
                                                                fieldValues = fieldValues2;
                                                                context3 = context;
                                                                object4 = object3;
                                                                config = config2;
                                                                b = 0;
                                                                i = 13;
                                                            } catch (Throwable th12) {
                                                                th = th12;
                                                                context2 = context;
                                                                object5 = (T) object3;
                                                                childContext2 = childContext;
                                                                if (childContext2 != null) {
                                                                }
                                                                parser.setContext(context2);
                                                                throw th;
                                                            }
                                                        } else {
                                                            if (object3 == null) {
                                                                fieldInfo3 = fieldInfo2;
                                                                try {
                                                                    config = config2;
                                                                    fieldValues2.put(fieldInfo3.name, fieldValue3);
                                                                    fieldClass3 = fieldClass2;
                                                                } catch (Throwable th13) {
                                                                    th = th13;
                                                                    context2 = context;
                                                                    object5 = (T) object3;
                                                                    childContext2 = childContext;
                                                                    if (childContext2 != null) {
                                                                    }
                                                                    parser.setContext(context2);
                                                                    throw th;
                                                                }
                                                            } else {
                                                                config = config2;
                                                                Object fieldValue10 = fieldValue3;
                                                                fieldInfo3 = fieldInfo2;
                                                                if (fieldValue10 == null) {
                                                                    fieldClass3 = fieldClass2;
                                                                    if (!(fieldClass3 == Integer.TYPE || fieldClass3 == Long.TYPE || fieldClass3 == Float.TYPE || fieldClass3 == Double.TYPE || fieldClass3 == Boolean.TYPE)) {
                                                                        fieldDeserializer2.setValue(object3, fieldValue10);
                                                                    }
                                                                } else {
                                                                    fieldClass3 = fieldClass2;
                                                                    Object fieldValue11 = fieldValue10;
                                                                    if (fieldClass3 == String.class) {
                                                                        if ((features & Feature.TrimStringFieldValue.mask) == 0 && (this.beanInfo.parserFeatures & Feature.TrimStringFieldValue.mask) == 0) {
                                                                            fieldValue11 = fieldValue10;
                                                                        }
                                                                        fieldValue11 = ((String) fieldValue10).trim();
                                                                    }
                                                                    fieldDeserializer2.setValue(object3, fieldValue11);
                                                                }
                                                            }
                                                            if (setFlags2 != null) {
                                                                int flagIndex = fieldIndex / 32;
                                                                setFlags2[flagIndex] = setFlags2[flagIndex] | (1 << (fieldIndex % 32));
                                                            }
                                                            if (lexer.matchStat == 4) {
                                                                fieldValues = fieldValues2;
                                                                context3 = context;
                                                                object4 = object3;
                                                                b = 0;
                                                                break;
                                                            }
                                                            fieldIndex2 = fieldIndex;
                                                            fieldValues = fieldValues2;
                                                            context3 = context;
                                                            object4 = object3;
                                                            b = 0;
                                                            i = 13;
                                                        }
                                                        if (lexer.token() == 16) {
                                                            typeKey = typeKey2;
                                                            context2 = context3;
                                                        } else if (lexer.token() == i) {
                                                            lexer.nextToken(16);
                                                            break;
                                                        } else {
                                                            typeKey = typeKey2;
                                                            context2 = context3;
                                                            try {
                                                                if (lexer.token() == 18 || lexer.token() == 1) {
                                                                }
                                                            } catch (Throwable th14) {
                                                                th = th14;
                                                                childContext2 = childContext;
                                                                object5 = (T) object4;
                                                                if (childContext2 != null) {
                                                                }
                                                                parser.setContext(context2);
                                                                throw th;
                                                            }
                                                        }
                                                        childContext3 = childContext;
                                                        object2 = object4;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    } else if (fieldClass == Date.class && fieldInfo.format == null) {
                                                        Object fieldValue12 = lexer.scanFieldDate(name_chars);
                                                        if (lexer.matchStat > 0) {
                                                            matchField = true;
                                                            valueParsed = true;
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue12;
                                                        } else if (lexer.matchStat == -2) {
                                                            fieldIndex2 = fieldIndex;
                                                            context2 = context;
                                                            typeKey = typeKey2;
                                                            notMatchCount = token4 + 1;
                                                            fieldValues = fieldValues3;
                                                            notMatchCount2 = token;
                                                            config = config2;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        } else {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue12;
                                                        }
                                                        if (!matchField) {
                                                        }
                                                        if (object3 == null) {
                                                        }
                                                        childContext = childContext3;
                                                        fieldValues2 = fieldValues3;
                                                        if (!matchField) {
                                                        }
                                                        if (lexer.token() == 16) {
                                                        }
                                                        childContext3 = childContext;
                                                        object2 = object4;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    } else if (fieldClass == BigDecimal.class) {
                                                        Object fieldValue13 = lexer.scanFieldDecimal(name_chars);
                                                        if (lexer.matchStat > 0) {
                                                            matchField = true;
                                                            valueParsed = true;
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue13;
                                                        } else if (lexer.matchStat == -2) {
                                                            fieldIndex2 = fieldIndex;
                                                            context2 = context;
                                                            typeKey = typeKey2;
                                                            notMatchCount = token4 + 1;
                                                            fieldValues = fieldValues3;
                                                            notMatchCount2 = token;
                                                            config = config2;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        } else {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue13;
                                                        }
                                                        if (!matchField) {
                                                        }
                                                        if (object3 == null) {
                                                        }
                                                        childContext = childContext3;
                                                        fieldValues2 = fieldValues3;
                                                        if (!matchField) {
                                                        }
                                                        if (lexer.token() == 16) {
                                                        }
                                                        childContext3 = childContext;
                                                        object2 = object4;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    } else if (fieldClass == BigInteger.class) {
                                                        Object fieldValue14 = lexer.scanFieldBigInteger(name_chars);
                                                        if (lexer.matchStat > 0) {
                                                            matchField = true;
                                                            valueParsed = true;
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue14;
                                                        } else if (lexer.matchStat == -2) {
                                                            fieldIndex2 = fieldIndex;
                                                            context2 = context;
                                                            typeKey = typeKey2;
                                                            notMatchCount = token4 + 1;
                                                            fieldValues = fieldValues3;
                                                            notMatchCount2 = token;
                                                            config = config2;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        } else {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                            fieldValue = fieldValue14;
                                                        }
                                                        if (!matchField) {
                                                        }
                                                        if (object3 == null) {
                                                        }
                                                        childContext = childContext3;
                                                        fieldValues2 = fieldValues3;
                                                        if (!matchField) {
                                                        }
                                                        if (lexer.token() == 16) {
                                                        }
                                                        childContext3 = childContext;
                                                        object2 = object4;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    } else {
                                                        if (fieldClass == Boolean.TYPE) {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                        } else if (fieldClass == Boolean.class) {
                                                            fieldClass2 = fieldClass;
                                                            fieldInfo2 = fieldInfo;
                                                        } else {
                                                            if (fieldClass == Float.TYPE) {
                                                                fieldClass2 = fieldClass;
                                                                fieldInfo2 = fieldInfo;
                                                            } else if (fieldClass == Float.class) {
                                                                fieldClass2 = fieldClass;
                                                                fieldInfo2 = fieldInfo;
                                                            } else {
                                                                if (fieldClass != Double.TYPE) {
                                                                    if (fieldClass != Double.class) {
                                                                        if (!fieldClass.isEnum() || !(parser.getConfig().getDeserializer(fieldClass) instanceof EnumDeserializer) || !(fieldAnnotation == null || fieldAnnotation.deserializeUsing() == Void.class)) {
                                                                            if (fieldClass == int[].class) {
                                                                                Object fieldValue15 = lexer.scanFieldIntArray(name_chars);
                                                                                if (lexer.matchStat > 0) {
                                                                                    matchField = true;
                                                                                    valueParsed = true;
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue15;
                                                                                } else if (lexer.matchStat == -2) {
                                                                                    fieldIndex2 = fieldIndex;
                                                                                    context2 = context;
                                                                                    typeKey = typeKey2;
                                                                                    notMatchCount = token4 + 1;
                                                                                    fieldValues = fieldValues3;
                                                                                    notMatchCount2 = token;
                                                                                    config = config2;
                                                                                    obj = fieldName;
                                                                                    context = context2;
                                                                                    fieldIndex3 = fieldIndex2 + 1;
                                                                                    token5 = notMatchCount2;
                                                                                    typeKey2 = typeKey;
                                                                                    config2 = config;
                                                                                    token4 = notMatchCount;
                                                                                    setFlags3 = setFlags2;
                                                                                    object5 = (T) object2;
                                                                                    fieldValues3 = fieldValues;
                                                                                } else {
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue15;
                                                                                }
                                                                                if (!matchField) {
                                                                                }
                                                                                if (object3 == null) {
                                                                                }
                                                                                childContext = childContext3;
                                                                                fieldValues2 = fieldValues3;
                                                                                if (!matchField) {
                                                                                }
                                                                                if (lexer.token() == 16) {
                                                                                }
                                                                                childContext3 = childContext;
                                                                                object2 = object4;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            } else if (fieldClass == float[].class) {
                                                                                Object fieldValue16 = lexer.scanFieldFloatArray(name_chars);
                                                                                if (lexer.matchStat > 0) {
                                                                                    matchField = true;
                                                                                    valueParsed = true;
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue16;
                                                                                } else if (lexer.matchStat == -2) {
                                                                                    fieldIndex2 = fieldIndex;
                                                                                    context2 = context;
                                                                                    typeKey = typeKey2;
                                                                                    notMatchCount = token4 + 1;
                                                                                    fieldValues = fieldValues3;
                                                                                    notMatchCount2 = token;
                                                                                    config = config2;
                                                                                    obj = fieldName;
                                                                                    context = context2;
                                                                                    fieldIndex3 = fieldIndex2 + 1;
                                                                                    token5 = notMatchCount2;
                                                                                    typeKey2 = typeKey;
                                                                                    config2 = config;
                                                                                    token4 = notMatchCount;
                                                                                    setFlags3 = setFlags2;
                                                                                    object5 = (T) object2;
                                                                                    fieldValues3 = fieldValues;
                                                                                } else {
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue16;
                                                                                }
                                                                                if (!matchField) {
                                                                                }
                                                                                if (object3 == null) {
                                                                                }
                                                                                childContext = childContext3;
                                                                                fieldValues2 = fieldValues3;
                                                                                if (!matchField) {
                                                                                }
                                                                                if (lexer.token() == 16) {
                                                                                }
                                                                                childContext3 = childContext;
                                                                                object2 = object4;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            } else if (fieldClass == float[][].class) {
                                                                                Object fieldValue17 = lexer.scanFieldFloatArray2(name_chars);
                                                                                if (lexer.matchStat > 0) {
                                                                                    matchField = true;
                                                                                    valueParsed = true;
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue17;
                                                                                } else if (lexer.matchStat == -2) {
                                                                                    fieldIndex2 = fieldIndex;
                                                                                    context2 = context;
                                                                                    typeKey = typeKey2;
                                                                                    notMatchCount = token4 + 1;
                                                                                    fieldValues = fieldValues3;
                                                                                    notMatchCount2 = token;
                                                                                    config = config2;
                                                                                    obj = fieldName;
                                                                                    context = context2;
                                                                                    fieldIndex3 = fieldIndex2 + 1;
                                                                                    token5 = notMatchCount2;
                                                                                    typeKey2 = typeKey;
                                                                                    config2 = config;
                                                                                    token4 = notMatchCount;
                                                                                    setFlags3 = setFlags2;
                                                                                    object5 = (T) object2;
                                                                                    fieldValues3 = fieldValues;
                                                                                } else {
                                                                                    fieldClass2 = fieldClass;
                                                                                    fieldInfo2 = fieldInfo;
                                                                                    fieldValue = fieldValue17;
                                                                                }
                                                                                if (!matchField) {
                                                                                }
                                                                                if (object3 == null) {
                                                                                }
                                                                                childContext = childContext3;
                                                                                fieldValues2 = fieldValues3;
                                                                                if (!matchField) {
                                                                                }
                                                                                if (lexer.token() == 16) {
                                                                                }
                                                                                childContext3 = childContext;
                                                                                object2 = object4;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            } else if (lexer.matchField(name_chars)) {
                                                                                matchField = true;
                                                                                fieldClass2 = fieldClass;
                                                                                fieldInfo2 = fieldInfo;
                                                                                fieldValue = null;
                                                                                if (!matchField) {
                                                                                }
                                                                                if (object3 == null) {
                                                                                }
                                                                                childContext = childContext3;
                                                                                fieldValues2 = fieldValues3;
                                                                                if (!matchField) {
                                                                                }
                                                                                if (lexer.token() == 16) {
                                                                                }
                                                                                childContext3 = childContext;
                                                                                object2 = object4;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            } else {
                                                                                fieldIndex2 = fieldIndex;
                                                                                context2 = context;
                                                                                typeKey = typeKey2;
                                                                                notMatchCount = token4;
                                                                                fieldValues = fieldValues3;
                                                                                notMatchCount2 = token;
                                                                                config = config2;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            }
                                                                        } else if (fieldDeserializer instanceof DefaultFieldDeserializer) {
                                                                            Object fieldValue18 = scanEnum(lexer, name_chars, ((DefaultFieldDeserializer) fieldDeserializer).fieldValueDeserilizer);
                                                                            if (lexer.matchStat > 0) {
                                                                                valueParsed = true;
                                                                                matchField = true;
                                                                            } else if (lexer.matchStat == -2) {
                                                                                fieldIndex2 = fieldIndex;
                                                                                context2 = context;
                                                                                typeKey = typeKey2;
                                                                                notMatchCount = token4 + 1;
                                                                                fieldValues = fieldValues3;
                                                                                notMatchCount2 = token;
                                                                                config = config2;
                                                                                obj = fieldName;
                                                                                context = context2;
                                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                                token5 = notMatchCount2;
                                                                                typeKey2 = typeKey;
                                                                                config2 = config;
                                                                                token4 = notMatchCount;
                                                                                setFlags3 = setFlags2;
                                                                                object5 = (T) object2;
                                                                                fieldValues3 = fieldValues;
                                                                            }
                                                                            fieldClass2 = fieldClass;
                                                                            fieldInfo2 = fieldInfo;
                                                                            fieldValue = fieldValue18;
                                                                            if (!matchField) {
                                                                            }
                                                                            if (object3 == null) {
                                                                            }
                                                                            childContext = childContext3;
                                                                            fieldValues2 = fieldValues3;
                                                                            if (!matchField) {
                                                                            }
                                                                            if (lexer.token() == 16) {
                                                                            }
                                                                            childContext3 = childContext;
                                                                            object2 = object4;
                                                                            obj = fieldName;
                                                                            context = context2;
                                                                            fieldIndex3 = fieldIndex2 + 1;
                                                                            token5 = notMatchCount2;
                                                                            typeKey2 = typeKey;
                                                                            config2 = config;
                                                                            token4 = notMatchCount;
                                                                            setFlags3 = setFlags2;
                                                                            object5 = (T) object2;
                                                                            fieldValues3 = fieldValues;
                                                                        } else {
                                                                            fieldClass2 = fieldClass;
                                                                            fieldInfo2 = fieldInfo;
                                                                        }
                                                                    }
                                                                }
                                                                double doubleVal = lexer.scanFieldDouble(name_chars);
                                                                if (doubleVal == 0.0d) {
                                                                    fieldClass2 = fieldClass;
                                                                    fieldInfo2 = fieldInfo;
                                                                    if (lexer.matchStat == 5) {
                                                                        fieldValue8 = null;
                                                                        if (lexer.matchStat <= 0) {
                                                                            matchField = true;
                                                                            valueParsed = true;
                                                                        } else if (lexer.matchStat == -2) {
                                                                            fieldIndex2 = fieldIndex;
                                                                            context2 = context;
                                                                            typeKey = typeKey2;
                                                                            notMatchCount = token4 + 1;
                                                                            fieldValues = fieldValues3;
                                                                            notMatchCount2 = token;
                                                                            config = config2;
                                                                            obj = fieldName;
                                                                            context = context2;
                                                                            fieldIndex3 = fieldIndex2 + 1;
                                                                            token5 = notMatchCount2;
                                                                            typeKey2 = typeKey;
                                                                            config2 = config;
                                                                            token4 = notMatchCount;
                                                                            setFlags3 = setFlags2;
                                                                            object5 = (T) object2;
                                                                            fieldValues3 = fieldValues;
                                                                        }
                                                                        fieldValue = fieldValue8;
                                                                        if (!matchField) {
                                                                        }
                                                                        if (object3 == null) {
                                                                        }
                                                                        childContext = childContext3;
                                                                        fieldValues2 = fieldValues3;
                                                                        if (!matchField) {
                                                                        }
                                                                        if (lexer.token() == 16) {
                                                                        }
                                                                        childContext3 = childContext;
                                                                        object2 = object4;
                                                                        obj = fieldName;
                                                                        context = context2;
                                                                        fieldIndex3 = fieldIndex2 + 1;
                                                                        token5 = notMatchCount2;
                                                                        typeKey2 = typeKey;
                                                                        config2 = config;
                                                                        token4 = notMatchCount;
                                                                        setFlags3 = setFlags2;
                                                                        object5 = (T) object2;
                                                                        fieldValues3 = fieldValues;
                                                                    }
                                                                } else {
                                                                    fieldClass2 = fieldClass;
                                                                    fieldInfo2 = fieldInfo;
                                                                }
                                                                fieldValue8 = Double.valueOf(doubleVal);
                                                                if (lexer.matchStat <= 0) {
                                                                }
                                                                fieldValue = fieldValue8;
                                                                if (!matchField) {
                                                                }
                                                                if (object3 == null) {
                                                                }
                                                                childContext = childContext3;
                                                                fieldValues2 = fieldValues3;
                                                                if (!matchField) {
                                                                }
                                                                if (lexer.token() == 16) {
                                                                }
                                                                childContext3 = childContext;
                                                                object2 = object4;
                                                                obj = fieldName;
                                                                context = context2;
                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                token5 = notMatchCount2;
                                                                typeKey2 = typeKey;
                                                                config2 = config;
                                                                token4 = notMatchCount;
                                                                setFlags3 = setFlags2;
                                                                object5 = (T) object2;
                                                                fieldValues3 = fieldValues;
                                                            }
                                                            float floatVal = lexer.scanFieldFloat(name_chars);
                                                            if (floatVal == 0.0f && lexer.matchStat == 5) {
                                                                fieldValue7 = null;
                                                            } else {
                                                                fieldValue7 = Float.valueOf(floatVal);
                                                            }
                                                            if (lexer.matchStat > 0) {
                                                                matchField = true;
                                                                valueParsed = true;
                                                            } else if (lexer.matchStat == -2) {
                                                                fieldIndex2 = fieldIndex;
                                                                context2 = context;
                                                                typeKey = typeKey2;
                                                                notMatchCount = token4 + 1;
                                                                fieldValues = fieldValues3;
                                                                notMatchCount2 = token;
                                                                config = config2;
                                                                obj = fieldName;
                                                                context = context2;
                                                                fieldIndex3 = fieldIndex2 + 1;
                                                                token5 = notMatchCount2;
                                                                typeKey2 = typeKey;
                                                                config2 = config;
                                                                token4 = notMatchCount;
                                                                setFlags3 = setFlags2;
                                                                object5 = (T) object2;
                                                                fieldValues3 = fieldValues;
                                                            }
                                                            fieldValue = fieldValue7;
                                                            if (!matchField) {
                                                            }
                                                            if (object3 == null) {
                                                            }
                                                            childContext = childContext3;
                                                            fieldValues2 = fieldValues3;
                                                            if (!matchField) {
                                                            }
                                                            if (lexer.token() == 16) {
                                                            }
                                                            childContext3 = childContext;
                                                            object2 = object4;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        }
                                                        boolean booleanVal = lexer.scanFieldBoolean(name_chars);
                                                        if (lexer.matchStat == 5) {
                                                            fieldValue6 = null;
                                                        } else {
                                                            fieldValue6 = Boolean.valueOf(booleanVal);
                                                        }
                                                        if (lexer.matchStat > 0) {
                                                            matchField = true;
                                                            valueParsed = true;
                                                        } else if (lexer.matchStat == -2) {
                                                            fieldIndex2 = fieldIndex;
                                                            context2 = context;
                                                            typeKey = typeKey2;
                                                            notMatchCount = token4 + 1;
                                                            fieldValues = fieldValues3;
                                                            notMatchCount2 = token;
                                                            config = config2;
                                                            obj = fieldName;
                                                            context = context2;
                                                            fieldIndex3 = fieldIndex2 + 1;
                                                            token5 = notMatchCount2;
                                                            typeKey2 = typeKey;
                                                            config2 = config;
                                                            token4 = notMatchCount;
                                                            setFlags3 = setFlags2;
                                                            object5 = (T) object2;
                                                            fieldValues3 = fieldValues;
                                                        }
                                                        fieldValue = fieldValue6;
                                                        if (!matchField) {
                                                        }
                                                        if (object3 == null) {
                                                        }
                                                        childContext = childContext3;
                                                        fieldValues2 = fieldValues3;
                                                        if (!matchField) {
                                                        }
                                                        if (lexer.token() == 16) {
                                                        }
                                                        childContext3 = childContext;
                                                        object2 = object4;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    }
                                                    long longVal = lexer.scanFieldLong(name_chars);
                                                    if (longVal == 0 && lexer.matchStat == 5) {
                                                        fieldValue5 = null;
                                                    } else {
                                                        fieldValue5 = Long.valueOf(longVal);
                                                    }
                                                    if (lexer.matchStat > 0) {
                                                        matchField = true;
                                                        valueParsed = true;
                                                    } else if (lexer.matchStat == -2) {
                                                        fieldIndex2 = fieldIndex;
                                                        context2 = context;
                                                        typeKey = typeKey2;
                                                        notMatchCount = token4 + 1;
                                                        fieldValues = fieldValues3;
                                                        notMatchCount2 = token;
                                                        config = config2;
                                                        obj = fieldName;
                                                        context = context2;
                                                        fieldIndex3 = fieldIndex2 + 1;
                                                        token5 = notMatchCount2;
                                                        typeKey2 = typeKey;
                                                        config2 = config;
                                                        token4 = notMatchCount;
                                                        setFlags3 = setFlags2;
                                                        object5 = (T) object2;
                                                        fieldValues3 = fieldValues;
                                                    }
                                                    fieldValue = fieldValue5;
                                                    if (!matchField) {
                                                    }
                                                    if (object3 == null) {
                                                    }
                                                    childContext = childContext3;
                                                    fieldValues2 = fieldValues3;
                                                    if (!matchField) {
                                                    }
                                                    if (lexer.token() == 16) {
                                                    }
                                                    childContext3 = childContext;
                                                    object2 = object4;
                                                    obj = fieldName;
                                                    context = context2;
                                                    fieldIndex3 = fieldIndex2 + 1;
                                                    token5 = notMatchCount2;
                                                    typeKey2 = typeKey;
                                                    config2 = config;
                                                    token4 = notMatchCount;
                                                    setFlags3 = setFlags2;
                                                    object5 = (T) object2;
                                                    fieldValues3 = fieldValues;
                                                } catch (Throwable th15) {
                                                    childContext2 = childContext3;
                                                    context2 = context;
                                                    object5 = (T) object2;
                                                    th = th15;
                                                    if (childContext2 != null) {
                                                    }
                                                    parser.setContext(context2);
                                                    throw th;
                                                }
                                            }
                                            int intVal = lexer.scanFieldInt(name_chars);
                                            if (intVal == 0 && lexer.matchStat == 5) {
                                                fieldValue4 = null;
                                            } else {
                                                fieldValue4 = Integer.valueOf(intVal);
                                            }
                                            if (lexer.matchStat > 0) {
                                                matchField = true;
                                                valueParsed = true;
                                            } else if (lexer.matchStat == -2) {
                                                fieldIndex2 = fieldIndex;
                                                context2 = context;
                                                typeKey = typeKey2;
                                                notMatchCount = token4 + 1;
                                                fieldValues = fieldValues3;
                                                notMatchCount2 = token;
                                                config = config2;
                                                obj = fieldName;
                                                context = context2;
                                                fieldIndex3 = fieldIndex2 + 1;
                                                token5 = notMatchCount2;
                                                typeKey2 = typeKey;
                                                config2 = config;
                                                token4 = notMatchCount;
                                                setFlags3 = setFlags2;
                                                object5 = (T) object2;
                                                fieldValues3 = fieldValues;
                                            }
                                            fieldValue = fieldValue4;
                                            if (!matchField) {
                                            }
                                            if (object3 == null) {
                                            }
                                            childContext = childContext3;
                                            fieldValues2 = fieldValues3;
                                            if (!matchField) {
                                            }
                                            if (lexer.token() == 16) {
                                            }
                                            childContext3 = childContext;
                                            object2 = object4;
                                            obj = fieldName;
                                            context = context2;
                                            fieldIndex3 = fieldIndex2 + 1;
                                            token5 = notMatchCount2;
                                            typeKey2 = typeKey;
                                            config2 = config;
                                            token4 = notMatchCount;
                                            setFlags3 = setFlags2;
                                            object5 = (T) object2;
                                            fieldValues3 = fieldValues;
                                        } catch (Throwable th16) {
                                            childContext2 = childContext3;
                                            context2 = context;
                                            th = th16;
                                            if (childContext2 != null) {
                                            }
                                            parser.setContext(context2);
                                            throw th;
                                        }
                                    } else {
                                        matchField = true;
                                        object2 = object5;
                                        setFlags2 = setFlags3;
                                        fieldClass2 = fieldClass;
                                        fieldInfo2 = fieldInfo;
                                        fieldValue = null;
                                        if (!matchField) {
                                        }
                                        if (object3 == null) {
                                        }
                                        childContext = childContext3;
                                        fieldValues2 = fieldValues3;
                                        if (!matchField) {
                                        }
                                        if (lexer.token() == 16) {
                                        }
                                        childContext3 = childContext;
                                        object2 = object4;
                                        obj = fieldName;
                                        context = context2;
                                        fieldIndex3 = fieldIndex2 + 1;
                                        token5 = notMatchCount2;
                                        typeKey2 = typeKey;
                                        config2 = config;
                                        token4 = notMatchCount;
                                        setFlags3 = setFlags2;
                                        object5 = (T) object2;
                                        fieldValues3 = fieldValues;
                                    }
                                } catch (Throwable th17) {
                                    childContext2 = childContext3;
                                    context2 = context;
                                    th = th17;
                                    if (childContext2 != null) {
                                    }
                                    parser.setContext(context2);
                                    throw th;
                                }
                            } else {
                                object2 = object5;
                                setFlags2 = setFlags3;
                                fieldClass2 = fieldClass;
                                fieldInfo2 = fieldInfo;
                            }
                            fieldValue = null;
                            if (!matchField) {
                            }
                            if (object3 == null) {
                            }
                            childContext = childContext3;
                            fieldValues2 = fieldValues3;
                            if (!matchField) {
                            }
                            if (lexer.token() == 16) {
                            }
                            childContext3 = childContext;
                            object2 = object4;
                            obj = fieldName;
                            context = context2;
                            fieldIndex3 = fieldIndex2 + 1;
                            token5 = notMatchCount2;
                            typeKey2 = typeKey;
                            config2 = config;
                            token4 = notMatchCount;
                            setFlags3 = setFlags2;
                            object5 = (T) object2;
                            fieldValues3 = fieldValues;
                        } catch (Throwable th18) {
                            context2 = context;
                            childContext2 = childContext3;
                            th = th18;
                            if (childContext2 != null) {
                                childContext2.object = object5;
                            }
                            parser.setContext(context2);
                            throw th;
                        }
                    }
                    throw new JSONException("syntax error, unexpect token " + JSONToken.name(lexer.token()));
                } catch (Throwable th19) {
                    context2 = context;
                    th = th19;
                    if (childContext2 != null) {
                    }
                    parser.setContext(context2);
                    throw th;
                }
            } else if (lexer.isBlankInput()) {
                if (0 != 0) {
                    childContext2.object = object5;
                }
                parser.setContext(context);
                return null;
            } else {
                if (token3 == 4) {
                    String strVal = lexer.stringVal();
                    if (strVal.length() == 0) {
                        lexer.nextToken();
                        if (0 != 0) {
                            childContext2.object = object5;
                        }
                        parser.setContext(context);
                        return null;
                    } else if (this.beanInfo.jsonType != null) {
                        Class<?>[] seeAlso = this.beanInfo.jsonType.seeAlso();
                        int length = seeAlso.length;
                        int i2 = 0;
                        while (i2 < length) {
                            Class<?> seeAlsoClass = seeAlso[i2];
                            if (Enum.class.isAssignableFrom(seeAlsoClass)) {
                                try {
                                    T t2 = (T) Enum.valueOf(seeAlsoClass, strVal);
                                    if (0 != 0) {
                                        childContext2.object = object5;
                                    }
                                    parser.setContext(context);
                                    return t2;
                                } catch (IllegalArgumentException e) {
                                }
                            } else {
                                i2++;
                                length = length;
                                obj2 = obj2;
                            }
                        }
                    }
                }
                if (token3 == 14 && lexer.getCurrent() == ']') {
                    lexer.next();
                    lexer.nextToken();
                    if (0 != 0) {
                        childContext2.object = object5;
                    }
                    parser.setContext(context);
                    return null;
                }
                if (this.beanInfo.factoryMethod != null && this.beanInfo.fields.length == 1) {
                    try {
                        FieldInfo field = this.beanInfo.fields[0];
                        if (field.fieldClass == Integer.class) {
                            if (token3 == 2) {
                                int intValue = lexer.intValue();
                                lexer.nextToken();
                                T t3 = (T) createFactoryInstance(config2, Integer.valueOf(intValue));
                                if (0 != 0) {
                                    childContext2.object = object5;
                                }
                                parser.setContext(context);
                                return t3;
                            }
                        } else if (field.fieldClass == String.class && token3 == 4) {
                            String stringVal = lexer.stringVal();
                            lexer.nextToken();
                            T t4 = (T) createFactoryInstance(config2, stringVal);
                            if (0 != 0) {
                                childContext2.object = object5;
                            }
                            parser.setContext(context);
                            return t4;
                        }
                    } catch (Exception ex) {
                        throw new JSONException(ex.getMessage(), ex);
                    }
                }
                StringBuilder buf = new StringBuilder();
                buf.append("syntax error, expect {, actual ");
                buf.append(lexer.tokenName());
                buf.append(", pos ");
                buf.append(lexer.pos());
                if (obj instanceof String) {
                    buf.append(", fieldName ");
                    buf.append(obj);
                }
                buf.append(", fastjson-version ");
                buf.append(JSON.VERSION);
                throw new JSONException(buf.toString());
            }
        }
    }

    /* access modifiers changed from: protected */
    public Enum scanEnum(JSONLexerBase lexer, char[] name_chars, ObjectDeserializer fieldValueDeserilizer) {
        EnumDeserializer enumDeserializer = null;
        if (fieldValueDeserilizer instanceof EnumDeserializer) {
            enumDeserializer = (EnumDeserializer) fieldValueDeserilizer;
        }
        if (enumDeserializer == null) {
            lexer.matchStat = -1;
            return null;
        }
        long enumNameHashCode = lexer.scanEnumSymbol(name_chars);
        if (lexer.matchStat <= 0) {
            return null;
        }
        Enum e = enumDeserializer.getEnumByHashCode(enumNameHashCode);
        if (e == null) {
            if (enumNameHashCode == TypeUtils.fnv1a_64_magic_hashcode) {
                return null;
            }
            if (lexer.isEnabled(Feature.ErrorOnEnumNotMatch)) {
                throw new JSONException("not match enum value, " + enumDeserializer.enumClass);
            }
        }
        return e;
    }

    public boolean parseField(DefaultJSONParser parser, String key, Object object, Type objectType, Map<String, Object> fieldValues) {
        return parseField(parser, key, object, objectType, fieldValues, null);
    }

    /* JADX WARN: Type inference failed for: r25v0, types: [boolean, int] */
    /* JADX WARN: Type inference failed for: r25v4 */
    /* JADX WARN: Type inference failed for: r25v5 */
    /* JADX WARN: Type inference failed for: r25v21 */
    /* JADX WARNING: Removed duplicated region for block: B:121:0x0292  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x0174  */
    /* JADX WARNING: Unknown variable types count: 1 */
    public boolean parseField(DefaultJSONParser parser, String key, Object object, Type objectType, Map<String, Object> fieldValues, int[] setFlags) {
        FieldDeserializer fieldDeserializer;
        JSONLexer lexer;
        ?? r25;
        FieldDeserializer fieldDeserializer2;
        FieldDeserializer fieldDeserializer3;
        FieldDeserializer fieldDeserializer4;
        Exception e;
        boolean z;
        FieldDeserializer fieldDeserializer5;
        int mask;
        int mask2;
        String fieldName;
        JavaBeanDeserializer javaBeanDeserializer = this;
        JSONLexer lexer2 = parser.lexer;
        int disableFieldSmartMatchMask = Feature.DisableFieldSmartMatch.mask;
        int initStringFieldAsEmpty = Feature.InitStringFieldAsEmpty.mask;
        if (lexer2.isEnabled(disableFieldSmartMatchMask) || (javaBeanDeserializer.beanInfo.parserFeatures & disableFieldSmartMatchMask) != 0) {
            fieldDeserializer = javaBeanDeserializer.getFieldDeserializer(key);
        } else if (lexer2.isEnabled(initStringFieldAsEmpty) || (javaBeanDeserializer.beanInfo.parserFeatures & initStringFieldAsEmpty) != 0) {
            fieldDeserializer = javaBeanDeserializer.smartMatch(key);
        } else {
            fieldDeserializer = javaBeanDeserializer.smartMatch(key, setFlags);
        }
        int mask3 = Feature.SupportNonPublicField.mask;
        if (fieldDeserializer != null) {
            fieldDeserializer5 = fieldDeserializer;
            lexer = lexer2;
            z = true;
        } else if (lexer2.isEnabled(mask3) || (javaBeanDeserializer.beanInfo.parserFeatures & mask3) != 0) {
            if (javaBeanDeserializer.extraFieldDeserializers == null) {
                ConcurrentHashMap extraFieldDeserializers2 = new ConcurrentHashMap(1, 0.75f, 1);
                Class c = javaBeanDeserializer.clazz;
                while (c != null && c != Object.class) {
                    Field[] fields = c.getDeclaredFields();
                    int length = fields.length;
                    int i = 0;
                    while (i < length) {
                        Field field = fields[i];
                        String fieldName2 = field.getName();
                        if (javaBeanDeserializer.getFieldDeserializer(fieldName2) != null) {
                            mask2 = mask3;
                        } else {
                            int fieldModifiers = field.getModifiers();
                            if ((fieldModifiers & 16) != 0) {
                                mask2 = mask3;
                            } else if ((fieldModifiers & 8) != 0) {
                                mask2 = mask3;
                            } else {
                                JSONField jsonField = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                                if (jsonField != null) {
                                    mask2 = mask3;
                                    String alteredFieldName = jsonField.name();
                                    if (!"".equals(alteredFieldName)) {
                                        fieldName = alteredFieldName;
                                        extraFieldDeserializers2.put(fieldName, field);
                                    }
                                } else {
                                    mask2 = mask3;
                                }
                                fieldName = fieldName2;
                                extraFieldDeserializers2.put(fieldName, field);
                            }
                        }
                        i++;
                        length = length;
                        fields = fields;
                        mask3 = mask2;
                    }
                    c = c.getSuperclass();
                    fieldDeserializer = fieldDeserializer;
                }
                fieldDeserializer5 = fieldDeserializer;
                mask = mask3;
                javaBeanDeserializer.extraFieldDeserializers = extraFieldDeserializers2;
            } else {
                fieldDeserializer5 = fieldDeserializer;
                mask = mask3;
            }
            Object deserOrField = javaBeanDeserializer.extraFieldDeserializers.get(key);
            if (deserOrField != null) {
                if (deserOrField instanceof FieldDeserializer) {
                    fieldDeserializer2 = (FieldDeserializer) deserOrField;
                    lexer = lexer2;
                    r25 = 1;
                } else {
                    Field field2 = (Field) deserOrField;
                    field2.setAccessible(true);
                    r25 = 1;
                    lexer = lexer2;
                    FieldDeserializer fieldDeserializer6 = new DefaultFieldDeserializer(parser.getConfig(), javaBeanDeserializer.clazz, new FieldInfo(key, field2.getDeclaringClass(), field2.getType(), field2.getGenericType(), field2, 0, 0, 0));
                    javaBeanDeserializer.extraFieldDeserializers.put(key, fieldDeserializer6);
                    fieldDeserializer2 = fieldDeserializer6;
                }
                if (fieldDeserializer2 == null) {
                    FieldDeserializer fieldDeserializer7 = fieldDeserializer2;
                    int fieldIndex = -1;
                    int i2 = 0;
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr = javaBeanDeserializer.sortedFieldDeserializers;
                        if (i2 >= fieldDeserializerArr.length) {
                            fieldDeserializer3 = fieldDeserializer7;
                            break;
                        }
                        fieldDeserializer3 = fieldDeserializer7;
                        if (fieldDeserializerArr[i2] == fieldDeserializer3) {
                            fieldIndex = i2;
                            break;
                        }
                        i2++;
                        fieldDeserializer7 = fieldDeserializer3;
                    }
                    if (fieldIndex == -1 || setFlags == null || !key.startsWith("_") || !isSetFlag(fieldIndex, setFlags)) {
                        lexer.nextTokenWithColon(fieldDeserializer3.getFastMatchToken());
                        fieldDeserializer3.parseField(parser, object, objectType, fieldValues);
                        if (setFlags != null) {
                            int flagIndex = fieldIndex / 32;
                            int i3 = setFlags[flagIndex];
                            int i4 = r25 == true ? 1 : 0;
                            int i5 = r25 == true ? 1 : 0;
                            int i6 = r25 == true ? 1 : 0;
                            int i7 = r25 == true ? 1 : 0;
                            int i8 = r25 == true ? 1 : 0;
                            int i9 = r25 == true ? 1 : 0;
                            int i10 = r25 == true ? 1 : 0;
                            setFlags[flagIndex] = i3 | (i4 << (fieldIndex % 32));
                        }
                        return r25;
                    }
                    parser.parseExtra(object, key);
                    return false;
                } else if (lexer.isEnabled(Feature.IgnoreNotMatch)) {
                    int fieldIndex2 = -1;
                    int i11 = 0;
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr2 = javaBeanDeserializer.sortedFieldDeserializers;
                        if (i11 >= fieldDeserializerArr2.length) {
                            break;
                        }
                        FieldDeserializer fieldDeser = fieldDeserializerArr2[i11];
                        FieldInfo fieldInfo = fieldDeser.fieldInfo;
                        if (!fieldInfo.unwrapped || !(fieldDeser instanceof DefaultFieldDeserializer)) {
                            fieldDeserializer4 = fieldDeserializer2;
                        } else if (fieldInfo.field != null) {
                            DefaultFieldDeserializer defaultFieldDeserializer = (DefaultFieldDeserializer) fieldDeser;
                            ObjectDeserializer fieldValueDeser = defaultFieldDeserializer.getFieldValueDeserilizer(parser.getConfig());
                            if (fieldValueDeser instanceof JavaBeanDeserializer) {
                                fieldDeserializer4 = fieldDeserializer2;
                                FieldDeserializer unwrappedFieldDeser = ((JavaBeanDeserializer) fieldValueDeser).getFieldDeserializer(key);
                                if (unwrappedFieldDeser != null) {
                                    try {
                                        Object fieldObject = fieldInfo.field.get(object);
                                        if (fieldObject == null) {
                                            try {
                                                fieldObject = ((JavaBeanDeserializer) fieldValueDeser).createInstance(parser, fieldInfo.fieldType);
                                                fieldDeser.setValue(object, fieldObject);
                                            } catch (Exception e2) {
                                                e = e2;
                                                throw new JSONException("parse unwrapped field error.", e);
                                            }
                                        }
                                        lexer.nextTokenWithColon(defaultFieldDeserializer.getFastMatchToken());
                                        unwrappedFieldDeser.parseField(parser, fieldObject, objectType, fieldValues);
                                        fieldIndex2 = i11;
                                    } catch (Exception e3) {
                                        e = e3;
                                        throw new JSONException("parse unwrapped field error.", e);
                                    }
                                }
                            } else {
                                fieldDeserializer4 = fieldDeserializer2;
                                if (fieldValueDeser instanceof MapDeserializer) {
                                    MapDeserializer javaBeanFieldValueDeserializer = (MapDeserializer) fieldValueDeser;
                                    try {
                                        Map fieldObject2 = (Map) fieldInfo.field.get(object);
                                        if (fieldObject2 == null) {
                                            fieldObject2 = javaBeanFieldValueDeserializer.createMap(fieldInfo.fieldType);
                                            fieldDeser.setValue(object, fieldObject2);
                                        }
                                        lexer.nextTokenWithColon();
                                        fieldObject2.put(key, parser.parse(key));
                                        fieldIndex2 = i11;
                                    } catch (Exception e4) {
                                        throw new JSONException("parse unwrapped field error.", e4);
                                    }
                                }
                            }
                        } else {
                            fieldDeserializer4 = fieldDeserializer2;
                            if (fieldInfo.method.getParameterTypes().length == 2) {
                                lexer.nextTokenWithColon();
                                Object fieldValue = parser.parse(key);
                                try {
                                    Method method = fieldInfo.method;
                                    Object[] objArr = new Object[2];
                                    objArr[0] = key;
                                    char c2 = r25 == true ? 1 : 0;
                                    char c3 = r25 == true ? 1 : 0;
                                    char c4 = r25 == true ? 1 : 0;
                                    char c5 = r25 == true ? 1 : 0;
                                    char c6 = r25 == true ? 1 : 0;
                                    char c7 = r25 == true ? 1 : 0;
                                    char c8 = r25 == true ? 1 : 0;
                                    objArr[c2] = fieldValue;
                                    method.invoke(object, objArr);
                                    fieldIndex2 = i11;
                                } catch (Exception e5) {
                                    throw new JSONException("parse unwrapped field error.", e5);
                                }
                            }
                        }
                        i11++;
                        javaBeanDeserializer = this;
                        fieldDeserializer2 = fieldDeserializer4;
                    }
                    if (fieldIndex2 != -1) {
                        if (setFlags != null) {
                            int flagIndex2 = fieldIndex2 / 32;
                            setFlags[flagIndex2] = setFlags[flagIndex2] | (r25 << (fieldIndex2 % 32));
                        }
                        return r25;
                    }
                    parser.parseExtra(object, key);
                    return false;
                } else {
                    throw new JSONException("setter not found, class " + this.clazz.getName() + ", property " + key);
                }
            } else {
                lexer = lexer2;
                z = true;
            }
        } else {
            fieldDeserializer5 = fieldDeserializer;
            lexer = lexer2;
            z = true;
        }
        fieldDeserializer2 = fieldDeserializer5;
        r25 = z;
        if (fieldDeserializer2 == null) {
        }
    }

    public FieldDeserializer smartMatch(String key) {
        return smartMatch(key, null);
    }

    public FieldDeserializer smartMatch(String key, int[] setFlags) {
        if (key == null) {
            return null;
        }
        FieldDeserializer fieldDeserializer = getFieldDeserializer(key, setFlags);
        if (fieldDeserializer != null) {
            return fieldDeserializer;
        }
        if (this.smartMatchHashArray == null) {
            long[] hashArray2 = new long[this.sortedFieldDeserializers.length];
            int i = 0;
            while (true) {
                FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                if (i >= fieldDeserializerArr.length) {
                    break;
                }
                hashArray2[i] = fieldDeserializerArr[i].fieldInfo.nameHashCode;
                i++;
            }
            Arrays.sort(hashArray2);
            this.smartMatchHashArray = hashArray2;
        }
        int pos = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_lower(key));
        if (pos < 0) {
            pos = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(key));
        }
        boolean is = false;
        if (pos < 0) {
            boolean startsWith = key.startsWith("is");
            is = startsWith;
            if (startsWith) {
                pos = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(key.substring(2)));
            }
        }
        if (pos >= 0) {
            if (this.smartMatchHashArrayMapping == null) {
                short[] mapping = new short[this.smartMatchHashArray.length];
                Arrays.fill(mapping, (short) -1);
                int i2 = 0;
                while (true) {
                    FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                    if (i2 >= fieldDeserializerArr2.length) {
                        break;
                    }
                    int p = Arrays.binarySearch(this.smartMatchHashArray, fieldDeserializerArr2[i2].fieldInfo.nameHashCode);
                    if (p >= 0) {
                        mapping[p] = (short) i2;
                    }
                    i2++;
                }
                this.smartMatchHashArrayMapping = mapping;
            }
            short s = this.smartMatchHashArrayMapping[pos];
            if (s != -1 && !isSetFlag(s, setFlags)) {
                fieldDeserializer = this.sortedFieldDeserializers[s];
            }
        }
        if (fieldDeserializer == null) {
            return fieldDeserializer;
        }
        FieldInfo fieldInfo = fieldDeserializer.fieldInfo;
        if ((fieldInfo.parserFeatures & Feature.DisableFieldSmartMatch.mask) != 0) {
            return null;
        }
        Class fieldClass = fieldInfo.fieldClass;
        if (!is || fieldClass == Boolean.TYPE || fieldClass == Boolean.class) {
            return fieldDeserializer;
        }
        return null;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }

    private Object createFactoryInstance(ParserConfig config, Object value) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        return this.beanInfo.factoryMethod.invoke(null, value);
    }

    public Object createInstance(Map<String, Object> map, ParserConfig config) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        boolean i;
        Integer index;
        Iterator<Map.Entry<String, Object>> it;
        Object value;
        double doubleValue;
        float floatValue;
        String input;
        Map<String, Object> map2 = null;
        if (this.beanInfo.creatorConstructor == null && this.beanInfo.factoryMethod == null) {
            Object object = createInstance((DefaultJSONParser) null, this.clazz);
            Iterator<Map.Entry<String, Object>> it2 = map.entrySet().iterator();
            while (it2.hasNext()) {
                Map.Entry<String, Object> entry = it2.next();
                Object value2 = entry.getValue();
                FieldDeserializer fieldDeser = smartMatch(entry.getKey());
                if (fieldDeser != null) {
                    FieldInfo fieldInfo = fieldDeser.fieldInfo;
                    Field field = fieldDeser.fieldInfo.field;
                    Type paramType = fieldInfo.fieldType;
                    Class<?> fieldClass = fieldInfo.fieldClass;
                    JSONField fieldAnnation = fieldInfo.getAnnotation();
                    if (fieldInfo.declaringClass == null || (fieldClass.isInstance(value2) && (fieldAnnation == null || fieldAnnation.deserializeUsing() == Void.class))) {
                        if (field == null || fieldInfo.method != null) {
                            it = it2;
                        } else {
                            Class fieldType = field.getType();
                            if (fieldType == Boolean.TYPE) {
                                if (value2 == Boolean.FALSE) {
                                    field.setBoolean(object, false);
                                } else if (value2 == Boolean.TRUE) {
                                    field.setBoolean(object, true);
                                } else {
                                    it = it2;
                                }
                            } else if (fieldType == Integer.TYPE) {
                                if (value2 instanceof Number) {
                                    field.setInt(object, ((Number) value2).intValue());
                                } else {
                                    it = it2;
                                }
                            } else if (fieldType == Long.TYPE) {
                                if (value2 instanceof Number) {
                                    field.setLong(object, ((Number) value2).longValue());
                                    map2 = null;
                                } else {
                                    it = it2;
                                }
                            } else if (fieldType != Float.TYPE) {
                                it = it2;
                                if (fieldType == Double.TYPE) {
                                    if (value2 instanceof Number) {
                                        field.setDouble(object, ((Number) value2).doubleValue());
                                        it2 = it;
                                        map2 = null;
                                    } else if (value2 instanceof String) {
                                        String strVal = (String) value2;
                                        if (strVal.length() <= 10) {
                                            doubleValue = TypeUtils.parseDouble(strVal);
                                        } else {
                                            doubleValue = Double.parseDouble(strVal);
                                        }
                                        field.setDouble(object, doubleValue);
                                        it2 = it;
                                        map2 = null;
                                    }
                                } else if (value2 != null && paramType == value2.getClass()) {
                                    field.set(object, value2);
                                    it2 = it;
                                    map2 = null;
                                }
                            } else if (value2 instanceof Number) {
                                field.setFloat(object, ((Number) value2).floatValue());
                                map2 = null;
                            } else if (value2 instanceof String) {
                                String strVal2 = (String) value2;
                                if (strVal2.length() <= 10) {
                                    floatValue = TypeUtils.parseFloat(strVal2);
                                } else {
                                    floatValue = Float.parseFloat(strVal2);
                                }
                                field.setFloat(object, floatValue);
                                it2 = it2;
                                map2 = null;
                            } else {
                                it = it2;
                            }
                        }
                        String format = fieldInfo.format;
                        if (format != null && paramType == Date.class) {
                            value = TypeUtils.castToDate(value2, format);
                        } else if (format != null && (paramType instanceof Class) && ((Class) paramType).getName().equals("java.time.LocalDateTime")) {
                            value = Jdk8DateCodec.castToLocalDateTime(value2, format);
                        } else if (paramType instanceof ParameterizedType) {
                            value = TypeUtils.cast(value2, (ParameterizedType) paramType, config);
                        } else {
                            value = TypeUtils.cast(value2, paramType, config);
                        }
                        fieldDeser.setValue(object, value);
                        it2 = it;
                        map2 = null;
                    } else {
                        if (!(value2 instanceof String) || !JSONValidator.from((String) value2).validate()) {
                            input = JSON.toJSONString(value2);
                        } else {
                            input = (String) value2;
                        }
                        fieldDeser.parseField(new DefaultJSONParser(input), object, paramType, map2);
                    }
                }
            }
            if (this.beanInfo.buildMethod == null) {
                return object;
            }
            try {
                return this.beanInfo.buildMethod.invoke(object, new Object[0]);
            } catch (Exception e) {
                throw new JSONException("build object error", e);
            }
        } else {
            FieldInfo[] fieldInfoList = this.beanInfo.fields;
            int size = fieldInfoList.length;
            Object[] params = new Object[size];
            Map<String, Integer> missFields = null;
            for (int i2 = 0; i2 < size; i2++) {
                FieldInfo fieldInfo2 = fieldInfoList[i2];
                boolean param = map.get(fieldInfo2.name);
                if (param == null) {
                    Class<?> fieldClass2 = fieldInfo2.fieldClass;
                    if (fieldClass2 == Integer.TYPE) {
                        param = 0;
                    } else if (fieldClass2 == Long.TYPE) {
                        param = 0L;
                    } else if (fieldClass2 == Short.TYPE) {
                        param = (short) 0;
                    } else if (fieldClass2 == Byte.TYPE) {
                        param = (byte) 0;
                    } else if (fieldClass2 == Float.TYPE) {
                        param = Float.valueOf(0.0f);
                    } else if (fieldClass2 == Double.TYPE) {
                        param = Double.valueOf(0.0d);
                    } else if (fieldClass2 == Character.TYPE) {
                        param = '0';
                    } else if (fieldClass2 == Boolean.TYPE) {
                        param = false;
                    }
                    if (missFields == null) {
                        missFields = new HashMap<>();
                    }
                    missFields.put(fieldInfo2.name, Integer.valueOf(i2));
                }
                params[i2] = param;
            }
            if (missFields != null) {
                for (Map.Entry<String, Object> entry2 : map.entrySet()) {
                    Object value3 = entry2.getValue();
                    FieldDeserializer fieldDeser2 = smartMatch(entry2.getKey());
                    if (!(fieldDeser2 == null || (index = missFields.get(fieldDeser2.fieldInfo.name)) == null)) {
                        params[index.intValue()] = value3;
                    }
                }
            }
            if (this.beanInfo.creatorConstructor != null) {
                boolean hasNull = false;
                if (this.beanInfo.f80kotlin) {
                    for (int i3 = 0; i3 < params.length; i3++) {
                        Object param2 = params[i3];
                        if (param2 == null) {
                            if (this.beanInfo.fields != null && i3 < this.beanInfo.fields.length && this.beanInfo.fields[i3].fieldClass == String.class) {
                                hasNull = true;
                            }
                        } else if (param2.getClass() != this.beanInfo.fields[i3].fieldClass) {
                            params[i3] = TypeUtils.cast(param2, (Class) this.beanInfo.fields[i3].fieldClass, config);
                        }
                    }
                    i = hasNull;
                } else {
                    i = false;
                }
                if (!i || this.beanInfo.kotlinDefaultConstructor == null) {
                    try {
                        return this.beanInfo.creatorConstructor.newInstance(params);
                    } catch (Exception e2) {
                        throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e2);
                    }
                } else {
                    try {
                        Object object2 = this.beanInfo.kotlinDefaultConstructor.newInstance(new Object[0]);
                        for (int i4 = 0; i4 < params.length; i4++) {
                            Object param3 = params[i4];
                            if (!(param3 == null || this.beanInfo.fields == null || i4 >= this.beanInfo.fields.length)) {
                                this.beanInfo.fields[i4].set(object2, param3);
                            }
                        }
                        return object2;
                    } catch (Exception e3) {
                        throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e3);
                    }
                }
            } else if (this.beanInfo.factoryMethod == null) {
                return null;
            } else {
                try {
                    return this.beanInfo.factoryMethod.invoke(null, params);
                } catch (Exception e4) {
                    throw new JSONException("create factory method error, " + this.beanInfo.factoryMethod.toString(), e4);
                }
            }
        }
    }

    public Type getFieldType(int ordinal) {
        return this.sortedFieldDeserializers[ordinal].fieldInfo.fieldType;
    }

    /* access modifiers changed from: protected */
    public Object parseRest(DefaultJSONParser parser, Type type, Object fieldName, Object instance, int features) {
        return parseRest(parser, type, fieldName, instance, features, new int[0]);
    }

    /* access modifiers changed from: protected */
    public Object parseRest(DefaultJSONParser parser, Type type, Object fieldName, Object instance, int features, int[] setFlags) {
        return deserialze(parser, type, fieldName, instance, features, setFlags);
    }

    protected static JavaBeanDeserializer getSeeAlso(ParserConfig config, JavaBeanInfo beanInfo2, String typeName) {
        if (beanInfo2.jsonType == null) {
            return null;
        }
        for (Class<?> seeAlsoClass : beanInfo2.jsonType.seeAlso()) {
            ObjectDeserializer seeAlsoDeser = config.getDeserializer(seeAlsoClass);
            if (seeAlsoDeser instanceof JavaBeanDeserializer) {
                JavaBeanDeserializer seeAlsoJavaBeanDeser = (JavaBeanDeserializer) seeAlsoDeser;
                JavaBeanInfo subBeanInfo = seeAlsoJavaBeanDeser.beanInfo;
                if (subBeanInfo.typeName.equals(typeName)) {
                    return seeAlsoJavaBeanDeser;
                }
                JavaBeanDeserializer subSeeAlso = getSeeAlso(config, subBeanInfo, typeName);
                if (subSeeAlso != null) {
                    return subSeeAlso;
                }
            }
        }
        return null;
    }

    protected static void parseArray(Collection collection, ObjectDeserializer deser, DefaultJSONParser parser, Type type, Object fieldName) {
        JSONLexerBase lexer = (JSONLexerBase) parser.lexer;
        int token = lexer.token();
        if (token == 8) {
            lexer.nextToken(16);
            lexer.token();
            return;
        }
        if (token != 14) {
            parser.throwException(token);
        }
        if (lexer.getCurrent() == '[') {
            lexer.next();
            lexer.setToken(14);
        } else {
            lexer.nextToken(14);
        }
        if (lexer.token() == 15) {
            lexer.nextToken();
            return;
        }
        int index = 0;
        while (true) {
            collection.add(deser.deserialze(parser, type, Integer.valueOf(index)));
            index++;
            if (lexer.token() != 16) {
                break;
            } else if (lexer.getCurrent() == '[') {
                lexer.next();
                lexer.setToken(14);
            } else {
                lexer.nextToken(14);
            }
        }
        int token2 = lexer.token();
        if (token2 != 15) {
            parser.throwException(token2);
        }
        if (lexer.getCurrent() == ',') {
            lexer.next();
            lexer.setToken(16);
            return;
        }
        lexer.nextToken(16);
    }
}
