package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.asm.ClassWriter;
import com.alibaba.fastjson.asm.FieldWriter;
import com.alibaba.fastjson.asm.Label;
import com.alibaba.fastjson.asm.MethodVisitor;
import com.alibaba.fastjson.asm.MethodWriter;
import com.alibaba.fastjson.asm.Opcodes;
import com.alibaba.fastjson.asm.Type;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.ASMClassLoader;
import com.alibaba.fastjson.util.ASMUtils;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.alipay.sdk.m.u.i;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXBasicComponentType;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.math.BigDecimal;
import java.util.Collection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicLong;

public class ASMSerializerFactory implements Opcodes {
    static final String JSONSerializer = ASMUtils.type(JSONSerializer.class);
    static final String JavaBeanSerializer = ASMUtils.type(JavaBeanSerializer.class);
    static final String JavaBeanSerializer_desc = ("L" + ASMUtils.type(JavaBeanSerializer.class) + i.b);
    static final String ObjectSerializer = ASMUtils.type(ObjectSerializer.class);
    static final String ObjectSerializer_desc = ("L" + ObjectSerializer + i.b);
    static final String SerialContext_desc = ASMUtils.desc(SerialContext.class);
    static final String SerializeFilterable_desc = ASMUtils.desc(SerializeFilterable.class);
    static final String SerializeWriter = ASMUtils.type(SerializeWriter.class);
    static final String SerializeWriter_desc = ("L" + SerializeWriter + i.b);
    protected final ASMClassLoader classLoader = new ASMClassLoader();
    private final AtomicLong seed = new AtomicLong();

    /* access modifiers changed from: package-private */
    public static class Context {
        static final int features = 5;
        static int fieldName = 6;
        static final int obj = 2;
        static int original = 7;
        static final int paramFieldName = 3;
        static final int paramFieldType = 4;
        static int processValue = 8;
        static final int serializer = 1;
        private final SerializeBeanInfo beanInfo;
        private final String className;
        private final FieldInfo[] getters;
        private final boolean nonContext;
        private int variantIndex = 9;
        private Map<String, Integer> variants = new HashMap();
        private final boolean writeDirect;

        public Context(FieldInfo[] getters2, SerializeBeanInfo beanInfo2, String className2, boolean writeDirect2, boolean nonContext2) {
            this.getters = getters2;
            this.className = className2;
            this.beanInfo = beanInfo2;
            this.writeDirect = writeDirect2;
            this.nonContext = nonContext2 || beanInfo2.beanType.isEnum();
        }

        public int var(String name) {
            if (this.variants.get(name) == null) {
                Map<String, Integer> map = this.variants;
                int i = this.variantIndex;
                this.variantIndex = i + 1;
                map.put(name, Integer.valueOf(i));
            }
            return this.variants.get(name).intValue();
        }

        public int var(String name, int increment) {
            if (this.variants.get(name) == null) {
                this.variants.put(name, Integer.valueOf(this.variantIndex));
                this.variantIndex += increment;
            }
            return this.variants.get(name).intValue();
        }

        public int getFieldOrinal(String name) {
            int size = this.getters.length;
            for (int i = 0; i < size; i++) {
                if (this.getters[i].name.equals(name)) {
                    return i;
                }
            }
            return -1;
        }
    }

    /* JADX INFO: Multiple debug info for r1v38 java.lang.String: [D('classNameFull' java.lang.String), D('packageName' java.lang.String)] */
    /* JADX WARNING: Removed duplicated region for block: B:103:0x0590  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x02aa  */
    /* JADX WARNING: Removed duplicated region for block: B:98:0x050f  */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x0588  */
    public JavaBeanSerializer createJavaBeanSerializer(SerializeBeanInfo beanInfo) throws Exception {
        String classNameFull;
        String classNameType;
        boolean DisableCircularReferenceDetect;
        int i;
        FieldInfo[] unsortedGetters;
        int i2;
        String methodName;
        String methodName2;
        boolean writeDirect;
        boolean nonContext;
        String classNameType2;
        boolean DisableCircularReferenceDetect2;
        JSONType jsonType;
        ClassWriter cw;
        String classNameFull2;
        int i3;
        Class<?> clazz = beanInfo.beanType;
        if (!clazz.isPrimitive()) {
            JSONType jsonType2 = (JSONType) TypeUtils.getAnnotation(clazz, JSONType.class);
            FieldInfo[] unsortedGetters2 = beanInfo.fields;
            for (FieldInfo fieldInfo : unsortedGetters2) {
                if (fieldInfo.field == null && fieldInfo.method != null && fieldInfo.method.getDeclaringClass().isInterface()) {
                    return new JavaBeanSerializer(beanInfo);
                }
            }
            FieldInfo[] getters = beanInfo.sortedFields;
            boolean nativeSorted = beanInfo.sortedFields == beanInfo.fields;
            if (getters.length > 256) {
                return new JavaBeanSerializer(beanInfo);
            }
            for (FieldInfo getter : getters) {
                if (!ASMUtils.checkName(getter.getMember().getName())) {
                    return new JavaBeanSerializer(beanInfo);
                }
            }
            String className = "ASMSerializer_" + this.seed.incrementAndGet() + "_" + clazz.getSimpleName();
            Package pkg = ASMSerializerFactory.class.getPackage();
            if (pkg != null) {
                String packageName = pkg.getName();
                classNameFull = packageName + Operators.DOT_STR + className;
                classNameType = packageName.replace(Operators.DOT, '/') + "/" + className;
            } else {
                classNameFull = className;
                classNameType = className;
            }
            ClassWriter cw2 = new ClassWriter();
            cw2.visit(49, 33, classNameType, JavaBeanSerializer, new String[]{ObjectSerializer});
            int length = getters.length;
            int i4 = 0;
            while (i4 < length) {
                FieldInfo fieldInfo2 = getters[i4];
                if (fieldInfo2.fieldClass.isPrimitive()) {
                    i3 = length;
                    classNameFull2 = classNameFull;
                } else if (fieldInfo2.fieldClass == String.class) {
                    i3 = length;
                    classNameFull2 = classNameFull;
                } else {
                    StringBuilder sb = new StringBuilder();
                    i3 = length;
                    sb.append(fieldInfo2.name);
                    sb.append("_asm_fieldType");
                    classNameFull2 = classNameFull;
                    new FieldWriter(cw2, 1, sb.toString(), "Ljava/lang/reflect/Type;").visitEnd();
                    if (List.class.isAssignableFrom(fieldInfo2.fieldClass)) {
                        new FieldWriter(cw2, 1, fieldInfo2.name + "_asm_list_item_ser_", ObjectSerializer_desc).visitEnd();
                    }
                    new FieldWriter(cw2, 1, fieldInfo2.name + "_asm_ser_", ObjectSerializer_desc).visitEnd();
                }
                i4++;
                length = i3;
                classNameFull = classNameFull2;
            }
            String classNameFull3 = classNameFull;
            MethodVisitor methodWriter = new MethodWriter(cw2, 1, "<init>", Operators.BRACKET_START_STR + ASMUtils.desc(SerializeBeanInfo.class) + ")V", null, null);
            int i5 = 25;
            methodWriter.visitVarInsn(25, 0);
            methodWriter.visitVarInsn(25, 1);
            methodWriter.visitMethodInsn(Opcodes.INVOKESPECIAL, JavaBeanSerializer, "<init>", Operators.BRACKET_START_STR + ASMUtils.desc(SerializeBeanInfo.class) + ")V");
            int i6 = 0;
            while (i6 < getters.length) {
                FieldInfo fieldInfo3 = getters[i6];
                if (fieldInfo3.fieldClass.isPrimitive()) {
                    cw = cw2;
                } else if (fieldInfo3.fieldClass == String.class) {
                    cw = cw2;
                } else {
                    methodWriter.visitVarInsn(i5, 0);
                    if (fieldInfo3.method != null) {
                        methodWriter.visitLdcInsn(Type.getType(ASMUtils.desc(fieldInfo3.declaringClass)));
                        methodWriter.visitLdcInsn(fieldInfo3.method.getName());
                        cw = cw2;
                        methodWriter.visitMethodInsn(Opcodes.INVOKESTATIC, ASMUtils.type(ASMUtils.class), "getMethodType", "(Ljava/lang/Class;Ljava/lang/String;)Ljava/lang/reflect/Type;");
                    } else {
                        cw = cw2;
                        methodWriter.visitVarInsn(25, 0);
                        methodWriter.visitLdcInsn(Integer.valueOf(i6));
                        methodWriter.visitMethodInsn(Opcodes.INVOKESPECIAL, JavaBeanSerializer, "getFieldType", "(I)Ljava/lang/reflect/Type;");
                    }
                    methodWriter.visitFieldInsn(Opcodes.PUTFIELD, classNameType, fieldInfo3.name + "_asm_fieldType", "Ljava/lang/reflect/Type;");
                }
                i6++;
                cw2 = cw;
                i5 = 25;
            }
            ClassWriter cw3 = cw2;
            methodWriter.visitInsn(177);
            methodWriter.visitMaxs(4, 4);
            methodWriter.visitEnd();
            if (jsonType2 != null) {
                SerializerFeature[] serialzeFeatures = jsonType2.serialzeFeatures();
                int length2 = serialzeFeatures.length;
                int i7 = 0;
                while (true) {
                    if (i7 >= length2) {
                        break;
                    } else if (serialzeFeatures[i7] == SerializerFeature.DisableCircularReferenceDetect) {
                        DisableCircularReferenceDetect = true;
                        break;
                    } else {
                        i7++;
                    }
                }
                MethodVisitor mw = methodWriter;
                i = 0;
                while (i < 3) {
                    if (i == 0) {
                        nonContext = DisableCircularReferenceDetect;
                        writeDirect = true;
                        methodName2 = "write";
                    } else if (i == 1) {
                        nonContext = DisableCircularReferenceDetect;
                        methodName2 = "writeNormal";
                        writeDirect = false;
                    } else {
                        nonContext = true;
                        methodName2 = "writeDirectNonContext";
                        writeDirect = true;
                    }
                    Context context = new Context(getters, beanInfo, classNameType, writeDirect, nonContext);
                    MethodVisitor methodWriter2 = new MethodWriter(cw3, 1, methodName2, "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V", null, new String[]{"java/io/IOException"});
                    Label endIf_ = new Label();
                    methodWriter2.visitVarInsn(25, 2);
                    methodWriter2.visitJumpInsn(Opcodes.IFNONNULL, endIf_);
                    methodWriter2.visitVarInsn(25, 1);
                    methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeNull", "()V");
                    methodWriter2.visitInsn(177);
                    methodWriter2.visitLabel(endIf_);
                    methodWriter2.visitVarInsn(25, 1);
                    methodWriter2.visitFieldInsn(180, JSONSerializer, "out", SerializeWriter_desc);
                    methodWriter2.visitVarInsn(58, context.var("out"));
                    if (nativeSorted) {
                        classNameType2 = classNameType;
                    } else if (context.writeDirect) {
                        classNameType2 = classNameType;
                    } else if (jsonType2 == null || jsonType2.alphabetic()) {
                        Label _else = new Label();
                        methodWriter2.visitVarInsn(25, context.var("out"));
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isSortField", "()Z");
                        methodWriter2.visitJumpInsn(154, _else);
                        methodWriter2.visitVarInsn(25, 0);
                        methodWriter2.visitVarInsn(25, 1);
                        methodWriter2.visitVarInsn(25, 2);
                        methodWriter2.visitVarInsn(25, 3);
                        methodWriter2.visitVarInsn(25, 4);
                        methodWriter2.visitVarInsn(21, 5);
                        classNameType2 = classNameType;
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, classNameType2, "writeUnsorted", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                        methodWriter2.visitInsn(177);
                        methodWriter2.visitLabel(_else);
                    } else {
                        classNameType2 = classNameType;
                    }
                    if (!context.writeDirect || nonContext) {
                        jsonType = jsonType2;
                        DisableCircularReferenceDetect2 = DisableCircularReferenceDetect;
                    } else {
                        Label _direct = new Label();
                        Label _directElse = new Label();
                        methodWriter2.visitVarInsn(25, 0);
                        methodWriter2.visitVarInsn(25, 1);
                        String str = JavaBeanSerializer;
                        StringBuilder sb2 = new StringBuilder();
                        sb2.append("(L");
                        jsonType = jsonType2;
                        sb2.append(JSONSerializer);
                        sb2.append(";)Z");
                        DisableCircularReferenceDetect2 = DisableCircularReferenceDetect;
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "writeDirect", sb2.toString());
                        methodWriter2.visitJumpInsn(154, _directElse);
                        methodWriter2.visitVarInsn(25, 0);
                        methodWriter2.visitVarInsn(25, 1);
                        methodWriter2.visitVarInsn(25, 2);
                        methodWriter2.visitVarInsn(25, 3);
                        methodWriter2.visitVarInsn(25, 4);
                        methodWriter2.visitVarInsn(21, 5);
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, classNameType2, "writeNormal", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                        methodWriter2.visitInsn(177);
                        methodWriter2.visitLabel(_directElse);
                        methodWriter2.visitVarInsn(25, context.var("out"));
                        methodWriter2.visitLdcInsn(Integer.valueOf(SerializerFeature.DisableCircularReferenceDetect.mask));
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
                        methodWriter2.visitJumpInsn(153, _direct);
                        methodWriter2.visitVarInsn(25, 0);
                        methodWriter2.visitVarInsn(25, 1);
                        methodWriter2.visitVarInsn(25, 2);
                        methodWriter2.visitVarInsn(25, 3);
                        methodWriter2.visitVarInsn(25, 4);
                        methodWriter2.visitVarInsn(21, 5);
                        methodWriter2.visitMethodInsn(Opcodes.INVOKEVIRTUAL, classNameType2, "writeDirectNonContext", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                        methodWriter2.visitInsn(177);
                        methodWriter2.visitLabel(_direct);
                    }
                    methodWriter2.visitVarInsn(25, 2);
                    methodWriter2.visitTypeInsn(192, ASMUtils.type(clazz));
                    methodWriter2.visitVarInsn(58, context.var("entity"));
                    generateWriteMethod(clazz, methodWriter2, getters, context);
                    methodWriter2.visitInsn(177);
                    methodWriter2.visitMaxs(7, context.variantIndex + 2);
                    methodWriter2.visitEnd();
                    i++;
                    mw = methodWriter2;
                    classNameType = classNameType2;
                    className = className;
                    unsortedGetters2 = unsortedGetters2;
                    jsonType2 = jsonType;
                    cw3 = cw3;
                    DisableCircularReferenceDetect = DisableCircularReferenceDetect2;
                    classNameFull3 = classNameFull3;
                }
                if (nativeSorted) {
                    Context context2 = new Context(getters, beanInfo, classNameType, false, DisableCircularReferenceDetect);
                    MethodVisitor mw2 = new MethodWriter(cw3, 1, "writeUnsorted", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V", null, new String[]{"java/io/IOException"});
                    mw2.visitVarInsn(25, 1);
                    mw2.visitFieldInsn(180, JSONSerializer, "out", SerializeWriter_desc);
                    mw2.visitVarInsn(58, context2.var("out"));
                    mw2.visitVarInsn(25, 2);
                    mw2.visitTypeInsn(192, ASMUtils.type(clazz));
                    mw2.visitVarInsn(58, context2.var("entity"));
                    unsortedGetters = unsortedGetters2;
                    generateWriteMethod(clazz, mw2, unsortedGetters, context2);
                    mw2.visitInsn(177);
                    mw2.visitMaxs(7, context2.variantIndex + 2);
                    mw2.visitEnd();
                } else {
                    unsortedGetters = unsortedGetters2;
                }
                i2 = 0;
                while (i2 < 3) {
                    boolean nonContext2 = DisableCircularReferenceDetect;
                    boolean writeDirect2 = false;
                    if (i2 == 0) {
                        methodName = "writeAsArray";
                        writeDirect2 = true;
                    } else if (i2 == 1) {
                        methodName = "writeAsArrayNormal";
                    } else {
                        writeDirect2 = true;
                        nonContext2 = true;
                        methodName = "writeAsArrayNonContext";
                    }
                    Context context3 = new Context(getters, beanInfo, classNameType, writeDirect2, nonContext2);
                    MethodVisitor mw3 = new MethodWriter(cw3, 1, methodName, "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V", null, new String[]{"java/io/IOException"});
                    mw3.visitVarInsn(25, 1);
                    mw3.visitFieldInsn(180, JSONSerializer, "out", SerializeWriter_desc);
                    mw3.visitVarInsn(58, context3.var("out"));
                    mw3.visitVarInsn(25, 2);
                    mw3.visitTypeInsn(192, ASMUtils.type(clazz));
                    mw3.visitVarInsn(58, context3.var("entity"));
                    generateWriteAsArray(clazz, mw3, getters, context3);
                    mw3.visitInsn(177);
                    mw3.visitMaxs(7, context3.variantIndex + 2);
                    mw3.visitEnd();
                    i2++;
                    unsortedGetters = unsortedGetters;
                }
                byte[] code = cw3.toByteArray();
                return (JavaBeanSerializer) this.classLoader.defineClassPublic(classNameFull3, code, 0, code.length).getConstructor(SerializeBeanInfo.class).newInstance(beanInfo);
            }
            DisableCircularReferenceDetect = false;
            MethodVisitor mw4 = methodWriter;
            i = 0;
            while (i < 3) {
            }
            if (nativeSorted) {
            }
            i2 = 0;
            while (i2 < 3) {
            }
            byte[] code2 = cw3.toByteArray();
            return (JavaBeanSerializer) this.classLoader.defineClassPublic(classNameFull3, code2, 0, code2.length).getConstructor(SerializeBeanInfo.class).newInstance(beanInfo);
        }
        throw new JSONException("unsupportd class " + clazz.getName());
    }

    private void generateWriteAsArray(Class<?> cls, MethodVisitor mw, FieldInfo[] getters, Context context) throws Exception {
        int i;
        int size;
        Label nonPropertyFilters_;
        String str;
        String str2;
        char i2;
        String str3;
        Label notNullEnd_;
        String str4;
        java.lang.reflect.Type elementType;
        Class<?> elementClass;
        char seperator;
        int i3;
        String str5;
        Label for_;
        Label forItemClassIfElse_;
        Label forItemNullEnd_;
        ASMSerializerFactory aSMSerializerFactory = this;
        FieldInfo[] fieldInfoArr = getters;
        Label nonPropertyFilters_2 = new Label();
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 0);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "hasPropertyFilters", Operators.BRACKET_START_STR + SerializeFilterable_desc + ")Z");
        mw.visitJumpInsn(154, nonPropertyFilters_2);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(25, 3);
        mw.visitVarInsn(25, 4);
        mw.visitVarInsn(21, 5);
        String str6 = JavaBeanSerializer;
        StringBuilder sb = new StringBuilder();
        sb.append("(L");
        sb.append(JSONSerializer);
        String str7 = ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V";
        sb.append(str7);
        mw.visitMethodInsn(Opcodes.INVOKESPECIAL, str6, "writeNoneASM", sb.toString());
        mw.visitInsn(177);
        mw.visitLabel(nonPropertyFilters_2);
        String str8 = "out";
        mw.visitVarInsn(25, context.var(str8));
        mw.visitVarInsn(16, 91);
        String str9 = "(I)V";
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
        int size2 = fieldInfoArr.length;
        if (size2 == 0) {
            mw.visitVarInsn(25, context.var(str8));
            mw.visitVarInsn(16, 93);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
            return;
        }
        int i4 = 0;
        while (i4 < size2) {
            char seperator2 = i4 == size2 + -1 ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
            FieldInfo fieldInfo = fieldInfoArr[i4];
            Class<?> fieldClass = fieldInfo.fieldClass;
            mw.visitLdcInsn(fieldInfo.name);
            mw.visitVarInsn(58, Context.fieldName);
            if (fieldClass == Byte.TYPE || fieldClass == Short.TYPE) {
                nonPropertyFilters_ = nonPropertyFilters_2;
                i = i4;
                size = size2;
                str = str9;
                i2 = seperator2;
                str2 = str8;
            } else if (fieldClass == Integer.TYPE) {
                nonPropertyFilters_ = nonPropertyFilters_2;
                i = i4;
                size = size2;
                str = str9;
                i2 = seperator2;
                str2 = str8;
            } else {
                if (fieldClass == Long.TYPE) {
                    mw.visitVarInsn(25, context.var(str8));
                    mw.visitInsn(89);
                    aSMSerializerFactory._get(mw, context, fieldInfo);
                    nonPropertyFilters_ = nonPropertyFilters_2;
                    size = size2;
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeLong", "(J)V");
                    mw.visitVarInsn(16, seperator2);
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                    str = str9;
                    i = i4;
                    str2 = str8;
                } else {
                    nonPropertyFilters_ = nonPropertyFilters_2;
                    size = size2;
                    if (fieldClass == Float.TYPE) {
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitInsn(89);
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitInsn(4);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFloat", "(FZ)V");
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (fieldClass == Double.TYPE) {
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitInsn(89);
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitInsn(4);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeDouble", "(DZ)V");
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (fieldClass == Boolean.TYPE) {
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitInsn(89);
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(Z)V");
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (fieldClass == Character.TYPE) {
                        mw.visitVarInsn(25, context.var(str8));
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Character", "toString", "(C)Ljava/lang/String;");
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeString", "(Ljava/lang/String;C)V");
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (fieldClass == String.class) {
                        mw.visitVarInsn(25, context.var(str8));
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeString", "(Ljava/lang/String;C)V");
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (fieldClass.isEnum()) {
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitInsn(89);
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeEnum", "(Ljava/lang/Enum;)V");
                        mw.visitVarInsn(16, seperator2);
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                        str = str9;
                        i = i4;
                        str2 = str8;
                    } else if (List.class.isAssignableFrom(fieldClass)) {
                        java.lang.reflect.Type fieldType = fieldInfo.fieldType;
                        if (fieldType instanceof Class) {
                            elementType = Object.class;
                        } else {
                            elementType = ((ParameterizedType) fieldType).getActualTypeArguments()[0];
                        }
                        if (elementType instanceof Class) {
                            elementClass = (Class) elementType;
                            if (elementClass == Object.class) {
                                elementClass = null;
                            }
                        } else {
                            elementClass = null;
                        }
                        aSMSerializerFactory._get(mw, context, fieldInfo);
                        i = i4;
                        mw.visitTypeInsn(192, "java/util/List");
                        mw.visitVarInsn(58, context.var(WXBasicComponentType.LIST));
                        if (elementClass != String.class || !context.writeDirect) {
                            Label nullEnd_ = new Label();
                            Label nullElse_ = new Label();
                            seperator = seperator2;
                            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
                            mw.visitJumpInsn(Opcodes.IFNONNULL, nullElse_);
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeNull", "()V");
                            mw.visitJumpInsn(Opcodes.GOTO, nullEnd_);
                            mw.visitLabel(nullElse_);
                            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
                            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, "java/util/List", AbsoluteConst.JSON_KEY_SIZE, "()I");
                            mw.visitVarInsn(54, context.var(AbsoluteConst.JSON_KEY_SIZE));
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitVarInsn(16, 91);
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                            Label for_2 = new Label();
                            Label forFirst_ = new Label();
                            Label forEnd_ = new Label();
                            mw.visitInsn(3);
                            mw.visitVarInsn(54, context.var("i"));
                            mw.visitLabel(for_2);
                            mw.visitVarInsn(21, context.var("i"));
                            mw.visitVarInsn(21, context.var(AbsoluteConst.JSON_KEY_SIZE));
                            mw.visitJumpInsn(Opcodes.IF_ICMPGE, forEnd_);
                            mw.visitVarInsn(21, context.var("i"));
                            mw.visitJumpInsn(153, forFirst_);
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitVarInsn(16, 44);
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str9);
                            mw.visitLabel(forFirst_);
                            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
                            mw.visitVarInsn(21, context.var("i"));
                            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, "java/util/List", "get", "(I)Ljava/lang/Object;");
                            mw.visitVarInsn(58, context.var("list_item"));
                            Label forItemNullEnd_2 = new Label();
                            Label forItemNullElse_ = new Label();
                            mw.visitVarInsn(25, context.var("list_item"));
                            mw.visitJumpInsn(Opcodes.IFNONNULL, forItemNullElse_);
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeNull", "()V");
                            mw.visitJumpInsn(Opcodes.GOTO, forItemNullEnd_2);
                            mw.visitLabel(forItemNullElse_);
                            Label forItemClassIfEnd_ = new Label();
                            Label forItemClassIfElse_2 = new Label();
                            if (elementClass == null || !Modifier.isPublic(elementClass.getModifiers())) {
                                for_ = for_2;
                                forItemNullEnd_ = forItemNullEnd_2;
                                str7 = str7;
                                forItemClassIfElse_ = forItemClassIfElse_2;
                            } else {
                                mw.visitVarInsn(25, context.var("list_item"));
                                for_ = for_2;
                                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Object", "getClass", "()Ljava/lang/Class;");
                                mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                                mw.visitJumpInsn(Opcodes.IF_ACMPNE, forItemClassIfElse_2);
                                aSMSerializerFactory._getListFieldItemSer(context, mw, fieldInfo, elementClass);
                                mw.visitVarInsn(58, context.var("list_item_desc"));
                                Label instanceOfElse_ = new Label();
                                Label instanceOfEnd_ = new Label();
                                if (context.writeDirect) {
                                    mw.visitVarInsn(25, context.var("list_item_desc"));
                                    mw.visitTypeInsn(Opcodes.INSTANCEOF, JavaBeanSerializer);
                                    mw.visitJumpInsn(153, instanceOfElse_);
                                    mw.visitVarInsn(25, context.var("list_item_desc"));
                                    mw.visitTypeInsn(192, JavaBeanSerializer);
                                    mw.visitVarInsn(25, 1);
                                    mw.visitVarInsn(25, context.var("list_item"));
                                    if (context.nonContext) {
                                        mw.visitInsn(1);
                                        forItemNullEnd_ = forItemNullEnd_2;
                                    } else {
                                        mw.visitVarInsn(21, context.var("i"));
                                        forItemNullEnd_ = forItemNullEnd_2;
                                        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                                    }
                                    mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                                    mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                                    String str10 = JavaBeanSerializer;
                                    StringBuilder sb2 = new StringBuilder();
                                    sb2.append("(L");
                                    sb2.append(JSONSerializer);
                                    str7 = str7;
                                    sb2.append(str7);
                                    forItemClassIfElse_ = forItemClassIfElse_2;
                                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str10, "writeAsArrayNonContext", sb2.toString());
                                    mw.visitJumpInsn(Opcodes.GOTO, instanceOfEnd_);
                                    mw.visitLabel(instanceOfElse_);
                                } else {
                                    forItemNullEnd_ = forItemNullEnd_2;
                                    str7 = str7;
                                    forItemClassIfElse_ = forItemClassIfElse_2;
                                }
                                mw.visitVarInsn(25, context.var("list_item_desc"));
                                mw.visitVarInsn(25, 1);
                                mw.visitVarInsn(25, context.var("list_item"));
                                if (context.nonContext) {
                                    mw.visitInsn(1);
                                } else {
                                    mw.visitVarInsn(21, context.var("i"));
                                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                                }
                                mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                                mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                                mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, ObjectSerializer, "write", "(L" + JSONSerializer + str7);
                                mw.visitLabel(instanceOfEnd_);
                                mw.visitJumpInsn(Opcodes.GOTO, forItemClassIfEnd_);
                            }
                            mw.visitLabel(forItemClassIfElse_);
                            mw.visitVarInsn(25, 1);
                            mw.visitVarInsn(25, context.var("list_item"));
                            if (context.nonContext) {
                                mw.visitInsn(1);
                            } else {
                                mw.visitVarInsn(21, context.var("i"));
                                mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                            }
                            if (elementClass == null || !Modifier.isPublic(elementClass.getModifiers())) {
                                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;)V");
                            } else {
                                mw.visitLdcInsn(Type.getType(ASMUtils.desc((Class) elementType)));
                                mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                            }
                            mw.visitLabel(forItemClassIfEnd_);
                            mw.visitLabel(forItemNullEnd_);
                            mw.visitIincInsn(context.var("i"), 1);
                            mw.visitJumpInsn(Opcodes.GOTO, for_);
                            mw.visitLabel(forEnd_);
                            str8 = str8;
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitVarInsn(16, 93);
                            String str11 = SerializeWriter;
                            str5 = str9;
                            i3 = Opcodes.INVOKEVIRTUAL;
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str11, "write", str5);
                            mw.visitLabel(nullEnd_);
                        } else {
                            mw.visitVarInsn(25, context.var(str8));
                            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(Ljava/util/List;)V");
                            str5 = str9;
                            seperator = seperator2;
                            i3 = Opcodes.INVOKEVIRTUAL;
                        }
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitVarInsn(16, seperator);
                        mw.visitMethodInsn(i3, SerializeWriter, "write", str5);
                        aSMSerializerFactory = this;
                        str = str5;
                        str2 = str8;
                    } else {
                        i = i4;
                        Label notNullEnd_2 = new Label();
                        Label notNullElse_ = new Label();
                        _get(mw, context, fieldInfo);
                        mw.visitInsn(89);
                        mw.visitVarInsn(58, context.var("field_" + fieldInfo.fieldClass.getName()));
                        mw.visitJumpInsn(Opcodes.IFNONNULL, notNullElse_);
                        mw.visitVarInsn(25, context.var(str8));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeNull", "()V");
                        mw.visitJumpInsn(Opcodes.GOTO, notNullEnd_2);
                        mw.visitLabel(notNullElse_);
                        Label classIfEnd_ = new Label();
                        Label classIfElse_ = new Label();
                        mw.visitVarInsn(25, context.var("field_" + fieldInfo.fieldClass.getName()));
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Object", "getClass", "()Ljava/lang/Class;");
                        mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldClass)));
                        mw.visitJumpInsn(Opcodes.IF_ACMPNE, classIfElse_);
                        _getFieldSer(context, mw, fieldInfo);
                        mw.visitVarInsn(58, context.var("fied_ser"));
                        Label instanceOfElse_2 = new Label();
                        Label instanceOfEnd_2 = new Label();
                        if (!context.writeDirect || !Modifier.isPublic(fieldClass.getModifiers())) {
                            notNullEnd_ = notNullEnd_2;
                            str3 = "writeWithFieldName";
                        } else {
                            mw.visitVarInsn(25, context.var("fied_ser"));
                            mw.visitTypeInsn(Opcodes.INSTANCEOF, JavaBeanSerializer);
                            mw.visitJumpInsn(153, instanceOfElse_2);
                            mw.visitVarInsn(25, context.var("fied_ser"));
                            mw.visitTypeInsn(192, JavaBeanSerializer);
                            mw.visitVarInsn(25, 1);
                            mw.visitVarInsn(25, context.var("field_" + fieldInfo.fieldClass.getName()));
                            mw.visitVarInsn(25, Context.fieldName);
                            mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldClass)));
                            mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                            String str12 = JavaBeanSerializer;
                            StringBuilder sb3 = new StringBuilder();
                            sb3.append("(L");
                            notNullEnd_ = notNullEnd_2;
                            sb3.append(JSONSerializer);
                            sb3.append(str7);
                            str3 = "writeWithFieldName";
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str12, "writeAsArrayNonContext", sb3.toString());
                            mw.visitJumpInsn(Opcodes.GOTO, instanceOfEnd_2);
                            mw.visitLabel(instanceOfElse_2);
                        }
                        mw.visitVarInsn(25, context.var("fied_ser"));
                        mw.visitVarInsn(25, 1);
                        mw.visitVarInsn(25, context.var("field_" + fieldInfo.fieldClass.getName()));
                        mw.visitVarInsn(25, Context.fieldName);
                        mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldClass)));
                        mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                        mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, ObjectSerializer, "write", "(L" + JSONSerializer + str7);
                        mw.visitLabel(instanceOfEnd_2);
                        mw.visitJumpInsn(Opcodes.GOTO, classIfEnd_);
                        mw.visitLabel(classIfElse_);
                        String format = fieldInfo.getFormat();
                        mw.visitVarInsn(25, 1);
                        mw.visitVarInsn(25, context.var("field_" + fieldInfo.fieldClass.getName()));
                        if (format != null) {
                            mw.visitLdcInsn(format);
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFormat", "(Ljava/lang/Object;Ljava/lang/String;)V");
                        } else {
                            mw.visitVarInsn(25, Context.fieldName);
                            if (!(fieldInfo.fieldType instanceof Class)) {
                                str4 = str3;
                            } else if (((Class) fieldInfo.fieldType).isPrimitive()) {
                                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, str3, "(Ljava/lang/Object;Ljava/lang/Object;)V");
                            } else {
                                str4 = str3;
                            }
                            mw.visitVarInsn(25, 0);
                            mw.visitFieldInsn(180, context.className, fieldInfo.name + "_asm_fieldType", "Ljava/lang/reflect/Type;");
                            mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, str4, "(Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                        }
                        mw.visitLabel(classIfEnd_);
                        mw.visitLabel(notNullEnd_);
                        str2 = str8;
                        mw.visitVarInsn(25, context.var(str2));
                        mw.visitVarInsn(16, seperator2);
                        str = str9;
                        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str);
                        aSMSerializerFactory = this;
                    }
                }
                i4 = i + 1;
                fieldInfoArr = getters;
                str8 = str2;
                str9 = str;
                nonPropertyFilters_2 = nonPropertyFilters_;
                size2 = size;
            }
            mw.visitVarInsn(25, context.var(str2));
            mw.visitInsn(89);
            aSMSerializerFactory = this;
            aSMSerializerFactory._get(mw, context, fieldInfo);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeInt", str);
            mw.visitVarInsn(16, i2);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", str);
            i4 = i + 1;
            fieldInfoArr = getters;
            str8 = str2;
            str9 = str;
            nonPropertyFilters_2 = nonPropertyFilters_;
            size2 = size;
        }
    }

    private void generateWriteMethod(Class<?> clazz, MethodVisitor mw, FieldInfo[] getters, Context context) throws Exception {
        Label end;
        String writeAsArrayMethodName;
        String str;
        String str2;
        int i;
        Class<?> propertyClass;
        FieldInfo property;
        FieldInfo getter;
        FieldInfo[] fieldInfoArr = getters;
        Label end2 = new Label();
        int size = fieldInfoArr.length;
        String str3 = "out";
        if (!context.writeDirect) {
            Label endSupper_ = new Label();
            Label supper_ = new Label();
            mw.visitVarInsn(25, context.var(str3));
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.PrettyFormat.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
            mw.visitJumpInsn(154, supper_);
            int length = fieldInfoArr.length;
            end = end2;
            int i2 = 0;
            while (true) {
                if (i2 >= length) {
                    getter = null;
                    break;
                } else if (fieldInfoArr[i2].method != null) {
                    getter = 1;
                    break;
                } else {
                    i2++;
                    length = length;
                }
            }
            if (getter != null) {
                mw.visitVarInsn(25, context.var(str3));
                mw.visitLdcInsn(Integer.valueOf(SerializerFeature.IgnoreErrorGetter.mask));
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
                mw.visitJumpInsn(153, endSupper_);
            } else {
                mw.visitJumpInsn(Opcodes.GOTO, endSupper_);
            }
            mw.visitLabel(supper_);
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitVarInsn(25, 4);
            mw.visitVarInsn(21, 5);
            mw.visitMethodInsn(Opcodes.INVOKESPECIAL, JavaBeanSerializer, "write", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            mw.visitInsn(177);
            mw.visitLabel(endSupper_);
        } else {
            end = end2;
        }
        if (!context.nonContext) {
            Label endRef_ = new Label();
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(21, 5);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JavaBeanSerializer, "writeReference", "(L" + JSONSerializer + ";Ljava/lang/Object;I)Z");
            mw.visitJumpInsn(153, endRef_);
            mw.visitInsn(177);
            mw.visitLabel(endRef_);
        }
        if (!context.writeDirect) {
            writeAsArrayMethodName = "writeAsArrayNormal";
        } else if (context.nonContext) {
            writeAsArrayMethodName = "writeAsArrayNonContext";
        } else {
            writeAsArrayMethodName = "writeAsArray";
        }
        if ((context.beanInfo.features & SerializerFeature.BeanToArray.mask) == 0) {
            Label endWriteAsArray_ = new Label();
            mw.visitVarInsn(25, context.var(str3));
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.BeanToArray.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
            mw.visitJumpInsn(153, endWriteAsArray_);
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitVarInsn(25, 4);
            mw.visitVarInsn(21, 5);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, context.className, writeAsArrayMethodName, "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            mw.visitInsn(177);
            mw.visitLabel(endWriteAsArray_);
        } else {
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitVarInsn(25, 4);
            mw.visitVarInsn(21, 5);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, context.className, writeAsArrayMethodName, "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            mw.visitInsn(177);
        }
        boolean z = context.nonContext;
        String str4 = Operators.BRACKET_START_STR;
        if (!z) {
            mw.visitVarInsn(25, 1);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "getContext", "()" + SerialContext_desc);
            mw.visitVarInsn(58, context.var("parent"));
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("parent"));
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, 3);
            mw.visitLdcInsn(Integer.valueOf(context.beanInfo.features));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "setContext", str4 + SerialContext_desc + "Ljava/lang/Object;Ljava/lang/Object;I)V");
        }
        boolean writeClasName = (context.beanInfo.features & SerializerFeature.WriteClassName.mask) != 0;
        if (writeClasName || !context.writeDirect) {
            Label end_ = new Label();
            Label else_ = new Label();
            Label writeClass_ = new Label();
            if (!writeClasName) {
                mw.visitVarInsn(25, 1);
                mw.visitVarInsn(25, 4);
                mw.visitVarInsn(25, 2);
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "isWriteClassName", "(Ljava/lang/reflect/Type;Ljava/lang/Object;)Z");
                mw.visitJumpInsn(153, else_);
            }
            mw.visitVarInsn(25, 4);
            mw.visitVarInsn(25, 2);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Object", "getClass", "()Ljava/lang/Class;");
            mw.visitJumpInsn(Opcodes.IF_ACMPEQ, else_);
            mw.visitLabel(writeClass_);
            mw.visitVarInsn(25, context.var(str3));
            mw.visitVarInsn(16, 123);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            if (context.beanInfo.typeKey != null) {
                mw.visitLdcInsn(context.beanInfo.typeKey);
            } else {
                mw.visitInsn(1);
            }
            mw.visitVarInsn(25, 2);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JavaBeanSerializer, "writeClassName", "(L" + JSONSerializer + ";Ljava/lang/String;Ljava/lang/Object;)V");
            mw.visitVarInsn(16, 44);
            mw.visitJumpInsn(Opcodes.GOTO, end_);
            mw.visitLabel(else_);
            mw.visitVarInsn(16, 123);
            mw.visitLabel(end_);
        } else {
            mw.visitVarInsn(16, 123);
        }
        mw.visitVarInsn(54, context.var("seperator"));
        if (!context.writeDirect) {
            _before(mw, context);
        }
        if (!context.writeDirect) {
            mw.visitVarInsn(25, context.var(str3));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isNotWriteDefaultValue", "()Z");
            mw.visitVarInsn(54, context.var("notWriteDefaultValue"));
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 0);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "checkValue", str4 + SerializeFilterable_desc + ")Z");
            mw.visitVarInsn(54, context.var("checkValue"));
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 0);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "hasNameFilters", str4 + SerializeFilterable_desc + ")Z");
            mw.visitVarInsn(54, context.var("hasNameFilters"));
        }
        int i3 = 0;
        while (i3 < size) {
            FieldInfo property2 = fieldInfoArr[i3];
            Class<?> propertyClass2 = property2.fieldClass;
            mw.visitLdcInsn(property2.name);
            mw.visitVarInsn(58, Context.fieldName);
            if (propertyClass2 == Byte.TYPE || propertyClass2 == Short.TYPE) {
                propertyClass = propertyClass2;
                property = property2;
                i = i3;
                str2 = str4;
                str = str3;
            } else if (propertyClass2 == Integer.TYPE) {
                propertyClass = propertyClass2;
                property = property2;
                i = i3;
                str2 = str4;
                str = str3;
            } else {
                if (propertyClass2 == Long.TYPE) {
                    _long(clazz, mw, property2, context);
                    i = i3;
                    str2 = str4;
                    str = str3;
                } else if (propertyClass2 == Float.TYPE) {
                    _float(clazz, mw, property2, context);
                    i = i3;
                    str2 = str4;
                    str = str3;
                } else if (propertyClass2 == Double.TYPE) {
                    _double(clazz, mw, property2, context);
                    i = i3;
                    str2 = str4;
                    str = str3;
                } else if (propertyClass2 == Boolean.TYPE) {
                    i = i3;
                    str2 = str4;
                    str = str3;
                    _int(clazz, mw, property2, context, context.var("boolean"), 'Z');
                } else {
                    i = i3;
                    str2 = str4;
                    str = str3;
                    if (propertyClass2 == Character.TYPE) {
                        _int(clazz, mw, property2, context, context.var("char"), 'C');
                    } else if (propertyClass2 == String.class) {
                        _string(clazz, mw, property2, context);
                    } else if (propertyClass2 == BigDecimal.class) {
                        _decimal(clazz, mw, property2, context);
                    } else if (List.class.isAssignableFrom(propertyClass2)) {
                        _list(clazz, mw, property2, context);
                    } else if (propertyClass2.isEnum()) {
                        _enum(clazz, mw, property2, context);
                    } else {
                        _object(clazz, mw, property2, context);
                    }
                }
                i3 = i + 1;
                fieldInfoArr = getters;
                str4 = str2;
                str3 = str;
            }
            _int(clazz, mw, property, context, context.var(propertyClass.getName()), 'I');
            i3 = i + 1;
            fieldInfoArr = getters;
            str4 = str2;
            str3 = str;
        }
        if (!context.writeDirect) {
            _after(mw, context);
        }
        Label _else = new Label();
        Label _end_if = new Label();
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitIntInsn(16, 123);
        mw.visitJumpInsn(160, _else);
        mw.visitVarInsn(25, context.var(str3));
        mw.visitVarInsn(16, 123);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
        mw.visitLabel(_else);
        mw.visitVarInsn(25, context.var(str3));
        mw.visitVarInsn(16, 125);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
        mw.visitLabel(_end_if);
        mw.visitLabel(end);
        if (!context.nonContext) {
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("parent"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "setContext", str4 + SerialContext_desc + ")V");
        }
    }

    private void _object(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label _end = new Label();
        _nameApply(mw, property, context, _end);
        _get(mw, context, property);
        mw.visitVarInsn(58, context.var("object"));
        _filters(mw, property, context, _end);
        _writeObject(mw, property, context, _end);
        mw.visitLabel(_end);
    }

    private void _enum(Class<?> cls, MethodVisitor mw, FieldInfo fieldInfo, Context context) {
        Label _not_null = new Label();
        Label _end_if = new Label();
        Label _end = new Label();
        _nameApply(mw, fieldInfo, context, _end);
        _get(mw, context, fieldInfo);
        mw.visitTypeInsn(192, "java/lang/Enum");
        mw.visitVarInsn(58, context.var("enum"));
        _filters(mw, fieldInfo, context, _end);
        mw.visitVarInsn(25, context.var("enum"));
        mw.visitJumpInsn(Opcodes.IFNONNULL, _not_null);
        _if_write_null(mw, fieldInfo, context);
        mw.visitJumpInsn(Opcodes.GOTO, _end_if);
        mw.visitLabel(_not_null);
        if (context.writeDirect) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(21, context.var("seperator"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitVarInsn(25, context.var("enum"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Enum", "name", "()Ljava/lang/String;");
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValueStringWithDoubleQuote", "(CLjava/lang/String;Ljava/lang/String;)V");
        } else {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(21, context.var("seperator"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitInsn(3);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldName", "(Ljava/lang/String;Z)V");
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("enum"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldInfo.fieldClass)));
            mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
        }
        _seperator(mw, context);
        mw.visitLabel(_end_if);
        mw.visitLabel(_end);
    }

    private void _int(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context, int var, char type) {
        Label end_ = new Label();
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(54, var);
        _filters(mw, property, context, end_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitVarInsn(21, var);
        String str = SerializeWriter;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "writeFieldValue", "(CLjava/lang/String;" + type + ")V");
        _seperator(mw, context);
        mw.visitLabel(end_);
    }

    private void _long(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label end_ = new Label();
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(55, context.var("long", 2));
        _filters(mw, property, context, end_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitVarInsn(22, context.var("long", 2));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValue", "(CLjava/lang/String;J)V");
        _seperator(mw, context);
        mw.visitLabel(end_);
    }

    private void _float(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label end_ = new Label();
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(56, context.var("float"));
        _filters(mw, property, context, end_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitVarInsn(23, context.var("float"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValue", "(CLjava/lang/String;F)V");
        _seperator(mw, context);
        mw.visitLabel(end_);
    }

    private void _double(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label end_ = new Label();
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(57, context.var("double", 2));
        _filters(mw, property, context, end_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitVarInsn(24, context.var("double", 2));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValue", "(CLjava/lang/String;D)V");
        _seperator(mw, context);
        mw.visitLabel(end_);
    }

    private void _get(MethodVisitor mw, Context context, FieldInfo fieldInfo) {
        Method method = fieldInfo.method;
        if (method != null) {
            mw.visitVarInsn(25, context.var("entity"));
            Class<?> declaringClass = method.getDeclaringClass();
            mw.visitMethodInsn(declaringClass.isInterface() ? Opcodes.INVOKEINTERFACE : Opcodes.INVOKEVIRTUAL, ASMUtils.type(declaringClass), method.getName(), ASMUtils.desc(method));
            if (!method.getReturnType().equals(fieldInfo.fieldClass)) {
                mw.visitTypeInsn(192, ASMUtils.type(fieldInfo.fieldClass));
                return;
            }
            return;
        }
        mw.visitVarInsn(25, context.var("entity"));
        Field field = fieldInfo.field;
        mw.visitFieldInsn(180, ASMUtils.type(fieldInfo.declaringClass), field.getName(), ASMUtils.desc(field.getType()));
        if (!field.getType().equals(fieldInfo.fieldClass)) {
            mw.visitTypeInsn(192, ASMUtils.type(fieldInfo.fieldClass));
        }
    }

    private void _decimal(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label end_ = new Label();
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(58, context.var("decimal"));
        _filters(mw, property, context, end_);
        Label if_ = new Label();
        Label else_ = new Label();
        Label endIf_ = new Label();
        mw.visitLabel(if_);
        mw.visitVarInsn(25, context.var("decimal"));
        mw.visitJumpInsn(Opcodes.IFNONNULL, else_);
        _if_write_null(mw, property, context);
        mw.visitJumpInsn(Opcodes.GOTO, endIf_);
        mw.visitLabel(else_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitVarInsn(25, context.var("decimal"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValue", "(CLjava/lang/String;Ljava/math/BigDecimal;)V");
        _seperator(mw, context);
        mw.visitJumpInsn(Opcodes.GOTO, endIf_);
        mw.visitLabel(endIf_);
        mw.visitLabel(end_);
    }

    private void _string(Class<?> cls, MethodVisitor mw, FieldInfo property, Context context) {
        Label end_ = new Label();
        if (property.name.equals(context.beanInfo.typeKey)) {
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 4);
            mw.visitVarInsn(25, 2);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "isWriteClassName", "(Ljava/lang/reflect/Type;Ljava/lang/Object;)Z");
            mw.visitJumpInsn(154, end_);
        }
        _nameApply(mw, property, context, end_);
        _get(mw, context, property);
        mw.visitVarInsn(58, context.var("string"));
        _filters(mw, property, context, end_);
        Label else_ = new Label();
        Label endIf_ = new Label();
        mw.visitVarInsn(25, context.var("string"));
        mw.visitJumpInsn(Opcodes.IFNONNULL, else_);
        _if_write_null(mw, property, context);
        mw.visitJumpInsn(Opcodes.GOTO, endIf_);
        mw.visitLabel(else_);
        if (AbsoluteConst.XML_TRIM.equals(property.format)) {
            mw.visitVarInsn(25, context.var("string"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/String", AbsoluteConst.XML_TRIM, "()Ljava/lang/String;");
            mw.visitVarInsn(58, context.var("string"));
        }
        if (context.writeDirect) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(21, context.var("seperator"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitVarInsn(25, context.var("string"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValueStringWithDoubleQuoteCheck", "(CLjava/lang/String;Ljava/lang/String;)V");
        } else {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(21, context.var("seperator"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitVarInsn(25, context.var("string"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldValue", "(CLjava/lang/String;Ljava/lang/String;)V");
        }
        _seperator(mw, context);
        mw.visitLabel(endIf_);
        mw.visitLabel(end_);
    }

    private void _list(Class<?> cls, MethodVisitor mw, FieldInfo fieldInfo, Context context) {
        Label _end_if_3;
        int i;
        int i2;
        Label forItemNullEnd_;
        Label for_;
        Label forEnd_;
        Label forItemClassIfElse_;
        String str;
        Label forItemClassIfEnd_;
        String writeMethodName;
        Label forItemClassIfEnd_2;
        String writeMethodName2;
        java.lang.reflect.Type elementType = TypeUtils.getCollectionItemType(fieldInfo.fieldType);
        Class<?> elementClass = null;
        if (elementType instanceof Class) {
            elementClass = (Class) elementType;
        }
        if (elementClass == Object.class || elementClass == Serializable.class) {
            elementClass = null;
        }
        Label end_ = new Label();
        Label else_ = new Label();
        Label endIf_ = new Label();
        _nameApply(mw, fieldInfo, context, end_);
        _get(mw, context, fieldInfo);
        mw.visitTypeInsn(192, "java/util/List");
        mw.visitVarInsn(58, context.var(WXBasicComponentType.LIST));
        _filters(mw, fieldInfo, context, end_);
        mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
        mw.visitJumpInsn(Opcodes.IFNONNULL, else_);
        _if_write_null(mw, fieldInfo, context);
        mw.visitJumpInsn(Opcodes.GOTO, endIf_);
        mw.visitLabel(else_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
        _writeFieldName(mw, context);
        mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
        mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, "java/util/List", AbsoluteConst.JSON_KEY_SIZE, "()I");
        mw.visitVarInsn(54, context.var(AbsoluteConst.JSON_KEY_SIZE));
        Label _else_3 = new Label();
        Label _end_if_32 = new Label();
        mw.visitVarInsn(21, context.var(AbsoluteConst.JSON_KEY_SIZE));
        mw.visitInsn(3);
        mw.visitJumpInsn(160, _else_3);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitLdcInsn("[]");
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(Ljava/lang/String;)V");
        mw.visitJumpInsn(Opcodes.GOTO, _end_if_32);
        mw.visitLabel(_else_3);
        if (!context.nonContext) {
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "setContext", "(Ljava/lang/Object;Ljava/lang/Object;)V");
        }
        if (elementType != String.class || !context.writeDirect) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(16, 91);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
            Label for_2 = new Label();
            Label forFirst_ = new Label();
            Label forEnd_2 = new Label();
            mw.visitInsn(3);
            _end_if_3 = _end_if_32;
            mw.visitVarInsn(54, context.var("i"));
            mw.visitLabel(for_2);
            mw.visitVarInsn(21, context.var("i"));
            mw.visitVarInsn(21, context.var(AbsoluteConst.JSON_KEY_SIZE));
            mw.visitJumpInsn(Opcodes.IF_ICMPGE, forEnd_2);
            mw.visitVarInsn(21, context.var("i"));
            mw.visitJumpInsn(153, forFirst_);
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(16, 44);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
            mw.visitLabel(forFirst_);
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
            mw.visitVarInsn(21, context.var("i"));
            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, "java/util/List", "get", "(I)Ljava/lang/Object;");
            mw.visitVarInsn(58, context.var("list_item"));
            Label forItemNullEnd_2 = new Label();
            Label forItemNullElse_ = new Label();
            mw.visitVarInsn(25, context.var("list_item"));
            mw.visitJumpInsn(Opcodes.IFNONNULL, forItemNullElse_);
            mw.visitVarInsn(25, context.var("out"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeNull", "()V");
            mw.visitJumpInsn(Opcodes.GOTO, forItemNullEnd_2);
            mw.visitLabel(forItemNullElse_);
            Label forItemClassIfEnd_3 = new Label();
            Label forItemClassIfElse_2 = new Label();
            if (elementClass == null || !Modifier.isPublic(elementClass.getModifiers())) {
                for_ = for_2;
                forItemClassIfEnd_ = forItemClassIfEnd_3;
                forItemNullEnd_ = forItemNullEnd_2;
                forItemClassIfElse_ = forItemClassIfElse_2;
                forEnd_ = forEnd_2;
                str = "write";
            } else {
                forEnd_ = forEnd_2;
                mw.visitVarInsn(25, context.var("list_item"));
                for_ = for_2;
                forItemNullEnd_ = forItemNullEnd_2;
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Object", "getClass", "()Ljava/lang/Class;");
                mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                mw.visitJumpInsn(Opcodes.IF_ACMPNE, forItemClassIfElse_2);
                _getListFieldItemSer(context, mw, fieldInfo, elementClass);
                mw.visitVarInsn(58, context.var("list_item_desc"));
                Label instanceOfElse_ = new Label();
                Label instanceOfEnd_ = new Label();
                if (context.writeDirect) {
                    if (!context.nonContext || !context.writeDirect) {
                        writeMethodName2 = "write";
                    } else {
                        writeMethodName2 = "writeDirectNonContext";
                    }
                    forItemClassIfElse_ = forItemClassIfElse_2;
                    mw.visitVarInsn(25, context.var("list_item_desc"));
                    mw.visitTypeInsn(Opcodes.INSTANCEOF, JavaBeanSerializer);
                    mw.visitJumpInsn(153, instanceOfElse_);
                    mw.visitVarInsn(25, context.var("list_item_desc"));
                    mw.visitTypeInsn(192, JavaBeanSerializer);
                    mw.visitVarInsn(25, 1);
                    mw.visitVarInsn(25, context.var("list_item"));
                    if (context.nonContext) {
                        mw.visitInsn(1);
                    } else {
                        mw.visitVarInsn(21, context.var("i"));
                        mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                    }
                    mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                    mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                    String str2 = JavaBeanSerializer;
                    StringBuilder sb = new StringBuilder();
                    forItemClassIfEnd_2 = forItemClassIfEnd_3;
                    sb.append("(L");
                    sb.append(JSONSerializer);
                    sb.append(";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                    writeMethodName = "write";
                    mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, writeMethodName2, sb.toString());
                    mw.visitJumpInsn(Opcodes.GOTO, instanceOfEnd_);
                    mw.visitLabel(instanceOfElse_);
                } else {
                    forItemClassIfEnd_2 = forItemClassIfEnd_3;
                    forItemClassIfElse_ = forItemClassIfElse_2;
                    writeMethodName = "write";
                }
                mw.visitVarInsn(25, context.var("list_item_desc"));
                mw.visitVarInsn(25, 1);
                mw.visitVarInsn(25, context.var("list_item"));
                if (context.nonContext) {
                    mw.visitInsn(1);
                } else {
                    mw.visitVarInsn(21, context.var("i"));
                    mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
                }
                mw.visitLdcInsn(Type.getType(ASMUtils.desc(elementClass)));
                mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                String str3 = ObjectSerializer;
                str = writeMethodName;
                mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, str3, str, "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
                mw.visitLabel(instanceOfEnd_);
                forItemClassIfEnd_ = forItemClassIfEnd_2;
                mw.visitJumpInsn(Opcodes.GOTO, forItemClassIfEnd_);
            }
            mw.visitLabel(forItemClassIfElse_);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("list_item"));
            if (context.nonContext) {
                mw.visitInsn(1);
            } else {
                mw.visitVarInsn(21, context.var("i"));
                mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
            }
            if (elementClass == null || !Modifier.isPublic(elementClass.getModifiers())) {
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;)V");
            } else {
                mw.visitLdcInsn(Type.getType(ASMUtils.desc((Class) elementType)));
                mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            }
            mw.visitLabel(forItemClassIfEnd_);
            mw.visitLabel(forItemNullEnd_);
            mw.visitIincInsn(context.var("i"), 1);
            mw.visitJumpInsn(Opcodes.GOTO, for_);
            mw.visitLabel(forEnd_);
            i2 = 25;
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(16, 93);
            String str4 = SerializeWriter;
            i = Opcodes.INVOKEVIRTUAL;
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str4, str, "(I)V");
        } else {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(Ljava/util/List;)V");
            _end_if_3 = _end_if_32;
            i2 = 25;
            i = Opcodes.INVOKEVIRTUAL;
        }
        mw.visitVarInsn(i2, 1);
        mw.visitMethodInsn(i, JSONSerializer, "popContext", "()V");
        mw.visitLabel(_end_if_3);
        _seperator(mw, context);
        mw.visitLabel(endIf_);
        mw.visitLabel(end_);
    }

    private void _filters(MethodVisitor mw, FieldInfo property, Context context, Label _end) {
        if (property.fieldTransient) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.SkipTransientField.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
            mw.visitJumpInsn(154, _end);
        }
        _notWriteDefault(mw, property, context, _end);
        if (!context.writeDirect) {
            _apply(mw, property, context);
            mw.visitJumpInsn(153, _end);
            _processKey(mw, property, context);
            _processValue(mw, property, context, _end);
        }
    }

    private void _nameApply(MethodVisitor mw, FieldInfo property, Context context, Label _end) {
        if (!context.writeDirect) {
            mw.visitVarInsn(25, 0);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, 2);
            mw.visitVarInsn(25, Context.fieldName);
            String str = JavaBeanSerializer;
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "applyName", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/String;)Z");
            mw.visitJumpInsn(153, _end);
            _labelApply(mw, property, context, _end);
        }
        if (property.field == null) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.IgnoreNonFieldGetter.mask));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
            mw.visitJumpInsn(154, _end);
        }
    }

    private void _labelApply(MethodVisitor mw, FieldInfo property, Context context, Label _end) {
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(property.label);
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "applyLabel", "(L" + JSONSerializer + ";Ljava/lang/String;)Z");
        mw.visitJumpInsn(153, _end);
    }

    private void _writeObject(MethodVisitor mw, FieldInfo fieldInfo, Context context, Label _end) {
        Label classIfElse_;
        String format;
        Label classIfEnd_;
        String writeMethodName;
        String format2 = fieldInfo.getFormat();
        Class<?> fieldClass = fieldInfo.fieldClass;
        Label notNull_ = new Label();
        if (context.writeDirect) {
            mw.visitVarInsn(25, context.var("object"));
        } else {
            mw.visitVarInsn(25, Context.processValue);
        }
        mw.visitInsn(89);
        mw.visitVarInsn(58, context.var("object"));
        mw.visitJumpInsn(Opcodes.IFNONNULL, notNull_);
        _if_write_null(mw, fieldInfo, context);
        mw.visitJumpInsn(Opcodes.GOTO, _end);
        mw.visitLabel(notNull_);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
        _writeFieldName(mw, context);
        Label classIfEnd_2 = new Label();
        Label classIfElse_2 = new Label();
        if (!Modifier.isPublic(fieldClass.getModifiers())) {
            format = format2;
            classIfEnd_ = classIfEnd_2;
            classIfElse_ = classIfElse_2;
        } else if (!ParserConfig.isPrimitive2(fieldClass)) {
            mw.visitVarInsn(25, context.var("object"));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, "java/lang/Object", "getClass", "()Ljava/lang/Class;");
            mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldClass)));
            mw.visitJumpInsn(Opcodes.IF_ACMPNE, classIfElse_2);
            _getFieldSer(context, mw, fieldInfo);
            mw.visitVarInsn(58, context.var("fied_ser"));
            Label instanceOfElse_ = new Label();
            Label instanceOfEnd_ = new Label();
            mw.visitVarInsn(25, context.var("fied_ser"));
            mw.visitTypeInsn(Opcodes.INSTANCEOF, JavaBeanSerializer);
            mw.visitJumpInsn(153, instanceOfElse_);
            boolean disableCircularReferenceDetect = (fieldInfo.serialzeFeatures & SerializerFeature.DisableCircularReferenceDetect.mask) != 0;
            boolean fieldBeanToArray = (SerializerFeature.BeanToArray.mask & fieldInfo.serialzeFeatures) != 0;
            if (disableCircularReferenceDetect || (context.nonContext && context.writeDirect)) {
                writeMethodName = fieldBeanToArray ? "writeAsArrayNonContext" : "writeDirectNonContext";
            } else if (fieldBeanToArray) {
                writeMethodName = "writeAsArray";
            } else {
                writeMethodName = "write";
            }
            mw.visitVarInsn(25, context.var("fied_ser"));
            mw.visitTypeInsn(192, JavaBeanSerializer);
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("object"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitVarInsn(25, 0);
            String str = context.className;
            StringBuilder sb = new StringBuilder();
            format = format2;
            sb.append(fieldInfo.name);
            sb.append("_asm_fieldType");
            mw.visitFieldInsn(180, str, sb.toString(), "Ljava/lang/reflect/Type;");
            mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
            String str2 = JavaBeanSerializer;
            StringBuilder sb2 = new StringBuilder();
            sb2.append("(L");
            classIfElse_ = classIfElse_2;
            sb2.append(JSONSerializer);
            sb2.append(";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, writeMethodName, sb2.toString());
            mw.visitJumpInsn(Opcodes.GOTO, instanceOfEnd_);
            mw.visitLabel(instanceOfElse_);
            mw.visitVarInsn(25, context.var("fied_ser"));
            mw.visitVarInsn(25, 1);
            mw.visitVarInsn(25, context.var("object"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitVarInsn(25, 0);
            String str3 = context.className;
            mw.visitFieldInsn(180, str3, fieldInfo.name + "_asm_fieldType", "Ljava/lang/reflect/Type;");
            mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
            String str4 = ObjectSerializer;
            mw.visitMethodInsn(Opcodes.INVOKEINTERFACE, str4, "write", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            mw.visitLabel(instanceOfEnd_);
            classIfEnd_ = classIfEnd_2;
            mw.visitJumpInsn(Opcodes.GOTO, classIfEnd_);
        } else {
            format = format2;
            classIfEnd_ = classIfEnd_2;
            classIfElse_ = classIfElse_2;
        }
        mw.visitLabel(classIfElse_);
        mw.visitVarInsn(25, 1);
        if (context.writeDirect) {
            mw.visitVarInsn(25, context.var("object"));
        } else {
            mw.visitVarInsn(25, Context.processValue);
        }
        if (format != null) {
            mw.visitLdcInsn(format);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFormat", "(Ljava/lang/Object;Ljava/lang/String;)V");
        } else {
            mw.visitVarInsn(25, Context.fieldName);
            if (!(fieldInfo.fieldType instanceof Class) || !((Class) fieldInfo.fieldType).isPrimitive()) {
                if (fieldInfo.fieldClass == String.class) {
                    mw.visitLdcInsn(Type.getType(ASMUtils.desc(String.class)));
                } else {
                    mw.visitVarInsn(25, 0);
                    String str5 = context.className;
                    mw.visitFieldInsn(180, str5, fieldInfo.name + "_asm_fieldType", "Ljava/lang/reflect/Type;");
                }
                mw.visitLdcInsn(Integer.valueOf(fieldInfo.serialzeFeatures));
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;Ljava/lang/reflect/Type;I)V");
            } else {
                mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, JSONSerializer, "writeWithFieldName", "(Ljava/lang/Object;Ljava/lang/Object;)V");
            }
        }
        mw.visitLabel(classIfEnd_);
        _seperator(mw, context);
    }

    private void _before(MethodVisitor mw, Context context) {
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(21, context.var("seperator"));
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "writeBefore", "(L" + JSONSerializer + ";Ljava/lang/Object;C)C");
        mw.visitVarInsn(54, context.var("seperator"));
    }

    private void _after(MethodVisitor mw, Context context) {
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(21, context.var("seperator"));
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "writeAfter", "(L" + JSONSerializer + ";Ljava/lang/Object;C)C");
        mw.visitVarInsn(54, context.var("seperator"));
    }

    private void _notWriteDefault(MethodVisitor mw, FieldInfo property, Context context, Label _end) {
        if (!context.writeDirect) {
            Label elseLabel = new Label();
            mw.visitVarInsn(21, context.var("notWriteDefaultValue"));
            mw.visitJumpInsn(153, elseLabel);
            Class<?> propertyClass = property.fieldClass;
            if (propertyClass == Boolean.TYPE) {
                mw.visitVarInsn(21, context.var("boolean"));
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Byte.TYPE) {
                mw.visitVarInsn(21, context.var("byte"));
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Short.TYPE) {
                mw.visitVarInsn(21, context.var("short"));
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Integer.TYPE) {
                mw.visitVarInsn(21, context.var("int"));
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Long.TYPE) {
                mw.visitVarInsn(22, context.var("long"));
                mw.visitInsn(9);
                mw.visitInsn(Opcodes.LCMP);
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Float.TYPE) {
                mw.visitVarInsn(23, context.var("float"));
                mw.visitInsn(11);
                mw.visitInsn(Opcodes.FCMPL);
                mw.visitJumpInsn(153, _end);
            } else if (propertyClass == Double.TYPE) {
                mw.visitVarInsn(24, context.var("double"));
                mw.visitInsn(14);
                mw.visitInsn(151);
                mw.visitJumpInsn(153, _end);
            }
            mw.visitLabel(elseLabel);
        }
    }

    private void _apply(MethodVisitor mw, FieldInfo property, Context context) {
        Class<?> propertyClass = property.fieldClass;
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(25, Context.fieldName);
        if (propertyClass == Byte.TYPE) {
            mw.visitVarInsn(21, context.var("byte"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Byte", "valueOf", "(B)Ljava/lang/Byte;");
        } else if (propertyClass == Short.TYPE) {
            mw.visitVarInsn(21, context.var("short"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Short", "valueOf", "(S)Ljava/lang/Short;");
        } else if (propertyClass == Integer.TYPE) {
            mw.visitVarInsn(21, context.var("int"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
        } else if (propertyClass == Character.TYPE) {
            mw.visitVarInsn(21, context.var("char"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Character", "valueOf", "(C)Ljava/lang/Character;");
        } else if (propertyClass == Long.TYPE) {
            mw.visitVarInsn(22, context.var("long", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Long", "valueOf", "(J)Ljava/lang/Long;");
        } else if (propertyClass == Float.TYPE) {
            mw.visitVarInsn(23, context.var("float"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Float", "valueOf", "(F)Ljava/lang/Float;");
        } else if (propertyClass == Double.TYPE) {
            mw.visitVarInsn(24, context.var("double", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Double", "valueOf", "(D)Ljava/lang/Double;");
        } else if (propertyClass == Boolean.TYPE) {
            mw.visitVarInsn(21, context.var("boolean"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Boolean", "valueOf", "(Z)Ljava/lang/Boolean;");
        } else if (propertyClass == BigDecimal.class) {
            mw.visitVarInsn(25, context.var("decimal"));
        } else if (propertyClass == String.class) {
            mw.visitVarInsn(25, context.var("string"));
        } else if (propertyClass.isEnum()) {
            mw.visitVarInsn(25, context.var("enum"));
        } else if (List.class.isAssignableFrom(propertyClass)) {
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
        } else {
            mw.visitVarInsn(25, context.var("object"));
        }
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "apply", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/String;Ljava/lang/Object;)Z");
    }

    private void _processValue(MethodVisitor mw, FieldInfo fieldInfo, Context context, Label _end) {
        Label processKeyElse_ = new Label();
        Class<?> fieldClass = fieldInfo.fieldClass;
        if (fieldClass.isPrimitive()) {
            Label checkValueEnd_ = new Label();
            mw.visitVarInsn(21, context.var("checkValue"));
            mw.visitJumpInsn(154, checkValueEnd_);
            mw.visitInsn(1);
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(58, Context.processValue);
            mw.visitJumpInsn(Opcodes.GOTO, processKeyElse_);
            mw.visitLabel(checkValueEnd_);
        }
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 0);
        mw.visitLdcInsn(Integer.valueOf(context.getFieldOrinal(fieldInfo.name)));
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "getBeanContext", "(I)" + ASMUtils.desc(BeanContext.class));
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(25, Context.fieldName);
        if (fieldClass == Byte.TYPE) {
            mw.visitVarInsn(21, context.var("byte"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Byte", "valueOf", "(B)Ljava/lang/Byte;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Short.TYPE) {
            mw.visitVarInsn(21, context.var("short"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Short", "valueOf", "(S)Ljava/lang/Short;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Integer.TYPE) {
            mw.visitVarInsn(21, context.var("int"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Character.TYPE) {
            mw.visitVarInsn(21, context.var("char"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Character", "valueOf", "(C)Ljava/lang/Character;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Long.TYPE) {
            mw.visitVarInsn(22, context.var("long", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Long", "valueOf", "(J)Ljava/lang/Long;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Float.TYPE) {
            mw.visitVarInsn(23, context.var("float"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Float", "valueOf", "(F)Ljava/lang/Float;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Double.TYPE) {
            mw.visitVarInsn(24, context.var("double", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Double", "valueOf", "(D)Ljava/lang/Double;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == Boolean.TYPE) {
            mw.visitVarInsn(21, context.var("boolean"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Boolean", "valueOf", "(Z)Ljava/lang/Boolean;");
            mw.visitInsn(89);
            mw.visitVarInsn(58, Context.original);
        } else if (fieldClass == BigDecimal.class) {
            mw.visitVarInsn(25, context.var("decimal"));
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(25, Context.original);
        } else if (fieldClass == String.class) {
            mw.visitVarInsn(25, context.var("string"));
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(25, Context.original);
        } else if (fieldClass.isEnum()) {
            mw.visitVarInsn(25, context.var("enum"));
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(25, Context.original);
        } else if (List.class.isAssignableFrom(fieldClass)) {
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(25, Context.original);
        } else {
            mw.visitVarInsn(25, context.var("object"));
            mw.visitVarInsn(58, Context.original);
            mw.visitVarInsn(25, Context.original);
        }
        String str2 = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, "processValue", "(L" + JSONSerializer + i.b + ASMUtils.desc(BeanContext.class) + "Ljava/lang/Object;Ljava/lang/String;" + "Ljava/lang/Object;" + ")Ljava/lang/Object;");
        mw.visitVarInsn(58, Context.processValue);
        mw.visitVarInsn(25, Context.original);
        mw.visitVarInsn(25, Context.processValue);
        mw.visitJumpInsn(Opcodes.IF_ACMPEQ, processKeyElse_);
        _writeObject(mw, fieldInfo, context, _end);
        mw.visitJumpInsn(Opcodes.GOTO, _end);
        mw.visitLabel(processKeyElse_);
    }

    private void _processKey(MethodVisitor mw, FieldInfo property, Context context) {
        Label _else_processKey = new Label();
        mw.visitVarInsn(21, context.var("hasNameFilters"));
        mw.visitJumpInsn(153, _else_processKey);
        Class<?> propertyClass = property.fieldClass;
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitVarInsn(25, 2);
        mw.visitVarInsn(25, Context.fieldName);
        if (propertyClass == Byte.TYPE) {
            mw.visitVarInsn(21, context.var("byte"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Byte", "valueOf", "(B)Ljava/lang/Byte;");
        } else if (propertyClass == Short.TYPE) {
            mw.visitVarInsn(21, context.var("short"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Short", "valueOf", "(S)Ljava/lang/Short;");
        } else if (propertyClass == Integer.TYPE) {
            mw.visitVarInsn(21, context.var("int"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Integer", "valueOf", "(I)Ljava/lang/Integer;");
        } else if (propertyClass == Character.TYPE) {
            mw.visitVarInsn(21, context.var("char"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Character", "valueOf", "(C)Ljava/lang/Character;");
        } else if (propertyClass == Long.TYPE) {
            mw.visitVarInsn(22, context.var("long", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Long", "valueOf", "(J)Ljava/lang/Long;");
        } else if (propertyClass == Float.TYPE) {
            mw.visitVarInsn(23, context.var("float"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Float", "valueOf", "(F)Ljava/lang/Float;");
        } else if (propertyClass == Double.TYPE) {
            mw.visitVarInsn(24, context.var("double", 2));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Double", "valueOf", "(D)Ljava/lang/Double;");
        } else if (propertyClass == Boolean.TYPE) {
            mw.visitVarInsn(21, context.var("boolean"));
            mw.visitMethodInsn(Opcodes.INVOKESTATIC, "java/lang/Boolean", "valueOf", "(Z)Ljava/lang/Boolean;");
        } else if (propertyClass == BigDecimal.class) {
            mw.visitVarInsn(25, context.var("decimal"));
        } else if (propertyClass == String.class) {
            mw.visitVarInsn(25, context.var("string"));
        } else if (propertyClass.isEnum()) {
            mw.visitVarInsn(25, context.var("enum"));
        } else if (List.class.isAssignableFrom(propertyClass)) {
            mw.visitVarInsn(25, context.var(WXBasicComponentType.LIST));
        } else {
            mw.visitVarInsn(25, context.var("object"));
        }
        String str = JavaBeanSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str, "processKey", "(L" + JSONSerializer + ";Ljava/lang/Object;Ljava/lang/String;Ljava/lang/Object;)Ljava/lang/String;");
        mw.visitVarInsn(58, Context.fieldName);
        mw.visitLabel(_else_processKey);
    }

    private void _if_write_null(MethodVisitor mw, FieldInfo fieldInfo, Context context) {
        int writeNullFeatures;
        Class<?> propertyClass = fieldInfo.fieldClass;
        Label _if = new Label();
        Label _else = new Label();
        Label _write_null = new Label();
        Label _end_if = new Label();
        mw.visitLabel(_if);
        JSONField annotation = fieldInfo.getAnnotation();
        int features = 0;
        if (annotation != null) {
            features = SerializerFeature.of(annotation.serialzeFeatures());
        }
        JSONType jsonType = context.beanInfo.jsonType;
        if (jsonType != null) {
            features |= SerializerFeature.of(jsonType.serialzeFeatures());
        }
        if (propertyClass == String.class) {
            writeNullFeatures = SerializerFeature.WriteMapNullValue.getMask() | SerializerFeature.WriteNullStringAsEmpty.getMask();
        } else if (Number.class.isAssignableFrom(propertyClass)) {
            writeNullFeatures = SerializerFeature.WriteMapNullValue.getMask() | SerializerFeature.WriteNullNumberAsZero.getMask();
        } else if (Collection.class.isAssignableFrom(propertyClass)) {
            writeNullFeatures = SerializerFeature.WriteMapNullValue.getMask() | SerializerFeature.WriteNullListAsEmpty.getMask();
        } else if (Boolean.class == propertyClass) {
            writeNullFeatures = SerializerFeature.WriteMapNullValue.getMask() | SerializerFeature.WriteNullBooleanAsFalse.getMask();
        } else {
            writeNullFeatures = SerializerFeature.WRITE_MAP_NULL_FEATURES;
        }
        if ((features & writeNullFeatures) == 0) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitLdcInsn(Integer.valueOf(writeNullFeatures));
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "isEnabled", "(I)Z");
            mw.visitJumpInsn(153, _else);
        }
        mw.visitLabel(_write_null);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(21, context.var("seperator"));
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "write", "(I)V");
        _writeFieldName(mw, context);
        mw.visitVarInsn(25, context.var("out"));
        mw.visitLdcInsn(Integer.valueOf(features));
        if (propertyClass == String.class || propertyClass == Character.class) {
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.WriteNullStringAsEmpty.mask));
        } else if (Number.class.isAssignableFrom(propertyClass)) {
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.WriteNullNumberAsZero.mask));
        } else if (propertyClass == Boolean.class) {
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.WriteNullBooleanAsFalse.mask));
        } else if (Collection.class.isAssignableFrom(propertyClass) || propertyClass.isArray()) {
            mw.visitLdcInsn(Integer.valueOf(SerializerFeature.WriteNullListAsEmpty.mask));
        } else {
            mw.visitLdcInsn(0);
        }
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeNull", "(II)V");
        _seperator(mw, context);
        mw.visitJumpInsn(Opcodes.GOTO, _end_if);
        mw.visitLabel(_else);
        mw.visitLabel(_end_if);
    }

    private void _writeFieldName(MethodVisitor mw, Context context) {
        if (context.writeDirect) {
            mw.visitVarInsn(25, context.var("out"));
            mw.visitVarInsn(25, Context.fieldName);
            mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldNameDirect", "(Ljava/lang/String;)V");
            return;
        }
        mw.visitVarInsn(25, context.var("out"));
        mw.visitVarInsn(25, Context.fieldName);
        mw.visitInsn(3);
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, SerializeWriter, "writeFieldName", "(Ljava/lang/String;Z)V");
    }

    private void _seperator(MethodVisitor mw, Context context) {
        mw.visitVarInsn(16, 44);
        mw.visitVarInsn(54, context.var("seperator"));
    }

    private void _getListFieldItemSer(Context context, MethodVisitor mw, FieldInfo fieldInfo, Class<?> itemType) {
        Label notNull_ = new Label();
        mw.visitVarInsn(25, 0);
        String str = context.className;
        mw.visitFieldInsn(180, str, fieldInfo.name + "_asm_list_item_ser_", ObjectSerializer_desc);
        mw.visitJumpInsn(Opcodes.IFNONNULL, notNull_);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(Type.getType(ASMUtils.desc(itemType)));
        String str2 = JSONSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, "getObjectWriter", "(Ljava/lang/Class;)" + ObjectSerializer_desc);
        String str3 = context.className;
        mw.visitFieldInsn(Opcodes.PUTFIELD, str3, fieldInfo.name + "_asm_list_item_ser_", ObjectSerializer_desc);
        mw.visitLabel(notNull_);
        mw.visitVarInsn(25, 0);
        String str4 = context.className;
        mw.visitFieldInsn(180, str4, fieldInfo.name + "_asm_list_item_ser_", ObjectSerializer_desc);
    }

    private void _getFieldSer(Context context, MethodVisitor mw, FieldInfo fieldInfo) {
        Label notNull_ = new Label();
        mw.visitVarInsn(25, 0);
        String str = context.className;
        mw.visitFieldInsn(180, str, fieldInfo.name + "_asm_ser_", ObjectSerializer_desc);
        mw.visitJumpInsn(Opcodes.IFNONNULL, notNull_);
        mw.visitVarInsn(25, 0);
        mw.visitVarInsn(25, 1);
        mw.visitLdcInsn(Type.getType(ASMUtils.desc(fieldInfo.fieldClass)));
        String str2 = JSONSerializer;
        mw.visitMethodInsn(Opcodes.INVOKEVIRTUAL, str2, "getObjectWriter", "(Ljava/lang/Class;)" + ObjectSerializer_desc);
        String str3 = context.className;
        mw.visitFieldInsn(Opcodes.PUTFIELD, str3, fieldInfo.name + "_asm_ser_", ObjectSerializer_desc);
        mw.visitLabel(notNull_);
        mw.visitVarInsn(25, 0);
        String str4 = context.className;
        mw.visitFieldInsn(180, str4, fieldInfo.name + "_asm_ser_", ObjectSerializer_desc);
    }
}
