package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.weex_amap.adapter.Constant;
import java.awt.Color;
import java.awt.Font;
import java.awt.Point;
import java.awt.Rectangle;
import java.io.IOException;
import java.lang.reflect.Type;

public class AwtCodec implements ObjectSerializer, ObjectDeserializer {
    public static final AwtCodec instance = new AwtCodec();

    public static boolean support(Class<?> clazz) {
        return clazz == Point.class || clazz == Rectangle.class || clazz == Font.class || clazz == Color.class;
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        SerializeWriter out = serializer.out;
        if (object == null) {
            out.writeNull();
            return;
        }
        if (object instanceof Point) {
            Point font = (Point) object;
            out.writeFieldValue(writeClassName(out, Point.class, Operators.BLOCK_START), Constants.Name.X, font.x);
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, Constants.Name.Y, font.y);
        } else if (object instanceof Font) {
            Font font2 = (Font) object;
            out.writeFieldValue(writeClassName(out, Font.class, Operators.BLOCK_START), "name", font2.getName());
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, "style", font2.getStyle());
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, AbsoluteConst.JSON_KEY_SIZE, font2.getSize());
        } else if (object instanceof Rectangle) {
            Rectangle rectangle = (Rectangle) object;
            out.writeFieldValue(writeClassName(out, Rectangle.class, Operators.BLOCK_START), Constants.Name.X, rectangle.x);
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, Constants.Name.Y, rectangle.y);
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, "width", rectangle.width);
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, "height", rectangle.height);
        } else if (object instanceof Color) {
            Color color = (Color) object;
            out.writeFieldValue(writeClassName(out, Color.class, Operators.BLOCK_START), "r", color.getRed());
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, "g", color.getGreen());
            out.writeFieldValue(Operators.ARRAY_SEPRATOR, "b", color.getBlue());
            if (color.getAlpha() > 0) {
                out.writeFieldValue(Operators.ARRAY_SEPRATOR, Constant.JSONKEY.ALPHE, color.getAlpha());
            }
        } else {
            throw new JSONException("not support awt class : " + object.getClass().getName());
        }
        out.write(125);
    }

    /* access modifiers changed from: protected */
    public char writeClassName(SerializeWriter out, Class<?> clazz, char sep) {
        if (!out.isEnabled(SerializerFeature.WriteClassName)) {
            return sep;
        }
        out.write(123);
        out.writeFieldName(JSON.DEFAULT_TYPE_KEY);
        out.writeString(clazz.getName());
        return Operators.ARRAY_SEPRATOR;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
        T obj;
        JSONLexer lexer = parser.lexer;
        if (lexer.token() == 8) {
            lexer.nextToken(16);
            return null;
        } else if (lexer.token() == 12 || lexer.token() == 16) {
            lexer.nextToken();
            if (type == Point.class) {
                obj = (T) parsePoint(parser, fieldName);
            } else if (type == Rectangle.class) {
                obj = (T) parseRectangle(parser);
            } else if (type == Color.class) {
                obj = (T) parseColor(parser);
            } else if (type == Font.class) {
                obj = (T) parseFont(parser);
            } else {
                throw new JSONException("not support awt class : " + type);
            }
            ParseContext context = parser.getContext();
            parser.setContext(obj, fieldName);
            parser.setContext(context);
            return obj;
        } else {
            throw new JSONException("syntax error");
        }
    }

    /* access modifiers changed from: protected */
    public Font parseFont(DefaultJSONParser parser) {
        JSONLexer lexer = parser.lexer;
        int size = 0;
        int style = 0;
        String name = null;
        while (lexer.token() != 13) {
            if (lexer.token() == 4) {
                String key = lexer.stringVal();
                lexer.nextTokenWithColon(2);
                if (key.equalsIgnoreCase("name")) {
                    if (lexer.token() == 4) {
                        name = lexer.stringVal();
                        lexer.nextToken();
                    } else {
                        throw new JSONException("syntax error");
                    }
                } else if (key.equalsIgnoreCase("style")) {
                    if (lexer.token() == 2) {
                        style = lexer.intValue();
                        lexer.nextToken();
                    } else {
                        throw new JSONException("syntax error");
                    }
                } else if (!key.equalsIgnoreCase(AbsoluteConst.JSON_KEY_SIZE)) {
                    throw new JSONException("syntax error, " + key);
                } else if (lexer.token() == 2) {
                    size = lexer.intValue();
                    lexer.nextToken();
                } else {
                    throw new JSONException("syntax error");
                }
                if (lexer.token() == 16) {
                    lexer.nextToken(4);
                }
            } else {
                throw new JSONException("syntax error");
            }
        }
        lexer.nextToken();
        return new Font(name, style, size);
    }

    /* access modifiers changed from: protected */
    public Color parseColor(DefaultJSONParser parser) {
        JSONLexer lexer = parser.lexer;
        int r = 0;
        int g = 0;
        int b = 0;
        int alpha = 0;
        while (lexer.token() != 13) {
            if (lexer.token() == 4) {
                String key = lexer.stringVal();
                lexer.nextTokenWithColon(2);
                if (lexer.token() == 2) {
                    int val = lexer.intValue();
                    lexer.nextToken();
                    if (key.equalsIgnoreCase("r")) {
                        r = val;
                    } else if (key.equalsIgnoreCase("g")) {
                        g = val;
                    } else if (key.equalsIgnoreCase("b")) {
                        b = val;
                    } else if (key.equalsIgnoreCase(Constant.JSONKEY.ALPHE)) {
                        alpha = val;
                    } else {
                        throw new JSONException("syntax error, " + key);
                    }
                    if (lexer.token() == 16) {
                        lexer.nextToken(4);
                    }
                } else {
                    throw new JSONException("syntax error");
                }
            } else {
                throw new JSONException("syntax error");
            }
        }
        lexer.nextToken();
        return new Color(r, g, b, alpha);
    }

    /* access modifiers changed from: protected */
    public Rectangle parseRectangle(DefaultJSONParser parser) {
        int val;
        JSONLexer lexer = parser.lexer;
        int x = 0;
        int y = 0;
        int width = 0;
        int height = 0;
        while (lexer.token() != 13) {
            if (lexer.token() == 4) {
                String key = lexer.stringVal();
                lexer.nextTokenWithColon(2);
                int token = lexer.token();
                if (token == 2) {
                    val = lexer.intValue();
                    lexer.nextToken();
                } else if (token == 3) {
                    val = (int) lexer.floatValue();
                    lexer.nextToken();
                } else {
                    throw new JSONException("syntax error");
                }
                if (key.equalsIgnoreCase(Constants.Name.X)) {
                    x = val;
                } else if (key.equalsIgnoreCase(Constants.Name.Y)) {
                    y = val;
                } else if (key.equalsIgnoreCase("width")) {
                    width = val;
                } else if (key.equalsIgnoreCase("height")) {
                    height = val;
                } else {
                    throw new JSONException("syntax error, " + key);
                }
                if (lexer.token() == 16) {
                    lexer.nextToken(4);
                }
            } else {
                throw new JSONException("syntax error");
            }
        }
        lexer.nextToken();
        return new Rectangle(x, y, width, height);
    }

    /* access modifiers changed from: protected */
    public Point parsePoint(DefaultJSONParser parser, Object fieldName) {
        int val;
        JSONLexer lexer = parser.lexer;
        int x = 0;
        int y = 0;
        while (lexer.token() != 13) {
            if (lexer.token() == 4) {
                String key = lexer.stringVal();
                if (JSON.DEFAULT_TYPE_KEY.equals(key)) {
                    parser.acceptType("java.awt.Point");
                } else if ("$ref".equals(key)) {
                    return (Point) parseRef(parser, fieldName);
                } else {
                    lexer.nextTokenWithColon(2);
                    int token = lexer.token();
                    if (token == 2) {
                        val = lexer.intValue();
                        lexer.nextToken();
                    } else if (token == 3) {
                        val = (int) lexer.floatValue();
                        lexer.nextToken();
                    } else {
                        throw new JSONException("syntax error : " + lexer.tokenName());
                    }
                    if (key.equalsIgnoreCase(Constants.Name.X)) {
                        x = val;
                    } else if (key.equalsIgnoreCase(Constants.Name.Y)) {
                        y = val;
                    } else {
                        throw new JSONException("syntax error, " + key);
                    }
                    if (lexer.token() == 16) {
                        lexer.nextToken(4);
                    }
                }
            } else {
                throw new JSONException("syntax error");
            }
        }
        lexer.nextToken();
        return new Point(x, y);
    }

    private Object parseRef(DefaultJSONParser parser, Object fieldName) {
        JSONLexer lexer = parser.getLexer();
        lexer.nextTokenWithColon(4);
        String ref = lexer.stringVal();
        parser.setContext(parser.getContext(), fieldName);
        parser.addResolveTask(new DefaultJSONParser.ResolveTask(parser.getContext(), ref));
        parser.popContext();
        parser.setResolveStatus(1);
        lexer.nextToken(13);
        parser.accept(13);
        return null;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }
}
