package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.HashSet;
import java.util.TreeSet;

public class CollectionCodec implements ObjectSerializer, ObjectDeserializer {
    public static final CollectionCodec instance = new CollectionCodec();

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        SerializeWriter out = serializer.out;
        if (object == null) {
            out.writeNull(SerializerFeature.WriteNullListAsEmpty);
            return;
        }
        Type elementType = (out.isEnabled(SerializerFeature.WriteClassName) || SerializerFeature.isEnabled(features, SerializerFeature.WriteClassName)) ? TypeUtils.getCollectionItemType(fieldType) : null;
        Collection<?> collection = (Collection) object;
        SerialContext context = serializer.context;
        serializer.setContext(context, object, fieldName, 0);
        if (out.isEnabled(SerializerFeature.WriteClassName)) {
            if (HashSet.class.isAssignableFrom(collection.getClass())) {
                out.append((CharSequence) "Set");
            } else if (TreeSet.class == collection.getClass()) {
                out.append((CharSequence) "TreeSet");
            }
        }
        int i = 0;
        try {
            out.append(Operators.ARRAY_START);
            for (Object item : collection) {
                int i2 = i + 1;
                if (i != 0) {
                    out.append(Operators.ARRAY_SEPRATOR);
                }
                if (item == null) {
                    out.writeNull();
                } else {
                    Class<?> clazz = item.getClass();
                    if (clazz == Integer.class) {
                        out.writeInt(((Integer) item).intValue());
                    } else if (clazz == Long.class) {
                        out.writeLong(((Long) item).longValue());
                        if (out.isEnabled(SerializerFeature.WriteClassName)) {
                            out.write(76);
                        }
                    } else {
                        ObjectSerializer itemSerializer = serializer.getObjectWriter(clazz);
                        if (!SerializerFeature.isEnabled(features, SerializerFeature.WriteClassName) || !(itemSerializer instanceof JavaBeanSerializer)) {
                            itemSerializer.write(serializer, item, Integer.valueOf(i2 - 1), elementType, features);
                        } else {
                            ((JavaBeanSerializer) itemSerializer).writeNoneASM(serializer, item, Integer.valueOf(i2 - 1), elementType, features);
                        }
                    }
                }
                i = i2;
            }
            out.append(Operators.ARRAY_END);
        } finally {
            serializer.context = context;
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
        Collection list;
        if (parser.lexer.token() == 8) {
            parser.lexer.nextToken(16);
            return null;
        } else if (type == JSONArray.class) {
            T t = (T) new JSONArray();
            parser.parseArray((Collection) t);
            return t;
        } else {
            if (parser.lexer.token() == 21) {
                parser.lexer.nextToken();
                list = (T) TypeUtils.createSet(type);
            } else {
                list = (T) TypeUtils.createCollection(type);
            }
            parser.parseArray(TypeUtils.getCollectionItemType(type), list, fieldName);
            return (T) list;
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 14;
    }
}
