package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.lang.reflect.WildcardType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class JavaBeanSerializer extends SerializeFilterable implements ObjectSerializer {
    protected final SerializeBeanInfo beanInfo;
    protected final FieldSerializer[] getters;
    private volatile transient long[] hashArray;
    private volatile transient short[] hashArrayMapping;
    protected final FieldSerializer[] sortedGetters;

    public JavaBeanSerializer(Class<?> beanType) {
        this(beanType, (Map<String, String>) null);
    }

    public JavaBeanSerializer(Class<?> beanType, String... aliasList) {
        this(beanType, createAliasMap(aliasList));
    }

    static Map<String, String> createAliasMap(String... aliasList) {
        Map<String, String> aliasMap = new HashMap<>();
        for (String alias : aliasList) {
            aliasMap.put(alias, alias);
        }
        return aliasMap;
    }

    public JSONType getJSONType() {
        return this.beanInfo.jsonType;
    }

    public Class<?> getType() {
        return this.beanInfo.beanType;
    }

    public JavaBeanSerializer(Class<?> beanType, Map<String, String> aliasMap) {
        this(TypeUtils.buildBeanInfo(beanType, aliasMap, null));
    }

    public JavaBeanSerializer(SerializeBeanInfo beanInfo2) {
        this.beanInfo = beanInfo2;
        this.sortedGetters = new FieldSerializer[beanInfo2.sortedFields.length];
        int i = 0;
        while (true) {
            FieldSerializer[] fieldSerializerArr = this.sortedGetters;
            if (i >= fieldSerializerArr.length) {
                break;
            }
            fieldSerializerArr[i] = new FieldSerializer(beanInfo2.beanType, beanInfo2.sortedFields[i]);
            i++;
        }
        if (beanInfo2.fields == beanInfo2.sortedFields) {
            this.getters = this.sortedGetters;
        } else {
            this.getters = new FieldSerializer[beanInfo2.fields.length];
            boolean hashNotMatch = false;
            int i2 = 0;
            while (true) {
                if (i2 >= this.getters.length) {
                    break;
                }
                FieldSerializer fieldSerializer = getFieldSerializer(beanInfo2.fields[i2].name);
                if (fieldSerializer == null) {
                    hashNotMatch = true;
                    break;
                } else {
                    this.getters[i2] = fieldSerializer;
                    i2++;
                }
            }
            if (hashNotMatch) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                System.arraycopy(fieldSerializerArr2, 0, this.getters, 0, fieldSerializerArr2.length);
            }
        }
        if (beanInfo2.jsonType != null) {
            for (Class<? extends SerializeFilter> filterClass : beanInfo2.jsonType.serialzeFilters()) {
                try {
                    addFilter((SerializeFilter) filterClass.getConstructor(new Class[0]).newInstance(new Object[0]));
                } catch (Exception e) {
                }
            }
        }
    }

    public void writeDirectNonContext(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        write(serializer, object, fieldName, fieldType, features);
    }

    public void writeAsArray(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        write(serializer, object, fieldName, fieldType, features);
    }

    public void writeAsArrayNonContext(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        write(serializer, object, fieldName, fieldType, features);
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        write(serializer, object, fieldName, fieldType, features, false);
    }

    public void writeNoneASM(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        write(serializer, object, fieldName, fieldType, features, false);
    }

    /* JADX INFO: Multiple debug info for r1v16 com.alibaba.fastjson.util.FieldInfo: [D('fieldInfo' com.alibaba.fastjson.util.FieldInfo), D('seperator' char)] */
    /* JADX INFO: Multiple debug info for r3v28 java.lang.String: [D('newSeperator' char), D('fieldInfoName' java.lang.String)] */
    /* JADX INFO: Multiple debug info for r4v27 java.lang.Class<?>: [D('i' int), D('fieldClass' java.lang.Class<?>)] */
    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:430:0x0681 A[SYNTHETIC, Splitter:B:430:0x0681] */
    /* JADX WARNING: Removed duplicated region for block: B:435:0x06a4 A[SYNTHETIC, Splitter:B:435:0x06a4] */
    /* JADX WARNING: Removed duplicated region for block: B:439:0x06bb A[ADDED_TO_REGION, Catch:{ all -> 0x06b8 }] */
    /* JADX WARNING: Removed duplicated region for block: B:448:0x0700 A[Catch:{ all -> 0x06b8 }] */
    /* JADX WARNING: Removed duplicated region for block: B:451:0x071e A[Catch:{ all -> 0x06b8 }] */
    /* JADX WARNING: Removed duplicated region for block: B:453:0x0725 A[Catch:{ all -> 0x06b8 }] */
    public void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features, boolean unwrapped) throws IOException {
        FieldSerializer[] getters2;
        Throwable th;
        SerialContext parent;
        FieldSerializer errorFieldSerializer;
        Exception e;
        Object obj;
        Throwable th2;
        Throwable cause;
        FieldSerializer errorFieldSerializer2;
        SerialContext parent2;
        char endSeperator;
        char endSeperator2;
        FieldSerializer[] getters3;
        int i;
        char newSeperator;
        boolean notApply;
        Object propertyValue;
        Object propertyValue2;
        Type type;
        Object obj2 = object;
        Object obj3 = fieldName;
        Type type2 = fieldType;
        SerializeWriter out = serializer.out;
        if (obj2 == null) {
            out.writeNull();
        } else if (!writeReference(serializer, obj2, features)) {
            if (out.sortField) {
                getters2 = this.sortedGetters;
            } else {
                getters2 = this.getters;
            }
            SerialContext parent3 = serializer.context;
            if (!this.beanInfo.beanType.isEnum()) {
                serializer.setContext(parent3, object, fieldName, this.beanInfo.features, features);
            }
            boolean writeAsArray = isWriteAsArray(serializer, features);
            char startSeperator = writeAsArray ? Operators.ARRAY_START : Operators.BLOCK_START;
            char endSeperator3 = writeAsArray ? Operators.ARRAY_END : Operators.BLOCK_END;
            if (!unwrapped) {
                try {
                    out.append(startSeperator);
                } catch (Exception e2) {
                    e = e2;
                    errorFieldSerializer = null;
                    parent = parent3;
                    obj = obj2;
                } catch (Throwable th3) {
                    th = th3;
                    parent = parent3;
                    serializer.context = parent;
                    throw th;
                }
            }
            try {
                if (getters2.length > 0 && out.isEnabled(SerializerFeature.PrettyFormat)) {
                    serializer.incrementIndent();
                    serializer.println();
                }
                boolean commaFlag = false;
                if ((this.beanInfo.features & SerializerFeature.WriteClassName.mask) == 0 && (SerializerFeature.WriteClassName.mask & features) == 0 && !serializer.isWriteClassName(type2, obj2)) {
                    errorFieldSerializer2 = null;
                } else {
                    Class<?> objClass = object.getClass();
                    if (objClass == type2 || !(type2 instanceof WildcardType)) {
                        type = fieldType;
                    } else {
                        type = TypeUtils.getClass(fieldType);
                    }
                    if (objClass != type) {
                        errorFieldSerializer2 = null;
                        try {
                            writeClassName(serializer, this.beanInfo.typeKey, obj2);
                            commaFlag = true;
                        } catch (Exception e3) {
                            e = e3;
                            parent = parent3;
                            obj = obj2;
                            errorFieldSerializer = null;
                            String errorMessage = "write javaBean error, fastjson version 1.2.83";
                            if (obj != null) {
                            }
                            if (fieldName != null) {
                            }
                            if (e.getMessage() != null) {
                            }
                            cause = null;
                            if (e instanceof InvocationTargetException) {
                            }
                            if (cause == null) {
                            }
                            throw new JSONException(errorMessage, cause);
                        } catch (Throwable th4) {
                            th = th4;
                            parent = parent3;
                            serializer.context = parent;
                            throw th;
                        }
                    } else {
                        errorFieldSerializer2 = null;
                    }
                }
                char seperator = commaFlag ? Operators.ARRAY_SEPRATOR : 0;
                try {
                    boolean writeClassName = out.isEnabled(SerializerFeature.WriteClassName);
                    char newSeperator2 = writeBefore(serializer, obj2, seperator);
                    boolean commaFlag2 = newSeperator2 == ',';
                    boolean skipTransient = out.isEnabled(SerializerFeature.SkipTransientField);
                    boolean ignoreNonFieldGetter = out.isEnabled(SerializerFeature.IgnoreNonFieldGetter);
                    int i2 = 0;
                    boolean commaFlag3 = commaFlag2;
                    while (i2 < getters2.length) {
                        try {
                            FieldSerializer fieldSerializer = getters2[i2];
                            Field field = fieldSerializer.fieldInfo.field;
                            FieldInfo fieldInfo = fieldSerializer.fieldInfo;
                            String fieldInfoName = fieldInfo.name;
                            Class<?> fieldClass = fieldInfo.fieldClass;
                            try {
                                boolean fieldUseSingleQuotes = SerializerFeature.isEnabled(out.features, fieldInfo.serialzeFeatures, SerializerFeature.UseSingleQuotes);
                                boolean directWritePrefix = out.quoteFieldNames && !fieldUseSingleQuotes;
                                if (skipTransient) {
                                    try {
                                        if (fieldInfo.fieldTransient) {
                                            newSeperator = newSeperator2;
                                            i = i2;
                                            endSeperator = endSeperator3;
                                            endSeperator2 = startSeperator;
                                            parent2 = parent3;
                                            getters3 = getters2;
                                            i2 = i + 1;
                                            obj2 = object;
                                            obj3 = fieldName;
                                            type2 = fieldType;
                                            newSeperator2 = newSeperator;
                                            seperator = seperator;
                                            getters2 = getters3;
                                            startSeperator = endSeperator2;
                                            endSeperator3 = endSeperator;
                                            parent3 = parent2;
                                        }
                                    } catch (Exception e4) {
                                        e = e4;
                                        obj = obj2;
                                        errorFieldSerializer = errorFieldSerializer2;
                                        parent = parent3;
                                        String errorMessage2 = "write javaBean error, fastjson version 1.2.83";
                                        if (obj != null) {
                                        }
                                        if (fieldName != null) {
                                        }
                                        if (e.getMessage() != null) {
                                        }
                                        cause = null;
                                        if (e instanceof InvocationTargetException) {
                                        }
                                        if (cause == null) {
                                        }
                                        throw new JSONException(errorMessage2, cause);
                                    } catch (Throwable th5) {
                                        th = th5;
                                        parent = parent3;
                                        serializer.context = parent;
                                        throw th;
                                    }
                                }
                                if (!ignoreNonFieldGetter || field != null) {
                                    if (applyName(serializer, obj2, fieldInfoName) && applyLabel(serializer, fieldInfo.label)) {
                                        notApply = false;
                                    } else if (writeAsArray) {
                                        notApply = true;
                                    } else {
                                        newSeperator = newSeperator2;
                                        i = i2;
                                        endSeperator = endSeperator3;
                                        endSeperator2 = startSeperator;
                                        parent2 = parent3;
                                        getters3 = getters2;
                                        i2 = i + 1;
                                        obj2 = object;
                                        obj3 = fieldName;
                                        type2 = fieldType;
                                        newSeperator2 = newSeperator;
                                        seperator = seperator;
                                        getters2 = getters3;
                                        startSeperator = endSeperator2;
                                        endSeperator3 = endSeperator;
                                        parent3 = parent2;
                                    }
                                    if (!fieldInfoName.equals(this.beanInfo.typeKey) || !serializer.isWriteClassName(type2, obj2)) {
                                        if (notApply) {
                                            propertyValue = null;
                                        } else {
                                            try {
                                                propertyValue = fieldSerializer.getPropertyValueDirect(obj2);
                                            } catch (InvocationTargetException ex) {
                                                errorFieldSerializer = fieldSerializer;
                                                try {
                                                    if (out.isEnabled(SerializerFeature.IgnoreErrorGetter)) {
                                                        errorFieldSerializer2 = errorFieldSerializer;
                                                        propertyValue = null;
                                                    } else {
                                                        throw ex;
                                                    }
                                                } catch (Exception e5) {
                                                    obj = object;
                                                    e = e5;
                                                    parent = parent3;
                                                    String errorMessage22 = "write javaBean error, fastjson version 1.2.83";
                                                    if (obj != null) {
                                                        try {
                                                            errorMessage22 = errorMessage22 + ", class " + object.getClass().getName();
                                                        } catch (Throwable th6) {
                                                            th2 = th6;
                                                            th = th2;
                                                            serializer.context = parent;
                                                            throw th;
                                                        }
                                                    }
                                                    if (fieldName != null) {
                                                        try {
                                                            errorMessage22 = errorMessage22 + ", fieldName : " + fieldName;
                                                        } catch (Throwable th7) {
                                                            th2 = th7;
                                                            th = th2;
                                                            serializer.context = parent;
                                                            throw th;
                                                        }
                                                    } else if (!(errorFieldSerializer == null || errorFieldSerializer.fieldInfo == null)) {
                                                        FieldInfo fieldInfo2 = errorFieldSerializer.fieldInfo;
                                                        if (fieldInfo2.method != null) {
                                                            errorMessage22 = errorMessage22 + ", method : " + fieldInfo2.method.getName();
                                                        } else {
                                                            errorMessage22 = errorMessage22 + ", fieldName : " + errorFieldSerializer.fieldInfo.name;
                                                        }
                                                    }
                                                    if (e.getMessage() != null) {
                                                        errorMessage22 = errorMessage22 + ", " + e.getMessage();
                                                    }
                                                    cause = null;
                                                    if (e instanceof InvocationTargetException) {
                                                        cause = e.getCause();
                                                    }
                                                    if (cause == null) {
                                                        cause = e;
                                                    }
                                                    throw new JSONException(errorMessage22, cause);
                                                } catch (Throwable th8) {
                                                    th = th8;
                                                    parent = parent3;
                                                    serializer.context = parent;
                                                    throw th;
                                                }
                                            } catch (Exception e6) {
                                                obj = object;
                                                e = e6;
                                                parent = parent3;
                                            } catch (Throwable th9) {
                                                th = th9;
                                                parent = parent3;
                                                serializer.context = parent;
                                                throw th;
                                            }
                                        }
                                        if (!apply(serializer, obj2, fieldInfoName, propertyValue)) {
                                            newSeperator = newSeperator2;
                                            i = i2;
                                            endSeperator = endSeperator3;
                                            endSeperator2 = startSeperator;
                                            parent2 = parent3;
                                            getters3 = getters2;
                                        } else {
                                            if (fieldClass != String.class || !AbsoluteConst.XML_TRIM.equals(fieldInfo.format) || propertyValue == null) {
                                                propertyValue2 = propertyValue;
                                            } else {
                                                propertyValue2 = ((String) propertyValue).trim();
                                            }
                                            String key = processKey(serializer, obj2, fieldInfoName, propertyValue2);
                                            newSeperator = newSeperator2;
                                            i = i2;
                                            getters3 = getters2;
                                            endSeperator = endSeperator3;
                                            endSeperator2 = startSeperator;
                                            parent2 = parent3;
                                            try {
                                                Object propertyValue3 = processValue(serializer, fieldSerializer.fieldContext, object, fieldInfoName, propertyValue2, features);
                                                if (propertyValue3 == null) {
                                                    int serialzeFeatures = fieldInfo.serialzeFeatures;
                                                    JSONField jsonField = fieldInfo.getAnnotation();
                                                    if (this.beanInfo.jsonType != null) {
                                                        serialzeFeatures |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                    }
                                                    if (jsonField != null && !"".equals(jsonField.defaultValue())) {
                                                        propertyValue3 = jsonField.defaultValue();
                                                    } else if (fieldClass == Boolean.class) {
                                                        int defaultMask = SerializerFeature.WriteNullBooleanAsFalse.mask;
                                                        int mask = SerializerFeature.WriteMapNullValue.mask | defaultMask;
                                                        if (writeAsArray || (serialzeFeatures & mask) != 0 || (out.features & mask) != 0) {
                                                            if ((serialzeFeatures & defaultMask) != 0) {
                                                                propertyValue3 = false;
                                                            } else if ((out.features & defaultMask) != 0 && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures) == 0) {
                                                                propertyValue3 = false;
                                                            }
                                                        }
                                                    } else if (fieldClass == String.class) {
                                                        int defaultMask2 = SerializerFeature.WriteNullStringAsEmpty.mask;
                                                        int mask2 = SerializerFeature.WriteMapNullValue.mask | defaultMask2;
                                                        if (writeAsArray || (serialzeFeatures & mask2) != 0 || (out.features & mask2) != 0) {
                                                            if ((serialzeFeatures & defaultMask2) != 0) {
                                                                propertyValue3 = "";
                                                            } else if ((out.features & defaultMask2) != 0 && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures) == 0) {
                                                                propertyValue3 = "";
                                                            }
                                                        }
                                                    } else if (Number.class.isAssignableFrom(fieldClass)) {
                                                        int defaultMask3 = SerializerFeature.WriteNullNumberAsZero.mask;
                                                        int mask3 = SerializerFeature.WriteMapNullValue.mask | defaultMask3;
                                                        if (writeAsArray || (serialzeFeatures & mask3) != 0 || (out.features & mask3) != 0) {
                                                            if ((serialzeFeatures & defaultMask3) != 0) {
                                                                propertyValue3 = 0;
                                                            } else if ((out.features & defaultMask3) != 0 && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures) == 0) {
                                                                propertyValue3 = 0;
                                                            }
                                                        }
                                                    } else if (Collection.class.isAssignableFrom(fieldClass)) {
                                                        int defaultMask4 = SerializerFeature.WriteNullListAsEmpty.mask;
                                                        int mask4 = SerializerFeature.WriteMapNullValue.mask | defaultMask4;
                                                        if (writeAsArray || (serialzeFeatures & mask4) != 0 || (out.features & mask4) != 0) {
                                                            if ((serialzeFeatures & defaultMask4) != 0) {
                                                                propertyValue3 = Collections.emptyList();
                                                            } else if ((out.features & defaultMask4) != 0 && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures) == 0) {
                                                                propertyValue3 = Collections.emptyList();
                                                            }
                                                        }
                                                    } else if (!writeAsArray && !fieldSerializer.writeNull && !out.isEnabled(SerializerFeature.WriteMapNullValue.mask) && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures) == 0) {
                                                    }
                                                }
                                                if (!(propertyValue3 == null || (!out.notWriteDefaultValue && (fieldInfo.serialzeFeatures & SerializerFeature.NotWriteDefaultValue.mask) == 0 && (this.beanInfo.features & SerializerFeature.NotWriteDefaultValue.mask) == 0))) {
                                                    Class<?> fieldCLass = fieldInfo.fieldClass;
                                                    if (fieldCLass != Byte.TYPE || !(propertyValue3 instanceof Byte) || ((Byte) propertyValue3).byteValue() != 0) {
                                                        if (fieldCLass != Short.TYPE || !(propertyValue3 instanceof Short) || ((Short) propertyValue3).shortValue() != 0) {
                                                            if (fieldCLass != Integer.TYPE || !(propertyValue3 instanceof Integer) || ((Integer) propertyValue3).intValue() != 0) {
                                                                if (fieldCLass != Long.TYPE || !(propertyValue3 instanceof Long) || ((Long) propertyValue3).longValue() != 0) {
                                                                    if (fieldCLass != Float.TYPE || !(propertyValue3 instanceof Float) || ((Float) propertyValue3).floatValue() != 0.0f) {
                                                                        if (fieldCLass != Double.TYPE || !(propertyValue3 instanceof Double) || ((Double) propertyValue3).doubleValue() != 0.0d) {
                                                                            if (fieldCLass == Boolean.TYPE && (propertyValue3 instanceof Boolean) && !((Boolean) propertyValue3).booleanValue()) {
                                                                            }
                                                                        }
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                                if (commaFlag3) {
                                                    if (!fieldInfo.unwrapped || !(propertyValue3 instanceof Map) || ((Map) propertyValue3).size() != 0) {
                                                        out.write(44);
                                                        if (out.isEnabled(SerializerFeature.PrettyFormat)) {
                                                            serializer.println();
                                                        }
                                                    }
                                                }
                                                if (key != fieldInfoName) {
                                                    if (!writeAsArray) {
                                                        out.writeFieldName(key, true);
                                                    }
                                                    serializer.write(propertyValue3);
                                                } else if (propertyValue2 != propertyValue3) {
                                                    if (!writeAsArray) {
                                                        fieldSerializer.writePrefix(serializer);
                                                    }
                                                    serializer.write(propertyValue3);
                                                } else {
                                                    if (!writeAsArray) {
                                                        boolean isMap = Map.class.isAssignableFrom(fieldClass);
                                                        boolean isJavaBean = (!fieldClass.isPrimitive() && !fieldClass.getName().startsWith("java.")) || fieldClass == Object.class;
                                                        if (writeClassName || !fieldInfo.unwrapped || (!isMap && !isJavaBean)) {
                                                            if (directWritePrefix) {
                                                                out.write(fieldInfo.name_chars, 0, fieldInfo.name_chars.length);
                                                            } else {
                                                                fieldSerializer.writePrefix(serializer);
                                                            }
                                                        }
                                                    }
                                                    if (!writeAsArray) {
                                                        JSONField fieldAnnotation = fieldInfo.getAnnotation();
                                                        if (fieldClass == String.class && (fieldAnnotation == null || fieldAnnotation.serializeUsing() == Void.class)) {
                                                            if (propertyValue3 == null) {
                                                                int serialzeFeatures2 = fieldSerializer.features;
                                                                if (this.beanInfo.jsonType != null) {
                                                                    serialzeFeatures2 |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                                }
                                                                if ((SerializerFeature.WriteNullStringAsEmpty.mask & out.features) != 0 && (SerializerFeature.WriteMapNullValue.mask & serialzeFeatures2) == 0) {
                                                                    out.writeString("");
                                                                } else if ((SerializerFeature.WriteNullStringAsEmpty.mask & serialzeFeatures2) != 0) {
                                                                    out.writeString("");
                                                                } else {
                                                                    out.writeNull();
                                                                }
                                                            } else {
                                                                String propertyValueString = (String) propertyValue3;
                                                                if (fieldUseSingleQuotes) {
                                                                    out.writeStringWithSingleQuote(propertyValueString);
                                                                } else {
                                                                    out.writeStringWithDoubleQuote(propertyValueString, (char) 0);
                                                                }
                                                            }
                                                        } else if (!fieldInfo.unwrapped || !(propertyValue3 instanceof Map) || ((Map) propertyValue3).size() != 0) {
                                                            fieldSerializer.writeValue(serializer, propertyValue3);
                                                        } else {
                                                            commaFlag3 = false;
                                                        }
                                                    } else {
                                                        fieldSerializer.writeValue(serializer, propertyValue3);
                                                    }
                                                }
                                                boolean fieldUnwrappedNull = false;
                                                if (fieldInfo.unwrapped && (propertyValue3 instanceof Map)) {
                                                    Map map = (Map) propertyValue3;
                                                    if (map.size() == 0) {
                                                        fieldUnwrappedNull = true;
                                                    } else if (!serializer.isEnabled(SerializerFeature.WriteMapNullValue)) {
                                                        boolean hasNotNull = false;
                                                        Iterator it = map.values().iterator();
                                                        while (true) {
                                                            if (it.hasNext()) {
                                                                if (it.next() != null) {
                                                                    hasNotNull = true;
                                                                    break;
                                                                }
                                                            } else {
                                                                break;
                                                            }
                                                        }
                                                        if (!hasNotNull) {
                                                            fieldUnwrappedNull = true;
                                                        }
                                                    }
                                                }
                                                if (!fieldUnwrappedNull) {
                                                    commaFlag3 = true;
                                                }
                                            } catch (Exception e7) {
                                                obj = object;
                                                e = e7;
                                                errorFieldSerializer = errorFieldSerializer2;
                                                parent = parent2;
                                                String errorMessage222 = "write javaBean error, fastjson version 1.2.83";
                                                if (obj != null) {
                                                }
                                                if (fieldName != null) {
                                                }
                                                if (e.getMessage() != null) {
                                                }
                                                cause = null;
                                                if (e instanceof InvocationTargetException) {
                                                }
                                                if (cause == null) {
                                                }
                                                throw new JSONException(errorMessage222, cause);
                                            } catch (Throwable th10) {
                                                th = th10;
                                                parent = parent2;
                                                serializer.context = parent;
                                                throw th;
                                            }
                                        }
                                        i2 = i + 1;
                                        obj2 = object;
                                        obj3 = fieldName;
                                        type2 = fieldType;
                                        newSeperator2 = newSeperator;
                                        seperator = seperator;
                                        getters2 = getters3;
                                        startSeperator = endSeperator2;
                                        endSeperator3 = endSeperator;
                                        parent3 = parent2;
                                    } else {
                                        newSeperator = newSeperator2;
                                        i = i2;
                                        endSeperator = endSeperator3;
                                        endSeperator2 = startSeperator;
                                        parent2 = parent3;
                                        getters3 = getters2;
                                        i2 = i + 1;
                                        obj2 = object;
                                        obj3 = fieldName;
                                        type2 = fieldType;
                                        newSeperator2 = newSeperator;
                                        seperator = seperator;
                                        getters2 = getters3;
                                        startSeperator = endSeperator2;
                                        endSeperator3 = endSeperator;
                                        parent3 = parent2;
                                    }
                                } else {
                                    newSeperator = newSeperator2;
                                    i = i2;
                                    endSeperator = endSeperator3;
                                    endSeperator2 = startSeperator;
                                    parent2 = parent3;
                                    getters3 = getters2;
                                    i2 = i + 1;
                                    obj2 = object;
                                    obj3 = fieldName;
                                    type2 = fieldType;
                                    newSeperator2 = newSeperator;
                                    seperator = seperator;
                                    getters2 = getters3;
                                    startSeperator = endSeperator2;
                                    endSeperator3 = endSeperator;
                                    parent3 = parent2;
                                }
                            } catch (Exception e8) {
                                obj = object;
                                e = e8;
                                errorFieldSerializer = errorFieldSerializer2;
                                parent = parent3;
                                String errorMessage2222 = "write javaBean error, fastjson version 1.2.83";
                                if (obj != null) {
                                }
                                if (fieldName != null) {
                                }
                                if (e.getMessage() != null) {
                                }
                                cause = null;
                                if (e instanceof InvocationTargetException) {
                                }
                                if (cause == null) {
                                }
                                throw new JSONException(errorMessage2222, cause);
                            } catch (Throwable th11) {
                                th = th11;
                                parent = parent3;
                                serializer.context = parent;
                                throw th;
                            }
                        } catch (Exception e9) {
                            obj = object;
                            e = e9;
                            parent = parent3;
                            errorFieldSerializer = errorFieldSerializer2;
                            String errorMessage22222 = "write javaBean error, fastjson version 1.2.83";
                            if (obj != null) {
                            }
                            if (fieldName != null) {
                            }
                            if (e.getMessage() != null) {
                            }
                            cause = null;
                            if (e instanceof InvocationTargetException) {
                            }
                            if (cause == null) {
                            }
                            throw new JSONException(errorMessage22222, cause);
                        } catch (Throwable th12) {
                            th = th12;
                            parent = parent3;
                            serializer.context = parent;
                            throw th;
                        }
                    }
                    obj = object;
                    try {
                        writeAfter(serializer, obj, commaFlag3 ? Operators.ARRAY_SEPRATOR : 0);
                    } catch (Exception e10) {
                        parent = parent3;
                        e = e10;
                        errorFieldSerializer = errorFieldSerializer2;
                        String errorMessage222222 = "write javaBean error, fastjson version 1.2.83";
                        if (obj != null) {
                        }
                        if (fieldName != null) {
                        }
                        if (e.getMessage() != null) {
                        }
                        cause = null;
                        if (e instanceof InvocationTargetException) {
                        }
                        if (cause == null) {
                        }
                        throw new JSONException(errorMessage222222, cause);
                    } catch (Throwable th13) {
                        parent = parent3;
                        th = th13;
                        serializer.context = parent;
                        throw th;
                    }
                } catch (Exception e11) {
                    parent = parent3;
                    obj = obj2;
                    e = e11;
                    errorFieldSerializer = errorFieldSerializer2;
                    String errorMessage2222222 = "write javaBean error, fastjson version 1.2.83";
                    if (obj != null) {
                    }
                    if (fieldName != null) {
                    }
                    if (e.getMessage() != null) {
                    }
                    cause = null;
                    if (e instanceof InvocationTargetException) {
                    }
                    if (cause == null) {
                    }
                    throw new JSONException(errorMessage2222222, cause);
                } catch (Throwable th14) {
                    parent = parent3;
                    th = th14;
                    serializer.context = parent;
                    throw th;
                }
            } catch (Exception e12) {
                parent = parent3;
                obj = obj2;
                e = e12;
                errorFieldSerializer = null;
                String errorMessage22222222 = "write javaBean error, fastjson version 1.2.83";
                if (obj != null) {
                }
                if (fieldName != null) {
                }
                if (e.getMessage() != null) {
                }
                cause = null;
                if (e instanceof InvocationTargetException) {
                }
                if (cause == null) {
                }
                throw new JSONException(errorMessage22222222, cause);
            } catch (Throwable th15) {
                parent = parent3;
                th = th15;
                serializer.context = parent;
                throw th;
            }
            try {
                if (getters2.length > 0) {
                    try {
                        if (out.isEnabled(SerializerFeature.PrettyFormat)) {
                            serializer.decrementIdent();
                            serializer.println();
                        }
                    } catch (Exception e13) {
                        e = e13;
                        errorFieldSerializer = errorFieldSerializer2;
                        parent = parent3;
                        String errorMessage222222222 = "write javaBean error, fastjson version 1.2.83";
                        if (obj != null) {
                        }
                        if (fieldName != null) {
                        }
                        if (e.getMessage() != null) {
                        }
                        cause = null;
                        if (e instanceof InvocationTargetException) {
                        }
                        if (cause == null) {
                        }
                        throw new JSONException(errorMessage222222222, cause);
                    } catch (Throwable th16) {
                        th = th16;
                        parent = parent3;
                        serializer.context = parent;
                        throw th;
                    }
                }
                if (!unwrapped) {
                    out.append(endSeperator3);
                }
                serializer.context = parent3;
            } catch (Exception e14) {
                parent = parent3;
                e = e14;
                errorFieldSerializer = errorFieldSerializer2;
                String errorMessage2222222222 = "write javaBean error, fastjson version 1.2.83";
                if (obj != null) {
                }
                if (fieldName != null) {
                }
                if (e.getMessage() != null) {
                }
                cause = null;
                if (e instanceof InvocationTargetException) {
                }
                if (cause == null) {
                }
                throw new JSONException(errorMessage2222222222, cause);
            } catch (Throwable th17) {
                parent = parent3;
                th = th17;
                serializer.context = parent;
                throw th;
            }
        }
    }

    /* access modifiers changed from: protected */
    public void writeClassName(JSONSerializer serializer, String typeKey, Object object) {
        if (typeKey == null) {
            typeKey = serializer.config.typeKey;
        }
        serializer.out.writeFieldName(typeKey, false);
        String typeName = this.beanInfo.typeName;
        if (typeName == null) {
            Class<?> clazz = object.getClass();
            if (TypeUtils.isProxy(clazz)) {
                clazz = clazz.getSuperclass();
            }
            typeName = clazz.getName();
        }
        serializer.write(typeName);
    }

    public boolean writeReference(JSONSerializer serializer, Object object, int fieldFeatures) {
        SerialContext context = serializer.context;
        int mask = SerializerFeature.DisableCircularReferenceDetect.mask;
        if (context == null || (context.features & mask) != 0 || (fieldFeatures & mask) != 0 || serializer.references == null || !serializer.references.containsKey(object)) {
            return false;
        }
        serializer.writeReference(object);
        return true;
    }

    /* access modifiers changed from: protected */
    public boolean isWriteAsArray(JSONSerializer serializer) {
        return isWriteAsArray(serializer, 0);
    }

    /* access modifiers changed from: protected */
    public boolean isWriteAsArray(JSONSerializer serializer, int fieldFeatrues) {
        int mask = SerializerFeature.BeanToArray.mask;
        return ((this.beanInfo.features & mask) == 0 && !serializer.out.beanToArray && (fieldFeatrues & mask) == 0) ? false : true;
    }

    public Object getFieldValue(Object object, String key) {
        FieldSerializer fieldDeser = getFieldSerializer(key);
        if (fieldDeser != null) {
            try {
                return fieldDeser.getPropertyValue(object);
            } catch (InvocationTargetException ex) {
                throw new JSONException("getFieldValue error." + key, ex);
            } catch (IllegalAccessException ex2) {
                throw new JSONException("getFieldValue error." + key, ex2);
            }
        } else {
            throw new JSONException("field not found. " + key);
        }
    }

    public Object getFieldValue(Object object, String key, long keyHash, boolean throwFieldNotFoundException) {
        FieldSerializer fieldDeser = getFieldSerializer(keyHash);
        if (fieldDeser != null) {
            try {
                return fieldDeser.getPropertyValue(object);
            } catch (InvocationTargetException ex) {
                throw new JSONException("getFieldValue error." + key, ex);
            } catch (IllegalAccessException ex2) {
                throw new JSONException("getFieldValue error." + key, ex2);
            }
        } else if (!throwFieldNotFoundException) {
            return null;
        } else {
            throw new JSONException("field not found. " + key);
        }
    }

    public FieldSerializer getFieldSerializer(String key) {
        if (key == null) {
            return null;
        }
        int low = 0;
        int high = this.sortedGetters.length - 1;
        while (low <= high) {
            int mid = (low + high) >>> 1;
            int cmp = this.sortedGetters[mid].fieldInfo.name.compareTo(key);
            if (cmp < 0) {
                low = mid + 1;
            } else if (cmp <= 0) {
                return this.sortedGetters[mid];
            } else {
                high = mid - 1;
            }
        }
        return null;
    }

    public FieldSerializer getFieldSerializer(long hash) {
        int p_t;
        PropertyNamingStrategy[] namingStrategies = null;
        if (this.hashArray == null) {
            namingStrategies = PropertyNamingStrategy.values();
            long[] hashArray2 = new long[(this.sortedGetters.length * namingStrategies.length)];
            int index = 0;
            int i = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr = this.sortedGetters;
                if (i >= fieldSerializerArr.length) {
                    break;
                }
                String name = fieldSerializerArr[i].fieldInfo.name;
                int index2 = index + 1;
                hashArray2[index] = TypeUtils.fnv1a_64(name);
                for (PropertyNamingStrategy propertyNamingStrategy : namingStrategies) {
                    String name_t = propertyNamingStrategy.translate(name);
                    if (!name.equals(name_t)) {
                        hashArray2[index2] = TypeUtils.fnv1a_64(name_t);
                        index2++;
                    }
                }
                i++;
                index = index2;
            }
            Arrays.sort(hashArray2, 0, index);
            this.hashArray = new long[index];
            System.arraycopy(hashArray2, 0, this.hashArray, 0, index);
        }
        int pos = Arrays.binarySearch(this.hashArray, hash);
        if (pos < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            if (namingStrategies == null) {
                namingStrategies = PropertyNamingStrategy.values();
            }
            short[] mapping = new short[this.hashArray.length];
            Arrays.fill(mapping, (short) -1);
            int i2 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                if (i2 >= fieldSerializerArr2.length) {
                    break;
                }
                String name2 = fieldSerializerArr2[i2].fieldInfo.name;
                int p = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(name2));
                if (p >= 0) {
                    mapping[p] = (short) i2;
                }
                for (PropertyNamingStrategy propertyNamingStrategy2 : namingStrategies) {
                    String name_t2 = propertyNamingStrategy2.translate(name2);
                    if (!name2.equals(name_t2) && (p_t = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(name_t2))) >= 0) {
                        mapping[p_t] = (short) i2;
                    }
                }
                i2++;
            }
            this.hashArrayMapping = mapping;
        }
        short s = this.hashArrayMapping[pos];
        if (s != -1) {
            return this.sortedGetters[s];
        }
        return null;
    }

    public List<Object> getFieldValues(Object object) throws Exception {
        List<Object> fieldValues = new ArrayList<>(this.sortedGetters.length);
        for (FieldSerializer getter : this.sortedGetters) {
            fieldValues.add(getter.getPropertyValue(object));
        }
        return fieldValues;
    }

    public List<Object> getObjectFieldValues(Object object) throws Exception {
        List<Object> fieldValues = new ArrayList<>(this.sortedGetters.length);
        FieldSerializer[] fieldSerializerArr = this.sortedGetters;
        for (FieldSerializer getter : fieldSerializerArr) {
            Class fieldClass = getter.fieldInfo.fieldClass;
            if (!fieldClass.isPrimitive() && !fieldClass.getName().startsWith("java.lang.")) {
                fieldValues.add(getter.getPropertyValue(object));
            }
        }
        return fieldValues;
    }

    public int getSize(Object object) throws Exception {
        int size = 0;
        for (FieldSerializer getter : this.sortedGetters) {
            if (getter.getPropertyValueDirect(object) != null) {
                size++;
            }
        }
        return size;
    }

    public Set<String> getFieldNames(Object object) throws Exception {
        Set<String> fieldNames = new HashSet<>();
        FieldSerializer[] fieldSerializerArr = this.sortedGetters;
        for (FieldSerializer getter : fieldSerializerArr) {
            if (getter.getPropertyValueDirect(object) != null) {
                fieldNames.add(getter.fieldInfo.name);
            }
        }
        return fieldNames;
    }

    public Map<String, Object> getFieldValuesMap(Object object) throws Exception {
        Map<String, Object> map = new LinkedHashMap<>(this.sortedGetters.length);
        FieldSerializer[] fieldSerializerArr = this.sortedGetters;
        for (FieldSerializer getter : fieldSerializerArr) {
            boolean skipTransient = SerializerFeature.isEnabled(getter.features, SerializerFeature.SkipTransientField);
            FieldInfo fieldInfo = getter.fieldInfo;
            if (!skipTransient || fieldInfo == null || !fieldInfo.fieldTransient) {
                if (getter.fieldInfo.unwrapped) {
                    Object map1 = JSON.toJSON(getter.getPropertyValue(object));
                    if (map1 instanceof Map) {
                        map.putAll((Map) map1);
                    } else {
                        map.put(getter.fieldInfo.name, getter.getPropertyValue(object));
                    }
                } else {
                    map.put(getter.fieldInfo.name, getter.getPropertyValue(object));
                }
            }
        }
        return map;
    }

    /* access modifiers changed from: protected */
    public BeanContext getBeanContext(int orinal) {
        return this.sortedGetters[orinal].fieldContext;
    }

    /* access modifiers changed from: protected */
    public Type getFieldType(int ordinal) {
        return this.sortedGetters[ordinal].fieldInfo.fieldType;
    }

    /* access modifiers changed from: protected */
    public char writeBefore(JSONSerializer jsonBeanDeser, Object object, char seperator) {
        if (jsonBeanDeser.beforeFilters != null) {
            for (BeforeFilter beforeFilter : jsonBeanDeser.beforeFilters) {
                seperator = beforeFilter.writeBefore(jsonBeanDeser, object, seperator);
            }
        }
        if (this.beforeFilters != null) {
            for (BeforeFilter beforeFilter2 : this.beforeFilters) {
                seperator = beforeFilter2.writeBefore(jsonBeanDeser, object, seperator);
            }
        }
        return seperator;
    }

    /* access modifiers changed from: protected */
    public char writeAfter(JSONSerializer jsonBeanDeser, Object object, char seperator) {
        if (jsonBeanDeser.afterFilters != null) {
            for (AfterFilter afterFilter : jsonBeanDeser.afterFilters) {
                seperator = afterFilter.writeAfter(jsonBeanDeser, object, seperator);
            }
        }
        if (this.afterFilters != null) {
            for (AfterFilter afterFilter2 : this.afterFilters) {
                seperator = afterFilter2.writeAfter(jsonBeanDeser, object, seperator);
            }
        }
        return seperator;
    }

    /* access modifiers changed from: protected */
    public boolean applyLabel(JSONSerializer jsonBeanDeser, String label) {
        if (jsonBeanDeser.labelFilters != null) {
            for (LabelFilter propertyFilter : jsonBeanDeser.labelFilters) {
                if (!propertyFilter.apply(label)) {
                    return false;
                }
            }
        }
        if (this.labelFilters == null) {
            return true;
        }
        for (LabelFilter propertyFilter2 : this.labelFilters) {
            if (!propertyFilter2.apply(label)) {
                return false;
            }
        }
        return true;
    }
}
