package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.util.TypeUtils;
import com.igexin.push.core.b;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.lang.reflect.Type;
import java.util.List;

public final class ListSerializer implements ObjectSerializer {
    public static final ListSerializer instance = new ListSerializer();

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public final void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        SerialContext context;
        Throwable th;
        Object item;
        SerializeWriter out;
        List<?> list;
        boolean writeClassName = serializer.out.isEnabled(SerializerFeature.WriteClassName) || SerializerFeature.isEnabled(features, SerializerFeature.WriteClassName);
        SerializeWriter out2 = serializer.out;
        Type elementType = writeClassName ? TypeUtils.getCollectionItemType(fieldType) : null;
        if (object == null) {
            out2.writeNull(SerializerFeature.WriteNullListAsEmpty);
            return;
        }
        List<?> list2 = (List) object;
        if (list2.size() == 0) {
            out2.append((CharSequence) "[]");
            return;
        }
        SerialContext context2 = serializer.context;
        serializer.setContext(context2, object, fieldName, 0);
        try {
            boolean isEnabled = out2.isEnabled(SerializerFeature.PrettyFormat);
            char c = Operators.ARRAY_SEPRATOR;
            if (isEnabled) {
                out2.append(Operators.ARRAY_START);
                serializer.incrementIndent();
                int i = 0;
                for (Object item2 : list2) {
                    if (i != 0) {
                        try {
                            out2.append(c);
                        } catch (Throwable th2) {
                            th = th2;
                            context = context2;
                        }
                    }
                    serializer.println();
                    if (item2 == null) {
                        context = context2;
                        list = list2;
                        out = out2;
                        serializer.out.writeNull();
                    } else if (serializer.containsReference(item2)) {
                        serializer.writeReference(item2);
                        context = context2;
                        list = list2;
                        out = out2;
                    } else {
                        ObjectSerializer itemSerializer = serializer.getObjectWriter(item2.getClass());
                        serializer.context = new SerialContext(context2, object, fieldName, 0, 0);
                        context = context2;
                        list = list2;
                        out = out2;
                        try {
                            itemSerializer.write(serializer, item2, Integer.valueOf(i), elementType, features);
                        } catch (Throwable th3) {
                            th = th3;
                            serializer.context = context;
                            throw th;
                        }
                    }
                    i++;
                    list2 = list;
                    context2 = context;
                    out2 = out;
                    c = Operators.ARRAY_SEPRATOR;
                }
                serializer.decrementIdent();
                serializer.println();
                out2.append(Operators.ARRAY_END);
                serializer.context = context2;
                return;
            }
            context = context2;
            char c2 = Operators.ARRAY_SEPRATOR;
            out2.append(Operators.ARRAY_START);
            int i2 = 0;
            int size = list2.size();
            ObjectSerializer itemSerializer2 = null;
            while (i2 < size) {
                try {
                    Object item3 = list2.get(i2);
                    if (i2 != 0) {
                        out2.append(c2);
                    }
                    if (item3 == null) {
                        out2.append((CharSequence) b.m);
                    } else {
                        Class<?> clazz = item3.getClass();
                        if (clazz == Integer.class) {
                            out2.writeInt(((Integer) item3).intValue());
                        } else if (clazz == Long.class) {
                            long val = ((Long) item3).longValue();
                            if (writeClassName) {
                                out2.writeLong(val);
                                out2.write(76);
                            } else {
                                out2.writeLong(val);
                            }
                        } else if ((SerializerFeature.DisableCircularReferenceDetect.mask & features) != 0) {
                            ObjectSerializer itemSerializer3 = serializer.getObjectWriter(item3.getClass());
                            itemSerializer3.write(serializer, item3, Integer.valueOf(i2), elementType, features);
                            itemSerializer2 = itemSerializer3;
                        } else {
                            if (!out2.disableCircularReferenceDetect) {
                                item = item3;
                                serializer.context = new SerialContext(context, object, fieldName, 0, 0);
                            } else {
                                item = item3;
                            }
                            if (serializer.containsReference(item)) {
                                serializer.writeReference(item);
                            } else {
                                itemSerializer2 = serializer.getObjectWriter(item.getClass());
                                if ((SerializerFeature.WriteClassName.mask & features) == 0 || !(itemSerializer2 instanceof JavaBeanSerializer)) {
                                    itemSerializer2.write(serializer, item, Integer.valueOf(i2), elementType, features);
                                } else {
                                    ((JavaBeanSerializer) itemSerializer2).writeNoneASM(serializer, item, Integer.valueOf(i2), elementType, features);
                                }
                            }
                        }
                    }
                    i2++;
                    c2 = Operators.ARRAY_SEPRATOR;
                } catch (Throwable th4) {
                    th = th4;
                    serializer.context = context;
                    throw th;
                }
            }
            out2.append(Operators.ARRAY_END);
            serializer.context = context;
        } catch (Throwable th5) {
            th = th5;
            context = context2;
            serializer.context = context;
            throw th;
        }
    }
}
