package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.lang.reflect.Array;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;

public class ObjectArrayCodec implements ObjectSerializer, ObjectDeserializer {
    public static final ObjectArrayCodec instance = new ObjectArrayCodec();

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public final void write(JSONSerializer serializer, Object object, Object fieldName, Type fieldType, int features) throws IOException {
        int i;
        char c;
        SerializeWriter out = serializer.out;
        Object[] array = (Object[]) object;
        if (object == null) {
            out.writeNull(SerializerFeature.WriteNullListAsEmpty);
            return;
        }
        int size = array.length;
        int end = size - 1;
        if (end == -1) {
            out.append((CharSequence) "[]");
            return;
        }
        SerialContext context = serializer.context;
        serializer.setContext(context, object, fieldName, 0);
        Class<?> preClazz = null;
        try {
            out.append(Operators.ARRAY_START);
            if (out.isEnabled(SerializerFeature.PrettyFormat)) {
                serializer.incrementIndent();
                serializer.println();
                for (int i2 = 0; i2 < size; i2++) {
                    if (i2 != 0) {
                        out.write(44);
                        serializer.println();
                    }
                    serializer.writeWithFieldName(array[i2], Integer.valueOf(i2));
                }
                serializer.decrementIdent();
                serializer.println();
                out.write(93);
                return;
            }
            ObjectSerializer preWriter = null;
            int i3 = 0;
            while (i3 < end) {
                Object item = array[i3];
                if (item == null) {
                    out.append((CharSequence) "null,");
                    i = i3;
                } else {
                    if (serializer.containsReference(item)) {
                        serializer.writeReference(item);
                        i = i3;
                        c = Operators.ARRAY_SEPRATOR;
                    } else {
                        Class<?> clazz = item.getClass();
                        if (clazz == preClazz) {
                            Integer valueOf = Integer.valueOf(i3);
                            i = i3;
                            c = Operators.ARRAY_SEPRATOR;
                            preWriter.write(serializer, item, valueOf, null, 0);
                        } else {
                            i = i3;
                            c = Operators.ARRAY_SEPRATOR;
                            preClazz = clazz;
                            ObjectSerializer preWriter2 = serializer.getObjectWriter(clazz);
                            preWriter2.write(serializer, item, Integer.valueOf(i), null, 0);
                            preWriter = preWriter2;
                        }
                    }
                    out.append(c);
                }
                i3 = i + 1;
            }
            Object item2 = array[end];
            if (item2 == null) {
                out.append((CharSequence) "null]");
            } else {
                if (serializer.containsReference(item2)) {
                    serializer.writeReference(item2);
                } else {
                    serializer.writeWithFieldName(item2, Integer.valueOf(end));
                }
                out.append(Operators.ARRAY_END);
            }
            serializer.context = context;
        } finally {
            serializer.context = context;
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:42:0x006a */
    /* JADX WARN: Type inference failed for: r8v0, types: [T, byte[]] */
    /* JADX WARNING: Unknown variable types count: 1 */
    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser parser, Type type, Object fieldName) {
        Class<?> cls;
        Type componentType;
        JSONLexer lexer = parser.lexer;
        int token = lexer.token();
        if (token == 8) {
            lexer.nextToken(16);
            return null;
        }
        if (token != 4) {
            if (token != 26) {
                if (type instanceof GenericArrayType) {
                    componentType = ((GenericArrayType) type).getGenericComponentType();
                    if (componentType instanceof TypeVariable) {
                        TypeVariable typeVar = (TypeVariable) componentType;
                        Type objType = parser.getContext().type;
                        if (objType instanceof ParameterizedType) {
                            ParameterizedType objParamType = (ParameterizedType) objType;
                            Type objRawType = objParamType.getRawType();
                            Type actualType = null;
                            if (objRawType instanceof Class) {
                                TypeVariable[] objTypeParams = ((Class) objRawType).getTypeParameters();
                                for (int i = 0; i < objTypeParams.length; i++) {
                                    if (objTypeParams[i].getName().equals(typeVar.getName())) {
                                        actualType = objParamType.getActualTypeArguments()[i];
                                    }
                                }
                            }
                            if (actualType instanceof Class) {
                                cls = (Class) actualType;
                            } else {
                                cls = Object.class;
                            }
                        } else {
                            cls = TypeUtils.getClass(typeVar.getBounds()[0]);
                        }
                    } else {
                        cls = TypeUtils.getClass(componentType);
                    }
                } else {
                    componentType = ((Class) type).getComponentType();
                    cls = componentType;
                }
                JSONArray array = new JSONArray();
                parser.parseArray(componentType, array, fieldName);
                return (T) toObjectArray(parser, cls, array);
            }
        }
        ?? r8 = (T) lexer.bytesValue();
        lexer.nextToken(16);
        if (r8.length != 0 || type == byte[].class) {
            return r8;
        }
        return null;
    }

    private <T> T toObjectArray(DefaultJSONParser parser, Class<?> componentType, JSONArray array) {
        Object element;
        if (array == null) {
            return null;
        }
        int size = array.size();
        T t = (T) Array.newInstance(componentType, size);
        for (int i = 0; i < size; i++) {
            Object value = array.get(i);
            if (value == array) {
                Array.set(t, i, t);
            } else if (componentType.isArray()) {
                if (componentType.isInstance(value)) {
                    element = value;
                } else {
                    element = toObjectArray(parser, componentType, (JSONArray) value);
                }
                Array.set(t, i, element);
            } else {
                Object element2 = null;
                if (value instanceof JSONArray) {
                    boolean contains = false;
                    JSONArray valueArray = (JSONArray) value;
                    int valueArraySize = valueArray.size();
                    for (int y = 0; y < valueArraySize; y++) {
                        if (valueArray.get(y) == array) {
                            valueArray.set(i, t);
                            contains = true;
                        }
                    }
                    if (contains) {
                        element2 = valueArray.toArray();
                    }
                }
                if (element2 == null) {
                    element2 = TypeUtils.cast(value, (Class) componentType, parser.getConfig());
                }
                Array.set(t, i, element2);
            }
        }
        array.setRelatedArray(t);
        array.setComponentType(componentType);
        return t;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 14;
    }
}
