package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.util.IOUtils;
import com.alibaba.fastjson.util.RyuDouble;
import com.alibaba.fastjson.util.RyuFloat;
import com.alipay.sdk.m.n.a;
import com.igexin.push.core.b;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.IOException;
import java.io.OutputStream;
import java.io.Writer;
import java.math.BigDecimal;
import java.nio.charset.Charset;
import java.util.List;

public final class SerializeWriter extends Writer {
    private static int BUFFER_THRESHOLD;
    private static final char[] VALUE_FALSE = ":false".toCharArray();
    private static final char[] VALUE_TRUE = ":true".toCharArray();
    private static final ThreadLocal<char[]> bufLocal = new ThreadLocal<>();
    private static final ThreadLocal<byte[]> bytesBufLocal = new ThreadLocal<>();
    static final int nonDirectFeatures = (((((((((SerializerFeature.UseSingleQuotes.mask | 0) | SerializerFeature.BrowserCompatible.mask) | SerializerFeature.PrettyFormat.mask) | SerializerFeature.WriteEnumUsingToString.mask) | SerializerFeature.WriteNonStringValueAsString.mask) | SerializerFeature.WriteSlashAsSpecial.mask) | SerializerFeature.IgnoreErrorGetter.mask) | SerializerFeature.WriteClassName.mask) | SerializerFeature.NotWriteDefaultValue.mask);
    protected boolean beanToArray;
    protected boolean browserSecure;
    protected char[] buf;
    protected int count;
    protected boolean disableCircularReferenceDetect;
    protected int features;
    protected char keySeperator;
    protected int maxBufSize;
    protected boolean notWriteDefaultValue;
    protected boolean quoteFieldNames;
    protected long sepcialBits;
    protected boolean sortField;
    protected boolean useSingleQuotes;
    protected boolean writeDirect;
    protected boolean writeEnumUsingName;
    protected boolean writeEnumUsingToString;
    protected boolean writeNonStringValueAsString;
    private final Writer writer;

    static {
        int serializer_buffer_threshold;
        BUFFER_THRESHOLD = 131072;
        try {
            String prop = IOUtils.getStringProperty("fastjson.serializer_buffer_threshold");
            if (prop != null && prop.length() > 0 && (serializer_buffer_threshold = Integer.parseInt(prop)) >= 64 && serializer_buffer_threshold <= 65536) {
                BUFFER_THRESHOLD = serializer_buffer_threshold * 1024;
            }
        } catch (Throwable th) {
        }
    }

    public SerializeWriter() {
        this((Writer) null);
    }

    public SerializeWriter(Writer writer2) {
        this(writer2, JSON.DEFAULT_GENERATE_FEATURE, SerializerFeature.EMPTY);
    }

    public SerializeWriter(SerializerFeature... features2) {
        this((Writer) null, features2);
    }

    public SerializeWriter(Writer writer2, SerializerFeature... features2) {
        this(writer2, 0, features2);
    }

    public SerializeWriter(Writer writer2, int defaultFeatures, SerializerFeature... features2) {
        this.maxBufSize = -1;
        this.writer = writer2;
        char[] cArr = bufLocal.get();
        this.buf = cArr;
        if (cArr != null) {
            bufLocal.set(null);
        } else {
            this.buf = new char[2048];
        }
        int featuresValue = defaultFeatures;
        for (SerializerFeature feature : features2) {
            featuresValue |= feature.getMask();
        }
        this.features = featuresValue;
        computeFeatures();
    }

    public int getMaxBufSize() {
        return this.maxBufSize;
    }

    public void setMaxBufSize(int maxBufSize2) {
        if (maxBufSize2 >= this.buf.length) {
            this.maxBufSize = maxBufSize2;
            return;
        }
        throw new JSONException("must > " + this.buf.length);
    }

    public int getBufferLength() {
        return this.buf.length;
    }

    public SerializeWriter(int initialSize) {
        this((Writer) null, initialSize);
    }

    public SerializeWriter(Writer writer2, int initialSize) {
        this.maxBufSize = -1;
        this.writer = writer2;
        if (initialSize > 0) {
            this.buf = new char[initialSize];
            computeFeatures();
            return;
        }
        throw new IllegalArgumentException("Negative initial size: " + initialSize);
    }

    public void config(SerializerFeature feature, boolean state) {
        if (state) {
            this.features |= feature.getMask();
            if (feature == SerializerFeature.WriteEnumUsingToString) {
                this.features &= ~SerializerFeature.WriteEnumUsingName.getMask();
            } else if (feature == SerializerFeature.WriteEnumUsingName) {
                this.features &= ~SerializerFeature.WriteEnumUsingToString.getMask();
            }
        } else {
            this.features &= ~feature.getMask();
        }
        computeFeatures();
    }

    /* access modifiers changed from: protected */
    public void computeFeatures() {
        boolean z = true;
        this.quoteFieldNames = (this.features & SerializerFeature.QuoteFieldNames.mask) != 0;
        this.useSingleQuotes = (this.features & SerializerFeature.UseSingleQuotes.mask) != 0;
        this.sortField = (this.features & SerializerFeature.SortField.mask) != 0;
        this.disableCircularReferenceDetect = (this.features & SerializerFeature.DisableCircularReferenceDetect.mask) != 0;
        this.beanToArray = (this.features & SerializerFeature.BeanToArray.mask) != 0;
        this.writeNonStringValueAsString = (this.features & SerializerFeature.WriteNonStringValueAsString.mask) != 0;
        this.notWriteDefaultValue = (this.features & SerializerFeature.NotWriteDefaultValue.mask) != 0;
        this.writeEnumUsingName = (this.features & SerializerFeature.WriteEnumUsingName.mask) != 0;
        this.writeEnumUsingToString = (this.features & SerializerFeature.WriteEnumUsingToString.mask) != 0;
        this.writeDirect = this.quoteFieldNames && (this.features & nonDirectFeatures) == 0 && (this.beanToArray || this.writeEnumUsingName);
        this.keySeperator = this.useSingleQuotes ? Operators.SINGLE_QUOTE : Operators.QUOTE;
        if ((this.features & SerializerFeature.BrowserSecure.mask) == 0) {
            z = false;
        }
        this.browserSecure = z;
        this.sepcialBits = z ? 5764610843043954687L : (this.features & SerializerFeature.WriteSlashAsSpecial.mask) != 0 ? 140758963191807L : 21474836479L;
    }

    public boolean isSortField() {
        return this.sortField;
    }

    public boolean isNotWriteDefaultValue() {
        return this.notWriteDefaultValue;
    }

    public boolean isEnabled(SerializerFeature feature) {
        return (this.features & feature.mask) != 0;
    }

    public boolean isEnabled(int feature) {
        return (this.features & feature) != 0;
    }

    @Override // java.io.Writer
    public void write(int c) {
        int newcount = this.count + 1;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else {
                flush();
                newcount = 1;
            }
        }
        this.buf[this.count] = (char) c;
        this.count = newcount;
    }

    @Override // java.io.Writer
    public void write(char[] c, int off, int len) {
        if (off < 0 || off > c.length || len < 0 || off + len > c.length || off + len < 0) {
            throw new IndexOutOfBoundsException();
        } else if (len != 0) {
            int newcount = this.count + len;
            if (newcount > this.buf.length) {
                if (this.writer == null) {
                    expandCapacity(newcount);
                } else {
                    do {
                        char[] cArr = this.buf;
                        int length = cArr.length;
                        int i = this.count;
                        int rest = length - i;
                        System.arraycopy(c, off, cArr, i, rest);
                        this.count = this.buf.length;
                        flush();
                        len -= rest;
                        off += rest;
                    } while (len > this.buf.length);
                    newcount = len;
                }
            }
            System.arraycopy(c, off, this.buf, this.count, len);
            this.count = newcount;
        }
    }

    public void expandCapacity(int minimumCapacity) {
        char[] charsLocal;
        int i = this.maxBufSize;
        if (i == -1 || minimumCapacity < i) {
            char[] cArr = this.buf;
            int newCapacity = cArr.length + (cArr.length >> 1) + 1;
            if (newCapacity < minimumCapacity) {
                newCapacity = minimumCapacity;
            }
            char[] newValue = new char[newCapacity];
            System.arraycopy(this.buf, 0, newValue, 0, this.count);
            if (this.buf.length < BUFFER_THRESHOLD && ((charsLocal = bufLocal.get()) == null || charsLocal.length < this.buf.length)) {
                bufLocal.set(this.buf);
            }
            this.buf = newValue;
            return;
        }
        throw new JSONException("serialize exceeded MAX_OUTPUT_LENGTH=" + this.maxBufSize + ", minimumCapacity=" + minimumCapacity);
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(CharSequence csq) {
        String s = csq == null ? b.m : csq.toString();
        write(s, 0, s.length());
        return this;
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(CharSequence csq, int start, int end) {
        String s = (csq == null ? b.m : csq).subSequence(start, end).toString();
        write(s, 0, s.length());
        return this;
    }

    @Override // java.lang.Appendable, java.io.Writer, java.io.Writer
    public SerializeWriter append(char c) {
        write(c);
        return this;
    }

    @Override // java.io.Writer
    public void write(String str, int off, int len) {
        int newcount = this.count + len;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else {
                do {
                    char[] cArr = this.buf;
                    int length = cArr.length;
                    int i = this.count;
                    int rest = length - i;
                    str.getChars(off, off + rest, cArr, i);
                    this.count = this.buf.length;
                    flush();
                    len -= rest;
                    off += rest;
                } while (len > this.buf.length);
                newcount = len;
            }
        }
        str.getChars(off, off + len, this.buf, this.count);
        this.count = newcount;
    }

    public void writeTo(Writer out) throws IOException {
        if (this.writer == null) {
            out.write(this.buf, 0, this.count);
            return;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    public void writeTo(OutputStream out, String charsetName) throws IOException {
        writeTo(out, Charset.forName(charsetName));
    }

    public void writeTo(OutputStream out, Charset charset) throws IOException {
        writeToEx(out, charset);
    }

    public int writeToEx(OutputStream out, Charset charset) throws IOException {
        if (this.writer != null) {
            throw new UnsupportedOperationException("writer not null");
        } else if (charset == IOUtils.UTF8) {
            return encodeToUTF8(out);
        } else {
            byte[] bytes = new String(this.buf, 0, this.count).getBytes(charset);
            out.write(bytes);
            return bytes.length;
        }
    }

    public char[] toCharArray() {
        if (this.writer == null) {
            int i = this.count;
            char[] newValue = new char[i];
            System.arraycopy(this.buf, 0, newValue, 0, i);
            return newValue;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    public char[] toCharArrayForSpringWebSocket() {
        if (this.writer == null) {
            int i = this.count;
            char[] newValue = new char[(i - 2)];
            System.arraycopy(this.buf, 1, newValue, 0, i - 2);
            return newValue;
        }
        throw new UnsupportedOperationException("writer not null");
    }

    public byte[] toBytes(String charsetName) {
        Charset charset;
        if (charsetName == null || "UTF-8".equals(charsetName)) {
            charset = IOUtils.UTF8;
        } else {
            charset = Charset.forName(charsetName);
        }
        return toBytes(charset);
    }

    public byte[] toBytes(Charset charset) {
        if (this.writer != null) {
            throw new UnsupportedOperationException("writer not null");
        } else if (charset == IOUtils.UTF8) {
            return encodeToUTF8Bytes();
        } else {
            return new String(this.buf, 0, this.count).getBytes(charset);
        }
    }

    private int encodeToUTF8(OutputStream out) throws IOException {
        int bytesLength = (int) (((double) this.count) * 3.0d);
        byte[] bytes = bytesBufLocal.get();
        if (bytes == null) {
            bytes = new byte[8192];
            bytesBufLocal.set(bytes);
        }
        if (bytes.length < bytesLength) {
            bytes = new byte[bytesLength];
        }
        int position = IOUtils.encodeUTF8(this.buf, 0, this.count, bytes);
        out.write(bytes, 0, position);
        if (bytes != bytes && bytes.length <= BUFFER_THRESHOLD) {
            bytesBufLocal.set(bytes);
        }
        return position;
    }

    private byte[] encodeToUTF8Bytes() {
        int bytesLength = (int) (((double) this.count) * 3.0d);
        byte[] bytes = bytesBufLocal.get();
        if (bytes == null) {
            bytes = new byte[8192];
            bytesBufLocal.set(bytes);
        }
        if (bytes.length < bytesLength) {
            bytes = new byte[bytesLength];
        }
        int position = IOUtils.encodeUTF8(this.buf, 0, this.count, bytes);
        byte[] copy = new byte[position];
        System.arraycopy(bytes, 0, copy, 0, position);
        if (bytes != bytes && bytes.length <= BUFFER_THRESHOLD) {
            bytesBufLocal.set(bytes);
        }
        return copy;
    }

    public int size() {
        return this.count;
    }

    public String toString() {
        return new String(this.buf, 0, this.count);
    }

    @Override // java.io.Closeable, java.io.Writer, java.lang.AutoCloseable
    public void close() {
        if (this.writer != null && this.count > 0) {
            flush();
        }
        char[] cArr = this.buf;
        if (cArr.length <= BUFFER_THRESHOLD) {
            bufLocal.set(cArr);
        }
        this.buf = null;
    }

    @Override // java.io.Writer
    public void write(String text) {
        if (text == null) {
            writeNull();
        } else {
            write(text, 0, text.length());
        }
    }

    public void writeInt(int i) {
        if (i == Integer.MIN_VALUE) {
            write("-2147483648");
            return;
        }
        int size = i < 0 ? IOUtils.stringSize(-i) + 1 : IOUtils.stringSize(i);
        int newcount = this.count + size;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else {
                char[] chars = new char[size];
                IOUtils.getChars(i, size, chars);
                write(chars, 0, chars.length);
                return;
            }
        }
        IOUtils.getChars(i, newcount, this.buf);
        this.count = newcount;
    }

    /* JADX INFO: Multiple debug info for r4v0 char[]: [D('emptyString' java.lang.String), D('CA' char[])] */
    public void writeByteArray(byte[] bytes) {
        if (isEnabled(SerializerFeature.WriteClassName.mask)) {
            writeHex(bytes);
            return;
        }
        int bytesLen = bytes.length;
        char quote = this.useSingleQuotes ? Operators.SINGLE_QUOTE : Operators.QUOTE;
        if (bytesLen == 0) {
            write(this.useSingleQuotes ? "''" : "\"\"");
            return;
        }
        char[] CA = IOUtils.CA;
        int eLen = (bytesLen / 3) * 3;
        int offset = this.count;
        int newcount = this.count + ((((bytesLen - 1) / 3) + 1) << 2) + 2;
        int i = 0;
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(quote);
                int i2 = 0;
                while (i2 < eLen) {
                    int s = i2 + 1;
                    int s2 = s + 1;
                    int i3 = ((bytes[i2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bytes[s] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bytes[s2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
                    write(CA[(i3 >>> 18) & 63]);
                    write(CA[(i3 >>> 12) & 63]);
                    write(CA[(i3 >>> 6) & 63]);
                    write(CA[i3 & 63]);
                    i2 = s2 + 1;
                }
                int left = bytesLen - eLen;
                if (left > 0) {
                    int i4 = (bytes[eLen] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 10;
                    if (left == 2) {
                        i = (bytes[bytesLen - 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 2;
                    }
                    int i5 = i | i4;
                    write(CA[i5 >> 12]);
                    write(CA[(i5 >>> 6) & 63]);
                    write(left == 2 ? CA[i5 & 63] : a.h);
                    write(61);
                }
                write(quote);
                return;
            }
            expandCapacity(newcount);
        }
        this.count = newcount;
        int offset2 = offset + 1;
        this.buf[offset] = quote;
        int i6 = 0;
        int d = offset2;
        while (i6 < eLen) {
            int s3 = i6 + 1;
            int s4 = s3 + 1;
            int i7 = ((bytes[i6] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bytes[s3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8);
            int s5 = s4 + 1;
            int i8 = i7 | (bytes[s4] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
            char[] cArr = this.buf;
            int d2 = d + 1;
            cArr[d] = CA[(i8 >>> 18) & 63];
            int d3 = d2 + 1;
            cArr[d2] = CA[(i8 >>> 12) & 63];
            int d4 = d3 + 1;
            cArr[d3] = CA[(i8 >>> 6) & 63];
            d = d4 + 1;
            cArr[d4] = CA[i8 & 63];
            i6 = s5;
        }
        int left2 = bytesLen - eLen;
        if (left2 > 0) {
            int i9 = (bytes[eLen] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 10;
            if (left2 == 2) {
                i = (bytes[bytesLen - 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 2;
            }
            int i10 = i9 | i;
            char[] cArr2 = this.buf;
            cArr2[newcount - 5] = CA[i10 >> 12];
            cArr2[newcount - 4] = CA[(i10 >>> 6) & 63];
            cArr2[newcount - 3] = left2 == 2 ? CA[i10 & 63] : a.h;
            this.buf[newcount - 2] = a.h;
        }
        this.buf[newcount - 1] = quote;
    }

    public void writeHex(byte[] bytes) {
        int newcount = this.count + (bytes.length * 2) + 3;
        if (newcount > this.buf.length) {
            expandCapacity(newcount);
        }
        char[] cArr = this.buf;
        int i = this.count;
        int i2 = i + 1;
        this.count = i2;
        cArr[i] = 'x';
        this.count = i2 + 1;
        cArr[i2] = Operators.SINGLE_QUOTE;
        for (byte b : bytes) {
            int a = b & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
            int b0 = a >> 4;
            int b1 = a & 15;
            char[] cArr2 = this.buf;
            int i3 = this.count;
            this.count = i3 + 1;
            int i4 = 48;
            cArr2[i3] = (char) ((b0 < 10 ? 48 : 55) + b0);
            char[] cArr3 = this.buf;
            int i5 = this.count;
            this.count = i5 + 1;
            if (b1 >= 10) {
                i4 = 55;
            }
            cArr3[i5] = (char) (i4 + b1);
        }
        char[] cArr4 = this.buf;
        int i6 = this.count;
        this.count = i6 + 1;
        cArr4[i6] = Operators.SINGLE_QUOTE;
    }

    public void writeFloat(float value, boolean checkWriteClassName) {
        if (value != value || value == Float.POSITIVE_INFINITY || value == Float.NEGATIVE_INFINITY) {
            writeNull();
            return;
        }
        int newcount = this.count + 15;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else {
                String str = RyuFloat.toString(value);
                write(str, 0, str.length());
                if (checkWriteClassName && isEnabled(SerializerFeature.WriteClassName)) {
                    write(70);
                    return;
                }
                return;
            }
        }
        this.count += RyuFloat.toString(value, this.buf, this.count);
        if (checkWriteClassName && isEnabled(SerializerFeature.WriteClassName)) {
            write(70);
        }
    }

    public void writeDouble(double value, boolean checkWriteClassName) {
        if (Double.isNaN(value) || Double.isInfinite(value)) {
            writeNull();
            return;
        }
        int newcount = this.count + 24;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else {
                String str = RyuDouble.toString(value);
                write(str, 0, str.length());
                if (checkWriteClassName && isEnabled(SerializerFeature.WriteClassName)) {
                    write(68);
                    return;
                }
                return;
            }
        }
        this.count += RyuDouble.toString(value, this.buf, this.count);
        if (checkWriteClassName && isEnabled(SerializerFeature.WriteClassName)) {
            write(68);
        }
    }

    public void writeEnum(Enum<?> value) {
        if (value == null) {
            writeNull();
            return;
        }
        String strVal = null;
        if (this.writeEnumUsingName && !this.writeEnumUsingToString) {
            strVal = value.name();
        } else if (this.writeEnumUsingToString) {
            strVal = value.toString();
        }
        if (strVal != null) {
            char quote = isEnabled(SerializerFeature.UseSingleQuotes) ? Operators.SINGLE_QUOTE : Operators.QUOTE;
            write(quote);
            write(strVal);
            write(quote);
            return;
        }
        writeInt(value.ordinal());
    }

    public void writeLongAndChar(long i, char c) throws IOException {
        writeLong(i);
        write(c);
    }

    public void writeLong(long i) {
        boolean needQuotationMark = isEnabled(SerializerFeature.BrowserCompatible) && !isEnabled(SerializerFeature.WriteClassName) && (i > 9007199254740991L || i < -9007199254740991L);
        if (i != Long.MIN_VALUE) {
            int size = i < 0 ? IOUtils.stringSize(-i) + 1 : IOUtils.stringSize(i);
            int newcount = this.count + size;
            if (needQuotationMark) {
                newcount += 2;
            }
            if (newcount > this.buf.length) {
                if (this.writer == null) {
                    expandCapacity(newcount);
                } else {
                    char[] chars = new char[size];
                    IOUtils.getChars(i, size, chars);
                    if (needQuotationMark) {
                        write(34);
                        write(chars, 0, chars.length);
                        write(34);
                        return;
                    }
                    write(chars, 0, chars.length);
                    return;
                }
            }
            if (needQuotationMark) {
                char[] cArr = this.buf;
                cArr[this.count] = Operators.QUOTE;
                IOUtils.getChars(i, newcount - 1, cArr);
                this.buf[newcount - 1] = Operators.QUOTE;
            } else {
                IOUtils.getChars(i, newcount, this.buf);
            }
            this.count = newcount;
        } else if (needQuotationMark) {
            write("\"-9223372036854775808\"");
        } else {
            write("-9223372036854775808");
        }
    }

    public void writeNull() {
        write(b.m);
    }

    public void writeNull(SerializerFeature feature) {
        writeNull(0, feature.mask);
    }

    public void writeNull(int beanFeatures, int feature) {
        if ((beanFeatures & feature) == 0 && (this.features & feature) == 0) {
            writeNull();
        } else if ((SerializerFeature.WriteMapNullValue.mask & beanFeatures) != 0 && ((~SerializerFeature.WriteMapNullValue.mask) & beanFeatures & SerializerFeature.WRITE_MAP_NULL_FEATURES) == 0) {
            writeNull();
        } else if (feature == SerializerFeature.WriteNullListAsEmpty.mask) {
            write("[]");
        } else if (feature == SerializerFeature.WriteNullStringAsEmpty.mask) {
            writeString("");
        } else if (feature == SerializerFeature.WriteNullBooleanAsFalse.mask) {
            write(AbsoluteConst.FALSE);
        } else if (feature == SerializerFeature.WriteNullNumberAsZero.mask) {
            write(48);
        } else {
            writeNull();
        }
    }

    /* JADX INFO: Multiple debug info for r13v28 int: [D('lastSpecialIndex' int), D('srcPos' int)] */
    /* JADX WARNING: Code restructure failed: missing block: B:138:0x0342, code lost:
        if ((r27.sepcialBits & (1 << r9)) == 0) goto L_0x0347;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:206:0x050f, code lost:
        if (r12 == '>') goto L_0x0514;
     */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x0350  */
    public void writeStringWithDoubleQuote(String text, char seperator) {
        int lastSpecialIndex;
        boolean special;
        if (text == null) {
            writeNull();
            if (seperator != 0) {
                write(seperator);
                return;
            }
            return;
        }
        int len = text.length();
        int newcount = this.count + len + 2;
        if (seperator != 0) {
            newcount++;
        }
        char c = '>';
        char c2 = '\f';
        char c3 = '\b';
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(34);
                int i = 0;
                while (i < text.length()) {
                    char ch = text.charAt(i);
                    if (!isEnabled(SerializerFeature.BrowserSecure) || !(ch == '(' || ch == ')' || ch == '<' || ch == c)) {
                        if (isEnabled(SerializerFeature.BrowserCompatible)) {
                            if (ch == '\b' || ch == '\f' || ch == '\n' || ch == '\r' || ch == '\t' || ch == '\"' || ch == '/' || ch == '\\') {
                                write(92);
                                write(IOUtils.replaceChars[ch]);
                            } else if (ch < ' ') {
                                write(92);
                                write(117);
                                write(48);
                                write(48);
                                write(IOUtils.ASCII_CHARS[ch * 2]);
                                write(IOUtils.ASCII_CHARS[(ch * 2) + 1]);
                            } else if (ch >= 127) {
                                write(92);
                                write(117);
                                write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                                write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                                write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                                write(IOUtils.DIGITS[ch & 15]);
                            }
                        } else if ((ch < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[ch] != 0) || (ch == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                            write(92);
                            if (IOUtils.specicalFlags_doubleQuotes[ch] == 4) {
                                write(117);
                                write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                                write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                                write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                                write(IOUtils.DIGITS[ch & 15]);
                            } else {
                                write(IOUtils.replaceChars[ch]);
                            }
                        }
                        write(ch);
                    } else {
                        write(92);
                        write(117);
                        write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                        write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                        write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                        write(IOUtils.DIGITS[ch & 15]);
                    }
                    i++;
                    c = '>';
                }
                write(34);
                if (seperator != 0) {
                    write(seperator);
                    return;
                }
                return;
            }
            expandCapacity(newcount);
        }
        int i2 = this.count;
        int start = i2 + 1;
        int end = start + len;
        char[] cArr = this.buf;
        cArr[i2] = Operators.QUOTE;
        text.getChars(0, len, cArr, start);
        this.count = newcount;
        if (isEnabled(SerializerFeature.BrowserCompatible)) {
            int lastSpecialIndex2 = -1;
            for (int i3 = start; i3 < end; i3++) {
                char ch2 = this.buf[i3];
                if (ch2 == '\"' || ch2 == '/' || ch2 == '\\') {
                    lastSpecialIndex2 = i3;
                    newcount++;
                } else if (ch2 == '\b' || ch2 == '\f' || ch2 == '\n' || ch2 == '\r' || ch2 == '\t') {
                    lastSpecialIndex2 = i3;
                    newcount++;
                } else if (ch2 < ' ') {
                    lastSpecialIndex2 = i3;
                    newcount += 5;
                } else if (ch2 >= 127) {
                    lastSpecialIndex2 = i3;
                    newcount += 5;
                }
            }
            if (newcount > this.buf.length) {
                expandCapacity(newcount);
            }
            this.count = newcount;
            int i4 = lastSpecialIndex2;
            while (i4 >= start) {
                char[] cArr2 = this.buf;
                char ch3 = cArr2[i4];
                if (ch3 == c3 || ch3 == c2 || ch3 == '\n' || ch3 == '\r' || ch3 == '\t') {
                    char[] cArr3 = this.buf;
                    System.arraycopy(cArr3, i4 + 1, cArr3, i4 + 2, (end - i4) - 1);
                    char[] cArr4 = this.buf;
                    cArr4[i4] = '\\';
                    cArr4[i4 + 1] = IOUtils.replaceChars[ch3];
                    end++;
                } else if (ch3 == '\"' || ch3 == '/' || ch3 == '\\') {
                    char[] cArr5 = this.buf;
                    System.arraycopy(cArr5, i4 + 1, cArr5, i4 + 2, (end - i4) - 1);
                    char[] cArr6 = this.buf;
                    cArr6[i4] = '\\';
                    cArr6[i4 + 1] = ch3;
                    end++;
                } else if (ch3 < ' ') {
                    System.arraycopy(cArr2, i4 + 1, cArr2, i4 + 6, (end - i4) - 1);
                    char[] cArr7 = this.buf;
                    cArr7[i4] = '\\';
                    cArr7[i4 + 1] = 'u';
                    cArr7[i4 + 2] = '0';
                    cArr7[i4 + 3] = '0';
                    cArr7[i4 + 4] = IOUtils.ASCII_CHARS[ch3 * 2];
                    this.buf[i4 + 5] = IOUtils.ASCII_CHARS[(ch3 * 2) + 1];
                    end += 5;
                } else if (ch3 >= 127) {
                    System.arraycopy(cArr2, i4 + 1, cArr2, i4 + 6, (end - i4) - 1);
                    char[] cArr8 = this.buf;
                    cArr8[i4] = '\\';
                    cArr8[i4 + 1] = 'u';
                    cArr8[i4 + 2] = IOUtils.DIGITS[(ch3 >>> '\f') & 15];
                    this.buf[i4 + 3] = IOUtils.DIGITS[(ch3 >>> '\b') & 15];
                    this.buf[i4 + 4] = IOUtils.DIGITS[(ch3 >>> 4) & 15];
                    this.buf[i4 + 5] = IOUtils.DIGITS[ch3 & 15];
                    end += 5;
                }
                i4--;
                c2 = '\f';
                c3 = '\b';
            }
            if (seperator != 0) {
                char[] cArr9 = this.buf;
                int i5 = this.count;
                cArr9[i5 - 2] = Operators.QUOTE;
                cArr9[i5 - 1] = seperator;
                return;
            }
            this.buf[this.count - 1] = Operators.QUOTE;
            return;
        }
        int specialCount = 0;
        int lastSpecialIndex3 = -1;
        int firstSpecialIndex = -1;
        char lastSpecial = 0;
        for (int i6 = start; i6 < end; i6++) {
            char ch4 = this.buf[i6];
            if (ch4 < ']') {
                if (ch4 < '@') {
                    lastSpecialIndex = lastSpecialIndex3;
                } else {
                    lastSpecialIndex = lastSpecialIndex3;
                }
                if (ch4 != '\\') {
                    special = false;
                    if (special) {
                        specialCount++;
                        if (ch4 == '(' || ch4 == ')' || ch4 == '<' || ch4 == '>' || (ch4 < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[ch4] == 4)) {
                            newcount += 4;
                        }
                        if (firstSpecialIndex == -1) {
                            firstSpecialIndex = i6;
                            lastSpecial = ch4;
                            lastSpecialIndex3 = i6;
                        } else {
                            lastSpecial = ch4;
                            lastSpecialIndex3 = i6;
                        }
                    }
                }
                special = true;
                if (special) {
                }
            } else if (ch4 < 127 || !(ch4 == 8232 || ch4 == 8233 || ch4 < 160)) {
                lastSpecialIndex = lastSpecialIndex3;
            } else {
                if (firstSpecialIndex == -1) {
                    firstSpecialIndex = i6;
                }
                specialCount++;
                newcount += 4;
                lastSpecialIndex3 = i6;
                lastSpecial = ch4;
            }
            lastSpecialIndex3 = lastSpecialIndex;
        }
        if (specialCount > 0) {
            int newcount2 = newcount + specialCount;
            if (newcount2 > this.buf.length) {
                expandCapacity(newcount2);
            }
            this.count = newcount2;
            if (specialCount != 1) {
                char c4 = 8232;
                if (specialCount > 1) {
                    int bufIndex = firstSpecialIndex;
                    int i7 = firstSpecialIndex - start;
                    while (i7 < text.length()) {
                        char ch5 = text.charAt(i7);
                        if (this.browserSecure) {
                            if (ch5 == '(' || ch5 == ')' || ch5 == '<') {
                            }
                            char[] cArr10 = this.buf;
                            int bufIndex2 = bufIndex + 1;
                            cArr10[bufIndex] = '\\';
                            int bufIndex3 = bufIndex2 + 1;
                            cArr10[bufIndex2] = 'u';
                            int bufIndex4 = bufIndex3 + 1;
                            cArr10[bufIndex3] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                            int bufIndex5 = bufIndex4 + 1;
                            this.buf[bufIndex4] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                            int bufIndex6 = bufIndex5 + 1;
                            this.buf[bufIndex5] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                            this.buf[bufIndex6] = IOUtils.DIGITS[ch5 & 15];
                            end += 5;
                            bufIndex = bufIndex6 + 1;
                            i7++;
                            c4 = 8232;
                        }
                        if (ch5 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[ch5] == 0) {
                            if (ch5 == '/') {
                                if (!isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                                }
                            }
                            if (ch5 == c4 || ch5 == 8233) {
                                char[] cArr11 = this.buf;
                                int bufIndex7 = bufIndex + 1;
                                cArr11[bufIndex] = '\\';
                                int bufIndex8 = bufIndex7 + 1;
                                cArr11[bufIndex7] = 'u';
                                int bufIndex9 = bufIndex8 + 1;
                                cArr11[bufIndex8] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                                int bufIndex10 = bufIndex9 + 1;
                                this.buf[bufIndex9] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                                int bufIndex11 = bufIndex10 + 1;
                                this.buf[bufIndex10] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                                bufIndex = bufIndex11 + 1;
                                this.buf[bufIndex11] = IOUtils.DIGITS[ch5 & 15];
                                end += 5;
                                i7++;
                                c4 = 8232;
                            } else {
                                this.buf[bufIndex] = ch5;
                                bufIndex++;
                                i7++;
                                c4 = 8232;
                            }
                        }
                        int bufIndex12 = bufIndex + 1;
                        this.buf[bufIndex] = '\\';
                        if (IOUtils.specicalFlags_doubleQuotes[ch5] == 4) {
                            char[] cArr12 = this.buf;
                            int bufIndex13 = bufIndex12 + 1;
                            cArr12[bufIndex12] = 'u';
                            int bufIndex14 = bufIndex13 + 1;
                            cArr12[bufIndex13] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                            int bufIndex15 = bufIndex14 + 1;
                            this.buf[bufIndex14] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                            int bufIndex16 = bufIndex15 + 1;
                            this.buf[bufIndex15] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                            this.buf[bufIndex16] = IOUtils.DIGITS[ch5 & 15];
                            end += 5;
                            bufIndex = bufIndex16 + 1;
                        } else {
                            this.buf[bufIndex12] = IOUtils.replaceChars[ch5];
                            end++;
                            bufIndex = bufIndex12 + 1;
                        }
                        i7++;
                        c4 = 8232;
                    }
                }
            } else if (lastSpecial == 8232) {
                char[] cArr13 = this.buf;
                System.arraycopy(cArr13, lastSpecialIndex3 + 1, cArr13, lastSpecialIndex3 + 6, (end - lastSpecialIndex3) - 1);
                char[] cArr14 = this.buf;
                cArr14[lastSpecialIndex3] = '\\';
                int lastSpecialIndex4 = lastSpecialIndex3 + 1;
                cArr14[lastSpecialIndex4] = 'u';
                int lastSpecialIndex5 = lastSpecialIndex4 + 1;
                cArr14[lastSpecialIndex5] = '2';
                int lastSpecialIndex6 = lastSpecialIndex5 + 1;
                cArr14[lastSpecialIndex6] = '0';
                int lastSpecialIndex7 = lastSpecialIndex6 + 1;
                cArr14[lastSpecialIndex7] = '2';
                cArr14[lastSpecialIndex7 + 1] = '8';
            } else if (lastSpecial == 8233) {
                char[] cArr15 = this.buf;
                System.arraycopy(cArr15, lastSpecialIndex3 + 1, cArr15, lastSpecialIndex3 + 6, (end - lastSpecialIndex3) - 1);
                char[] cArr16 = this.buf;
                cArr16[lastSpecialIndex3] = '\\';
                int lastSpecialIndex8 = lastSpecialIndex3 + 1;
                cArr16[lastSpecialIndex8] = 'u';
                int lastSpecialIndex9 = lastSpecialIndex8 + 1;
                cArr16[lastSpecialIndex9] = '2';
                int lastSpecialIndex10 = lastSpecialIndex9 + 1;
                cArr16[lastSpecialIndex10] = '0';
                int lastSpecialIndex11 = lastSpecialIndex10 + 1;
                cArr16[lastSpecialIndex11] = '2';
                cArr16[lastSpecialIndex11 + 1] = '9';
            } else if (lastSpecial == '(' || lastSpecial == ')' || lastSpecial == '<' || lastSpecial == '>') {
                char[] cArr17 = this.buf;
                System.arraycopy(cArr17, lastSpecialIndex3 + 1, cArr17, lastSpecialIndex3 + 6, (end - lastSpecialIndex3) - 1);
                char[] cArr18 = this.buf;
                cArr18[lastSpecialIndex3] = '\\';
                int lastSpecialIndex12 = lastSpecialIndex3 + 1;
                cArr18[lastSpecialIndex12] = 'u';
                int lastSpecialIndex13 = lastSpecialIndex12 + 1;
                cArr18[lastSpecialIndex13] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                int lastSpecialIndex14 = lastSpecialIndex13 + 1;
                this.buf[lastSpecialIndex14] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                int lastSpecialIndex15 = lastSpecialIndex14 + 1;
                this.buf[lastSpecialIndex15] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                this.buf[lastSpecialIndex15 + 1] = IOUtils.DIGITS[lastSpecial & 15];
            } else if (lastSpecial >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[lastSpecial] != 4) {
                char[] cArr19 = this.buf;
                System.arraycopy(cArr19, lastSpecialIndex3 + 1, cArr19, lastSpecialIndex3 + 2, (end - lastSpecialIndex3) - 1);
                char[] cArr20 = this.buf;
                cArr20[lastSpecialIndex3] = '\\';
                cArr20[lastSpecialIndex3 + 1] = IOUtils.replaceChars[lastSpecial];
            } else {
                char[] cArr21 = this.buf;
                System.arraycopy(cArr21, lastSpecialIndex3 + 1, cArr21, lastSpecialIndex3 + 6, (end - lastSpecialIndex3) - 1);
                char[] cArr22 = this.buf;
                int bufIndex17 = lastSpecialIndex3 + 1;
                cArr22[lastSpecialIndex3] = '\\';
                int bufIndex18 = bufIndex17 + 1;
                cArr22[bufIndex17] = 'u';
                int bufIndex19 = bufIndex18 + 1;
                cArr22[bufIndex18] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                int bufIndex20 = bufIndex19 + 1;
                this.buf[bufIndex19] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                int bufIndex21 = bufIndex20 + 1;
                this.buf[bufIndex20] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                int i8 = bufIndex21 + 1;
                this.buf[bufIndex21] = IOUtils.DIGITS[lastSpecial & 15];
            }
        }
        if (seperator != 0) {
            char[] cArr23 = this.buf;
            int i9 = this.count;
            cArr23[i9 - 2] = Operators.QUOTE;
            cArr23[i9 - 1] = seperator;
            return;
        }
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:138:0x0338, code lost:
        if ((r27.sepcialBits & (1 << r9)) == 0) goto L_0x033d;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:206:0x04f0, code lost:
        if (r12 == '>') goto L_0x04f5;
     */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x0346  */
    /* JADX WARNING: Removed duplicated region for block: B:259:0x0370 A[SYNTHETIC] */
    public void writeStringWithDoubleQuote(char[] text, char seperator) {
        char c;
        int end;
        boolean special;
        if (text == null) {
            writeNull();
            if (seperator != 0) {
                write(seperator);
                return;
            }
            return;
        }
        int len = text.length;
        int newcount = this.count + len + 2;
        if (seperator != 0) {
            newcount++;
        }
        char c2 = '>';
        char c3 = '\f';
        char c4 = '\b';
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(34);
                int i = 0;
                while (i < text.length) {
                    char ch = text[i];
                    if (!isEnabled(SerializerFeature.BrowserSecure) || !(ch == '(' || ch == ')' || ch == '<' || ch == c2)) {
                        if (isEnabled(SerializerFeature.BrowserCompatible)) {
                            if (ch == '\b' || ch == '\f' || ch == '\n' || ch == '\r' || ch == '\t' || ch == '\"' || ch == '/' || ch == '\\') {
                                write(92);
                                write(IOUtils.replaceChars[ch]);
                            } else if (ch < ' ') {
                                write(92);
                                write(117);
                                write(48);
                                write(48);
                                write(IOUtils.ASCII_CHARS[ch * 2]);
                                write(IOUtils.ASCII_CHARS[(ch * 2) + 1]);
                            } else if (ch >= 127) {
                                write(92);
                                write(117);
                                write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                                write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                                write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                                write(IOUtils.DIGITS[ch & 15]);
                            }
                        } else if ((ch < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[ch] != 0) || (ch == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                            write(92);
                            if (IOUtils.specicalFlags_doubleQuotes[ch] == 4) {
                                write(117);
                                write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                                write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                                write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                                write(IOUtils.DIGITS[ch & 15]);
                            } else {
                                write(IOUtils.replaceChars[ch]);
                            }
                        }
                        write(ch);
                    } else {
                        write(92);
                        write(117);
                        write(IOUtils.DIGITS[(ch >>> '\f') & 15]);
                        write(IOUtils.DIGITS[(ch >>> '\b') & 15]);
                        write(IOUtils.DIGITS[(ch >>> 4) & 15]);
                        write(IOUtils.DIGITS[ch & 15]);
                    }
                    i++;
                    c2 = '>';
                }
                write(34);
                if (seperator != 0) {
                    write(seperator);
                    return;
                }
                return;
            }
            expandCapacity(newcount);
        }
        int i2 = this.count;
        int start = i2 + 1;
        int end2 = start + len;
        char[] cArr = this.buf;
        cArr[i2] = Operators.QUOTE;
        System.arraycopy(text, 0, cArr, start, text.length);
        this.count = newcount;
        if (isEnabled(SerializerFeature.BrowserCompatible)) {
            int lastSpecialIndex = -1;
            for (int i3 = start; i3 < end2; i3++) {
                char ch2 = this.buf[i3];
                if (ch2 == '\"' || ch2 == '/' || ch2 == '\\') {
                    lastSpecialIndex = i3;
                    newcount++;
                } else if (ch2 == '\b' || ch2 == '\f' || ch2 == '\n' || ch2 == '\r' || ch2 == '\t') {
                    lastSpecialIndex = i3;
                    newcount++;
                } else if (ch2 < ' ') {
                    lastSpecialIndex = i3;
                    newcount += 5;
                } else if (ch2 >= 127) {
                    lastSpecialIndex = i3;
                    newcount += 5;
                }
            }
            if (newcount > this.buf.length) {
                expandCapacity(newcount);
            }
            this.count = newcount;
            int i4 = lastSpecialIndex;
            while (i4 >= start) {
                char[] cArr2 = this.buf;
                char ch3 = cArr2[i4];
                if (ch3 == c4 || ch3 == c3 || ch3 == '\n' || ch3 == '\r' || ch3 == '\t') {
                    char[] cArr3 = this.buf;
                    System.arraycopy(cArr3, i4 + 1, cArr3, i4 + 2, (end2 - i4) - 1);
                    char[] cArr4 = this.buf;
                    cArr4[i4] = '\\';
                    cArr4[i4 + 1] = IOUtils.replaceChars[ch3];
                    end2++;
                } else if (ch3 == '\"' || ch3 == '/' || ch3 == '\\') {
                    char[] cArr5 = this.buf;
                    System.arraycopy(cArr5, i4 + 1, cArr5, i4 + 2, (end2 - i4) - 1);
                    char[] cArr6 = this.buf;
                    cArr6[i4] = '\\';
                    cArr6[i4 + 1] = ch3;
                    end2++;
                } else if (ch3 < ' ') {
                    System.arraycopy(cArr2, i4 + 1, cArr2, i4 + 6, (end2 - i4) - 1);
                    char[] cArr7 = this.buf;
                    cArr7[i4] = '\\';
                    cArr7[i4 + 1] = 'u';
                    cArr7[i4 + 2] = '0';
                    cArr7[i4 + 3] = '0';
                    cArr7[i4 + 4] = IOUtils.ASCII_CHARS[ch3 * 2];
                    this.buf[i4 + 5] = IOUtils.ASCII_CHARS[(ch3 * 2) + 1];
                    end2 += 5;
                } else if (ch3 >= 127) {
                    System.arraycopy(cArr2, i4 + 1, cArr2, i4 + 6, (end2 - i4) - 1);
                    char[] cArr8 = this.buf;
                    cArr8[i4] = '\\';
                    cArr8[i4 + 1] = 'u';
                    cArr8[i4 + 2] = IOUtils.DIGITS[(ch3 >>> '\f') & 15];
                    this.buf[i4 + 3] = IOUtils.DIGITS[(ch3 >>> '\b') & 15];
                    this.buf[i4 + 4] = IOUtils.DIGITS[(ch3 >>> 4) & 15];
                    this.buf[i4 + 5] = IOUtils.DIGITS[ch3 & 15];
                    end2 += 5;
                }
                i4--;
                c3 = '\f';
                c4 = '\b';
            }
            if (seperator != 0) {
                char[] cArr9 = this.buf;
                int i5 = this.count;
                cArr9[i5 - 2] = Operators.QUOTE;
                cArr9[i5 - 1] = seperator;
                return;
            }
            this.buf[this.count - 1] = Operators.QUOTE;
            return;
        }
        int specialCount = 0;
        int lastSpecialIndex2 = -1;
        int firstSpecialIndex = -1;
        char lastSpecial = 0;
        int i6 = start;
        while (true) {
            c = 8232;
            if (i6 >= end2) {
                break;
            }
            char ch4 = this.buf[i6];
            if (ch4 < ']') {
                if (ch4 < '@') {
                    end = end2;
                } else {
                    end = end2;
                }
                if (ch4 != '\\') {
                    special = false;
                    if (!special) {
                        specialCount++;
                        lastSpecialIndex2 = i6;
                        if (ch4 == '(' || ch4 == ')' || ch4 == '<' || ch4 == '>' || (ch4 < IOUtils.specicalFlags_doubleQuotes.length && IOUtils.specicalFlags_doubleQuotes[ch4] == 4)) {
                            newcount += 4;
                        }
                        if (firstSpecialIndex == -1) {
                            lastSpecial = ch4;
                            firstSpecialIndex = i6;
                        } else {
                            lastSpecial = ch4;
                        }
                    }
                }
                special = true;
                if (!special) {
                }
            } else if (ch4 < 127 || !(ch4 == 8232 || ch4 == 8233 || ch4 < 160)) {
                end = end2;
            } else {
                if (firstSpecialIndex == -1) {
                    firstSpecialIndex = i6;
                }
                specialCount++;
                lastSpecialIndex2 = i6;
                newcount += 4;
                lastSpecial = ch4;
                end = end2;
            }
            i6++;
            end2 = end;
        }
        int end3 = end2;
        if (specialCount > 0) {
            int newcount2 = newcount + specialCount;
            if (newcount2 > this.buf.length) {
                expandCapacity(newcount2);
            }
            this.count = newcount2;
            if (specialCount == 1) {
                if (lastSpecial == 8232) {
                    char[] cArr10 = this.buf;
                    System.arraycopy(cArr10, lastSpecialIndex2 + 1, cArr10, lastSpecialIndex2 + 6, (end3 - lastSpecialIndex2) - 1);
                    char[] cArr11 = this.buf;
                    cArr11[lastSpecialIndex2] = '\\';
                    int lastSpecialIndex3 = lastSpecialIndex2 + 1;
                    cArr11[lastSpecialIndex3] = 'u';
                    int lastSpecialIndex4 = lastSpecialIndex3 + 1;
                    cArr11[lastSpecialIndex4] = '2';
                    int lastSpecialIndex5 = lastSpecialIndex4 + 1;
                    cArr11[lastSpecialIndex5] = '0';
                    int lastSpecialIndex6 = lastSpecialIndex5 + 1;
                    cArr11[lastSpecialIndex6] = '2';
                    cArr11[lastSpecialIndex6 + 1] = '8';
                } else if (lastSpecial == 8233) {
                    char[] cArr12 = this.buf;
                    System.arraycopy(cArr12, lastSpecialIndex2 + 1, cArr12, lastSpecialIndex2 + 6, (end3 - lastSpecialIndex2) - 1);
                    char[] cArr13 = this.buf;
                    cArr13[lastSpecialIndex2] = '\\';
                    int lastSpecialIndex7 = lastSpecialIndex2 + 1;
                    cArr13[lastSpecialIndex7] = 'u';
                    int lastSpecialIndex8 = lastSpecialIndex7 + 1;
                    cArr13[lastSpecialIndex8] = '2';
                    int lastSpecialIndex9 = lastSpecialIndex8 + 1;
                    cArr13[lastSpecialIndex9] = '0';
                    int lastSpecialIndex10 = lastSpecialIndex9 + 1;
                    cArr13[lastSpecialIndex10] = '2';
                    cArr13[lastSpecialIndex10 + 1] = '9';
                } else if (lastSpecial == '(' || lastSpecial == ')' || lastSpecial == '<' || lastSpecial == '>') {
                    char[] cArr14 = this.buf;
                    System.arraycopy(cArr14, lastSpecialIndex2 + 1, cArr14, lastSpecialIndex2 + 6, (end3 - lastSpecialIndex2) - 1);
                    char[] cArr15 = this.buf;
                    cArr15[lastSpecialIndex2] = '\\';
                    int lastSpecialIndex11 = lastSpecialIndex2 + 1;
                    cArr15[lastSpecialIndex11] = 'u';
                    int lastSpecialIndex12 = lastSpecialIndex11 + 1;
                    cArr15[lastSpecialIndex12] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                    int lastSpecialIndex13 = lastSpecialIndex12 + 1;
                    this.buf[lastSpecialIndex13] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                    int lastSpecialIndex14 = lastSpecialIndex13 + 1;
                    this.buf[lastSpecialIndex14] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                    this.buf[lastSpecialIndex14 + 1] = IOUtils.DIGITS[lastSpecial & 15];
                } else if (lastSpecial >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[lastSpecial] != 4) {
                    char[] cArr16 = this.buf;
                    System.arraycopy(cArr16, lastSpecialIndex2 + 1, cArr16, lastSpecialIndex2 + 2, (end3 - lastSpecialIndex2) - 1);
                    char[] cArr17 = this.buf;
                    cArr17[lastSpecialIndex2] = '\\';
                    cArr17[lastSpecialIndex2 + 1] = IOUtils.replaceChars[lastSpecial];
                } else {
                    char[] cArr18 = this.buf;
                    System.arraycopy(cArr18, lastSpecialIndex2 + 1, cArr18, lastSpecialIndex2 + 6, (end3 - lastSpecialIndex2) - 1);
                    char[] cArr19 = this.buf;
                    int bufIndex = lastSpecialIndex2 + 1;
                    cArr19[lastSpecialIndex2] = '\\';
                    int bufIndex2 = bufIndex + 1;
                    cArr19[bufIndex] = 'u';
                    int bufIndex3 = bufIndex2 + 1;
                    cArr19[bufIndex2] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                    int bufIndex4 = bufIndex3 + 1;
                    this.buf[bufIndex3] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                    int bufIndex5 = bufIndex4 + 1;
                    this.buf[bufIndex4] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                    int i7 = bufIndex5 + 1;
                    this.buf[bufIndex5] = IOUtils.DIGITS[lastSpecial & 15];
                }
            } else if (specialCount > 1) {
                int bufIndex6 = firstSpecialIndex;
                int i8 = firstSpecialIndex - start;
                while (i8 < text.length) {
                    char ch5 = text[i8];
                    if (this.browserSecure) {
                        if (ch5 == '(' || ch5 == ')' || ch5 == '<') {
                        }
                        char[] cArr20 = this.buf;
                        int bufIndex7 = bufIndex6 + 1;
                        cArr20[bufIndex6] = '\\';
                        int bufIndex8 = bufIndex7 + 1;
                        cArr20[bufIndex7] = 'u';
                        int bufIndex9 = bufIndex8 + 1;
                        cArr20[bufIndex8] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                        int bufIndex10 = bufIndex9 + 1;
                        this.buf[bufIndex9] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                        int bufIndex11 = bufIndex10 + 1;
                        this.buf[bufIndex10] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                        this.buf[bufIndex11] = IOUtils.DIGITS[ch5 & 15];
                        end3 += 5;
                        bufIndex6 = bufIndex11 + 1;
                        i8++;
                        c = 8232;
                    }
                    if (ch5 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[ch5] == 0) {
                        if (ch5 == '/') {
                            if (!isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                            }
                        }
                        if (ch5 == c || ch5 == 8233) {
                            char[] cArr21 = this.buf;
                            int bufIndex12 = bufIndex6 + 1;
                            cArr21[bufIndex6] = '\\';
                            int bufIndex13 = bufIndex12 + 1;
                            cArr21[bufIndex12] = 'u';
                            int bufIndex14 = bufIndex13 + 1;
                            cArr21[bufIndex13] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                            int bufIndex15 = bufIndex14 + 1;
                            this.buf[bufIndex14] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                            int bufIndex16 = bufIndex15 + 1;
                            this.buf[bufIndex15] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                            bufIndex6 = bufIndex16 + 1;
                            this.buf[bufIndex16] = IOUtils.DIGITS[ch5 & 15];
                            end3 += 5;
                            i8++;
                            c = 8232;
                        } else {
                            this.buf[bufIndex6] = ch5;
                            bufIndex6++;
                            i8++;
                            c = 8232;
                        }
                    }
                    int bufIndex17 = bufIndex6 + 1;
                    this.buf[bufIndex6] = '\\';
                    if (IOUtils.specicalFlags_doubleQuotes[ch5] == 4) {
                        char[] cArr22 = this.buf;
                        int bufIndex18 = bufIndex17 + 1;
                        cArr22[bufIndex17] = 'u';
                        int bufIndex19 = bufIndex18 + 1;
                        cArr22[bufIndex18] = IOUtils.DIGITS[(ch5 >>> '\f') & 15];
                        int bufIndex20 = bufIndex19 + 1;
                        this.buf[bufIndex19] = IOUtils.DIGITS[(ch5 >>> '\b') & 15];
                        int bufIndex21 = bufIndex20 + 1;
                        this.buf[bufIndex20] = IOUtils.DIGITS[(ch5 >>> 4) & 15];
                        this.buf[bufIndex21] = IOUtils.DIGITS[ch5 & 15];
                        end3 += 5;
                        bufIndex6 = bufIndex21 + 1;
                    } else {
                        this.buf[bufIndex17] = IOUtils.replaceChars[ch5];
                        end3++;
                        bufIndex6 = bufIndex17 + 1;
                    }
                    i8++;
                    c = 8232;
                }
            }
        }
        if (seperator != 0) {
            char[] cArr23 = this.buf;
            int i9 = this.count;
            cArr23[i9 - 2] = Operators.QUOTE;
            cArr23[i9 - 1] = seperator;
            return;
        }
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    public void writeFieldNameDirect(String text) {
        int len = text.length();
        int newcount = this.count + len + 3;
        if (newcount > this.buf.length) {
            expandCapacity(newcount);
        }
        int i = this.count;
        char[] cArr = this.buf;
        cArr[i] = Operators.QUOTE;
        text.getChars(0, len, cArr, i + 1);
        this.count = newcount;
        char[] cArr2 = this.buf;
        cArr2[newcount - 2] = Operators.QUOTE;
        cArr2[newcount - 1] = Operators.CONDITION_IF_MIDDLE;
    }

    public void write(List<String> list) {
        int offset;
        if (list.isEmpty()) {
            write("[]");
            return;
        }
        int offset2 = this.count;
        int i = 0;
        int list_size = list.size();
        while (i < list_size) {
            String text = list.get(i);
            boolean hasSpecial = false;
            if (text == null) {
                hasSpecial = true;
            } else {
                int len = text.length();
                for (int j = 0; j < len; j++) {
                    char ch = text.charAt(j);
                    boolean z = ch < ' ' || ch > '~' || ch == '\"' || ch == '\\';
                    hasSpecial = z;
                    if (z) {
                        break;
                    }
                }
            }
            if (hasSpecial) {
                this.count = offset2;
                write(91);
                for (int j2 = 0; j2 < list.size(); j2++) {
                    String text2 = list.get(j2);
                    if (j2 != 0) {
                        write(44);
                    }
                    if (text2 == null) {
                        write(b.m);
                    } else {
                        writeStringWithDoubleQuote(text2, (char) 0);
                    }
                }
                write(93);
                return;
            }
            int newcount = text.length() + offset2 + 3;
            if (i == list.size() - 1) {
                newcount++;
            }
            if (newcount > this.buf.length) {
                this.count = offset2;
                expandCapacity(newcount);
            }
            if (i == 0) {
                offset = offset2 + 1;
                this.buf[offset2] = Operators.ARRAY_START;
            } else {
                this.buf[offset2] = Operators.ARRAY_SEPRATOR;
                offset = offset2 + 1;
            }
            int offset3 = offset + 1;
            this.buf[offset] = Operators.QUOTE;
            text.getChars(0, text.length(), this.buf, offset3);
            int offset4 = offset3 + text.length();
            this.buf[offset4] = Operators.QUOTE;
            i++;
            offset2 = offset4 + 1;
        }
        this.buf[offset2] = Operators.ARRAY_END;
        this.count = offset2 + 1;
    }

    public void writeFieldValue(char seperator, String name, char value) {
        write(seperator);
        writeFieldName(name);
        if (value == 0) {
            writeString("\u0000");
        } else {
            writeString(Character.toString(value));
        }
    }

    public void writeFieldValue(char seperator, String name, boolean value) {
        if (!this.quoteFieldNames) {
            write(seperator);
            writeFieldName(name);
            write(value);
            return;
        }
        int intSize = value ? 4 : 5;
        int nameLen = name.length();
        int newcount = this.count + nameLen + 4 + intSize;
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(seperator);
                writeString(name);
                write(58);
                write(value);
                return;
            }
            expandCapacity(newcount);
        }
        int start = this.count;
        this.count = newcount;
        char[] cArr = this.buf;
        cArr[start] = seperator;
        int nameEnd = start + nameLen + 1;
        cArr[start + 1] = this.keySeperator;
        name.getChars(0, nameLen, cArr, start + 2);
        char[] cArr2 = this.buf;
        cArr2[nameEnd + 1] = this.keySeperator;
        if (value) {
            System.arraycopy(VALUE_TRUE, 0, cArr2, nameEnd + 2, 5);
        } else {
            System.arraycopy(VALUE_FALSE, 0, cArr2, nameEnd + 2, 6);
        }
    }

    public void write(boolean value) {
        if (value) {
            write(AbsoluteConst.TRUE);
        } else {
            write(AbsoluteConst.FALSE);
        }
    }

    public void writeFieldValue(char seperator, String name, int value) {
        if (value == Integer.MIN_VALUE || !this.quoteFieldNames) {
            write(seperator);
            writeFieldName(name);
            writeInt(value);
            return;
        }
        int intSize = value < 0 ? IOUtils.stringSize(-value) + 1 : IOUtils.stringSize(value);
        int nameLen = name.length();
        int newcount = this.count + nameLen + 4 + intSize;
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(seperator);
                writeFieldName(name);
                writeInt(value);
                return;
            }
            expandCapacity(newcount);
        }
        int start = this.count;
        this.count = newcount;
        char[] cArr = this.buf;
        cArr[start] = seperator;
        int nameEnd = start + nameLen + 1;
        cArr[start + 1] = this.keySeperator;
        name.getChars(0, nameLen, cArr, start + 2);
        char[] cArr2 = this.buf;
        cArr2[nameEnd + 1] = this.keySeperator;
        cArr2[nameEnd + 2] = Operators.CONDITION_IF_MIDDLE;
        IOUtils.getChars(value, this.count, cArr2);
    }

    public void writeFieldValue(char seperator, String name, long value) {
        if (value == Long.MIN_VALUE || !this.quoteFieldNames || isEnabled(SerializerFeature.BrowserCompatible.mask)) {
            write(seperator);
            writeFieldName(name);
            writeLong(value);
            return;
        }
        int intSize = value < 0 ? IOUtils.stringSize(-value) + 1 : IOUtils.stringSize(value);
        int nameLen = name.length();
        int newcount = this.count + nameLen + 4 + intSize;
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(seperator);
                writeFieldName(name);
                writeLong(value);
                return;
            }
            expandCapacity(newcount);
        }
        int start = this.count;
        this.count = newcount;
        char[] cArr = this.buf;
        cArr[start] = seperator;
        int nameEnd = start + nameLen + 1;
        cArr[start + 1] = this.keySeperator;
        name.getChars(0, nameLen, cArr, start + 2);
        char[] cArr2 = this.buf;
        cArr2[nameEnd + 1] = this.keySeperator;
        cArr2[nameEnd + 2] = Operators.CONDITION_IF_MIDDLE;
        IOUtils.getChars(value, this.count, cArr2);
    }

    public void writeFieldValue(char seperator, String name, float value) {
        write(seperator);
        writeFieldName(name);
        writeFloat(value, false);
    }

    public void writeFieldValue(char seperator, String name, double value) {
        write(seperator);
        writeFieldName(name);
        writeDouble(value, false);
    }

    public void writeFieldValue(char seperator, String name, String value) {
        if (!this.quoteFieldNames) {
            write(seperator);
            writeFieldName(name);
            if (value == null) {
                writeNull();
            } else {
                writeString(value);
            }
        } else if (this.useSingleQuotes) {
            write(seperator);
            writeFieldName(name);
            if (value == null) {
                writeNull();
            } else {
                writeString(value);
            }
        } else if (isEnabled(SerializerFeature.BrowserCompatible)) {
            write(seperator);
            writeStringWithDoubleQuote(name, Operators.CONDITION_IF_MIDDLE);
            writeStringWithDoubleQuote(value, (char) 0);
        } else {
            writeFieldValueStringWithDoubleQuoteCheck(seperator, name, value);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:108:0x02b9, code lost:
        if (r7 == '>') goto L_0x02be;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x00c7, code lost:
        if ((r32.sepcialBits & (1 << r12)) == 0) goto L_0x00cc;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x00f5, code lost:
        if (com.alibaba.fastjson.util.IOUtils.specicalFlags_doubleQuotes[r12] == 4) goto L_0x00fd;
     */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x00d5  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x010b  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0110  */
    public void writeFieldValueStringWithDoubleQuoteCheck(char seperator, String name, String value) {
        int valueLen;
        int newcount;
        int newcount2;
        int newcount3;
        int newcount4;
        boolean special;
        int nameLen = name.length();
        int newcount5 = this.count;
        if (value == null) {
            valueLen = 4;
            newcount = newcount5 + nameLen + 8;
        } else {
            valueLen = value.length();
            newcount = newcount5 + nameLen + valueLen + 6;
        }
        if (newcount > this.buf.length) {
            if (this.writer != null) {
                write(seperator);
                writeStringWithDoubleQuote(name, Operators.CONDITION_IF_MIDDLE);
                writeStringWithDoubleQuote(value, (char) 0);
                return;
            }
            expandCapacity(newcount);
        }
        char[] cArr = this.buf;
        int i = this.count;
        cArr[i] = seperator;
        int nameStart = i + 2;
        int nameEnd = nameStart + nameLen;
        cArr[i + 1] = Operators.QUOTE;
        name.getChars(0, nameLen, cArr, nameStart);
        this.count = newcount;
        char[] cArr2 = this.buf;
        cArr2[nameEnd] = Operators.QUOTE;
        int index = nameEnd + 1;
        int index2 = index + 1;
        cArr2[index] = Operators.CONDITION_IF_MIDDLE;
        if (value == null) {
            int index3 = index2 + 1;
            cArr2[index2] = 'n';
            int index4 = index3 + 1;
            cArr2[index3] = 'u';
            int index5 = index4 + 1;
            cArr2[index4] = 'l';
            int i2 = index5 + 1;
            cArr2[index5] = 'l';
            return;
        }
        int index6 = index2 + 1;
        cArr2[index2] = Operators.QUOTE;
        int valueEnd = index6 + valueLen;
        value.getChars(0, valueLen, cArr2, index6);
        int specialCount = 0;
        int lastSpecialIndex = -1;
        int firstSpecialIndex = -1;
        char lastSpecial = 0;
        int i3 = index6;
        while (i3 < valueEnd) {
            char ch = this.buf[i3];
            if (ch < ']') {
                if (ch < '@') {
                    newcount4 = newcount;
                } else {
                    newcount4 = newcount;
                }
                if (ch != '\\') {
                    special = false;
                    if (!special) {
                        specialCount++;
                        lastSpecial = ch;
                        if (ch != '(' && ch != ')' && ch != '<' && ch != '>') {
                            if (ch < IOUtils.specicalFlags_doubleQuotes.length) {
                            }
                            if (firstSpecialIndex != -1) {
                                firstSpecialIndex = i3;
                                lastSpecialIndex = i3;
                                newcount = newcount4;
                            } else {
                                lastSpecialIndex = i3;
                                newcount = newcount4;
                            }
                            i3++;
                            nameLen = nameLen;
                        }
                        newcount4 += 4;
                        if (firstSpecialIndex != -1) {
                        }
                        i3++;
                        nameLen = nameLen;
                    }
                }
                special = true;
                if (!special) {
                }
            } else if (ch < 127 || !(ch == 8232 || ch == 8233 || ch < 160)) {
                newcount4 = newcount;
            } else {
                if (firstSpecialIndex == -1) {
                    firstSpecialIndex = i3;
                }
                specialCount++;
                newcount += 4;
                lastSpecialIndex = i3;
                lastSpecial = ch;
                i3++;
                nameLen = nameLen;
            }
            newcount = newcount4;
            i3++;
            nameLen = nameLen;
        }
        if (specialCount > 0) {
            int newcount6 = newcount + specialCount;
            if (newcount6 > this.buf.length) {
                expandCapacity(newcount6);
            }
            this.count = newcount6;
            if (specialCount != 1) {
                newcount2 = newcount6;
                if (specialCount > 1) {
                    int bufIndex = firstSpecialIndex;
                    for (int i4 = firstSpecialIndex - index6; i4 < value.length(); i4++) {
                        char ch2 = value.charAt(i4);
                        if (this.browserSecure) {
                            if (ch2 == '(' || ch2 == ')' || ch2 == '<') {
                            }
                            char[] cArr3 = this.buf;
                            int bufIndex2 = bufIndex + 1;
                            cArr3[bufIndex] = '\\';
                            int bufIndex3 = bufIndex2 + 1;
                            cArr3[bufIndex2] = 'u';
                            int bufIndex4 = bufIndex3 + 1;
                            cArr3[bufIndex3] = IOUtils.DIGITS[(ch2 >>> '\f') & 15];
                            int bufIndex5 = bufIndex4 + 1;
                            this.buf[bufIndex4] = IOUtils.DIGITS[(ch2 >>> '\b') & 15];
                            int bufIndex6 = bufIndex5 + 1;
                            this.buf[bufIndex5] = IOUtils.DIGITS[(ch2 >>> 4) & 15];
                            this.buf[bufIndex6] = IOUtils.DIGITS[ch2 & 15];
                            valueEnd += 5;
                            bufIndex = bufIndex6 + 1;
                        }
                        if (ch2 >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[ch2] == 0) {
                            if (ch2 == '/') {
                                if (!isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                                }
                            }
                            if (ch2 == 8232 || ch2 == 8233) {
                                char[] cArr4 = this.buf;
                                int bufIndex7 = bufIndex + 1;
                                cArr4[bufIndex] = '\\';
                                int bufIndex8 = bufIndex7 + 1;
                                cArr4[bufIndex7] = 'u';
                                int bufIndex9 = bufIndex8 + 1;
                                cArr4[bufIndex8] = IOUtils.DIGITS[(ch2 >>> '\f') & 15];
                                int bufIndex10 = bufIndex9 + 1;
                                this.buf[bufIndex9] = IOUtils.DIGITS[(ch2 >>> '\b') & 15];
                                int bufIndex11 = bufIndex10 + 1;
                                this.buf[bufIndex10] = IOUtils.DIGITS[(ch2 >>> 4) & 15];
                                this.buf[bufIndex11] = IOUtils.DIGITS[ch2 & 15];
                                valueEnd += 5;
                                bufIndex = bufIndex11 + 1;
                            } else {
                                this.buf[bufIndex] = ch2;
                                bufIndex++;
                            }
                        }
                        int bufIndex12 = bufIndex + 1;
                        this.buf[bufIndex] = '\\';
                        if (IOUtils.specicalFlags_doubleQuotes[ch2] == 4) {
                            char[] cArr5 = this.buf;
                            int bufIndex13 = bufIndex12 + 1;
                            cArr5[bufIndex12] = 'u';
                            int bufIndex14 = bufIndex13 + 1;
                            cArr5[bufIndex13] = IOUtils.DIGITS[(ch2 >>> '\f') & 15];
                            int bufIndex15 = bufIndex14 + 1;
                            this.buf[bufIndex14] = IOUtils.DIGITS[(ch2 >>> '\b') & 15];
                            int bufIndex16 = bufIndex15 + 1;
                            this.buf[bufIndex15] = IOUtils.DIGITS[(ch2 >>> 4) & 15];
                            this.buf[bufIndex16] = IOUtils.DIGITS[ch2 & 15];
                            valueEnd += 5;
                            bufIndex = bufIndex16 + 1;
                        } else {
                            this.buf[bufIndex12] = IOUtils.replaceChars[ch2];
                            valueEnd++;
                            bufIndex = bufIndex12 + 1;
                        }
                    }
                }
            } else if (lastSpecial == 8232) {
                char[] cArr6 = this.buf;
                System.arraycopy(cArr6, lastSpecialIndex + 1, cArr6, lastSpecialIndex + 6, (valueEnd - lastSpecialIndex) - 1);
                char[] cArr7 = this.buf;
                cArr7[lastSpecialIndex] = '\\';
                int lastSpecialIndex2 = lastSpecialIndex + 1;
                cArr7[lastSpecialIndex2] = 'u';
                int lastSpecialIndex3 = lastSpecialIndex2 + 1;
                cArr7[lastSpecialIndex3] = '2';
                int lastSpecialIndex4 = lastSpecialIndex3 + 1;
                cArr7[lastSpecialIndex4] = '0';
                int lastSpecialIndex5 = lastSpecialIndex4 + 1;
                cArr7[lastSpecialIndex5] = '2';
                cArr7[lastSpecialIndex5 + 1] = '8';
            } else if (lastSpecial == 8233) {
                char[] cArr8 = this.buf;
                System.arraycopy(cArr8, lastSpecialIndex + 1, cArr8, lastSpecialIndex + 6, (valueEnd - lastSpecialIndex) - 1);
                char[] cArr9 = this.buf;
                cArr9[lastSpecialIndex] = '\\';
                int lastSpecialIndex6 = lastSpecialIndex + 1;
                cArr9[lastSpecialIndex6] = 'u';
                int lastSpecialIndex7 = lastSpecialIndex6 + 1;
                cArr9[lastSpecialIndex7] = '2';
                int lastSpecialIndex8 = lastSpecialIndex7 + 1;
                cArr9[lastSpecialIndex8] = '0';
                int lastSpecialIndex9 = lastSpecialIndex8 + 1;
                cArr9[lastSpecialIndex9] = '2';
                cArr9[lastSpecialIndex9 + 1] = '9';
            } else {
                if (lastSpecial == '(' || lastSpecial == ')' || lastSpecial == '<') {
                    newcount2 = newcount6;
                } else if (lastSpecial == '>') {
                    newcount2 = newcount6;
                } else if (lastSpecial >= IOUtils.specicalFlags_doubleQuotes.length || IOUtils.specicalFlags_doubleQuotes[lastSpecial] != 4) {
                    newcount3 = newcount6;
                    char[] cArr10 = this.buf;
                    System.arraycopy(cArr10, lastSpecialIndex + 1, cArr10, lastSpecialIndex + 2, (valueEnd - lastSpecialIndex) - 1);
                    char[] cArr11 = this.buf;
                    cArr11[lastSpecialIndex] = '\\';
                    cArr11[lastSpecialIndex + 1] = IOUtils.replaceChars[lastSpecial];
                } else {
                    newcount3 = newcount6;
                    char[] cArr12 = this.buf;
                    System.arraycopy(cArr12, lastSpecialIndex + 1, cArr12, lastSpecialIndex + 6, (valueEnd - lastSpecialIndex) - 1);
                    char[] cArr13 = this.buf;
                    int bufIndex17 = lastSpecialIndex + 1;
                    cArr13[lastSpecialIndex] = '\\';
                    int bufIndex18 = bufIndex17 + 1;
                    cArr13[bufIndex17] = 'u';
                    int bufIndex19 = bufIndex18 + 1;
                    cArr13[bufIndex18] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                    int bufIndex20 = bufIndex19 + 1;
                    this.buf[bufIndex19] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                    int bufIndex21 = bufIndex20 + 1;
                    this.buf[bufIndex20] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                    int i5 = bufIndex21 + 1;
                    this.buf[bufIndex21] = IOUtils.DIGITS[lastSpecial & 15];
                }
                char[] cArr14 = this.buf;
                System.arraycopy(cArr14, lastSpecialIndex + 1, cArr14, lastSpecialIndex + 6, (valueEnd - lastSpecialIndex) - 1);
                char[] cArr15 = this.buf;
                int bufIndex22 = lastSpecialIndex + 1;
                cArr15[lastSpecialIndex] = '\\';
                int bufIndex23 = bufIndex22 + 1;
                cArr15[bufIndex22] = 'u';
                int bufIndex24 = bufIndex23 + 1;
                cArr15[bufIndex23] = IOUtils.DIGITS[(lastSpecial >>> '\f') & 15];
                int bufIndex25 = bufIndex24 + 1;
                this.buf[bufIndex24] = IOUtils.DIGITS[(lastSpecial >>> '\b') & 15];
                int bufIndex26 = bufIndex25 + 1;
                this.buf[bufIndex25] = IOUtils.DIGITS[(lastSpecial >>> 4) & 15];
                int i6 = bufIndex26 + 1;
                this.buf[bufIndex26] = IOUtils.DIGITS[lastSpecial & 15];
            }
        }
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    public void writeFieldValueStringWithDoubleQuote(char seperator, String name, String value) {
        int nameLen = name.length();
        int newcount = this.count;
        int valueLen = value.length();
        int newcount2 = newcount + nameLen + valueLen + 6;
        if (newcount2 > this.buf.length) {
            if (this.writer != null) {
                write(seperator);
                writeStringWithDoubleQuote(name, Operators.CONDITION_IF_MIDDLE);
                writeStringWithDoubleQuote(value, (char) 0);
                return;
            }
            expandCapacity(newcount2);
        }
        char[] cArr = this.buf;
        int i = this.count;
        cArr[i] = seperator;
        int nameStart = i + 2;
        int nameEnd = nameStart + nameLen;
        cArr[i + 1] = Operators.QUOTE;
        name.getChars(0, nameLen, cArr, nameStart);
        this.count = newcount2;
        char[] cArr2 = this.buf;
        cArr2[nameEnd] = Operators.QUOTE;
        int index = nameEnd + 1;
        int index2 = index + 1;
        cArr2[index] = Operators.CONDITION_IF_MIDDLE;
        cArr2[index2] = Operators.QUOTE;
        value.getChars(0, valueLen, cArr2, index2 + 1);
        this.buf[this.count - 1] = Operators.QUOTE;
    }

    public void writeFieldValue(char seperator, String name, Enum<?> value) {
        if (value == null) {
            write(seperator);
            writeFieldName(name);
            writeNull();
        } else if (this.writeEnumUsingName && !this.writeEnumUsingToString) {
            writeEnumFieldValue(seperator, name, value.name());
        } else if (this.writeEnumUsingToString) {
            writeEnumFieldValue(seperator, name, value.toString());
        } else {
            writeFieldValue(seperator, name, value.ordinal());
        }
    }

    private void writeEnumFieldValue(char seperator, String name, String value) {
        if (this.useSingleQuotes) {
            writeFieldValue(seperator, name, value);
        } else {
            writeFieldValueStringWithDoubleQuote(seperator, name, value);
        }
    }

    public void writeFieldValue(char seperator, String name, BigDecimal value) {
        String str;
        write(seperator);
        writeFieldName(name);
        if (value == null) {
            writeNull();
            return;
        }
        int scale = value.scale();
        if (!isEnabled(SerializerFeature.WriteBigDecimalAsPlain) || scale < -100 || scale >= 100) {
            str = value.toString();
        } else {
            str = value.toPlainString();
        }
        write(str);
    }

    public void writeString(String text, char seperator) {
        if (this.useSingleQuotes) {
            writeStringWithSingleQuote(text);
            write(seperator);
            return;
        }
        writeStringWithDoubleQuote(text, seperator);
    }

    public void writeString(String text) {
        if (this.useSingleQuotes) {
            writeStringWithSingleQuote(text);
        } else {
            writeStringWithDoubleQuote(text, (char) 0);
        }
    }

    public void writeString(char[] chars) {
        if (this.useSingleQuotes) {
            writeStringWithSingleQuote(chars);
        } else {
            writeStringWithDoubleQuote(new String(chars), (char) 0);
        }
    }

    /* access modifiers changed from: protected */
    public void writeStringWithSingleQuote(String text) {
        if (text == null) {
            int newcount = this.count + 4;
            if (newcount > this.buf.length) {
                expandCapacity(newcount);
            }
            b.m.getChars(0, 4, this.buf, this.count);
            this.count = newcount;
            return;
        }
        int len = text.length();
        int newcount2 = this.count + len + 2;
        char c = '\r';
        char c2 = '\\';
        if (newcount2 > this.buf.length) {
            if (this.writer != null) {
                write(39);
                for (int i = 0; i < text.length(); i++) {
                    char ch = text.charAt(i);
                    if (ch <= '\r' || ch == '\\' || ch == '\'' || (ch == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                        write(92);
                        write(IOUtils.replaceChars[ch]);
                    } else {
                        write(ch);
                    }
                }
                write(39);
                return;
            }
            expandCapacity(newcount2);
        }
        int i2 = this.count;
        int start = i2 + 1;
        int end = start + len;
        char[] cArr = this.buf;
        cArr[i2] = Operators.SINGLE_QUOTE;
        text.getChars(0, len, cArr, start);
        this.count = newcount2;
        int specialCount = 0;
        int lastSpecialIndex = -1;
        char lastSpecial = 0;
        for (int i3 = start; i3 < end; i3++) {
            char ch2 = this.buf[i3];
            if (ch2 <= '\r' || ch2 == '\\' || ch2 == '\'' || (ch2 == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                specialCount++;
                lastSpecialIndex = i3;
                lastSpecial = ch2;
            }
        }
        int newcount3 = newcount2 + specialCount;
        if (newcount3 > this.buf.length) {
            expandCapacity(newcount3);
        }
        this.count = newcount3;
        if (specialCount == 1) {
            char[] cArr2 = this.buf;
            System.arraycopy(cArr2, lastSpecialIndex + 1, cArr2, lastSpecialIndex + 2, (end - lastSpecialIndex) - 1);
            char[] cArr3 = this.buf;
            cArr3[lastSpecialIndex] = '\\';
            cArr3[lastSpecialIndex + 1] = IOUtils.replaceChars[lastSpecial];
        } else if (specialCount > 1) {
            char[] cArr4 = this.buf;
            System.arraycopy(cArr4, lastSpecialIndex + 1, cArr4, lastSpecialIndex + 2, (end - lastSpecialIndex) - 1);
            char[] cArr5 = this.buf;
            cArr5[lastSpecialIndex] = '\\';
            int lastSpecialIndex2 = lastSpecialIndex + 1;
            cArr5[lastSpecialIndex2] = IOUtils.replaceChars[lastSpecial];
            int end2 = end + 1;
            int i4 = lastSpecialIndex2 - 2;
            while (i4 >= start) {
                char ch3 = this.buf[i4];
                if (ch3 > c && ch3 != c2 && ch3 != '\'') {
                    if (ch3 == '/') {
                        if (!isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                        }
                    }
                    i4--;
                    c = '\r';
                }
                char[] cArr6 = this.buf;
                System.arraycopy(cArr6, i4 + 1, cArr6, i4 + 2, (end2 - i4) - 1);
                char[] cArr7 = this.buf;
                c2 = '\\';
                cArr7[i4] = '\\';
                cArr7[i4 + 1] = IOUtils.replaceChars[ch3];
                end2++;
                i4--;
                c = '\r';
            }
        }
        this.buf[this.count - 1] = Operators.SINGLE_QUOTE;
    }

    /* JADX INFO: Multiple debug info for r3v0 int: [D('newcount' int), D('len' int)] */
    /* access modifiers changed from: protected */
    public void writeStringWithSingleQuote(char[] chars) {
        if (chars == null) {
            int newcount = this.count + 4;
            if (newcount > this.buf.length) {
                expandCapacity(newcount);
            }
            b.m.getChars(0, 4, this.buf, this.count);
            this.count = newcount;
            return;
        }
        int len = chars.length;
        int newcount2 = this.count + len + 2;
        char c = '\r';
        char c2 = '\\';
        if (newcount2 > this.buf.length) {
            if (this.writer != null) {
                write(39);
                for (char ch : chars) {
                    if (ch <= '\r' || ch == '\\' || ch == '\'' || (ch == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                        write(92);
                        write(IOUtils.replaceChars[ch]);
                    } else {
                        write(ch);
                    }
                }
                write(39);
                return;
            }
            expandCapacity(newcount2);
        }
        int i = this.count;
        int start = i + 1;
        int end = start + len;
        char[] cArr = this.buf;
        cArr[i] = Operators.SINGLE_QUOTE;
        System.arraycopy(chars, 0, cArr, start, chars.length);
        this.count = newcount2;
        int specialCount = 0;
        int lastSpecialIndex = -1;
        char lastSpecial = 0;
        for (int i2 = start; i2 < end; i2++) {
            char ch2 = this.buf[i2];
            if (ch2 <= '\r' || ch2 == '\\' || ch2 == '\'' || (ch2 == '/' && isEnabled(SerializerFeature.WriteSlashAsSpecial))) {
                specialCount++;
                lastSpecialIndex = i2;
                lastSpecial = ch2;
            }
        }
        int newcount3 = newcount2 + specialCount;
        if (newcount3 > this.buf.length) {
            expandCapacity(newcount3);
        }
        this.count = newcount3;
        if (specialCount == 1) {
            char[] cArr2 = this.buf;
            System.arraycopy(cArr2, lastSpecialIndex + 1, cArr2, lastSpecialIndex + 2, (end - lastSpecialIndex) - 1);
            char[] cArr3 = this.buf;
            cArr3[lastSpecialIndex] = '\\';
            cArr3[lastSpecialIndex + 1] = IOUtils.replaceChars[lastSpecial];
        } else if (specialCount > 1) {
            char[] cArr4 = this.buf;
            System.arraycopy(cArr4, lastSpecialIndex + 1, cArr4, lastSpecialIndex + 2, (end - lastSpecialIndex) - 1);
            char[] cArr5 = this.buf;
            cArr5[lastSpecialIndex] = '\\';
            int lastSpecialIndex2 = lastSpecialIndex + 1;
            cArr5[lastSpecialIndex2] = IOUtils.replaceChars[lastSpecial];
            int end2 = end + 1;
            int i3 = lastSpecialIndex2 - 2;
            while (i3 >= start) {
                char ch3 = this.buf[i3];
                if (ch3 > c && ch3 != c2 && ch3 != '\'') {
                    if (ch3 == '/') {
                        if (!isEnabled(SerializerFeature.WriteSlashAsSpecial)) {
                        }
                    }
                    i3--;
                    c = '\r';
                }
                char[] cArr6 = this.buf;
                System.arraycopy(cArr6, i3 + 1, cArr6, i3 + 2, (end2 - i3) - 1);
                char[] cArr7 = this.buf;
                c2 = '\\';
                cArr7[i3] = '\\';
                cArr7[i3 + 1] = IOUtils.replaceChars[ch3];
                end2++;
                i3--;
                c = '\r';
            }
        }
        this.buf[this.count - 1] = Operators.SINGLE_QUOTE;
    }

    public void writeFieldName(String key) {
        writeFieldName(key, false);
    }

    public void writeFieldName(String key, boolean checkSpecial) {
        if (key == null) {
            write("null:");
        } else if (this.useSingleQuotes) {
            if (this.quoteFieldNames) {
                writeStringWithSingleQuote(key);
                write(58);
                return;
            }
            writeKeyWithSingleQuoteIfHasSpecial(key);
        } else if (this.quoteFieldNames) {
            writeStringWithDoubleQuote(key, Operators.CONDITION_IF_MIDDLE);
        } else {
            boolean hashSpecial = key.length() == 0;
            int i = 0;
            while (true) {
                if (i >= key.length()) {
                    break;
                }
                char ch = key.charAt(i);
                if ((ch < '@' && (this.sepcialBits & (1 << ch)) != 0) || ch == '\\') {
                    hashSpecial = true;
                    break;
                }
                i++;
            }
            if (hashSpecial) {
                writeStringWithDoubleQuote(key, Operators.CONDITION_IF_MIDDLE);
                return;
            }
            write(key);
            write(58);
        }
    }

    /* JADX INFO: Multiple debug info for r6v2 int: [D('newCount' int), D('start' int)] */
    private void writeKeyWithSingleQuoteIfHasSpecial(String text) {
        byte[] specicalFlags_singleQuotes = IOUtils.specicalFlags_singleQuotes;
        int len = text.length();
        int newcount = this.count + len + 1;
        if (newcount > this.buf.length) {
            if (this.writer == null) {
                expandCapacity(newcount);
            } else if (len == 0) {
                write(39);
                write(39);
                write(58);
                return;
            } else {
                boolean hasSpecial = false;
                int i = 0;
                while (true) {
                    if (i >= len) {
                        break;
                    }
                    char ch = text.charAt(i);
                    if (ch < specicalFlags_singleQuotes.length && specicalFlags_singleQuotes[ch] != 0) {
                        hasSpecial = true;
                        break;
                    }
                    i++;
                }
                if (hasSpecial) {
                    write(39);
                }
                for (int i2 = 0; i2 < len; i2++) {
                    char ch2 = text.charAt(i2);
                    if (ch2 >= specicalFlags_singleQuotes.length || specicalFlags_singleQuotes[ch2] == 0) {
                        write(ch2);
                    } else {
                        write(92);
                        write(IOUtils.replaceChars[ch2]);
                    }
                }
                if (hasSpecial) {
                    write(39);
                }
                write(58);
                return;
            }
        }
        if (len == 0) {
            int i3 = this.count;
            if (i3 + 3 > this.buf.length) {
                expandCapacity(i3 + 3);
            }
            char[] cArr = this.buf;
            int i4 = this.count;
            int i5 = i4 + 1;
            this.count = i5;
            cArr[i4] = Operators.SINGLE_QUOTE;
            int i6 = i5 + 1;
            this.count = i6;
            cArr[i5] = Operators.SINGLE_QUOTE;
            this.count = i6 + 1;
            cArr[i6] = Operators.CONDITION_IF_MIDDLE;
            return;
        }
        int start = this.count;
        int end = start + len;
        text.getChars(0, len, this.buf, start);
        this.count = newcount;
        boolean hasSpecial2 = false;
        int i7 = start;
        while (i7 < end) {
            char[] cArr2 = this.buf;
            char ch3 = cArr2[i7];
            if (ch3 < specicalFlags_singleQuotes.length && specicalFlags_singleQuotes[ch3] != 0) {
                if (!hasSpecial2) {
                    newcount += 3;
                    if (newcount > cArr2.length) {
                        expandCapacity(newcount);
                    }
                    this.count = newcount;
                    char[] cArr3 = this.buf;
                    System.arraycopy(cArr3, i7 + 1, cArr3, i7 + 3, (end - i7) - 1);
                    char[] cArr4 = this.buf;
                    System.arraycopy(cArr4, 0, cArr4, 1, i7);
                    char[] cArr5 = this.buf;
                    cArr5[start] = Operators.SINGLE_QUOTE;
                    int i8 = i7 + 1;
                    cArr5[i8] = '\\';
                    i7 = i8 + 1;
                    cArr5[i7] = IOUtils.replaceChars[ch3];
                    end += 2;
                    this.buf[this.count - 2] = Operators.SINGLE_QUOTE;
                    hasSpecial2 = true;
                } else {
                    newcount++;
                    if (newcount > cArr2.length) {
                        expandCapacity(newcount);
                    }
                    this.count = newcount;
                    char[] cArr6 = this.buf;
                    System.arraycopy(cArr6, i7 + 1, cArr6, i7 + 2, end - i7);
                    char[] cArr7 = this.buf;
                    cArr7[i7] = '\\';
                    i7++;
                    cArr7[i7] = IOUtils.replaceChars[ch3];
                    end++;
                }
            }
            i7++;
        }
        this.buf[newcount - 1] = Operators.CONDITION_IF_MIDDLE;
    }

    @Override // java.io.Writer, java.io.Flushable
    public void flush() {
        Writer writer2 = this.writer;
        if (writer2 != null) {
            try {
                writer2.write(this.buf, 0, this.count);
                this.writer.flush();
                this.count = 0;
            } catch (IOException e) {
                throw new JSONException(e.getMessage(), e);
            }
        }
    }

    public void reset() {
        this.count = 0;
    }
}
