package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPObject;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONScanner;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.parser.deserializer.EnumDeserializer;
import com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.serializer.CalendarCodec;
import com.alibaba.fastjson.serializer.SerializeBeanInfo;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.alipay.sdk.m.u.i;
import com.igexin.push.core.b;
import com.taobao.weex.el.parse.Operators;
import com.tencent.qphone.base.util.QLog;
import com.uc.crashsdk.export.CrashStatKey;
import com.vivo.push.PushClientConstants;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.ExifInterface;
import java.io.InputStream;
import java.io.Reader;
import java.lang.annotation.Annotation;
import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Array;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.GenericArrayType;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.Clob;
import java.sql.Date;
import java.sql.Time;
import java.sql.Timestamp;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.AbstractCollection;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.BitSet;
import java.util.Calendar;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.Currency;
import java.util.EnumSet;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.IdentityHashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Queue;
import java.util.Set;
import java.util.TreeMap;
import java.util.TreeSet;
import java.util.UUID;
import java.util.WeakHashMap;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class TypeUtils {
    private static final Pattern NUMBER_WITH_TRAILING_ZEROS_PATTERN = Pattern.compile("\\.0*$");
    private static Object OPTIONAL_EMPTY = null;
    private static boolean OPTIONAL_ERROR = false;
    private static Function<Map<String, Class<?>>, Void> addBaseClassMappingsFunction = new Function<Map<String, Class<?>>, Void>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass6 */

        public Void apply(Map<String, Class<?>> mappings) {
            Class[] classes = {Time.class, Date.class, Timestamp.class};
            for (Class clazz : classes) {
                if (clazz != null) {
                    mappings.put(clazz.getName(), clazz);
                }
            }
            return null;
        }
    };
    private static BiFunction<Object, Class, Object> castFunction = new BiFunction<Object, Class, Object>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass5 */

        public Object apply(Object obj, Class clazz) {
            if (clazz == Date.class) {
                return TypeUtils.castToSqlDate(obj);
            }
            if (clazz == Time.class) {
                return TypeUtils.castToSqlTime(obj);
            }
            if (clazz == Timestamp.class) {
                return TypeUtils.castToTimestamp(obj);
            }
            return null;
        }
    };
    private static Function<Object, Object> castToSqlDateFunction = new Function<Object, Object>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass2 */

        @Override // com.alibaba.fastjson.util.Function
        public Object apply(Object value) {
            if (value == null) {
                return null;
            }
            if (value instanceof Date) {
                return (Date) value;
            }
            if (value instanceof java.util.Date) {
                return new Date(((java.util.Date) value).getTime());
            }
            if (value instanceof Calendar) {
                return new Date(((Calendar) value).getTimeInMillis());
            }
            long longValue = 0;
            if (value instanceof BigDecimal) {
                longValue = TypeUtils.longValue((BigDecimal) value);
            } else if (value instanceof Number) {
                longValue = ((Number) value).longValue();
            }
            if (value instanceof String) {
                String strVal = (String) value;
                if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                    return null;
                }
                if (TypeUtils.isNumber(strVal)) {
                    longValue = Long.parseLong(strVal);
                } else {
                    JSONScanner scanner = new JSONScanner(strVal);
                    if (scanner.scanISO8601DateIfMatch(false)) {
                        longValue = scanner.getCalendar().getTime().getTime();
                    } else {
                        throw new JSONException("can not cast to Timestamp, value : " + strVal);
                    }
                }
            }
            if (longValue > 0) {
                return new Date(longValue);
            }
            throw new JSONException("can not cast to Date, value : " + value);
        }
    };
    private static Function<Object, Object> castToSqlTimeFunction = new Function<Object, Object>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass3 */

        @Override // com.alibaba.fastjson.util.Function
        public Object apply(Object value) {
            if (value == null) {
                return null;
            }
            if (value instanceof Time) {
                return (Time) value;
            }
            if (value instanceof java.util.Date) {
                return new Time(((java.util.Date) value).getTime());
            }
            if (value instanceof Calendar) {
                return new Time(((Calendar) value).getTimeInMillis());
            }
            long longValue = 0;
            if (value instanceof BigDecimal) {
                longValue = TypeUtils.longValue((BigDecimal) value);
            } else if (value instanceof Number) {
                longValue = ((Number) value).longValue();
            }
            if (value instanceof String) {
                String strVal = (String) value;
                if (strVal.length() == 0 || b.m.equalsIgnoreCase(strVal)) {
                    return null;
                }
                if (TypeUtils.isNumber(strVal)) {
                    longValue = Long.parseLong(strVal);
                } else if (strVal.length() == 8 && strVal.charAt(2) == ':' && strVal.charAt(5) == ':') {
                    return Time.valueOf(strVal);
                } else {
                    JSONScanner scanner = new JSONScanner(strVal);
                    if (scanner.scanISO8601DateIfMatch(false)) {
                        longValue = scanner.getCalendar().getTime().getTime();
                    } else {
                        throw new JSONException("can not cast to Timestamp, value : " + strVal);
                    }
                }
            }
            if (longValue > 0) {
                return new Time(longValue);
            }
            throw new JSONException("can not cast to Date, value : " + value);
        }
    };
    public static Function<Object, Object> castToTimestampFunction = new Function<Object, Object>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass4 */

        @Override // com.alibaba.fastjson.util.Function
        public Object apply(Object value) {
            if (value == null) {
                return null;
            }
            if (value instanceof Calendar) {
                return new Timestamp(((Calendar) value).getTimeInMillis());
            }
            if (value instanceof Timestamp) {
                return (Timestamp) value;
            }
            if (value instanceof java.util.Date) {
                return new Timestamp(((java.util.Date) value).getTime());
            }
            long longValue = 0;
            if (value instanceof BigDecimal) {
                longValue = TypeUtils.longValue((BigDecimal) value);
            } else if (value instanceof Number) {
                longValue = ((Number) value).longValue();
            }
            if (value instanceof String) {
                String strVal = (String) value;
                if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                    return null;
                }
                if (strVal.endsWith(".000000000")) {
                    strVal = strVal.substring(0, strVal.length() - 10);
                } else if (strVal.endsWith(".000000")) {
                    strVal = strVal.substring(0, strVal.length() - 7);
                }
                if (strVal.length() == 29 && strVal.charAt(4) == '-' && strVal.charAt(7) == '-' && strVal.charAt(10) == ' ' && strVal.charAt(13) == ':' && strVal.charAt(16) == ':' && strVal.charAt(19) == '.') {
                    int year = TypeUtils.num(strVal.charAt(0), strVal.charAt(1), strVal.charAt(2), strVal.charAt(3));
                    return new Timestamp(year - 1900, TypeUtils.num(strVal.charAt(5), strVal.charAt(6)) - 1, TypeUtils.num(strVal.charAt(8), strVal.charAt(9)), TypeUtils.num(strVal.charAt(11), strVal.charAt(12)), TypeUtils.num(strVal.charAt(14), strVal.charAt(15)), TypeUtils.num(strVal.charAt(17), strVal.charAt(18)), TypeUtils.num(strVal.charAt(20), strVal.charAt(21), strVal.charAt(22), strVal.charAt(23), strVal.charAt(24), strVal.charAt(25), strVal.charAt(26), strVal.charAt(27), strVal.charAt(28)));
                } else if (TypeUtils.isNumber(strVal)) {
                    longValue = Long.parseLong(strVal);
                } else {
                    JSONScanner scanner = new JSONScanner(strVal);
                    if (scanner.scanISO8601DateIfMatch(false)) {
                        longValue = scanner.getCalendar().getTime().getTime();
                    } else {
                        throw new JSONException("can not cast to Timestamp, value : " + strVal);
                    }
                }
            }
            return new Timestamp(longValue);
        }
    };
    private static volatile boolean classXmlAccessorType_error = false;
    private static Class<? extends Annotation> class_JacksonCreator = null;
    private static boolean class_JacksonCreator_error = false;
    private static Class<? extends Annotation> class_ManyToMany = null;
    private static boolean class_ManyToMany_error = false;
    private static Class<? extends Annotation> class_OneToMany = null;
    private static boolean class_OneToMany_error = false;
    private static volatile Class class_XmlAccessType = null;
    private static volatile Class class_XmlAccessorType = null;
    private static Class class_deque = null;
    public static boolean compatibleWithFieldName = false;
    public static boolean compatibleWithJavaBean = false;
    private static volatile Field field_XmlAccessType_FIELD = null;
    private static volatile Object field_XmlAccessType_FIELD_VALUE = null;
    public static final long fnv1a_64_magic_hashcode = -3750763034362895579L;
    public static final long fnv1a_64_magic_prime = 1099511628211L;
    private static Function<Class, Boolean> isClobFunction = new Function<Class, Boolean>() {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass1 */

        public Boolean apply(Class clazz) {
            return Boolean.valueOf(Clob.class.isAssignableFrom(clazz));
        }
    };
    private static final Set<String> isProxyClassNames = new HashSet<String>(6) {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass8 */

        {
            add("net.sf.cglib.proxy.Factory");
            add("org.springframework.cglib.proxy.Factory");
            add("javassist.util.proxy.ProxyObject");
            add("org.apache.ibatis.javassist.util.proxy.ProxyObject");
            add("org.hibernate.proxy.HibernateProxy");
            add("org.springframework.context.annotation.ConfigurationClassEnhancer$EnhancedConfiguration");
        }
    };
    private static volatile Map<Class, String[]> kotlinIgnores;
    private static volatile boolean kotlinIgnores_error;
    private static volatile boolean kotlin_class_klass_error;
    private static volatile boolean kotlin_error;
    private static volatile Constructor kotlin_kclass_constructor;
    private static volatile Method kotlin_kclass_getConstructors;
    private static volatile Method kotlin_kfunction_getParameters;
    private static volatile Method kotlin_kparameter_getName;
    private static volatile Class kotlin_metadata;
    private static volatile boolean kotlin_metadata_error;
    private static ConcurrentMap<String, Class<?>> mappings = new ConcurrentHashMap(256, 0.75f, 1);
    private static Method method_HibernateIsInitialized = null;
    private static boolean method_HibernateIsInitialized_error = false;
    private static volatile Method method_XmlAccessorType_value = null;
    private static Class<?> optionalClass;
    private static boolean optionalClassInited = false;
    private static Method oracleDateMethod;
    private static boolean oracleDateMethodInited = false;
    private static Method oracleTimestampMethod;
    private static boolean oracleTimestampMethodInited = false;
    private static Class<?> pathClass;
    private static boolean pathClass_error = false;
    private static final Map primitiveTypeMap = new HashMap<Class, String>(8) {
        /* class com.alibaba.fastjson.util.TypeUtils.AnonymousClass7 */

        {
            put(Boolean.TYPE, "Z");
            put(Character.TYPE, "C");
            put(Byte.TYPE, "B");
            put(Short.TYPE, ExifInterface.LATITUDE_SOUTH);
            put(Integer.TYPE, "I");
            put(Long.TYPE, "J");
            put(Float.TYPE, "F");
            put(Double.TYPE, QLog.TAG_REPORTLEVEL_DEVELOPER);
        }
    };
    private static boolean setAccessibleEnable = true;
    private static Class<? extends Annotation> transientClass;
    private static boolean transientClassInited = false;

    static {
        compatibleWithJavaBean = false;
        compatibleWithFieldName = false;
        class_deque = null;
        try {
            compatibleWithJavaBean = AbsoluteConst.TRUE.equals(IOUtils.getStringProperty(IOUtils.FASTJSON_COMPATIBLEWITHJAVABEAN));
            compatibleWithFieldName = AbsoluteConst.TRUE.equals(IOUtils.getStringProperty(IOUtils.FASTJSON_COMPATIBLEWITHFIELDNAME));
        } catch (Throwable th) {
        }
        try {
            class_deque = Class.forName("java.util.Deque");
        } catch (Throwable th2) {
        }
        addBaseClassMappings();
    }

    public static boolean isXmlField(Class clazz) {
        Annotation annotation;
        if (class_XmlAccessorType == null && !classXmlAccessorType_error) {
            try {
                class_XmlAccessorType = Class.forName("javax.xml.bind.annotation.XmlAccessorType");
            } catch (Throwable th) {
                classXmlAccessorType_error = true;
            }
        }
        if (class_XmlAccessorType == null || (annotation = getAnnotation(clazz, class_XmlAccessorType)) == null) {
            return false;
        }
        if (method_XmlAccessorType_value == null && !classXmlAccessorType_error) {
            try {
                method_XmlAccessorType_value = class_XmlAccessorType.getMethod("value", new Class[0]);
            } catch (Throwable th2) {
                classXmlAccessorType_error = true;
            }
        }
        if (method_XmlAccessorType_value == null) {
            return false;
        }
        Object value = null;
        if (!classXmlAccessorType_error) {
            try {
                value = method_XmlAccessorType_value.invoke(annotation, new Object[0]);
            } catch (Throwable th3) {
                classXmlAccessorType_error = true;
            }
        }
        if (value == null) {
            return false;
        }
        if (class_XmlAccessType == null && !classXmlAccessorType_error) {
            try {
                class_XmlAccessType = Class.forName("javax.xml.bind.annotation.XmlAccessType");
                field_XmlAccessType_FIELD = class_XmlAccessType.getField("FIELD");
                field_XmlAccessType_FIELD_VALUE = field_XmlAccessType_FIELD.get(null);
            } catch (Throwable th4) {
                classXmlAccessorType_error = true;
            }
        }
        if (value == field_XmlAccessType_FIELD_VALUE) {
            return true;
        }
        return false;
    }

    public static Annotation getXmlAccessorType(Class clazz) {
        if (class_XmlAccessorType == null && !classXmlAccessorType_error) {
            try {
                class_XmlAccessorType = Class.forName("javax.xml.bind.annotation.XmlAccessorType");
            } catch (Throwable th) {
                classXmlAccessorType_error = true;
            }
        }
        if (class_XmlAccessorType == null) {
            return null;
        }
        return getAnnotation(clazz, class_XmlAccessorType);
    }

    public static boolean isClob(Class clazz) {
        Boolean isClob = (Boolean) ModuleUtil.callWhenHasJavaSql(isClobFunction, clazz);
        if (isClob != null) {
            return isClob.booleanValue();
        }
        return false;
    }

    public static String castToString(Object value) {
        if (value == null) {
            return null;
        }
        return value.toString();
    }

    public static Byte castToByte(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof BigDecimal) {
            return Byte.valueOf(byteValue((BigDecimal) value));
        }
        if (value instanceof Number) {
            return Byte.valueOf(((Number) value).byteValue());
        }
        if (value instanceof String) {
            String strVal = (String) value;
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            return Byte.valueOf(Byte.parseByte(strVal));
        } else if (value instanceof Boolean) {
            return Byte.valueOf(((Boolean) value).booleanValue() ? (byte) 1 : 0);
        } else {
            throw new JSONException("can not cast to byte, value : " + value);
        }
    }

    public static Character castToChar(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Character) {
            return (Character) value;
        }
        if (value instanceof String) {
            String strVal = (String) value;
            if (strVal.length() == 0) {
                return null;
            }
            if (strVal.length() == 1) {
                return Character.valueOf(strVal.charAt(0));
            }
            throw new JSONException("can not cast to char, value : " + value);
        }
        throw new JSONException("can not cast to char, value : " + value);
    }

    public static Short castToShort(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof BigDecimal) {
            return Short.valueOf(shortValue((BigDecimal) value));
        }
        if (value instanceof Number) {
            return Short.valueOf(((Number) value).shortValue());
        }
        if (value instanceof String) {
            String strVal = (String) value;
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            return Short.valueOf(Short.parseShort(strVal));
        } else if (value instanceof Boolean) {
            return Short.valueOf(((Boolean) value).booleanValue() ? (short) 1 : 0);
        } else {
            throw new JSONException("can not cast to short, value : " + value);
        }
    }

    public static BigDecimal castToBigDecimal(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Float) {
            if (Float.isNaN(((Float) value).floatValue()) || Float.isInfinite(((Float) value).floatValue())) {
                return null;
            }
        } else if (value instanceof Double) {
            if (Double.isNaN(((Double) value).doubleValue()) || Double.isInfinite(((Double) value).doubleValue())) {
                return null;
            }
        } else if (value instanceof BigDecimal) {
            return (BigDecimal) value;
        } else {
            if (value instanceof BigInteger) {
                return new BigDecimal((BigInteger) value);
            }
            if ((value instanceof Map) && ((Map) value).size() == 0) {
                return null;
            }
        }
        String strVal = value.toString();
        if (strVal.length() == 0 || strVal.equalsIgnoreCase(b.m)) {
            return null;
        }
        if (strVal.length() <= 65535) {
            return new BigDecimal(strVal);
        }
        throw new JSONException("decimal overflow");
    }

    public static BigInteger castToBigInteger(Object value) {
        int scale;
        if (value == null) {
            return null;
        }
        if (value instanceof Float) {
            Float floatValue = (Float) value;
            if (Float.isNaN(floatValue.floatValue()) || Float.isInfinite(floatValue.floatValue())) {
                return null;
            }
            return BigInteger.valueOf(floatValue.longValue());
        } else if (value instanceof Double) {
            Double doubleValue = (Double) value;
            if (Double.isNaN(doubleValue.doubleValue()) || Double.isInfinite(doubleValue.doubleValue())) {
                return null;
            }
            return BigInteger.valueOf(doubleValue.longValue());
        } else if (value instanceof BigInteger) {
            return (BigInteger) value;
        } else {
            if ((value instanceof BigDecimal) && (scale = ((BigDecimal) value).scale()) > -1000 && scale < 1000) {
                return ((BigDecimal) value).toBigInteger();
            }
            String strVal = value.toString();
            if (strVal.length() == 0 || strVal.equalsIgnoreCase(b.m)) {
                return null;
            }
            if (strVal.length() <= 65535) {
                return new BigInteger(strVal);
            }
            throw new JSONException("decimal overflow");
        }
    }

    public static Float castToFloat(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Number) {
            return Float.valueOf(((Number) value).floatValue());
        }
        if (value instanceof String) {
            String strVal = value.toString();
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            if (strVal.indexOf(44) != -1) {
                strVal = strVal.replaceAll(",", "");
            }
            return Float.valueOf(Float.parseFloat(strVal));
        } else if (value instanceof Boolean) {
            return Float.valueOf(((Boolean) value).booleanValue() ? 1.0f : 0.0f);
        } else {
            throw new JSONException("can not cast to float, value : " + value);
        }
    }

    public static Double castToDouble(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Number) {
            return Double.valueOf(((Number) value).doubleValue());
        }
        if (value instanceof String) {
            String strVal = value.toString();
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            if (strVal.indexOf(44) != -1) {
                strVal = strVal.replaceAll(",", "");
            }
            return Double.valueOf(Double.parseDouble(strVal));
        } else if (value instanceof Boolean) {
            return Double.valueOf(((Boolean) value).booleanValue() ? 1.0d : 0.0d);
        } else {
            throw new JSONException("can not cast to double, value : " + value);
        }
    }

    public static java.util.Date castToDate(Object value) {
        return castToDate(value, null);
    }

    public static java.util.Date castToDate(Object value, String format) {
        if (value == null) {
            return null;
        }
        if (value instanceof java.util.Date) {
            return (java.util.Date) value;
        }
        if (value instanceof Calendar) {
            return ((Calendar) value).getTime();
        }
        long longValue = -1;
        if (value instanceof BigDecimal) {
            return new java.util.Date(longValue((BigDecimal) value));
        }
        if (value instanceof Number) {
            long longValue2 = ((Number) value).longValue();
            if ("unixtime".equals(format)) {
                longValue2 *= 1000;
            }
            return new java.util.Date(longValue2);
        }
        if (value instanceof String) {
            String strVal = (String) value;
            JSONScanner dateLexer = new JSONScanner(strVal);
            try {
                if (dateLexer.scanISO8601DateIfMatch(false)) {
                    return dateLexer.getCalendar().getTime();
                }
                dateLexer.close();
                if (strVal.startsWith("/Date(") && strVal.endsWith(")/")) {
                    strVal = strVal.substring(6, strVal.length() - 2);
                }
                if (strVal.indexOf(45) > 0 || strVal.indexOf(43) > 0 || format != null) {
                    if (format == null) {
                        int len = strVal.length();
                        if (len == JSON.DEFFAULT_DATE_FORMAT.length() || (len == 22 && JSON.DEFFAULT_DATE_FORMAT.equals("yyyyMMddHHmmssSSSZ"))) {
                            format = JSON.DEFFAULT_DATE_FORMAT;
                        } else if (len == 10) {
                            format = "yyyy-MM-dd";
                        } else if (len == "yyyy-MM-dd HH:mm:ss".length()) {
                            format = "yyyy-MM-dd HH:mm:ss";
                        } else if (len == 29 && strVal.charAt(26) == ':' && strVal.charAt(28) == '0') {
                            format = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX";
                        } else if (len == 23 && strVal.charAt(19) == ',') {
                            format = "yyyy-MM-dd HH:mm:ss,SSS";
                        } else {
                            format = "yyyy-MM-dd HH:mm:ss.SSS";
                        }
                    }
                    SimpleDateFormat dateFormat = new SimpleDateFormat(format, JSON.defaultLocale);
                    dateFormat.setTimeZone(JSON.defaultTimeZone);
                    try {
                        return dateFormat.parse(strVal);
                    } catch (ParseException e) {
                        throw new JSONException("can not cast to Date, value : " + strVal);
                    }
                } else if (strVal.length() == 0) {
                    return null;
                } else {
                    longValue = Long.parseLong(strVal);
                }
            } finally {
                dateLexer.close();
            }
        }
        if (longValue != -1) {
            return new java.util.Date(longValue);
        }
        Class<?> clazz = value.getClass();
        if ("oracle.sql.TIMESTAMP".equals(clazz.getName())) {
            if (oracleTimestampMethod == null && !oracleTimestampMethodInited) {
                try {
                    oracleTimestampMethod = clazz.getMethod("toJdbc", new Class[0]);
                } catch (NoSuchMethodException e2) {
                } catch (Throwable th) {
                    oracleTimestampMethodInited = true;
                    throw th;
                }
                oracleTimestampMethodInited = true;
            }
            try {
                return (java.util.Date) oracleTimestampMethod.invoke(value, new Object[0]);
            } catch (Exception e3) {
                throw new JSONException("can not cast oracle.sql.TIMESTAMP to Date", e3);
            }
        } else if ("oracle.sql.DATE".equals(clazz.getName())) {
            if (oracleDateMethod == null && !oracleDateMethodInited) {
                try {
                    oracleDateMethod = clazz.getMethod("toJdbc", new Class[0]);
                } catch (NoSuchMethodException e4) {
                } catch (Throwable th2) {
                    oracleDateMethodInited = true;
                    throw th2;
                }
                oracleDateMethodInited = true;
            }
            try {
                return (java.util.Date) oracleDateMethod.invoke(value, new Object[0]);
            } catch (Exception e5) {
                throw new JSONException("can not cast oracle.sql.DATE to Date", e5);
            }
        } else {
            throw new JSONException("can not cast to Date, value : " + value);
        }
    }

    public static Object castToSqlDate(Object value) {
        return ModuleUtil.callWhenHasJavaSql(castToSqlDateFunction, value);
    }

    public static long longExtractValue(Number number) {
        if (number instanceof BigDecimal) {
            return ((BigDecimal) number).longValueExact();
        }
        return number.longValue();
    }

    public static Object castToSqlTime(Object value) {
        return ModuleUtil.callWhenHasJavaSql(castToSqlTimeFunction, value);
    }

    public static Object castToTimestamp(Object value) {
        return ModuleUtil.callWhenHasJavaSql(castToTimestampFunction, value);
    }

    static int num(char c0, char c1) {
        if (c0 < '0' || c0 > '9' || c1 < '0' || c1 > '9') {
            return -1;
        }
        return ((c0 - '0') * 10) + (c1 - '0');
    }

    static int num(char c0, char c1, char c2, char c3) {
        if (c0 < '0' || c0 > '9' || c1 < '0' || c1 > '9' || c2 < '0' || c2 > '9' || c3 < '0' || c3 > '9') {
            return -1;
        }
        return ((c0 - '0') * 1000) + ((c1 - '0') * 100) + ((c2 - '0') * 10) + (c3 - '0');
    }

    static int num(char c0, char c1, char c2, char c3, char c4, char c5, char c6, char c7, char c8) {
        if (c0 < '0' || c0 > '9' || c1 < '0' || c1 > '9' || c2 < '0' || c2 > '9' || c3 < '0' || c3 > '9' || c4 < '0' || c4 > '9' || c5 < '0' || c5 > '9' || c6 < '0' || c6 > '9' || c7 < '0' || c7 > '9' || c8 < '0' || c8 > '9') {
            return -1;
        }
        return ((c0 - '0') * 100000000) + ((c1 - '0') * 10000000) + ((c2 - '0') * CrashStatKey.STATS_REPORT_FINISHED) + ((c3 - '0') * 100000) + ((c4 - '0') * 10000) + ((c5 - '0') * 1000) + ((c6 - '0') * 100) + ((c7 - '0') * 10) + (c8 - '0');
    }

    public static boolean isNumber(String str) {
        for (int i = 0; i < str.length(); i++) {
            char ch = str.charAt(i);
            if (ch == '+' || ch == '-') {
                if (i != 0) {
                    return false;
                }
            } else if (ch < '0' || ch > '9') {
                return false;
            }
        }
        return true;
    }

    public static Long castToLong(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof BigDecimal) {
            return Long.valueOf(longValue((BigDecimal) value));
        }
        if (value instanceof Number) {
            return Long.valueOf(((Number) value).longValue());
        }
        if (value instanceof String) {
            String strVal = (String) value;
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            if (strVal.indexOf(44) != -1) {
                strVal = strVal.replaceAll(",", "");
            }
            try {
                return Long.valueOf(Long.parseLong(strVal));
            } catch (NumberFormatException e) {
                JSONScanner dateParser = new JSONScanner(strVal);
                Calendar calendar = null;
                if (dateParser.scanISO8601DateIfMatch(false)) {
                    calendar = dateParser.getCalendar();
                }
                dateParser.close();
                if (calendar != null) {
                    return Long.valueOf(calendar.getTimeInMillis());
                }
            }
        }
        if (value instanceof Map) {
            Map map = (Map) value;
            if (map.size() == 2 && map.containsKey("andIncrement") && map.containsKey("andDecrement")) {
                Iterator iter = map.values().iterator();
                iter.next();
                return castToLong(iter.next());
            }
        }
        if (value instanceof Boolean) {
            return Long.valueOf(((Boolean) value).booleanValue() ? 1 : 0);
        }
        throw new JSONException("can not cast to long, value : " + value);
    }

    public static byte byteValue(BigDecimal decimal) {
        if (decimal == null) {
            return 0;
        }
        int scale = decimal.scale();
        if (scale < -100 || scale > 100) {
            return decimal.byteValueExact();
        }
        return decimal.byteValue();
    }

    public static short shortValue(BigDecimal decimal) {
        if (decimal == null) {
            return 0;
        }
        int scale = decimal.scale();
        if (scale < -100 || scale > 100) {
            return decimal.shortValueExact();
        }
        return decimal.shortValue();
    }

    public static int intValue(BigDecimal decimal) {
        if (decimal == null) {
            return 0;
        }
        int scale = decimal.scale();
        if (scale < -100 || scale > 100) {
            return decimal.intValueExact();
        }
        return decimal.intValue();
    }

    public static long longValue(BigDecimal decimal) {
        if (decimal == null) {
            return 0;
        }
        int scale = decimal.scale();
        if (scale < -100 || scale > 100) {
            return decimal.longValueExact();
        }
        return decimal.longValue();
    }

    public static Integer castToInt(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Integer) {
            return (Integer) value;
        }
        if (value instanceof BigDecimal) {
            return Integer.valueOf(intValue((BigDecimal) value));
        }
        if (value instanceof Number) {
            return Integer.valueOf(((Number) value).intValue());
        }
        if (value instanceof String) {
            String strVal = (String) value;
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
            if (strVal.indexOf(44) != -1) {
                strVal = strVal.replaceAll(",", "");
            }
            Matcher matcher = NUMBER_WITH_TRAILING_ZEROS_PATTERN.matcher(strVal);
            if (matcher.find()) {
                strVal = matcher.replaceAll("");
            }
            return Integer.valueOf(Integer.parseInt(strVal));
        } else if (value instanceof Boolean) {
            return Integer.valueOf(((Boolean) value).booleanValue() ? 1 : 0);
        } else {
            if (value instanceof Map) {
                Map map = (Map) value;
                if (map.size() == 2 && map.containsKey("andIncrement") && map.containsKey("andDecrement")) {
                    Iterator iter = map.values().iterator();
                    iter.next();
                    return castToInt(iter.next());
                }
            }
            throw new JSONException("can not cast to int, value : " + value);
        }
    }

    public static byte[] castToBytes(Object value) {
        if (value instanceof byte[]) {
            return (byte[]) value;
        }
        if (value instanceof String) {
            return IOUtils.decodeBase64((String) value);
        }
        throw new JSONException("can not cast to byte[], value : " + value);
    }

    public static Boolean castToBoolean(Object value) {
        if (value == null) {
            return null;
        }
        if (value instanceof Boolean) {
            return (Boolean) value;
        }
        boolean z = false;
        if (value instanceof BigDecimal) {
            if (intValue((BigDecimal) value) == 1) {
                z = true;
            }
            return Boolean.valueOf(z);
        } else if (value instanceof Number) {
            if (((Number) value).intValue() == 1) {
                z = true;
            }
            return Boolean.valueOf(z);
        } else {
            if (value instanceof String) {
                String strVal = (String) value;
                if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                    return null;
                }
                if (AbsoluteConst.TRUE.equalsIgnoreCase(strVal) || "1".equals(strVal)) {
                    return Boolean.TRUE;
                }
                if (AbsoluteConst.FALSE.equalsIgnoreCase(strVal) || "0".equals(strVal)) {
                    return Boolean.FALSE;
                }
                if ("Y".equalsIgnoreCase(strVal) || ExifInterface.GPS_DIRECTION_TRUE.equals(strVal)) {
                    return Boolean.TRUE;
                }
                if ("F".equalsIgnoreCase(strVal) || "N".equals(strVal)) {
                    return Boolean.FALSE;
                }
            }
            throw new JSONException("can not cast to boolean, value : " + value);
        }
    }

    public static <T> T castToJavaBean(Object obj, Class<T> clazz) {
        return (T) cast(obj, (Class) clazz, ParserConfig.getGlobalInstance());
    }

    /* JADX DEBUG: Multi-variable search result rejected for r6v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public static <T> T cast(Object obj, Class<T> clazz, ParserConfig config) {
        Calendar calendar;
        if (obj == 0) {
            if (clazz == Integer.TYPE) {
                return (T) 0;
            }
            if (clazz == Long.TYPE) {
                return (T) 0L;
            }
            if (clazz == Short.TYPE) {
                return (T) 0;
            }
            if (clazz == Byte.TYPE) {
                return (T) (byte) 0;
            }
            if (clazz == Float.TYPE) {
                return (T) Float.valueOf(0.0f);
            }
            if (clazz == Double.TYPE) {
                return (T) Double.valueOf(0.0d);
            }
            if (clazz == Boolean.TYPE) {
                return (T) Boolean.FALSE;
            }
            return null;
        } else if (clazz == null) {
            throw new IllegalArgumentException("clazz is null");
        } else if (clazz == obj.getClass()) {
            return obj;
        } else {
            if (!(obj instanceof Map)) {
                if (clazz.isArray()) {
                    if (obj instanceof Collection) {
                        Collection<Object> collection = (Collection) obj;
                        int index = 0;
                        T t = (T) Array.newInstance(clazz.getComponentType(), collection.size());
                        for (Object item : collection) {
                            Array.set(t, index, cast(item, (Class) clazz.getComponentType(), config));
                            index++;
                        }
                        return t;
                    } else if (clazz == byte[].class) {
                        return (T) castToBytes(obj);
                    }
                }
                if (clazz.isAssignableFrom(obj.getClass())) {
                    return obj;
                }
                if (clazz == Boolean.TYPE || clazz == Boolean.class) {
                    return (T) castToBoolean(obj);
                }
                if (clazz == Byte.TYPE || clazz == Byte.class) {
                    return (T) castToByte(obj);
                }
                if (clazz == Character.TYPE || clazz == Character.class) {
                    return (T) castToChar(obj);
                }
                if (clazz == Short.TYPE || clazz == Short.class) {
                    return (T) castToShort(obj);
                }
                if (clazz == Integer.TYPE || clazz == Integer.class) {
                    return (T) castToInt(obj);
                }
                if (clazz == Long.TYPE || clazz == Long.class) {
                    return (T) castToLong(obj);
                }
                if (clazz == Float.TYPE || clazz == Float.class) {
                    return (T) castToFloat(obj);
                }
                if (clazz == Double.TYPE || clazz == Double.class) {
                    return (T) castToDouble(obj);
                }
                if (clazz == String.class) {
                    return (T) castToString(obj);
                }
                if (clazz == BigDecimal.class) {
                    return (T) castToBigDecimal(obj);
                }
                if (clazz == BigInteger.class) {
                    return (T) castToBigInteger(obj);
                }
                if (clazz == java.util.Date.class) {
                    return (T) castToDate(obj);
                }
                T retObj = (T) ModuleUtil.callWhenHasJavaSql(castFunction, obj, clazz);
                if (retObj != null) {
                    return retObj;
                }
                if (clazz.isEnum()) {
                    return (T) castToEnum(obj, clazz, config);
                }
                if (Calendar.class.isAssignableFrom(clazz)) {
                    java.util.Date date = castToDate(obj);
                    if (clazz == Calendar.class) {
                        calendar = (T) Calendar.getInstance(JSON.defaultTimeZone, JSON.defaultLocale);
                    } else {
                        try {
                            calendar = (T) clazz.newInstance();
                        } catch (Exception e) {
                            throw new JSONException("can not cast to : " + clazz.getName(), e);
                        }
                    }
                    calendar.setTime(date);
                    return (T) calendar;
                }
                String className = clazz.getName();
                if (className.equals("javax.xml.datatype.XMLGregorianCalendar")) {
                    java.util.Date date2 = castToDate(obj);
                    Calendar calendar2 = Calendar.getInstance(JSON.defaultTimeZone, JSON.defaultLocale);
                    calendar2.setTime(date2);
                    return (T) CalendarCodec.instance.createXMLGregorianCalendar(calendar2);
                }
                if (obj instanceof String) {
                    String strVal = (String) obj;
                    if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                        return null;
                    }
                    if (clazz == Currency.class) {
                        return (T) Currency.getInstance(strVal);
                    }
                    if (clazz == Locale.class) {
                        return (T) toLocale(strVal);
                    }
                    if (className.startsWith("java.time.")) {
                        return (T) JSON.parseObject(JSON.toJSONString(strVal), clazz);
                    }
                }
                if (config.get(clazz) != null) {
                    return (T) JSON.parseObject(JSON.toJSONString(obj), clazz);
                }
                throw new JSONException("can not cast to : " + clazz.getName());
            } else if (clazz == Map.class) {
                return obj;
            } else {
                return (clazz != Object.class || ((Map) obj).containsKey(JSON.DEFAULT_TYPE_KEY)) ? (T) castToJavaBean((Map) obj, clazz, config) : obj;
            }
        }
    }

    public static Locale toLocale(String strVal) {
        String[] items = strVal.split("_");
        if (items.length == 1) {
            return new Locale(items[0]);
        }
        if (items.length == 2) {
            return new Locale(items[0], items[1]);
        }
        return new Locale(items[0], items[1], items[2]);
    }

    public static <T> T castToEnum(Object obj, Class<T> clazz, ParserConfig mapping) {
        try {
            if (obj instanceof String) {
                String name = (String) obj;
                if (name.length() == 0) {
                    return null;
                }
                if (mapping == null) {
                    mapping = ParserConfig.getGlobalInstance();
                }
                ObjectDeserializer deserializer = mapping.getDeserializer(clazz);
                return deserializer instanceof EnumDeserializer ? (T) ((EnumDeserializer) deserializer).getEnumByHashCode(fnv1a_64(name)) : (T) Enum.valueOf(clazz, name);
            }
            if (obj instanceof BigDecimal) {
                int ordinal = intValue((BigDecimal) obj);
                T[] enumConstants = clazz.getEnumConstants();
                if (ordinal < enumConstants.length) {
                    return enumConstants[ordinal];
                }
            }
            if (obj instanceof Number) {
                int ordinal2 = ((Number) obj).intValue();
                T[] enumConstants2 = clazz.getEnumConstants();
                if (ordinal2 < enumConstants2.length) {
                    return enumConstants2[ordinal2];
                }
            }
            throw new JSONException("can not cast to : " + clazz.getName());
        } catch (Exception ex) {
            throw new JSONException("can not cast to : " + clazz.getName(), ex);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    public static <T> T cast(Object obj, Type type, ParserConfig mapping) {
        if (obj == 0) {
            return null;
        }
        if (type instanceof Class) {
            return (T) cast(obj, (Class) type, mapping);
        }
        if (type instanceof ParameterizedType) {
            return (T) cast(obj, (ParameterizedType) type, mapping);
        }
        if (obj instanceof String) {
            String strVal = (String) obj;
            if (strVal.length() == 0 || b.m.equals(strVal) || "NULL".equals(strVal)) {
                return null;
            }
        }
        if (type instanceof TypeVariable) {
            return obj;
        }
        throw new JSONException("can not cast to : " + type);
    }

    public static <T> T cast(Object obj, ParameterizedType type, ParserConfig mapping) {
        Object itemValue;
        Object itemValue2;
        Type rawTye = type.getRawType();
        if (rawTye == List.class || rawTye == ArrayList.class) {
            Type itemType = type.getActualTypeArguments()[0];
            if (obj instanceof List) {
                List listObj = (List) obj;
                T t = (T) new ArrayList(listObj.size());
                for (Object item : listObj) {
                    if (!(itemType instanceof Class)) {
                        itemValue2 = cast(item, itemType, mapping);
                    } else if (item == null || item.getClass() != JSONObject.class) {
                        itemValue2 = cast(item, (Class) itemType, mapping);
                    } else {
                        itemValue2 = ((JSONObject) item).toJavaObject((Class) itemType, mapping, 0);
                    }
                    t.add(itemValue2);
                }
                return t;
            }
        }
        if (rawTye == Set.class || rawTye == HashSet.class || rawTye == TreeSet.class || rawTye == Collection.class || rawTye == List.class || rawTye == ArrayList.class) {
            Type itemType2 = type.getActualTypeArguments()[0];
            if (obj instanceof Iterable) {
                Collection collection = (rawTye == Set.class || rawTye == HashSet.class) ? (T) new HashSet() : rawTye == TreeSet.class ? (T) new TreeSet() : (T) new ArrayList();
                for (Object item2 : (Iterable) obj) {
                    if (!(itemType2 instanceof Class)) {
                        itemValue = cast(item2, itemType2, mapping);
                    } else if (item2 == null || item2.getClass() != JSONObject.class) {
                        itemValue = cast(item2, (Class) itemType2, mapping);
                    } else {
                        itemValue = ((JSONObject) item2).toJavaObject((Class) itemType2, mapping, 0);
                    }
                    collection.add(itemValue);
                }
                return (T) collection;
            }
        }
        if (rawTye == Map.class || rawTye == HashMap.class) {
            Type keyType = type.getActualTypeArguments()[0];
            Type valueType = type.getActualTypeArguments()[1];
            if (obj instanceof Map) {
                T t2 = (T) new HashMap();
                for (Map.Entry entry : ((Map) obj).entrySet()) {
                    t2.put(cast(entry.getKey(), keyType, mapping), cast(entry.getValue(), valueType, mapping));
                }
                return t2;
            }
        }
        if ((obj instanceof String) && ((String) obj).length() == 0) {
            return null;
        }
        Type[] actualTypeArguments = type.getActualTypeArguments();
        if (actualTypeArguments.length == 1 && (type.getActualTypeArguments()[0] instanceof WildcardType)) {
            return (T) cast(obj, rawTye, mapping);
        }
        if (rawTye == Map.Entry.class && (obj instanceof Map) && ((Map) obj).size() == 1) {
            T t3 = (T) ((Map.Entry) ((Map) obj).entrySet().iterator().next());
            Object entryValue = t3.getValue();
            if (actualTypeArguments.length == 2 && (entryValue instanceof Map)) {
                t3.setValue(cast(entryValue, actualTypeArguments[1], mapping));
            }
            return t3;
        }
        if (rawTye instanceof Class) {
            if (mapping == null) {
                mapping = ParserConfig.global;
            }
            ObjectDeserializer deserializer = mapping.getDeserializer(rawTye);
            if (deserializer != null) {
                return (T) deserializer.deserialze(new DefaultJSONParser(JSON.toJSONString(obj), mapping), type, null);
            }
        }
        throw new JSONException("can not cast to : " + type);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r6v0, resolved type: java.util.Map<java.lang.String, java.lang.Object> */
    /* JADX WARN: Multi-variable type inference failed */
    public static <T> T castToJavaBean(Map<String, Object> map, Class<T> clazz, ParserConfig config) {
        JSONObject object;
        int lineNumber;
        if (clazz == StackTraceElement.class) {
            try {
                String declaringClass = (String) map.get(PushClientConstants.TAG_CLASS_NAME);
                String methodName = (String) map.get("methodName");
                String fileName = (String) map.get("fileName");
                Number value = (Number) map.get("lineNumber");
                if (value == null) {
                    lineNumber = 0;
                } else if (value instanceof BigDecimal) {
                    lineNumber = ((BigDecimal) value).intValueExact();
                } else {
                    lineNumber = value.intValue();
                }
                return (T) new StackTraceElement(declaringClass, methodName, fileName, lineNumber);
            } catch (Exception e) {
                throw new JSONException(e.getMessage(), e);
            }
        } else {
            Object iClassObject = map.get(JSON.DEFAULT_TYPE_KEY);
            if (iClassObject instanceof String) {
                String className = (String) iClassObject;
                if (config == null) {
                    config = ParserConfig.global;
                }
                Class<?> loadClazz = config.checkAutoType(className, null);
                if (loadClazz == null) {
                    throw new ClassNotFoundException(className + " not found");
                } else if (!loadClazz.equals(clazz)) {
                    return (T) castToJavaBean(map, loadClazz, config);
                }
            }
            if (clazz.isInterface()) {
                if (map instanceof JSONObject) {
                    object = (JSONObject) map;
                } else {
                    object = new JSONObject(map);
                }
                if (config == null) {
                    config = ParserConfig.getGlobalInstance();
                }
                if (config.get(clazz) != null) {
                    return (T) JSON.parseObject(JSON.toJSONString(object), clazz);
                }
                return (T) Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{clazz}, object);
            }
            if (clazz == Locale.class) {
                Object arg0 = map.get("language");
                Object arg1 = map.get("country");
                if (arg0 instanceof String) {
                    String language = (String) arg0;
                    if (arg1 instanceof String) {
                        return (T) new Locale(language, (String) arg1);
                    }
                    if (arg1 == null) {
                        return (T) new Locale(language);
                    }
                }
            }
            if (clazz == String.class && (map instanceof JSONObject)) {
                return (T) map.toString();
            }
            if (clazz == JSON.class && (map instanceof JSONObject)) {
                return map;
            }
            if (clazz == LinkedHashMap.class && (map instanceof JSONObject)) {
                T t = (T) ((JSONObject) map).getInnerMap();
                if (t instanceof LinkedHashMap) {
                    return t;
                }
            }
            if (clazz.isInstance(map)) {
                return map;
            }
            if (clazz == JSONObject.class) {
                return (T) new JSONObject(map);
            }
            if (config == null) {
                config = ParserConfig.getGlobalInstance();
            }
            JavaBeanDeserializer javaBeanDeser = null;
            ObjectDeserializer deserializer = config.getDeserializer(clazz);
            if (deserializer instanceof JavaBeanDeserializer) {
                javaBeanDeser = (JavaBeanDeserializer) deserializer;
            }
            if (javaBeanDeser != null) {
                return (T) javaBeanDeser.createInstance(map, config);
            }
            throw new JSONException("can not get javaBeanDeserializer. " + clazz.getName());
        }
    }

    private static void addBaseClassMappings() {
        mappings.put("byte", Byte.TYPE);
        mappings.put("short", Short.TYPE);
        mappings.put("int", Integer.TYPE);
        mappings.put("long", Long.TYPE);
        mappings.put("float", Float.TYPE);
        mappings.put("double", Double.TYPE);
        mappings.put("boolean", Boolean.TYPE);
        mappings.put("char", Character.TYPE);
        mappings.put("[byte", byte[].class);
        mappings.put("[short", short[].class);
        mappings.put("[int", int[].class);
        mappings.put("[long", long[].class);
        mappings.put("[float", float[].class);
        mappings.put("[double", double[].class);
        mappings.put("[boolean", boolean[].class);
        mappings.put("[char", char[].class);
        mappings.put("[B", byte[].class);
        mappings.put("[S", short[].class);
        mappings.put("[I", int[].class);
        mappings.put("[J", long[].class);
        mappings.put("[F", float[].class);
        mappings.put("[D", double[].class);
        mappings.put("[C", char[].class);
        mappings.put("[Z", boolean[].class);
        Class[] classes = {Object.class, Cloneable.class, loadClass("java.lang.AutoCloseable"), Exception.class, RuntimeException.class, IllegalAccessError.class, IllegalAccessException.class, IllegalArgumentException.class, IllegalMonitorStateException.class, IllegalStateException.class, IllegalThreadStateException.class, IndexOutOfBoundsException.class, InstantiationError.class, InstantiationException.class, InternalError.class, InterruptedException.class, LinkageError.class, NegativeArraySizeException.class, NoClassDefFoundError.class, NoSuchFieldError.class, NoSuchFieldException.class, NoSuchMethodError.class, NoSuchMethodException.class, NullPointerException.class, NumberFormatException.class, OutOfMemoryError.class, SecurityException.class, StackOverflowError.class, StringIndexOutOfBoundsException.class, TypeNotPresentException.class, VerifyError.class, StackTraceElement.class, HashMap.class, LinkedHashMap.class, Hashtable.class, TreeMap.class, IdentityHashMap.class, WeakHashMap.class, LinkedHashMap.class, HashSet.class, LinkedHashSet.class, TreeSet.class, ArrayList.class, TimeUnit.class, ConcurrentHashMap.class, AtomicInteger.class, AtomicLong.class, Collections.EMPTY_MAP.getClass(), Boolean.class, Character.class, Byte.class, Short.class, Integer.class, Long.class, Float.class, Double.class, Number.class, String.class, BigDecimal.class, BigInteger.class, BitSet.class, Calendar.class, java.util.Date.class, Locale.class, UUID.class, SimpleDateFormat.class, JSONObject.class, JSONPObject.class, JSONArray.class};
        for (Class clazz : classes) {
            if (clazz != null) {
                mappings.put(clazz.getName(), clazz);
            }
        }
        ModuleUtil.callWhenHasJavaSql(addBaseClassMappingsFunction, mappings);
    }

    public static void clearClassMapping() {
        mappings.clear();
        addBaseClassMappings();
    }

    public static void addMapping(String className, Class<?> clazz) {
        mappings.put(className, clazz);
    }

    public static Class<?> loadClass(String className) {
        return loadClass(className, null);
    }

    public static boolean isPath(Class<?> clazz) {
        if (pathClass == null && !pathClass_error) {
            try {
                pathClass = Class.forName("java.nio.file.Path");
            } catch (Throwable th) {
                pathClass_error = true;
            }
        }
        Class<?> cls = pathClass;
        if (cls != null) {
            return cls.isAssignableFrom(clazz);
        }
        return false;
    }

    public static Class<?> getClassFromMapping(String className) {
        return mappings.get(className);
    }

    public static Class<?> loadClass(String className, ClassLoader classLoader) {
        return loadClass(className, classLoader, false);
    }

    public static Class<?> loadClass(String className, ClassLoader classLoader, boolean cache) {
        if (className == null || className.length() == 0) {
            return null;
        }
        if (className.length() <= 198) {
            Class<?> clazz = mappings.get(className);
            if (clazz != null) {
                return clazz;
            }
            if (className.charAt(0) == '[') {
                return Array.newInstance(loadClass(className.substring(1), classLoader), 0).getClass();
            }
            if (className.startsWith("L") && className.endsWith(i.b)) {
                return loadClass(className.substring(1, className.length() - 1), classLoader);
            }
            if (classLoader != null) {
                try {
                    Class<?> clazz2 = classLoader.loadClass(className);
                    if (cache) {
                        mappings.put(className, clazz2);
                    }
                    return clazz2;
                } catch (Throwable e) {
                    e.printStackTrace();
                }
            }
            try {
                ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
                if (!(contextClassLoader == null || contextClassLoader == classLoader)) {
                    Class<?> clazz3 = contextClassLoader.loadClass(className);
                    if (cache) {
                        mappings.put(className, clazz3);
                    }
                    return clazz3;
                }
            } catch (Throwable th) {
            }
            try {
                Class<?> clazz4 = Class.forName(className);
                if (cache) {
                    mappings.put(className, clazz4);
                }
                return clazz4;
            } catch (Throwable th2) {
                return clazz;
            }
        } else {
            throw new JSONException("illegal className : " + className);
        }
    }

    public static SerializeBeanInfo buildBeanInfo(Class<?> beanType, Map<String, String> aliasMap, PropertyNamingStrategy propertyNamingStrategy) {
        return buildBeanInfo(beanType, aliasMap, propertyNamingStrategy, false);
    }

    public static SerializeBeanInfo buildBeanInfo(Class<?> beanType, Map<String, String> aliasMap, PropertyNamingStrategy propertyNamingStrategy, boolean fieldBased) {
        int features;
        String typeKey;
        String typeName;
        String[] orders;
        PropertyNamingStrategy propertyNamingStrategy2;
        List<FieldInfo> fieldInfoList;
        FieldInfo[] fields;
        List<FieldInfo> sortedFieldList;
        FieldInfo[] sortedFields;
        List<FieldInfo> list;
        PropertyNamingStrategy propertyNamingStrategy3;
        JSONType jsonType = (JSONType) getAnnotation(beanType, JSONType.class);
        String typeKey2 = null;
        if (jsonType != null) {
            String[] orders2 = jsonType.orders();
            String typeName2 = jsonType.typeName();
            if (typeName2.length() == 0) {
                typeName2 = null;
            }
            PropertyNamingStrategy jsonTypeNaming = jsonType.naming();
            if (jsonTypeNaming != PropertyNamingStrategy.NeverUseThisValueExceptDefaultValue) {
                propertyNamingStrategy3 = jsonTypeNaming;
            } else {
                propertyNamingStrategy3 = propertyNamingStrategy;
            }
            int features2 = SerializerFeature.of(jsonType.serialzeFeatures());
            Class<?> supperClass = beanType.getSuperclass();
            while (supperClass != null && supperClass != Object.class) {
                JSONType superJsonType = (JSONType) getAnnotation(supperClass, JSONType.class);
                if (superJsonType == null) {
                    break;
                }
                typeKey2 = superJsonType.typeKey();
                if (typeKey2.length() != 0) {
                    break;
                }
                supperClass = supperClass.getSuperclass();
            }
            for (Class<?> interfaceClass : beanType.getInterfaces()) {
                JSONType superJsonType2 = (JSONType) getAnnotation(interfaceClass, JSONType.class);
                if (superJsonType2 != null) {
                    typeKey2 = superJsonType2.typeKey();
                    if (typeKey2.length() != 0) {
                        break;
                    }
                }
            }
            if (typeKey2 != null && typeKey2.length() == 0) {
                typeKey2 = null;
            }
            orders = orders2;
            typeName = typeName2;
            typeKey = typeKey2;
            propertyNamingStrategy2 = propertyNamingStrategy3;
            features = features2;
        } else {
            propertyNamingStrategy2 = propertyNamingStrategy;
            orders = null;
            typeName = null;
            typeKey = null;
            features = 0;
        }
        Map<String, Field> fieldCacheMap = new HashMap<>();
        ParserConfig.parserAllFieldToCache(beanType, fieldCacheMap);
        if (fieldBased) {
            fieldInfoList = computeGettersWithFieldBase(beanType, aliasMap, false, propertyNamingStrategy2);
        } else {
            fieldInfoList = computeGetters(beanType, jsonType, aliasMap, fieldCacheMap, false, propertyNamingStrategy2);
        }
        FieldInfo[] fields2 = new FieldInfo[fieldInfoList.size()];
        fieldInfoList.toArray(fields2);
        if (orders == null || orders.length == 0) {
            fields = fields2;
            List<FieldInfo> sortedFieldList2 = new ArrayList<>(fieldInfoList);
            Collections.sort(sortedFieldList2);
            sortedFieldList = sortedFieldList2;
        } else {
            if (fieldBased) {
                list = computeGettersWithFieldBase(beanType, aliasMap, true, propertyNamingStrategy2);
                fields = fields2;
            } else {
                fields = fields2;
                list = computeGetters(beanType, jsonType, aliasMap, fieldCacheMap, true, propertyNamingStrategy2);
            }
            sortedFieldList = list;
        }
        FieldInfo[] sortedFields2 = new FieldInfo[sortedFieldList.size()];
        sortedFieldList.toArray(sortedFields2);
        if (Arrays.equals(sortedFields2, fields)) {
            sortedFields = fields;
        } else {
            sortedFields = sortedFields2;
        }
        return new SerializeBeanInfo(beanType, jsonType, typeName, typeKey, features, fields, sortedFields);
    }

    public static List<FieldInfo> computeGettersWithFieldBase(Class<?> clazz, Map<String, String> aliasMap, boolean sorted, PropertyNamingStrategy propertyNamingStrategy) {
        Map<String, FieldInfo> fieldInfoMap = new LinkedHashMap<>();
        for (Class<?> currentClass = clazz; currentClass != null; currentClass = currentClass.getSuperclass()) {
            computeFields(currentClass, aliasMap, propertyNamingStrategy, fieldInfoMap, currentClass.getDeclaredFields());
        }
        return getFieldInfos(clazz, sorted, fieldInfoMap);
    }

    public static List<FieldInfo> computeGetters(Class<?> clazz, Map<String, String> aliasMap) {
        return computeGetters(clazz, aliasMap, true);
    }

    public static List<FieldInfo> computeGetters(Class<?> clazz, Map<String, String> aliasMap, boolean sorted) {
        Map<String, Field> fieldCacheMap = new HashMap<>();
        ParserConfig.parserAllFieldToCache(clazz, fieldCacheMap);
        return computeGetters(clazz, (JSONType) getAnnotation(clazz, JSONType.class), aliasMap, fieldCacheMap, sorted, PropertyNamingStrategy.CamelCase);
    }

    /* JADX INFO: Multiple debug info for r2v54 int: [D('paramAnnotationArrays' java.lang.annotation.Annotation[][]), D('annotation' com.alibaba.fastjson.annotation.JSONField)] */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x038c  */
    /* JADX WARNING: Removed duplicated region for block: B:186:0x041c  */
    public static List<FieldInfo> computeGetters(Class<?> clazz, JSONType jsonType, Map<String, String> aliasMap, Map<String, Field> fieldCacheMap, boolean sorted, PropertyNamingStrategy propertyNamingStrategy) {
        Method[] methods;
        int i;
        short[] paramNameMapping;
        int i2;
        Map<String, FieldInfo> fieldInfoMap;
        String[] paramNames;
        Annotation[][] paramAnnotationArrays;
        Constructor[] constructors;
        int ordinal;
        JSONField annotation;
        Class<?> returnType;
        String methodName;
        Method method;
        Map<String, FieldInfo> fieldInfoMap2;
        int ordinal2;
        JSONField annotation2;
        Map<String, FieldInfo> fieldInfoMap3;
        int i3;
        Map<String, FieldInfo> fieldInfoMap4;
        String propertyName;
        Field field;
        String label;
        int parserFeatures;
        int serialzeFeatures;
        int parserFeatures2;
        JSONField fieldAnnotation;
        Map<String, String> map;
        String propertyName2;
        String propertyName3;
        Field field2;
        Boolean fieldAnnotationAndNameExists;
        String label2;
        int parserFeatures3;
        int serialzeFeatures2;
        int parserFeatures4;
        JSONField fieldAnnotation2;
        Map<String, String> map2;
        String propertyName4;
        String propertyName5;
        int i4;
        String propertyName6;
        JSONField annotation3;
        Field field3;
        Class<?> cls = clazz;
        Map<String, String> map3 = aliasMap;
        Map<String, Field> map4 = fieldCacheMap;
        Map<String, FieldInfo> fieldInfoMap5 = new LinkedHashMap<>();
        boolean kotlin2 = isKotlin(clazz);
        Constructor[] constructors2 = null;
        Annotation[][] paramAnnotationArrays2 = null;
        String[] paramNames2 = null;
        short[] paramNameMapping2 = null;
        Method[] methods2 = clazz.getMethods();
        try {
            Arrays.sort(methods2, new MethodInheritanceComparator());
        } catch (Throwable th) {
        }
        int length = methods2.length;
        int i5 = 0;
        while (i5 < length) {
            Method method2 = methods2[i5];
            String methodName2 = method2.getName();
            int ordinal3 = 0;
            int serialzeFeatures3 = 0;
            int parserFeatures5 = 0;
            String label3 = null;
            if (Modifier.isStatic(method2.getModifiers())) {
                i2 = length;
                paramNameMapping = paramNameMapping2;
                i = i5;
                methods = methods2;
                fieldInfoMap = fieldInfoMap5;
            } else {
                Class<?> returnType2 = method2.getReturnType();
                if (returnType2.equals(Void.TYPE)) {
                    i2 = length;
                    paramNameMapping = paramNameMapping2;
                    i = i5;
                    methods = methods2;
                    fieldInfoMap = fieldInfoMap5;
                } else if (method2.getParameterTypes().length != 0) {
                    i2 = length;
                    paramNameMapping = paramNameMapping2;
                    i = i5;
                    methods = methods2;
                    fieldInfoMap = fieldInfoMap5;
                } else if (returnType2 == ClassLoader.class || returnType2 == InputStream.class) {
                    i2 = length;
                    paramNameMapping = paramNameMapping2;
                    i = i5;
                    methods = methods2;
                    fieldInfoMap = fieldInfoMap5;
                } else if (returnType2 == Reader.class) {
                    i2 = length;
                    paramNameMapping = paramNameMapping2;
                    i = i5;
                    methods = methods2;
                    fieldInfoMap = fieldInfoMap5;
                } else {
                    if (methodName2.equals("getMetaClass")) {
                        i2 = length;
                        if (returnType2.getName().equals("groovy.lang.MetaClass")) {
                            paramNameMapping = paramNameMapping2;
                            i = i5;
                            methods = methods2;
                            fieldInfoMap = fieldInfoMap5;
                        }
                    } else {
                        i2 = length;
                    }
                    if (methodName2.equals("getSuppressed") && method2.getDeclaringClass() == Throwable.class) {
                        paramNameMapping = paramNameMapping2;
                        i = i5;
                        methods = methods2;
                        fieldInfoMap = fieldInfoMap5;
                    } else if (!kotlin2 || !isKotlinIgnore(cls, methodName2)) {
                        boolean fieldAnnotationAndNameExists2 = false;
                        JSONField annotation4 = (JSONField) getAnnotation(method2, JSONField.class);
                        if (annotation4 == null) {
                            annotation4 = getSuperMethodAnnotation(cls, method2);
                        }
                        if (annotation4 != null || !kotlin2) {
                            paramNameMapping = paramNameMapping2;
                            ordinal = 0;
                            constructors = constructors2;
                            paramAnnotationArrays = paramAnnotationArrays2;
                            paramNames = paramNames2;
                            annotation = annotation4;
                        } else {
                            if (constructors2 == null) {
                                constructors2 = clazz.getDeclaredConstructors();
                                Constructor creatorConstructor = getKotlinConstructor(constructors2);
                                if (creatorConstructor != null) {
                                    paramAnnotationArrays2 = getParameterAnnotations(creatorConstructor);
                                    paramNames2 = getKoltinConstructorParameters(clazz);
                                    if (paramNames2 != null) {
                                        String[] paramNames_sorted = new String[paramNames2.length];
                                        annotation3 = annotation4;
                                        System.arraycopy(paramNames2, 0, paramNames_sorted, 0, paramNames2.length);
                                        Arrays.sort(paramNames_sorted);
                                        short[] paramNameMapping3 = new short[paramNames2.length];
                                        short p = 0;
                                        while (p < paramNames2.length) {
                                            paramNameMapping3[Arrays.binarySearch(paramNames_sorted, paramNames2[p])] = p;
                                            p = (short) (p + 1);
                                            constructors2 = constructors2;
                                        }
                                        paramNames2 = paramNames_sorted;
                                        paramNameMapping2 = paramNameMapping3;
                                        constructors2 = constructors2;
                                    } else {
                                        annotation3 = annotation4;
                                    }
                                } else {
                                    annotation3 = annotation4;
                                }
                            } else {
                                annotation3 = annotation4;
                            }
                            if (paramNames2 == null || paramNameMapping2 == null || !methodName2.startsWith("get")) {
                                constructors = constructors2;
                                paramAnnotationArrays = paramAnnotationArrays2;
                                paramNames = paramNames2;
                                ordinal = 0;
                            } else {
                                String propertyName7 = decapitalize(methodName2.substring(3));
                                int p2 = Arrays.binarySearch(paramNames2, propertyName7);
                                if (p2 < 0) {
                                    constructors = constructors2;
                                    int i6 = 0;
                                    while (true) {
                                        ordinal = ordinal3;
                                        if (i6 >= paramNames2.length) {
                                            break;
                                        } else if (propertyName7.equalsIgnoreCase(paramNames2[i6])) {
                                            p2 = i6;
                                            break;
                                        } else {
                                            i6++;
                                            ordinal3 = ordinal;
                                        }
                                    }
                                } else {
                                    constructors = constructors2;
                                    ordinal = 0;
                                }
                                if (p2 >= 0) {
                                    Annotation[] paramAnnotations = paramAnnotationArrays2[paramNameMapping2[p2]];
                                    if (paramAnnotations != null) {
                                        int length2 = paramAnnotations.length;
                                        paramAnnotationArrays = paramAnnotationArrays2;
                                        int i7 = 0;
                                        while (true) {
                                            if (i7 >= length2) {
                                                paramNames = paramNames2;
                                                break;
                                            }
                                            Annotation paramAnnotation = paramAnnotations[i7];
                                            paramNames = paramNames2;
                                            if (paramAnnotation instanceof JSONField) {
                                                annotation3 = (JSONField) paramAnnotation;
                                                break;
                                            }
                                            i7++;
                                            length2 = length2;
                                            paramNames2 = paramNames;
                                        }
                                    } else {
                                        paramAnnotationArrays = paramAnnotationArrays2;
                                        paramNames = paramNames2;
                                    }
                                    if (annotation3 == null && (field3 = ParserConfig.getFieldFromCache(propertyName7, map4)) != null) {
                                        annotation = (JSONField) getAnnotation(field3, JSONField.class);
                                        paramNameMapping = paramNameMapping2;
                                    }
                                } else {
                                    paramAnnotationArrays = paramAnnotationArrays2;
                                    paramNames = paramNames2;
                                }
                            }
                            paramNameMapping = paramNameMapping2;
                            annotation = annotation3;
                        }
                        if (annotation != null) {
                            if (!annotation.serialize()) {
                                i = i5;
                                methods = methods2;
                                fieldInfoMap = fieldInfoMap5;
                            } else {
                                int ordinal4 = annotation.ordinal();
                                serialzeFeatures3 = SerializerFeature.of(annotation.serialzeFeatures());
                                parserFeatures5 = Feature.of(annotation.parseFeatures());
                                if (annotation.name().length() != 0) {
                                    String propertyName8 = annotation.name();
                                    if (map3 != null) {
                                        String propertyName9 = map3.get(propertyName8);
                                        if (propertyName9 == null) {
                                            i = i5;
                                            methods = methods2;
                                            fieldInfoMap = fieldInfoMap5;
                                        } else {
                                            propertyName6 = propertyName9;
                                        }
                                    } else {
                                        propertyName6 = propertyName8;
                                    }
                                    i = i5;
                                    methods = methods2;
                                    fieldInfoMap5.put(propertyName6, new FieldInfo(propertyName6, method2, null, clazz, null, ordinal4, serialzeFeatures3, parserFeatures5, annotation, null, null));
                                    fieldInfoMap = fieldInfoMap5;
                                } else {
                                    methodName = methodName2;
                                    method = method2;
                                    i = i5;
                                    methods = methods2;
                                    returnType = returnType2;
                                    fieldInfoMap2 = fieldInfoMap5;
                                    if (annotation.label().length() != 0) {
                                        label3 = annotation.label();
                                        ordinal2 = ordinal4;
                                    } else {
                                        ordinal2 = ordinal4;
                                    }
                                }
                            }
                            constructors2 = constructors;
                            paramAnnotationArrays2 = paramAnnotationArrays;
                            paramNames2 = paramNames;
                        } else {
                            methodName = methodName2;
                            method = method2;
                            i = i5;
                            methods = methods2;
                            returnType = returnType2;
                            fieldInfoMap2 = fieldInfoMap5;
                            ordinal2 = ordinal;
                        }
                        if (methodName.startsWith("get")) {
                            if (methodName.length() < 4) {
                                fieldInfoMap = fieldInfoMap2;
                            } else if (methodName.equals("getClass")) {
                                fieldInfoMap = fieldInfoMap2;
                            } else if (!methodName.equals("getDeclaringClass") || !clazz.isEnum()) {
                                char c3 = methodName.charAt(3);
                                Field field4 = null;
                                if (Character.isUpperCase(c3) || c3 > 512) {
                                    if (compatibleWithJavaBean) {
                                        i4 = 3;
                                        propertyName5 = decapitalize(methodName.substring(3));
                                    } else {
                                        i4 = 3;
                                        propertyName5 = getPropertyNameByMethodName(methodName);
                                    }
                                    propertyName3 = getPropertyNameByCompatibleFieldName(map4, methodName, propertyName5, i4);
                                } else if (c3 == '_') {
                                    propertyName3 = methodName.substring(3);
                                    field4 = map4.get(propertyName3);
                                    if (field4 == null) {
                                        String propertyName10 = methodName.substring(4);
                                        field4 = ParserConfig.getFieldFromCache(propertyName10, map4);
                                        if (field4 == null) {
                                            propertyName3 = propertyName3;
                                        } else {
                                            propertyName3 = propertyName10;
                                        }
                                    }
                                } else if (c3 == 'f') {
                                    propertyName3 = methodName.substring(3);
                                } else if (methodName.length() < 5 || !Character.isUpperCase(methodName.charAt(4))) {
                                    propertyName3 = methodName.substring(3);
                                    field4 = ParserConfig.getFieldFromCache(propertyName3, map4);
                                    if (field4 == null) {
                                        fieldInfoMap = fieldInfoMap2;
                                    }
                                } else {
                                    propertyName3 = decapitalize(methodName.substring(3));
                                }
                                if (isJSONTypeIgnore(cls, propertyName3)) {
                                    fieldInfoMap = fieldInfoMap2;
                                } else {
                                    if (field4 == null) {
                                        field4 = ParserConfig.getFieldFromCache(propertyName3, map4);
                                    }
                                    if (field4 == null && propertyName3.length() > 1) {
                                        char ch = propertyName3.charAt(1);
                                        if (ch >= 'A' && ch <= 'Z') {
                                            field2 = ParserConfig.getFieldFromCache(decapitalize(methodName.substring(3)), map4);
                                            if (field2 == null) {
                                                JSONField fieldAnnotation3 = (JSONField) getAnnotation(field2, JSONField.class);
                                                if (fieldAnnotation3 == null) {
                                                    map2 = aliasMap;
                                                    parserFeatures3 = parserFeatures5;
                                                    fieldAnnotationAndNameExists = false;
                                                    parserFeatures4 = ordinal2;
                                                    label2 = label3;
                                                    serialzeFeatures2 = serialzeFeatures3;
                                                    fieldAnnotation2 = fieldAnnotation3;
                                                } else if (!fieldAnnotation3.serialize()) {
                                                    fieldInfoMap = fieldInfoMap2;
                                                } else {
                                                    int ordinal5 = fieldAnnotation3.ordinal();
                                                    int serialzeFeatures4 = SerializerFeature.of(fieldAnnotation3.serialzeFeatures());
                                                    int parserFeatures6 = Feature.of(fieldAnnotation3.parseFeatures());
                                                    if (fieldAnnotation3.name().length() != 0) {
                                                        fieldAnnotationAndNameExists2 = true;
                                                        String propertyName11 = fieldAnnotation3.name();
                                                        if (aliasMap != null) {
                                                            String propertyName12 = aliasMap.get(propertyName11);
                                                            if (propertyName12 == null) {
                                                                fieldInfoMap = fieldInfoMap2;
                                                            } else {
                                                                propertyName3 = propertyName12;
                                                                map2 = aliasMap;
                                                            }
                                                        } else {
                                                            propertyName3 = propertyName11;
                                                            map2 = aliasMap;
                                                        }
                                                    } else {
                                                        map2 = aliasMap;
                                                    }
                                                    if (fieldAnnotation3.label().length() != 0) {
                                                        parserFeatures4 = ordinal5;
                                                        serialzeFeatures2 = serialzeFeatures4;
                                                        parserFeatures3 = parserFeatures6;
                                                        fieldAnnotationAndNameExists = fieldAnnotationAndNameExists2;
                                                        label2 = fieldAnnotation3.label();
                                                        fieldAnnotation2 = fieldAnnotation3;
                                                    } else {
                                                        fieldAnnotation2 = fieldAnnotation3;
                                                        parserFeatures4 = ordinal5;
                                                        parserFeatures3 = parserFeatures6;
                                                        fieldAnnotationAndNameExists = fieldAnnotationAndNameExists2;
                                                        label2 = label3;
                                                        serialzeFeatures2 = serialzeFeatures4;
                                                    }
                                                }
                                            } else {
                                                map2 = aliasMap;
                                                parserFeatures3 = parserFeatures5;
                                                fieldAnnotationAndNameExists = false;
                                                parserFeatures4 = ordinal2;
                                                label2 = label3;
                                                serialzeFeatures2 = serialzeFeatures3;
                                                fieldAnnotation2 = null;
                                            }
                                            if (map2 == null && (propertyName3 = map2.get(propertyName3)) == null) {
                                                fieldInfoMap = fieldInfoMap2;
                                            } else {
                                                if (propertyNamingStrategy != null || fieldAnnotationAndNameExists.booleanValue()) {
                                                    propertyName4 = propertyName3;
                                                } else {
                                                    propertyName4 = propertyNamingStrategy.translate(propertyName3);
                                                }
                                                annotation2 = annotation;
                                                fieldInfoMap3 = fieldInfoMap2;
                                                i3 = 3;
                                                fieldInfoMap3.put(propertyName4, new FieldInfo(propertyName4, method, field2, clazz, null, parserFeatures4, serialzeFeatures2, parserFeatures3, annotation, fieldAnnotation2, label2));
                                                ordinal2 = parserFeatures4;
                                                serialzeFeatures3 = serialzeFeatures2;
                                                parserFeatures5 = parserFeatures3;
                                                label3 = label2;
                                            }
                                        }
                                    }
                                    field2 = field4;
                                    if (field2 == null) {
                                    }
                                    if (map2 == null) {
                                    }
                                    if (propertyNamingStrategy != null) {
                                    }
                                    propertyName4 = propertyName3;
                                    annotation2 = annotation;
                                    fieldInfoMap3 = fieldInfoMap2;
                                    i3 = 3;
                                    fieldInfoMap3.put(propertyName4, new FieldInfo(propertyName4, method, field2, clazz, null, parserFeatures4, serialzeFeatures2, parserFeatures3, annotation, fieldAnnotation2, label2));
                                    ordinal2 = parserFeatures4;
                                    serialzeFeatures3 = serialzeFeatures2;
                                    parserFeatures5 = parserFeatures3;
                                    label3 = label2;
                                }
                            } else {
                                fieldInfoMap = fieldInfoMap2;
                            }
                            constructors2 = constructors;
                            paramAnnotationArrays2 = paramAnnotationArrays;
                            paramNames2 = paramNames;
                        } else {
                            annotation2 = annotation;
                            fieldInfoMap3 = fieldInfoMap2;
                            i3 = 3;
                        }
                        if (!methodName.startsWith("is")) {
                            fieldInfoMap = fieldInfoMap3;
                            map4 = fieldCacheMap;
                        } else if (methodName.length() < i3) {
                            fieldInfoMap = fieldInfoMap3;
                            map4 = fieldCacheMap;
                        } else if (returnType == Boolean.TYPE || returnType == Boolean.class) {
                            char c2 = methodName.charAt(2);
                            Field field5 = null;
                            if (Character.isUpperCase(c2)) {
                                if (compatibleWithJavaBean) {
                                    propertyName2 = decapitalize(methodName.substring(2));
                                } else {
                                    propertyName2 = Character.toLowerCase(methodName.charAt(2)) + methodName.substring(i3);
                                }
                                fieldInfoMap4 = fieldInfoMap3;
                                map4 = fieldCacheMap;
                                propertyName = getPropertyNameByCompatibleFieldName(map4, methodName, propertyName2, 2);
                            } else {
                                fieldInfoMap4 = fieldInfoMap3;
                                map4 = fieldCacheMap;
                                if (c2 == '_') {
                                    propertyName = methodName.substring(i3);
                                    field5 = map4.get(propertyName);
                                    if (field5 == null && (field5 = ParserConfig.getFieldFromCache((propertyName = methodName.substring(2)), map4)) == null) {
                                        propertyName = propertyName;
                                    }
                                } else if (c2 == 'f') {
                                    propertyName = methodName.substring(2);
                                } else {
                                    propertyName = methodName.substring(2);
                                    field5 = ParserConfig.getFieldFromCache(propertyName, map4);
                                    if (field5 == null) {
                                        fieldInfoMap = fieldInfoMap4;
                                    }
                                }
                            }
                            if (isJSONTypeIgnore(clazz, propertyName)) {
                                fieldInfoMap = fieldInfoMap4;
                            } else {
                                if (field5 == null) {
                                    field5 = ParserConfig.getFieldFromCache(propertyName, map4);
                                }
                                if (field5 == null) {
                                    field = ParserConfig.getFieldFromCache(methodName, map4);
                                } else {
                                    field = field5;
                                }
                                if (field != null) {
                                    JSONField fieldAnnotation4 = (JSONField) getAnnotation(field, JSONField.class);
                                    if (fieldAnnotation4 == null) {
                                        map = aliasMap;
                                        parserFeatures = parserFeatures5;
                                        label = label3;
                                        parserFeatures2 = ordinal2;
                                        serialzeFeatures = serialzeFeatures3;
                                        fieldAnnotation = fieldAnnotation4;
                                    } else if (!fieldAnnotation4.serialize()) {
                                        fieldInfoMap = fieldInfoMap4;
                                    } else {
                                        int ordinal6 = fieldAnnotation4.ordinal();
                                        int serialzeFeatures5 = SerializerFeature.of(fieldAnnotation4.serialzeFeatures());
                                        int parserFeatures7 = Feature.of(fieldAnnotation4.parseFeatures());
                                        if (fieldAnnotation4.name().length() != 0) {
                                            propertyName = fieldAnnotation4.name();
                                            map = aliasMap;
                                            if (map != null && (propertyName = map.get(propertyName)) == null) {
                                                fieldInfoMap = fieldInfoMap4;
                                            }
                                        } else {
                                            map = aliasMap;
                                        }
                                        if (fieldAnnotation4.label().length() != 0) {
                                            parserFeatures = parserFeatures7;
                                            label = fieldAnnotation4.label();
                                            parserFeatures2 = ordinal6;
                                            serialzeFeatures = serialzeFeatures5;
                                            fieldAnnotation = fieldAnnotation4;
                                        } else {
                                            parserFeatures = parserFeatures7;
                                            label = label3;
                                            parserFeatures2 = ordinal6;
                                            serialzeFeatures = serialzeFeatures5;
                                            fieldAnnotation = fieldAnnotation4;
                                        }
                                    }
                                } else {
                                    map = aliasMap;
                                    parserFeatures = parserFeatures5;
                                    label = label3;
                                    parserFeatures2 = ordinal2;
                                    serialzeFeatures = serialzeFeatures3;
                                    fieldAnnotation = null;
                                }
                                if (map == null || (propertyName = map.get(propertyName)) != null) {
                                    if (propertyNamingStrategy != null) {
                                        propertyName = propertyNamingStrategy.translate(propertyName);
                                    }
                                    if (fieldInfoMap4.containsKey(propertyName)) {
                                        fieldInfoMap = fieldInfoMap4;
                                    } else {
                                        fieldInfoMap = fieldInfoMap4;
                                        fieldInfoMap.put(propertyName, new FieldInfo(propertyName, method, field, clazz, null, parserFeatures2, serialzeFeatures, parserFeatures, annotation2, fieldAnnotation, label));
                                    }
                                } else {
                                    fieldInfoMap = fieldInfoMap4;
                                }
                            }
                        } else {
                            fieldInfoMap = fieldInfoMap3;
                            map4 = fieldCacheMap;
                        }
                        constructors2 = constructors;
                        paramAnnotationArrays2 = paramAnnotationArrays;
                        paramNames2 = paramNames;
                    } else {
                        paramNameMapping = paramNameMapping2;
                        i = i5;
                        methods = methods2;
                        fieldInfoMap = fieldInfoMap5;
                    }
                }
            }
            i5 = i + 1;
            cls = clazz;
            map3 = aliasMap;
            fieldInfoMap5 = fieldInfoMap;
            length = i2;
            paramNameMapping2 = paramNameMapping;
            methods2 = methods;
        }
        computeFields(clazz, aliasMap, propertyNamingStrategy, fieldInfoMap5, clazz.getFields());
        return getFieldInfos(clazz, sorted, fieldInfoMap5);
    }

    private static List<FieldInfo> getFieldInfos(Class<?> clazz, boolean sorted, Map<String, FieldInfo> fieldInfoMap) {
        List<FieldInfo> fieldInfoList = new ArrayList<>();
        String[] orders = null;
        JSONType annotation = (JSONType) getAnnotation(clazz, JSONType.class);
        if (annotation != null) {
            orders = annotation.orders();
        }
        if (orders == null || orders.length <= 0) {
            fieldInfoList.addAll(fieldInfoMap.values());
            if (sorted) {
                Collections.sort(fieldInfoList);
            }
        } else {
            LinkedHashMap<String, FieldInfo> map = new LinkedHashMap<>(fieldInfoMap.size());
            for (FieldInfo field : fieldInfoMap.values()) {
                map.put(field.name, field);
            }
            for (String item : orders) {
                FieldInfo field2 = map.get(item);
                if (field2 != null) {
                    fieldInfoList.add(field2);
                    map.remove(item);
                }
            }
            fieldInfoList.addAll(map.values());
        }
        return fieldInfoList;
    }

    private static void computeFields(Class<?> clazz, Map<String, String> aliasMap, PropertyNamingStrategy propertyNamingStrategy, Map<String, FieldInfo> fieldInfoMap, Field[] fields) {
        String label;
        int parserFeatures;
        int serialzeFeatures;
        int ordinal;
        String propertyName;
        for (Field field : fields) {
            if (!Modifier.isStatic(field.getModifiers())) {
                JSONField fieldAnnotation = (JSONField) getAnnotation(field, JSONField.class);
                String propertyName2 = field.getName();
                if (fieldAnnotation == null) {
                    ordinal = 0;
                    serialzeFeatures = 0;
                    parserFeatures = 0;
                    label = null;
                } else if (fieldAnnotation.serialize()) {
                    int ordinal2 = fieldAnnotation.ordinal();
                    int serialzeFeatures2 = SerializerFeature.of(fieldAnnotation.serialzeFeatures());
                    int parserFeatures2 = Feature.of(fieldAnnotation.parseFeatures());
                    if (fieldAnnotation.name().length() != 0) {
                        propertyName2 = fieldAnnotation.name();
                    }
                    if (fieldAnnotation.label().length() != 0) {
                        ordinal = ordinal2;
                        serialzeFeatures = serialzeFeatures2;
                        parserFeatures = parserFeatures2;
                        label = fieldAnnotation.label();
                    } else {
                        ordinal = ordinal2;
                        serialzeFeatures = serialzeFeatures2;
                        parserFeatures = parserFeatures2;
                        label = null;
                    }
                }
                if (aliasMap == null || (propertyName2 = aliasMap.get(propertyName2)) != null) {
                    if (propertyNamingStrategy != null) {
                        propertyName = propertyNamingStrategy.translate(propertyName2);
                    } else {
                        propertyName = propertyName2;
                    }
                    if (!fieldInfoMap.containsKey(propertyName)) {
                        fieldInfoMap.put(propertyName, new FieldInfo(propertyName, null, field, clazz, null, ordinal, serialzeFeatures, parserFeatures, null, fieldAnnotation, label));
                    }
                }
            }
        }
    }

    private static String getPropertyNameByCompatibleFieldName(Map<String, Field> fieldCacheMap, String methodName, String propertyName, int fromIdx) {
        if (!compatibleWithFieldName || fieldCacheMap.containsKey(propertyName)) {
            return propertyName;
        }
        String tempPropertyName = methodName.substring(fromIdx);
        return fieldCacheMap.containsKey(tempPropertyName) ? tempPropertyName : propertyName;
    }

    public static JSONField getSuperMethodAnnotation(Class<?> clazz, Method method) {
        JSONField annotation;
        JSONField annotation2;
        Class<?>[] interfaces = clazz.getInterfaces();
        if (interfaces.length > 0) {
            Class<?>[] types = method.getParameterTypes();
            for (Class<?> interfaceClass : interfaces) {
                Method[] methods = interfaceClass.getMethods();
                for (Method interfaceMethod : methods) {
                    Class<?>[] interfaceTypes = interfaceMethod.getParameterTypes();
                    if (interfaceTypes.length == types.length && interfaceMethod.getName().equals(method.getName())) {
                        boolean match = true;
                        int i = 0;
                        while (true) {
                            if (i >= types.length) {
                                break;
                            } else if (!interfaceTypes[i].equals(types[i])) {
                                match = false;
                                break;
                            } else {
                                i++;
                            }
                        }
                        if (match && (annotation2 = (JSONField) getAnnotation(interfaceMethod, JSONField.class)) != null) {
                            return annotation2;
                        }
                    }
                }
            }
        }
        Class<?> superClass = clazz.getSuperclass();
        if (superClass != null && Modifier.isAbstract(superClass.getModifiers())) {
            Class<?>[] types2 = method.getParameterTypes();
            Method[] methods2 = superClass.getMethods();
            for (Method interfaceMethod2 : methods2) {
                Class<?>[] interfaceTypes2 = interfaceMethod2.getParameterTypes();
                if (interfaceTypes2.length == types2.length && interfaceMethod2.getName().equals(method.getName())) {
                    boolean match2 = true;
                    int i2 = 0;
                    while (true) {
                        if (i2 >= types2.length) {
                            break;
                        } else if (!interfaceTypes2[i2].equals(types2[i2])) {
                            match2 = false;
                            break;
                        } else {
                            i2++;
                        }
                    }
                    if (match2 && (annotation = (JSONField) getAnnotation(interfaceMethod2, JSONField.class)) != null) {
                        return annotation;
                    }
                }
            }
        }
        return null;
    }

    private static boolean isJSONTypeIgnore(Class<?> clazz, String propertyName) {
        JSONType jsonType = (JSONType) getAnnotation(clazz, JSONType.class);
        if (jsonType != null) {
            String[] fields = jsonType.includes();
            if (fields.length > 0) {
                for (String field : fields) {
                    if (propertyName.equals(field)) {
                        return false;
                    }
                }
                return true;
            }
            for (String field2 : jsonType.ignores()) {
                if (propertyName.equals(field2)) {
                    return true;
                }
            }
        }
        if (clazz.getSuperclass() == Object.class || clazz.getSuperclass() == null) {
            return false;
        }
        return isJSONTypeIgnore(clazz.getSuperclass(), propertyName);
    }

    public static boolean isGenericParamType(Type type) {
        Type superType;
        if (type instanceof ParameterizedType) {
            return true;
        }
        if (!(type instanceof Class) || (superType = ((Class) type).getGenericSuperclass()) == Object.class || !isGenericParamType(superType)) {
            return false;
        }
        return true;
    }

    public static Type getGenericParamType(Type type) {
        if (!(type instanceof ParameterizedType) && (type instanceof Class)) {
            return getGenericParamType(((Class) type).getGenericSuperclass());
        }
        return type;
    }

    public static Type unwrapOptional(Type type) {
        if (!optionalClassInited) {
            try {
                optionalClass = Class.forName("java.util.Optional");
            } catch (Exception e) {
            } catch (Throwable th) {
                optionalClassInited = true;
                throw th;
            }
            optionalClassInited = true;
        }
        if (type instanceof ParameterizedType) {
            ParameterizedType parameterizedType = (ParameterizedType) type;
            if (parameterizedType.getRawType() == optionalClass) {
                return parameterizedType.getActualTypeArguments()[0];
            }
        }
        return type;
    }

    public static Class<?> getClass(Type type) {
        if (type.getClass() == Class.class) {
            return (Class) type;
        }
        if (type instanceof ParameterizedType) {
            return getClass(((ParameterizedType) type).getRawType());
        }
        if (type instanceof TypeVariable) {
            Type boundType = ((TypeVariable) type).getBounds()[0];
            if (boundType instanceof Class) {
                return (Class) boundType;
            }
            return getClass(boundType);
        } else if (!(type instanceof WildcardType)) {
            return Object.class;
        } else {
            Type[] upperBounds = ((WildcardType) type).getUpperBounds();
            if (upperBounds.length == 1) {
                return getClass(upperBounds[0]);
            }
            return Object.class;
        }
    }

    public static Field getField(Class<?> clazz, String fieldName, Field[] declaredFields) {
        char c0;
        char c1;
        for (Field field : declaredFields) {
            String itemName = field.getName();
            if (fieldName.equals(itemName)) {
                return field;
            }
            if (fieldName.length() > 2 && (c0 = fieldName.charAt(0)) >= 'a' && c0 <= 'z' && (c1 = fieldName.charAt(1)) >= 'A' && c1 <= 'Z' && fieldName.equalsIgnoreCase(itemName)) {
                return field;
            }
        }
        Class<?> superClass = clazz.getSuperclass();
        if (superClass == null || superClass == Object.class) {
            return null;
        }
        return getField(superClass, fieldName, superClass.getDeclaredFields());
    }

    public static int getSerializeFeatures(Class<?> clazz) {
        JSONType annotation = (JSONType) getAnnotation(clazz, JSONType.class);
        if (annotation == null) {
            return 0;
        }
        return SerializerFeature.of(annotation.serialzeFeatures());
    }

    public static int getParserFeatures(Class<?> clazz) {
        JSONType annotation = (JSONType) getAnnotation(clazz, JSONType.class);
        if (annotation == null) {
            return 0;
        }
        return Feature.of(annotation.parseFeatures());
    }

    public static String decapitalize(String name) {
        if (name == null || name.length() == 0) {
            return name;
        }
        if (name.length() > 1 && Character.isUpperCase(name.charAt(1)) && Character.isUpperCase(name.charAt(0))) {
            return name;
        }
        char[] chars = name.toCharArray();
        chars[0] = Character.toLowerCase(chars[0]);
        return new String(chars);
    }

    public static String getPropertyNameByMethodName(String methodName) {
        return Character.toLowerCase(methodName.charAt(3)) + methodName.substring(4);
    }

    static void setAccessible(AccessibleObject obj) {
        if (setAccessibleEnable && !obj.isAccessible()) {
            try {
                obj.setAccessible(true);
            } catch (Throwable th) {
                setAccessibleEnable = false;
            }
        }
    }

    public static Type getCollectionItemType(Type fieldType) {
        if (fieldType instanceof ParameterizedType) {
            return getCollectionItemType((ParameterizedType) fieldType);
        }
        if (fieldType instanceof Class) {
            return getCollectionItemType((Class<?>) ((Class) fieldType));
        }
        return Object.class;
    }

    private static Type getCollectionItemType(Class<?> clazz) {
        if (clazz.getName().startsWith("java.")) {
            return Object.class;
        }
        return getCollectionItemType(getCollectionSuperType(clazz));
    }

    private static Type getCollectionItemType(ParameterizedType parameterizedType) {
        Type rawType = parameterizedType.getRawType();
        Type[] actualTypeArguments = parameterizedType.getActualTypeArguments();
        if (rawType == Collection.class) {
            return getWildcardTypeUpperBounds(actualTypeArguments[0]);
        }
        Class<?> rawClass = (Class) rawType;
        Map<TypeVariable, Type> actualTypeMap = createActualTypeMap(rawClass.getTypeParameters(), actualTypeArguments);
        Type superType = getCollectionSuperType(rawClass);
        if (!(superType instanceof ParameterizedType)) {
            return getCollectionItemType((Class<?>) ((Class) superType));
        }
        Class<?> superClass = getRawClass(superType);
        Type[] superClassTypeParameters = ((ParameterizedType) superType).getActualTypeArguments();
        if (superClassTypeParameters.length > 0) {
            return getCollectionItemType(makeParameterizedType(superClass, superClassTypeParameters, actualTypeMap));
        }
        return getCollectionItemType(superClass);
    }

    private static Type getCollectionSuperType(Class<?> clazz) {
        Type assignable = null;
        Type[] genericInterfaces = clazz.getGenericInterfaces();
        for (Type type : genericInterfaces) {
            Class<?> rawClass = getRawClass(type);
            if (rawClass == Collection.class) {
                return type;
            }
            if (Collection.class.isAssignableFrom(rawClass)) {
                assignable = type;
            }
        }
        return assignable == null ? clazz.getGenericSuperclass() : assignable;
    }

    private static Map<TypeVariable, Type> createActualTypeMap(TypeVariable[] typeParameters, Type[] actualTypeArguments) {
        int length = typeParameters.length;
        Map<TypeVariable, Type> actualTypeMap = new HashMap<>(length);
        for (int i = 0; i < length; i++) {
            actualTypeMap.put(typeParameters[i], actualTypeArguments[i]);
        }
        return actualTypeMap;
    }

    private static ParameterizedType makeParameterizedType(Class<?> rawClass, Type[] typeParameters, Map<TypeVariable, Type> actualTypeMap) {
        int length = typeParameters.length;
        Type[] actualTypeArguments = new Type[length];
        for (int i = 0; i < length; i++) {
            actualTypeArguments[i] = getActualType(typeParameters[i], actualTypeMap);
        }
        return new ParameterizedTypeImpl(actualTypeArguments, null, rawClass);
    }

    private static Type getActualType(Type typeParameter, Map<TypeVariable, Type> actualTypeMap) {
        if (typeParameter instanceof TypeVariable) {
            return actualTypeMap.get(typeParameter);
        }
        if (typeParameter instanceof ParameterizedType) {
            return makeParameterizedType(getRawClass(typeParameter), ((ParameterizedType) typeParameter).getActualTypeArguments(), actualTypeMap);
        }
        if (typeParameter instanceof GenericArrayType) {
            return new GenericArrayTypeImpl(getActualType(((GenericArrayType) typeParameter).getGenericComponentType(), actualTypeMap));
        }
        return typeParameter;
    }

    private static Type getWildcardTypeUpperBounds(Type type) {
        if (!(type instanceof WildcardType)) {
            return type;
        }
        Type[] upperBounds = ((WildcardType) type).getUpperBounds();
        return upperBounds.length > 0 ? upperBounds[0] : Object.class;
    }

    public static Class<?> getCollectionItemClass(Type fieldType) {
        if (!(fieldType instanceof ParameterizedType)) {
            return Object.class;
        }
        Type actualTypeArgument = ((ParameterizedType) fieldType).getActualTypeArguments()[0];
        if (actualTypeArgument instanceof WildcardType) {
            Type[] upperBounds = ((WildcardType) actualTypeArgument).getUpperBounds();
            if (upperBounds.length == 1) {
                actualTypeArgument = upperBounds[0];
            }
        }
        if (actualTypeArgument instanceof Class) {
            Class<?> itemClass = (Class) actualTypeArgument;
            if (Modifier.isPublic(itemClass.getModifiers())) {
                return itemClass;
            }
            throw new JSONException("can not create ASMParser");
        }
        throw new JSONException("can not create ASMParser");
    }

    public static Type checkPrimitiveArray(GenericArrayType genericArrayType) {
        Type genericComponentType = genericArrayType.getGenericComponentType();
        String prefix = Operators.ARRAY_START_STR;
        while (genericComponentType instanceof GenericArrayType) {
            genericComponentType = ((GenericArrayType) genericComponentType).getGenericComponentType();
            prefix = prefix + prefix;
        }
        if (!(genericComponentType instanceof Class)) {
            return genericArrayType;
        }
        Class<?> ck = (Class) genericComponentType;
        if (!ck.isPrimitive()) {
            return genericArrayType;
        }
        try {
            String postfix = (String) primitiveTypeMap.get(ck);
            if (postfix == null) {
                return genericArrayType;
            }
            return Class.forName(prefix + postfix);
        } catch (ClassNotFoundException e) {
            return genericArrayType;
        }
    }

    /* JADX INFO: Multiple debug info for r1v16 java.util.EnumSet: [D('set' java.util.Set), D('itemType' java.lang.reflect.Type)] */
    public static Set createSet(Type type) {
        Type itemType;
        Class<?> rawClass = getRawClass(type);
        if (rawClass == AbstractCollection.class || rawClass == Collection.class) {
            return new HashSet();
        }
        if (rawClass.isAssignableFrom(HashSet.class)) {
            return new HashSet();
        }
        if (rawClass.isAssignableFrom(LinkedHashSet.class)) {
            return new LinkedHashSet();
        }
        if (rawClass.isAssignableFrom(TreeSet.class)) {
            return new TreeSet();
        }
        if (rawClass.isAssignableFrom(EnumSet.class)) {
            if (type instanceof ParameterizedType) {
                itemType = ((ParameterizedType) type).getActualTypeArguments()[0];
            } else {
                itemType = Object.class;
            }
            return EnumSet.noneOf((Class) itemType);
        }
        try {
            return (Set) rawClass.newInstance();
        } catch (Exception e) {
            throw new JSONException("create instance error, class " + rawClass.getName());
        }
    }

    /* JADX INFO: Multiple debug info for r1v23 java.util.EnumSet: [D('itemType' java.lang.reflect.Type), D('list' java.util.Collection)] */
    public static Collection createCollection(Type type) {
        Class<?> cls;
        Type itemType;
        Class<?> rawClass = getRawClass(type);
        if (rawClass == AbstractCollection.class || rawClass == Collection.class) {
            return new ArrayList();
        }
        if (rawClass.isAssignableFrom(HashSet.class)) {
            return new HashSet();
        }
        if (rawClass.isAssignableFrom(LinkedHashSet.class)) {
            return new LinkedHashSet();
        }
        if (rawClass.isAssignableFrom(TreeSet.class)) {
            return new TreeSet();
        }
        if (rawClass.isAssignableFrom(ArrayList.class)) {
            return new ArrayList();
        }
        if (rawClass.isAssignableFrom(EnumSet.class)) {
            if (type instanceof ParameterizedType) {
                itemType = ((ParameterizedType) type).getActualTypeArguments()[0];
            } else {
                itemType = Object.class;
            }
            return EnumSet.noneOf((Class) itemType);
        } else if (rawClass.isAssignableFrom(Queue.class) || ((cls = class_deque) != null && rawClass.isAssignableFrom(cls))) {
            return new LinkedList();
        } else {
            try {
                return (Collection) rawClass.newInstance();
            } catch (Exception e) {
                throw new JSONException("create instance error, class " + rawClass.getName());
            }
        }
    }

    public static Class<?> getRawClass(Type type) {
        if (type instanceof Class) {
            return (Class) type;
        }
        if (type instanceof ParameterizedType) {
            return getRawClass(((ParameterizedType) type).getRawType());
        }
        if (type instanceof WildcardType) {
            Type[] upperBounds = ((WildcardType) type).getUpperBounds();
            if (upperBounds.length == 1) {
                return getRawClass(upperBounds[0]);
            }
            throw new JSONException("TODO");
        }
        throw new JSONException("TODO");
    }

    public static boolean isProxy(Class<?> clazz) {
        for (Class<?> item : clazz.getInterfaces()) {
            if (isProxyClassNames.contains(item.getName())) {
                return true;
            }
        }
        return false;
    }

    /* JADX DEBUG: Type inference failed for r1v5. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends java.lang.annotation.Annotation> */
    public static boolean isTransient(Method method) {
        if (method == null) {
            return false;
        }
        if (!transientClassInited) {
            try {
                transientClass = Class.forName("java.beans.Transient");
            } catch (Exception e) {
            } catch (Throwable th) {
                transientClassInited = true;
                throw th;
            }
            transientClassInited = true;
        }
        Class<? extends Annotation> cls = transientClass;
        if (cls == null || getAnnotation(method, cls) == null) {
            return false;
        }
        return true;
    }

    /* JADX DEBUG: Type inference failed for r1v6. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends java.lang.annotation.Annotation> */
    public static boolean isAnnotationPresentOneToMany(Method method) {
        if (method == null) {
            return false;
        }
        if (class_OneToMany == null && !class_OneToMany_error) {
            try {
                class_OneToMany = Class.forName("javax.persistence.OneToMany");
            } catch (Throwable th) {
                class_OneToMany_error = true;
            }
        }
        Class<? extends Annotation> cls = class_OneToMany;
        if (cls == null || !method.isAnnotationPresent(cls)) {
            return false;
        }
        return true;
    }

    /* JADX DEBUG: Type inference failed for r1v9. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends java.lang.annotation.Annotation> */
    public static boolean isAnnotationPresentManyToMany(Method method) {
        if (method == null) {
            return false;
        }
        if (class_ManyToMany == null && !class_ManyToMany_error) {
            try {
                class_ManyToMany = Class.forName("javax.persistence.ManyToMany");
            } catch (Throwable th) {
                class_ManyToMany_error = true;
            }
        }
        if (class_ManyToMany == null) {
            return false;
        }
        if (method.isAnnotationPresent(class_OneToMany) || method.isAnnotationPresent(class_ManyToMany)) {
            return true;
        }
        return false;
    }

    public static boolean isHibernateInitialized(Object object) {
        if (object == null) {
            return false;
        }
        if (method_HibernateIsInitialized == null && !method_HibernateIsInitialized_error) {
            try {
                method_HibernateIsInitialized = Class.forName("org.hibernate.Hibernate").getMethod("isInitialized", Object.class);
            } catch (Throwable th) {
                method_HibernateIsInitialized_error = true;
            }
        }
        Method method = method_HibernateIsInitialized;
        if (method != null) {
            try {
                return ((Boolean) method.invoke(null, object)).booleanValue();
            } catch (Throwable th2) {
            }
        }
        return true;
    }

    public static double parseDouble(String str) {
        int len = str.length();
        if (len > 10) {
            return Double.parseDouble(str);
        }
        boolean negative = false;
        long longValue = 0;
        int scale = 0;
        for (int i = 0; i < len; i++) {
            char ch = str.charAt(i);
            if (ch == '-' && i == 0) {
                negative = true;
            } else if (ch == '.') {
                if (scale != 0) {
                    return Double.parseDouble(str);
                }
                scale = (len - i) - 1;
            } else if (ch < '0' || ch > '9') {
                return Double.parseDouble(str);
            } else {
                longValue = (10 * longValue) + ((long) (ch - '0'));
            }
        }
        if (negative) {
            longValue = -longValue;
        }
        switch (scale) {
            case 0:
                return (double) longValue;
            case 1:
                return ((double) longValue) / 10.0d;
            case 2:
                return ((double) longValue) / 100.0d;
            case 3:
                return ((double) longValue) / 1000.0d;
            case 4:
                return ((double) longValue) / 10000.0d;
            case 5:
                return ((double) longValue) / 100000.0d;
            case 6:
                return ((double) longValue) / 1000000.0d;
            case 7:
                return ((double) longValue) / 1.0E7d;
            case 8:
                return ((double) longValue) / 1.0E8d;
            case 9:
                return ((double) longValue) / 1.0E9d;
            default:
                return Double.parseDouble(str);
        }
    }

    public static float parseFloat(String str) {
        int len = str.length();
        if (len >= 10) {
            return Float.parseFloat(str);
        }
        boolean negative = false;
        long longValue = 0;
        int scale = 0;
        for (int i = 0; i < len; i++) {
            char ch = str.charAt(i);
            if (ch == '-' && i == 0) {
                negative = true;
            } else if (ch == '.') {
                if (scale != 0) {
                    return Float.parseFloat(str);
                }
                scale = (len - i) - 1;
            } else if (ch < '0' || ch > '9') {
                return Float.parseFloat(str);
            } else {
                longValue = (10 * longValue) + ((long) (ch - '0'));
            }
        }
        if (negative) {
            longValue = -longValue;
        }
        switch (scale) {
            case 0:
                return (float) longValue;
            case 1:
                return ((float) longValue) / 10.0f;
            case 2:
                return ((float) longValue) / 100.0f;
            case 3:
                return ((float) longValue) / 1000.0f;
            case 4:
                return ((float) longValue) / 10000.0f;
            case 5:
                return ((float) longValue) / 100000.0f;
            case 6:
                return ((float) longValue) / 1000000.0f;
            case 7:
                return ((float) longValue) / 1.0E7f;
            case 8:
                return ((float) longValue) / 1.0E8f;
            case 9:
                return ((float) longValue) / 1.0E9f;
            default:
                return Float.parseFloat(str);
        }
    }

    public static long fnv1a_64_extract(String key) {
        long hashCode = fnv1a_64_magic_hashcode;
        for (int i = 0; i < key.length(); i++) {
            char ch = key.charAt(i);
            if (!(ch == '_' || ch == '-')) {
                if (ch >= 'A' && ch <= 'Z') {
                    ch = (char) (ch + ' ');
                }
                hashCode = (hashCode ^ ((long) ch)) * fnv1a_64_magic_prime;
            }
        }
        return hashCode;
    }

    public static long fnv1a_64_lower(String key) {
        long hashCode = fnv1a_64_magic_hashcode;
        for (int i = 0; i < key.length(); i++) {
            char ch = key.charAt(i);
            if (ch >= 'A' && ch <= 'Z') {
                ch = (char) (ch + ' ');
            }
            hashCode = (hashCode ^ ((long) ch)) * fnv1a_64_magic_prime;
        }
        return hashCode;
    }

    public static long fnv1a_64(String key) {
        long hashCode = fnv1a_64_magic_hashcode;
        for (int i = 0; i < key.length(); i++) {
            hashCode = (hashCode ^ ((long) key.charAt(i))) * fnv1a_64_magic_prime;
        }
        return hashCode;
    }

    public static boolean isKotlin(Class clazz) {
        if (kotlin_metadata == null && !kotlin_metadata_error) {
            try {
                kotlin_metadata = Class.forName("kotlin.Metadata");
            } catch (Throwable th) {
                kotlin_metadata_error = true;
            }
        }
        if (kotlin_metadata == null || !clazz.isAnnotationPresent(kotlin_metadata)) {
            return false;
        }
        return true;
    }

    public static Constructor getKotlinConstructor(Constructor[] constructors) {
        return getKotlinConstructor(constructors, null);
    }

    public static Constructor getKotlinConstructor(Constructor[] constructors, String[] paramNames) {
        Constructor creatorConstructor = null;
        for (Constructor constructor : constructors) {
            Class<?>[] parameterTypes = constructor.getParameterTypes();
            if ((paramNames == null || parameterTypes.length == paramNames.length) && ((parameterTypes.length <= 0 || !parameterTypes[parameterTypes.length - 1].getName().equals("kotlin.jvm.internal.DefaultConstructorMarker")) && (creatorConstructor == null || creatorConstructor.getParameterTypes().length < parameterTypes.length))) {
                creatorConstructor = constructor;
            }
        }
        return creatorConstructor;
    }

    public static String[] getKoltinConstructorParameters(Class clazz) {
        if (kotlin_kclass_constructor == null && !kotlin_class_klass_error) {
            try {
                kotlin_kclass_constructor = Class.forName("kotlin.reflect.jvm.internal.KClassImpl").getConstructor(Class.class);
            } catch (Throwable th) {
                kotlin_class_klass_error = true;
            }
        }
        if (kotlin_kclass_constructor == null) {
            return null;
        }
        if (kotlin_kclass_getConstructors == null && !kotlin_class_klass_error) {
            try {
                kotlin_kclass_getConstructors = Class.forName("kotlin.reflect.jvm.internal.KClassImpl").getMethod("getConstructors", new Class[0]);
            } catch (Throwable th2) {
                kotlin_class_klass_error = true;
            }
        }
        if (kotlin_kfunction_getParameters == null && !kotlin_class_klass_error) {
            try {
                kotlin_kfunction_getParameters = Class.forName("kotlin.reflect.KFunction").getMethod("getParameters", new Class[0]);
            } catch (Throwable th3) {
                kotlin_class_klass_error = true;
            }
        }
        if (kotlin_kparameter_getName == null && !kotlin_class_klass_error) {
            try {
                kotlin_kparameter_getName = Class.forName("kotlin.reflect.KParameter").getMethod("getName", new Class[0]);
            } catch (Throwable th4) {
                kotlin_class_klass_error = true;
            }
        }
        if (kotlin_error) {
            return null;
        }
        Object constructor = null;
        try {
            Iterator iterator = ((Iterable) kotlin_kclass_getConstructors.invoke(kotlin_kclass_constructor.newInstance(clazz), new Object[0])).iterator();
            while (iterator.hasNext()) {
                Object item = iterator.next();
                List parameters = (List) kotlin_kfunction_getParameters.invoke(item, new Object[0]);
                if (constructor == null || parameters.size() != 0) {
                    constructor = item;
                }
                iterator.hasNext();
            }
            if (constructor == null) {
                return null;
            }
            List parameters2 = (List) kotlin_kfunction_getParameters.invoke(constructor, new Object[0]);
            String[] names = new String[parameters2.size()];
            for (int i = 0; i < parameters2.size(); i++) {
                names[i] = (String) kotlin_kparameter_getName.invoke(parameters2.get(i), new Object[0]);
            }
            return names;
        } catch (Throwable e) {
            e.printStackTrace();
            kotlin_error = true;
            return null;
        }
    }

    private static boolean isKotlinIgnore(Class clazz, String methodName) {
        String[] ignores;
        if (kotlinIgnores == null && !kotlinIgnores_error) {
            try {
                Map<Class, String[]> map = new HashMap<>();
                map.put(Class.forName("kotlin.ranges.CharRange"), new String[]{"getEndInclusive", "isEmpty"});
                map.put(Class.forName("kotlin.ranges.IntRange"), new String[]{"getEndInclusive", "isEmpty"});
                map.put(Class.forName("kotlin.ranges.LongRange"), new String[]{"getEndInclusive", "isEmpty"});
                map.put(Class.forName("kotlin.ranges.ClosedFloatRange"), new String[]{"getEndInclusive", "isEmpty"});
                map.put(Class.forName("kotlin.ranges.ClosedDoubleRange"), new String[]{"getEndInclusive", "isEmpty"});
                kotlinIgnores = map;
            } catch (Throwable th) {
                kotlinIgnores_error = true;
            }
        }
        if (kotlinIgnores == null || (ignores = kotlinIgnores.get(clazz)) == null || Arrays.binarySearch(ignores, methodName) < 0) {
            return false;
        }
        return true;
    }

    public static <A extends Annotation> A getAnnotation(Class<?> targetClass, Class<A> annotationClass) {
        A targetAnnotation = (A) targetClass.getAnnotation(annotationClass);
        Class<?> mixInClass = null;
        Type type = JSON.getMixInAnnotations(targetClass);
        if (type instanceof Class) {
            mixInClass = (Class) type;
        }
        if (mixInClass != null) {
            A mixInAnnotation = (A) mixInClass.getAnnotation(annotationClass);
            Annotation[] annotations = mixInClass.getAnnotations();
            if (mixInAnnotation == null && annotations.length > 0) {
                for (Annotation annotation : annotations) {
                    mixInAnnotation = (A) annotation.annotationType().getAnnotation(annotationClass);
                    if (mixInAnnotation != null) {
                        break;
                    }
                }
            }
            if (mixInAnnotation != null) {
                return mixInAnnotation;
            }
        }
        Annotation[] targetClassAnnotations = targetClass.getAnnotations();
        if (targetAnnotation == null && targetClassAnnotations.length > 0) {
            for (Annotation annotation2 : targetClassAnnotations) {
                targetAnnotation = (A) annotation2.annotationType().getAnnotation(annotationClass);
                if (targetAnnotation != null) {
                    break;
                }
            }
        }
        return targetAnnotation;
    }

    public static <A extends Annotation> A getAnnotation(Field field, Class<A> annotationClass) {
        A mixInAnnotation;
        A targetAnnotation = (A) field.getAnnotation(annotationClass);
        Class<?> mixInClass = null;
        Type type = JSON.getMixInAnnotations(field.getDeclaringClass());
        if (type instanceof Class) {
            mixInClass = (Class) type;
        }
        if (mixInClass != null) {
            Field mixInField = null;
            String fieldName = field.getName();
            Class<?> currClass = mixInClass;
            while (true) {
                if (currClass == null || currClass == Object.class) {
                    break;
                }
                try {
                    mixInField = currClass.getDeclaredField(fieldName);
                    break;
                } catch (NoSuchFieldException e) {
                    currClass = currClass.getSuperclass();
                }
            }
            if (!(mixInField == null || (mixInAnnotation = (A) mixInField.getAnnotation(annotationClass)) == null)) {
                return mixInAnnotation;
            }
        }
        return targetAnnotation;
    }

    public static <A extends Annotation> A getAnnotation(Method method, Class<A> annotationClass) {
        A mixInAnnotation;
        A targetAnnotation = (A) method.getAnnotation(annotationClass);
        Class<?> mixInClass = null;
        Type type = JSON.getMixInAnnotations(method.getDeclaringClass());
        if (type instanceof Class) {
            mixInClass = (Class) type;
        }
        if (mixInClass != null) {
            Method mixInMethod = null;
            String methodName = method.getName();
            Class<?>[] parameterTypes = method.getParameterTypes();
            Class<?> currClass = mixInClass;
            while (true) {
                if (currClass == null || currClass == Object.class) {
                    break;
                }
                try {
                    mixInMethod = currClass.getDeclaredMethod(methodName, parameterTypes);
                    break;
                } catch (NoSuchMethodException e) {
                    currClass = currClass.getSuperclass();
                }
            }
            if (!(mixInMethod == null || (mixInAnnotation = (A) mixInMethod.getAnnotation(annotationClass)) == null)) {
                return mixInAnnotation;
            }
        }
        return targetAnnotation;
    }

    public static Annotation[][] getParameterAnnotations(Method method) {
        Annotation[][] mixInAnnotations;
        Annotation[][] targetAnnotations = method.getParameterAnnotations();
        Class<?> mixInClass = null;
        Type type = JSON.getMixInAnnotations(method.getDeclaringClass());
        if (type instanceof Class) {
            mixInClass = (Class) type;
        }
        if (mixInClass != null) {
            Method mixInMethod = null;
            String methodName = method.getName();
            Class<?>[] parameterTypes = method.getParameterTypes();
            Class<?> currClass = mixInClass;
            while (true) {
                if (currClass == null || currClass == Object.class) {
                    break;
                }
                try {
                    mixInMethod = currClass.getDeclaredMethod(methodName, parameterTypes);
                    break;
                } catch (NoSuchMethodException e) {
                    currClass = currClass.getSuperclass();
                }
            }
            if (!(mixInMethod == null || (mixInAnnotations = mixInMethod.getParameterAnnotations()) == null)) {
                return mixInAnnotations;
            }
        }
        return targetAnnotations;
    }

    public static Annotation[][] getParameterAnnotations(Constructor constructor) {
        Annotation[][] mixInAnnotations;
        Annotation[][] targetAnnotations = constructor.getParameterAnnotations();
        Class<?> mixInClass = null;
        Type type = JSON.getMixInAnnotations(constructor.getDeclaringClass());
        if (type instanceof Class) {
            mixInClass = (Class) type;
        }
        if (mixInClass != null) {
            Constructor mixInConstructor = null;
            Class<?>[] parameterTypes = constructor.getParameterTypes();
            List<Class<?>> enclosingClasses = new ArrayList<>(2);
            for (Class<?> enclosingClass = mixInClass.getEnclosingClass(); enclosingClass != null; enclosingClass = enclosingClass.getEnclosingClass()) {
                enclosingClasses.add(enclosingClass);
            }
            int level = enclosingClasses.size();
            Class<?> currClass = mixInClass;
            while (true) {
                if (currClass == null || currClass == Object.class) {
                    break;
                }
                if (level == 0) {
                    mixInConstructor = mixInClass.getDeclaredConstructor(parameterTypes);
                    break;
                }
                try {
                    Class<?>[] outerClassAndParameterTypes = new Class[(parameterTypes.length + level)];
                    System.arraycopy(parameterTypes, 0, outerClassAndParameterTypes, level, parameterTypes.length);
                    for (int i = level; i > 0; i--) {
                        outerClassAndParameterTypes[i - 1] = enclosingClasses.get(i - 1);
                    }
                    mixInConstructor = mixInClass.getDeclaredConstructor(outerClassAndParameterTypes);
                } catch (NoSuchMethodException e) {
                    level--;
                    currClass = currClass.getSuperclass();
                }
            }
            if (!(mixInConstructor == null || (mixInAnnotations = mixInConstructor.getParameterAnnotations()) == null)) {
                return mixInAnnotations;
            }
        }
        return targetAnnotations;
    }

    /* JADX DEBUG: Type inference failed for r1v6. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends java.lang.annotation.Annotation> */
    public static boolean isJacksonCreator(Method method) {
        if (method == null) {
            return false;
        }
        if (class_JacksonCreator == null && !class_JacksonCreator_error) {
            try {
                class_JacksonCreator = Class.forName("com.fasterxml.jackson.annotation.JsonCreator");
            } catch (Throwable th) {
                class_JacksonCreator_error = true;
            }
        }
        Class<? extends Annotation> cls = class_JacksonCreator;
        if (cls == null || !method.isAnnotationPresent(cls)) {
            return false;
        }
        return true;
    }

    public static Object optionalEmpty(Type type) {
        Class clazz;
        if (OPTIONAL_ERROR || (clazz = getClass(type)) == null) {
            return null;
        }
        String className = clazz.getName();
        if (!"java.util.Optional".equals(className)) {
            return null;
        }
        if (OPTIONAL_EMPTY == null) {
            try {
                OPTIONAL_EMPTY = Class.forName(className).getMethod("empty", new Class[0]).invoke(null, new Object[0]);
            } catch (Throwable th) {
                OPTIONAL_ERROR = true;
            }
        }
        return OPTIONAL_EMPTY;
    }

    public static class MethodInheritanceComparator implements Comparator<Method> {
        public int compare(Method m1, Method m2) {
            int cmp = m1.getName().compareTo(m2.getName());
            if (cmp != 0) {
                return cmp;
            }
            Class<?> class1 = m1.getReturnType();
            Class<?> class2 = m2.getReturnType();
            if (class1.equals(class2)) {
                return 0;
            }
            if (class1.isAssignableFrom(class2)) {
                return -1;
            }
            if (class2.isAssignableFrom(class1)) {
                return 1;
            }
            return 0;
        }
    }
}
