package com.baidu.aip.core.mini;

import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.os.Handler;
import androidx.core.content.ContextCompat;
import com.baidu.speech.asr.SpeechConstant;
import com.facebook.common.util.UriUtil;
import com.xiaomi.mipush.sdk.Constants;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.R;
import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.TreeSet;
import org.json.JSONObject;

public class AutoCheck {
    private static final String TAG = "AutoCheck";
    public static final boolean isOnlineLited = false;
    private LinkedHashMap<String, Check> checks;
    private Context context;
    private boolean enableOffline;
    private Handler handler;
    private boolean hasError;
    private boolean isFinished = false;
    private String name;

    public AutoCheck(Context context2, Handler handler2, boolean enableOffline2) {
        this.context = context2;
        this.checks = new LinkedHashMap<>();
        this.handler = handler2;
        this.enableOffline = enableOffline2;
    }

    public void checkAsr(final Map<String, Object> params) {
        new Thread(new Runnable() {
            /* class com.baidu.aip.core.mini.AutoCheck.AnonymousClass1 */

            public void run() {
                AutoCheck obj = AutoCheck.this.checkAsrInternal(params);
                AutoCheck.this.name = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_recognition);
                synchronized (obj) {
                    AutoCheck.this.isFinished = true;
                    AutoCheck.this.handler.sendMessage(AutoCheck.this.handler.obtainMessage(10086, obj));
                }
            }
        }).start();
    }

    public String obtainErrorMessage() {
        return formatString(new PrintConfig());
    }

    public String obtainDebugMessage() {
        PrintConfig config = new PrintConfig();
        config.withInfo = true;
        return formatString(config);
    }

    public String obtainAllMessage() {
        PrintConfig config = new PrintConfig();
        config.withLog = true;
        config.withInfo = true;
        config.withLogOnSuccess = true;
        return formatString(config);
    }

    private String formatString(PrintConfig config) {
        StringBuilder sb = new StringBuilder();
        this.hasError = false;
        for (Map.Entry<String, Check> entry : this.checks.entrySet()) {
            Check check = entry.getValue();
            String testName = entry.getKey();
            if (check.hasError()) {
                if (!this.hasError) {
                    this.hasError = true;
                }
                sb.append(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sb_text_error));
                sb.append(testName);
                sb.append(" 】  ");
                sb.append(check.getErrorMessage());
                sb.append("\n");
                if (check.hasFix()) {
                    sb.append(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sb_text_fix_method));
                    sb.append(testName);
                    sb.append(" 】  ");
                    sb.append(check.getFixMessage());
                    sb.append("\n");
                }
            } else if (config.withEachCheckInfo) {
                sb.append(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sb_text_no_error_report));
                sb.append(testName);
                sb.append(" 】  ");
                sb.append("\n");
            }
            if (config.withInfo && check.hasInfo()) {
                sb.append(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sb_text_check_again));
                sb.append(testName);
                sb.append("】 ");
                sb.append(check.getInfoMessage());
                sb.append("\n");
            }
            if (config.withLog && ((config.withLogOnSuccess || this.hasError) && check.hasLog())) {
                sb.append("【log】:" + check.getLogMessage());
                sb.append("\n");
            }
        }
        if (!this.hasError) {
            sb.append("【" + this.name + DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sb_text_success_no_error));
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private AutoCheck checkAsrInternal(Map<String, Object> params) {
        commonSetting(params);
        this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_vertify_out_audio), new FileCheck(this.context, params, SpeechConstant.IN_FILE));
        this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_vertify_offline_bsg), new FileCheck(this.context, params, SpeechConstant.ASR_OFFLINE_ENGINE_GRAMMER_FILE_PATH));
        for (Map.Entry<String, Check> e : this.checks.entrySet()) {
            Check check = e.getValue();
            check.check();
            if (check.hasError()) {
                break;
            }
        }
        return this;
    }

    private void commonSetting(Map<String, Object> params) {
        this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_check_android_permission), new PermissionCheck(this.context));
        this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_check_android_so), new JniCheck(this.context));
        try {
            AppInfoCheck infoCheck = new AppInfoCheck(this.context, params);
            this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_check_appid_appkey), infoCheck);
            if (this.enableOffline) {
                this.checks.put(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_check_package_name), new ApplicationIdCheck(this.context, infoCheck.appId));
            }
        } catch (PackageManager.NameNotFoundException e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    public static class PrintConfig {
        public boolean withEachCheckInfo;
        public boolean withInfo;
        public boolean withLog;
        public boolean withLogOnSuccess;

        private PrintConfig() {
            this.withEachCheckInfo = false;
            this.withInfo = false;
            this.withLog = false;
            this.withLogOnSuccess = false;
        }
    }

    /* access modifiers changed from: private */
    public static class PermissionCheck extends Check {
        private Context context;

        public PermissionCheck(Context context2) {
            this.context = context2;
        }

        @Override // com.baidu.aip.core.mini.AutoCheck.Check
        public void check() {
            String[] permissions = {"android.permission.RECORD_AUDIO", "android.permission.ACCESS_NETWORK_STATE", "android.permission.INTERNET", "android.permission.READ_PHONE_STATE"};
            ArrayList<String> toApplyList = new ArrayList<>();
            for (String perm : permissions) {
                if (ContextCompat.checkSelfPermission(this.context, perm) != 0) {
                    toApplyList.add(perm);
                }
            }
            if (!toApplyList.isEmpty()) {
                this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_loss_permission) + toApplyList;
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_copy_permission_from_manifest);
            }
        }
    }

    /* access modifiers changed from: private */
    public static class JniCheck extends Check {
        private Context context;
        private String[] soNames = {"libBaiduSpeechSDK.so", "libvad.dnn.so", "libbd_easr_s1_merge_normal_20151216.dat.so", "libbdEASRAndroid.so", "libbdSpilWakeup.so"};

        public JniCheck(Context context2) {
            this.context = context2;
        }

        @Override // com.baidu.aip.core.mini.AutoCheck.Check
        public void check() {
            String path = this.context.getApplicationInfo().nativeLibraryDir;
            appendLogMessage(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_jni_dir) + path);
            File[] files = new File(path).listFiles();
            TreeSet<String> set = new TreeSet<>();
            if (files != null) {
                for (File file : files) {
                    set.add(file.getName());
                }
            }
            String[] strArr = this.soNames;
            for (String name : strArr) {
                if (!set.contains(name)) {
                    this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_jni_error_msg_one) + path + DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_jni_error_msg_two) + name + DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_jni_error_msg_three) + set.toString();
                    this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_jni_fix_message);
                    return;
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public static class AppInfoCheck extends Check {
        private String appId;
        private String appKey;
        private String secretKey;

        public AppInfoCheck(Context context, Map<String, Object> params) throws PackageManager.NameNotFoundException {
            Bundle metaData = context.getPackageManager().getApplicationInfo(context.getPackageName(), 128).metaData;
            if (params.get("appid") != null) {
                this.appId = params.get("appid").toString();
            } else {
                int id = metaData.getInt("com.baidu.speech.APP_ID", 0);
                if (id > 0) {
                    this.appId = "" + id;
                }
            }
            if (params.get("key") != null) {
                this.appKey = params.get("key").toString();
            } else {
                this.appKey = metaData.getString("com.baidu.speech.API_KEY", "");
            }
            if (params.get("secret") != null) {
                this.secretKey = params.get("secret").toString();
            } else {
                this.secretKey = metaData.getString("com.baidu.speech.SECRET_KEY", "");
            }
        }

        @Override // com.baidu.aip.core.mini.AutoCheck.Check
        public void check() {
            appendLogMessage("try to check appId " + this.appId + " ,appKey=" + this.appKey + " ,secretKey" + this.secretKey);
            String str = this.appId;
            if (str == null || str.isEmpty()) {
                this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_appid_empty);
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_appid_fill);
                return;
            }
            String str2 = this.appKey;
            if (str2 == null || str2.isEmpty()) {
                this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_appkey_empty);
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_appkey_fill);
                return;
            }
            String str3 = this.secretKey;
            if (str3 == null || str3.isEmpty()) {
                this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_secretkey_empty);
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_text_secretkey_fill);
                return;
            }
            try {
                checkOnline();
            } catch (UnknownHostException e) {
                this.infoMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_error_no_network) + e.getMessage();
            } catch (Exception e2) {
                this.errorMessage = e2.getClass().getCanonicalName() + Constants.COLON_SEPARATOR + e2.getMessage();
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_fixmessage_check_appid_appkey_again);
            }
        }

        public void checkOnline() throws Exception {
            String line;
            HttpURLConnection conn = (HttpURLConnection) new URL("http://openapi.baidu.com/oauth/2.0/token?grant_type=client_credentials&client_id=" + this.appKey + "&client_secret=" + this.secretKey).openConnection();
            conn.setRequestMethod(com.tencent.connect.common.Constants.HTTP_GET);
            conn.setConnectTimeout(1000);
            BufferedReader reader = new BufferedReader(new InputStreamReader(conn.getInputStream()));
            StringBuilder result = new StringBuilder();
            do {
                line = reader.readLine();
                if (line != null) {
                    result.append(line);
                    continue;
                }
            } while (line != null);
            String res = result.toString();
            if (!res.contains("audio_voice_assistant_get")) {
                this.errorMessage = "appid:" + this.appId + DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_error_no_audio_voice_assistant_get);
                this.fixMessage = "secretKey";
                return;
            }
            appendLogMessage("openapi return " + res);
            JSONObject jsonObject = new JSONObject(res);
            String error = jsonObject.optString("error");
            if (error == null || error.isEmpty()) {
                String token = jsonObject.getString(com.tencent.connect.common.Constants.PARAM_ACCESS_TOKEN);
                if (token != null) {
                    if (token.endsWith("-" + this.appId)) {
                        return;
                    }
                }
                this.errorMessage = StringUtil.format(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_error_appkey_message_format), this.appId, token);
                this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_fixmessage_check_appid_appkey_again);
                return;
            }
            this.errorMessage = StringUtil.format(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_error_appkey_message_format), error, result);
            this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_fixmessage_check_appid_appkey_again);
        }
    }

    /* access modifiers changed from: private */
    public static class ApplicationIdCheck extends Check {
        private String appId;
        private Context context;

        public ApplicationIdCheck(Context context2, String appId2) {
            this.appId = appId2;
            this.context = context2;
        }

        @Override // com.baidu.aip.core.mini.AutoCheck.Check
        public void check() {
            this.infoMessage = StringUtil.format(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_sdk_fix_message_step), this.appId) + getApplicationId();
        }

        private String getApplicationId() {
            return this.context.getPackageName();
        }
    }

    /* access modifiers changed from: private */
    public static class FileCheck extends Check {
        private boolean allowAssets = true;
        private boolean allowRes = false;
        private Context context;
        private String key;
        private Map<String, Object> params;

        public FileCheck(Context context2, Map<String, Object> params2, String key2) {
            this.context = context2;
            this.params = params2;
            this.key = key2;
            if (key2.equals(SpeechConstant.IN_FILE)) {
                this.allowRes = true;
                this.allowAssets = false;
            }
        }

        @Override // com.baidu.aip.core.mini.AutoCheck.Check
        public void check() {
            if (this.params.containsKey(this.key)) {
                String value = this.params.get(this.key).toString();
                if (this.allowAssets) {
                    int len = "assets".length();
                    int totalLen = ":///".length() + len;
                    if (value.startsWith("assets")) {
                        String filename = value.substring(totalLen);
                        if (!":///".equals(value.substring(len, totalLen)) || filename.isEmpty()) {
                            this.errorMessage = StringUtil.format(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_param_error_format), this.key, value);
                            this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_param_error_format_fix);
                        }
                        try {
                            this.context.getAssets().open(filename);
                        } catch (IOException e) {
                            this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_asset_file_loss) + filename;
                            this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_asset_file_loss_fix);
                            e.printStackTrace();
                        }
                        appendLogMessage(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_asset_check_done) + filename);
                    }
                }
                if (this.allowRes) {
                    int len2 = UriUtil.LOCAL_RESOURCE_SCHEME.length();
                    int totalLen2 = ":///".length() + len2;
                    if (value.startsWith(UriUtil.LOCAL_RESOURCE_SCHEME)) {
                        String filename2 = value.substring(totalLen2);
                        if (!":///".equals(value.substring(len2, totalLen2)) || filename2.isEmpty()) {
                            this.errorMessage = StringUtil.format(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_param_error_format), this.key, value);
                            this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_param_error_format_fix_two);
                        }
                        if (getClass().getClassLoader().getResourceAsStream(filename2) == null) {
                            this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_res_file_loss) + filename2;
                            this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_res_file_loss_fix);
                        }
                        appendLogMessage(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_res_check_done) + filename2);
                    }
                }
                if (value.startsWith("/")) {
                    if (!new File(value).canRead()) {
                        this.errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_file_path_not_exist) + value;
                        this.fixMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_file_path_not_exist_fix);
                    }
                    appendLogMessage(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_msg_file_path_check_done) + value);
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public static abstract class Check {
        protected String errorMessage = null;
        protected String fixMessage = null;
        protected String infoMessage = null;
        protected StringBuilder logMessage = new StringBuilder();

        public abstract void check();

        public boolean hasError() {
            return this.errorMessage != null;
        }

        public boolean hasFix() {
            return this.fixMessage != null;
        }

        public boolean hasInfo() {
            return this.infoMessage != null;
        }

        public boolean hasLog() {
            return !this.logMessage.toString().isEmpty();
        }

        public void appendLogMessage(String message) {
            StringBuilder sb = this.logMessage;
            sb.append(message + "\n");
        }

        public String getErrorMessage() {
            return this.errorMessage;
        }

        public String getFixMessage() {
            return this.fixMessage;
        }

        public String getInfoMessage() {
            return this.infoMessage;
        }

        public String getLogMessage() {
            return this.logMessage.toString();
        }
    }
}
