package com.baidu.aip.core.recog;

import android.content.Context;
import com.baidu.aip.core.recog.listener.IRecogListener;
import com.baidu.aip.core.recog.listener.RecogEventAdapter;
import com.baidu.speech.EventListener;
import com.baidu.speech.EventManager;
import com.baidu.speech.EventManagerFactory;
import com.baidu.speech.asr.SpeechConstant;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.feature.R;
import java.util.Map;
import org.json.JSONObject;

public class MyRecognizer {
    private static final String TAG = "MyRecognizer";
    private static volatile boolean isInited = false;
    private static boolean isOfflineEngineLoaded = false;
    private EventManager asr;
    private EventListener eventListener;

    public MyRecognizer(Context context, IRecogListener recogListener) {
        this(context, new RecogEventAdapter(recogListener));
    }

    public MyRecognizer(Context context, EventListener eventListener2) {
        if (!isInited) {
            isInited = true;
            this.eventListener = eventListener2;
            EventManager create = EventManagerFactory.create(context, "asr");
            this.asr = create;
            create.registerListener(eventListener2);
            return;
        }
        throw new RuntimeException(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_exception_not_call_release));
    }

    public void loadOfflineEngine(Map<String, Object> params) {
        this.asr.send(SpeechConstant.ASR_KWS_LOAD_ENGINE, new JSONObject(params).toString(), null, 0, 0);
        isOfflineEngineLoaded = true;
    }

    public void start(Map<String, Object> params) {
        this.asr.send(SpeechConstant.ASR_START, new JSONObject(params).toString(), null, 0, 0);
    }

    public void stop() {
        if (isInited) {
            this.asr.send(SpeechConstant.ASR_STOP, "{}", null, 0, 0);
            return;
        }
        throw new RuntimeException("release() was called");
    }

    public void cancel() {
        if (isInited) {
            this.asr.send("asr.cancel", "{}", null, 0, 0);
            return;
        }
        throw new RuntimeException("release() was called");
    }

    public void release() {
        if (this.asr != null) {
            cancel();
            if (isOfflineEngineLoaded) {
                this.asr.send(SpeechConstant.ASR_KWS_UNLOAD_ENGINE, null, null, 0, 0);
                isOfflineEngineLoaded = false;
            }
            this.asr.unregisterListener(this.eventListener);
            this.asr = null;
            isInited = false;
        }
    }

    public void setEventListener(IRecogListener recogListener) {
        if (isInited) {
            RecogEventAdapter recogEventAdapter = new RecogEventAdapter(recogListener);
            this.eventListener = recogEventAdapter;
            this.asr.registerListener(recogEventAdapter);
            return;
        }
        throw new RuntimeException("release() was called");
    }
}
