package com.baidu.aip.core.recog;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class RecogResult {
    private static final int ERROR_NONE = 0;
    private String desc;
    private int error = -1;
    private String origalJson;
    private String origalResult;
    private String resultType;
    private String[] resultsRecognition;
    private String sn;
    private int subError = -1;

    public static RecogResult parseJson(String jsonStr) {
        RecogResult result = new RecogResult();
        result.setOrigalJson(jsonStr);
        try {
            JSONObject json = new JSONObject(jsonStr);
            int error2 = json.optInt("error");
            int subError2 = json.optInt("sub_error");
            result.setError(error2);
            result.setDesc(json.optString("desc"));
            result.setResultType(json.optString("result_type"));
            result.setSubError(subError2);
            if (error2 == 0) {
                result.setOrigalResult(json.getString("origin_result"));
                JSONArray arr = json.optJSONArray("results_recognition");
                if (arr != null) {
                    int size = arr.length();
                    String[] recogs = new String[size];
                    for (int i = 0; i < size; i++) {
                        recogs[i] = arr.getString(i);
                    }
                    result.setResultsRecognition(recogs);
                }
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return result;
    }

    public boolean hasError() {
        return this.error != 0;
    }

    public boolean isFinalResult() {
        return "final_result".equals(this.resultType);
    }

    public boolean isPartialResult() {
        return "partial_result".equals(this.resultType);
    }

    public boolean isNluResult() {
        return "nlu_result".equals(this.resultType);
    }

    public String getOrigalJson() {
        return this.origalJson;
    }

    public void setOrigalJson(String origalJson2) {
        this.origalJson = origalJson2;
    }

    public String[] getResultsRecognition() {
        return this.resultsRecognition;
    }

    public void setResultsRecognition(String[] resultsRecognition2) {
        this.resultsRecognition = resultsRecognition2;
    }

    public String getSn() {
        return this.sn;
    }

    public void setSn(String sn2) {
        this.sn = sn2;
    }

    public int getError() {
        return this.error;
    }

    public void setError(int error2) {
        this.error = error2;
    }

    public String getDesc() {
        return this.desc;
    }

    public void setDesc(String desc2) {
        this.desc = desc2;
    }

    public String getOrigalResult() {
        return this.origalResult;
    }

    public void setOrigalResult(String origalResult2) {
        this.origalResult = origalResult2;
    }

    public String getResultType() {
        return this.resultType;
    }

    public void setResultType(String resultType2) {
        this.resultType = resultType2;
    }

    public int getSubError() {
        return this.subError;
    }

    public void setSubError(int subError2) {
        this.subError = subError2;
    }
}
