package com.baidu.aip.core.recog.listener;

import android.os.Handler;
import android.os.Message;
import com.baidu.aip.core.recog.RecogResult;
import com.baidu.speech.asr.SpeechConstant;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.feature.R;

public class MessageStatusRecogListener extends StatusRecogListener {
    private static final String TAG = "MesStatusRecogListener";
    private Handler handler;
    private boolean needTime = true;
    private long speechEndTime = 0;

    public MessageStatusRecogListener(Handler handler2) {
        this.handler = handler2;
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrReady() {
        super.onAsrReady();
        this.speechEndTime = 0;
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrBegin() {
        super.onAsrBegin();
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrEnd() {
        super.onAsrEnd();
        this.speechEndTime = System.currentTimeMillis();
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrPartialResult(String[] results, RecogResult recogResult) {
        super.onAsrPartialResult(results, recogResult);
        sendMessage(results[0], this.status, true);
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrFinalResult(String[] results, RecogResult recogResult) {
        super.onAsrFinalResult(results, recogResult);
        this.speechEndTime = 0;
        sendMessage(results, this.status, true);
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrFinishError(int errorCode, int subErrorCode, String descMessage, RecogResult recogResult) {
        super.onAsrFinishError(errorCode, subErrorCode, descMessage, recogResult);
        this.speechEndTime = 0;
        sendMessage("{errorCode:'" + errorCode + "',subErrorCode:'" + subErrorCode + "',descMessage:'" + descMessage + "'}", this.status, true);
        this.speechEndTime = 0;
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrOnlineNluResult(String nluResult) {
        super.onAsrOnlineNluResult(nluResult);
        if (!nluResult.isEmpty()) {
            sendMessage(new String[]{nluResult}, this.status, true);
        }
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrFinish(RecogResult recogResult) {
        super.onAsrFinish(recogResult);
        String[] result = recogResult.getResultsRecognition();
        if (result != null && result.length > 0) {
            sendMessage(recogResult.getResultsRecognition(), this.status, true);
        }
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrLongFinish() {
        super.onAsrLongFinish();
        sendStatusMessage(SpeechConstant.CALLBACK_EVENT_ASR_LONG_SPEECH, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_exception_long_voice_distinguish_done));
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrExit() {
        super.onAsrExit();
        sendStatusMessage(SpeechConstant.CALLBACK_EVENT_ASR_EXIT, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_speech_baidu_exception_distinguish_engine_idle));
    }

    @Override // com.baidu.aip.core.recog.listener.StatusRecogListener, com.baidu.aip.core.recog.listener.IRecogListener
    public void onAsrVolume(int volumePercent, int volume) {
        super.onAsrVolume(volumePercent, volume);
        sendMessage(Integer.valueOf(volume), this.status, true);
    }

    private void sendStatusMessage(String eventName, String message) {
        sendMessage(Operators.ARRAY_START_STR + eventName + Operators.ARRAY_END_STR + message, this.status);
    }

    private void sendMessage(String message) {
        sendMessage(message, 9001);
    }

    private void sendMessage(String message, int what) {
        sendMessage(message, what, false);
    }

    private void sendMessage(Object message, int what, boolean highlight) {
        Message msg = Message.obtain();
        msg.what = what;
        msg.arg1 = this.status;
        if (highlight) {
            msg.arg2 = 1;
        }
        msg.obj = message;
        this.handler.sendMessage(msg);
    }
}
