package com.baidu.aip.core.recog.listener;

import android.util.Log;
import com.baidu.aip.core.recog.RecogResult;
import com.baidu.speech.EventListener;
import com.baidu.speech.asr.SpeechConstant;
import org.json.JSONException;
import org.json.JSONObject;

public class RecogEventAdapter implements EventListener {
    private static final String TAG = "RecogEventAdapter";
    private IRecogListener listener;

    public RecogEventAdapter(IRecogListener listener2) {
        this.listener = listener2;
    }

    @Override // com.baidu.speech.EventListener
    public void onEvent(String name, String params, byte[] data, int offset, int length) {
        Log.i(TAG, "name:" + name + "; params:" + params);
        if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_LOADED)) {
            this.listener.onOfflineLoaded();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_UNLOADED)) {
            this.listener.onOfflineUnLoaded();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_READY)) {
            this.listener.onAsrReady();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_BEGIN)) {
            this.listener.onAsrBegin();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_END)) {
            this.listener.onAsrEnd();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_PARTIAL)) {
            RecogResult recogResult = RecogResult.parseJson(params);
            String[] results = recogResult.getResultsRecognition();
            if (recogResult.isFinalResult()) {
                this.listener.onAsrFinalResult(results, recogResult);
            } else if (recogResult.isPartialResult()) {
                this.listener.onAsrPartialResult(results, recogResult);
            } else if (recogResult.isNluResult()) {
                this.listener.onAsrOnlineNluResult(new String(data, offset, length));
            }
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_FINISH)) {
            RecogResult recogResult2 = RecogResult.parseJson(params);
            if (recogResult2.hasError()) {
                this.listener.onAsrFinishError(recogResult2.getError(), recogResult2.getSubError(), recogResult2.getDesc(), recogResult2);
                return;
            }
            this.listener.onAsrFinish(recogResult2);
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_LONG_SPEECH)) {
            this.listener.onAsrLongFinish();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_EXIT)) {
            this.listener.onAsrExit();
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_VOLUME)) {
            Volume vol = parseVolumeJson(params);
            this.listener.onAsrVolume(vol.volumePercent, vol.volume);
        } else if (name.equals(SpeechConstant.CALLBACK_EVENT_ASR_AUDIO)) {
            int length2 = data.length;
            this.listener.onAsrAudio(data, offset, length);
        }
    }

    private Volume parseVolumeJson(String jsonStr) {
        Volume vol = new Volume();
        vol.origalJson = jsonStr;
        try {
            JSONObject json = new JSONObject(jsonStr);
            vol.volumePercent = json.getInt("volume-percent");
            vol.volume = json.getInt("volume");
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return vol;
    }

    /* access modifiers changed from: private */
    public class Volume {
        private String origalJson;
        private int volume;
        private int volumePercent;

        private Volume() {
            this.volumePercent = -1;
            this.volume = -1;
        }
    }
}
