package com.baidu.speech.asr;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import com.baidu.speech.EventListener;
import com.baidu.speech.EventManager;
import com.baidu.speech.utils.LogUtil;
import java.util.ArrayList;
import java.util.Iterator;

public class EventManagerWp implements EventManager {
    private static final String TAG = "EventManagerWp";
    private static final String version = "1.1.0.20161226";
    private Exception initException = null;
    private ArrayList<EventListener> listeners = new ArrayList<>();
    private Context mContext;
    private WakeUpControl mEnginer;
    private Handler mHandler = new Handler(Looper.getMainLooper());

    public EventManagerWp(Context context) {
        this.mContext = context;
        try {
            this.mEnginer = new WakeUpControl(context);
        } catch (Exception e) {
            e.printStackTrace();
            this.initException = e;
        }
    }

    public static final String getSDKVersion() {
        return version;
    }

    @Override // com.baidu.speech.EventManager
    public void registerListener(EventListener eventListener) {
        if (eventListener != null && !this.listeners.contains(eventListener)) {
            this.listeners.add(eventListener);
        }
    }

    @Override // com.baidu.speech.EventManager
    public void send(String str, String str2, byte[] bArr, int i, int i2) {
        LogUtil.v(TAG, "send cmd : " + str + " send params : " + str2);
        AnalysisInterceptor.getInstance(this.mContext).send(str, str2, bArr, i, i2);
        if (!TextUtils.isEmpty(str)) {
            if (SpeechConstant.WAKEUP_START.equals(str) && this.initException != null) {
                Iterator<EventListener> it = this.listeners.iterator();
                while (it.hasNext()) {
                    final EventListener next = it.next();
                    this.mHandler.post(new Runnable() {
                        /* class com.baidu.speech.asr.EventManagerWp.AnonymousClass1 */

                        public void run() {
                            if (next != null) {
                                LogUtil.v(EventManagerWp.TAG, "onEvent mCommand : wp.error and wp.exit  onEvent mParam : " + EventManagerWp.this.initException.getMessage());
                                next.onEvent(SpeechConstant.CALLBACK_EVENT_WAKEUP_ERROR, EventManagerWp.this.initException.getMessage(), null, 0, 0);
                                next.onEvent(SpeechConstant.CALLBACK_EVENT_WAKEUP_STOPED, EventManagerWp.this.initException.getMessage(), null, 0, 0);
                            }
                        }
                    });
                }
            }
            WakeUpControl wakeUpControl = this.mEnginer;
            if (wakeUpControl != null && str != null) {
                wakeUpControl.setListener(new EventListener() {
                    /* class com.baidu.speech.asr.EventManagerWp.AnonymousClass2 */

                    @Override // com.baidu.speech.EventListener
                    public void onEvent(final String str, final String str2, final byte[] bArr, final int i, final int i2) {
                        synchronized (EventManagerWp.this.listeners) {
                            Iterator it = EventManagerWp.this.listeners.iterator();
                            while (it.hasNext()) {
                                final EventListener eventListener = (EventListener) it.next();
                                EventManagerWp.this.mHandler.post(new Runnable() {
                                    /* class com.baidu.speech.asr.EventManagerWp.AnonymousClass2.AnonymousClass1 */

                                    public void run() {
                                        if (eventListener != null) {
                                            LogUtil.v(EventManagerWp.TAG, "onEvent mCommand : " + str + " onEvent mParam : " + str2);
                                            eventListener.onEvent(str, str2, bArr, i, i2);
                                            AnalysisInterceptor.getInstance(EventManagerWp.this.mContext).onEvent(str, str2, bArr, i, i2, false);
                                        }
                                    }
                                });
                            }
                        }
                    }
                });
                this.mEnginer.postEvent(str, str2);
            }
        }
    }

    @Override // com.baidu.speech.EventManager
    public void unregisterListener(EventListener eventListener) {
        this.listeners.remove(eventListener);
    }
}
