package com.baidu.speech.asr;

import android.content.Context;
import com.amap.api.maps.model.MyLocationStyle;
import com.baidu.speech.EventListener;
import com.baidu.speech.core.BDSErrorDescription;
import com.baidu.speech.core.BDSMessage;
import com.baidu.speech.core.BDSParamBase;
import com.baidu.speech.core.BDSSDKLoader;
import com.baidu.speech.utils.Policy;
import com.baidu.speech.utils.Utility;
import com.taobao.weex.ui.component.WXImage;
import java.util.HashMap;
import java.util.Vector;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class SlotControl implements BDSSDKLoader.BDSCoreEventListener {
    private static String ASR_PARAM_KEY_NETWORK_STATUS = "asr_param_key_network_status.int";
    private static String ASR_PARAM_KEY_PLATFORM = "asr_param_key_platform.string";
    private static String ASR_PARAM_KEY_SDK_VERSION = "asr_param_key_sdk_version.string";
    private static final int PLOADER_ERROR_CODE_REQUEST_ERROR = 2;
    private static final String UPLOADER_CMD_CANCEL = "uploader.cancel";
    private static final String UPLOADER_CMD_CONFIG = "uploader.config";
    private static final String UPLOADER_CMD_START = "uploader.start";
    private static final String UPLOADER_CUID = "upl_param_key_cuid.string";
    private static final int UPLOADER_ERROR_CODE_NET_UNAVAILAVLE = 4;
    private static final int UPLOADER_ERROR_CODE_OK = 0;
    private static final int UPLOADER_ERROR_CODE_PARAM_ERROR = 1;
    private static final int UPLOADER_ERROR_CODE_RESPONSE_ERROR = 3;
    private static final String UPLOADER_NET_STATUS_KEY = "upl_param_key_network_status.int";
    private static final String UPLOADER_PRODUCT_ID = "upl_param_key_product_id.string";
    private static final String UPLOADER_SLOT_NAME_KEY = "upl_param_key_upload_slot_name.string";
    private static final String UPLOADER_URL = "upl_param_key_url.string";
    private static final String UPLOADER_WORDS_KEY = "upl_param_key_upload_words.vector<string>";
    private Context context;
    private EventListener mListener;
    private JSONObject mParams;
    private BDSSDKLoader.BDSSDKInterface m_Uploadcore;
    private String outFile = null;

    public SlotControl(Context context2) throws Exception {
        this.context = context2;
        try {
            BDSSDKLoader.loadLibraries();
            BDSSDKLoader.BDSSDKInterface sDKObjectForSDKType = BDSSDKLoader.getSDKObjectForSDKType("UploaderCore", context2);
            this.m_Uploadcore = sDKObjectForSDKType;
            if (sDKObjectForSDKType == null) {
                throw new Exception("ASR core support is not linked in package");
            } else if (sDKObjectForSDKType.instanceInitialized()) {
                this.m_Uploadcore.setListener(this);
            } else {
                throw new Exception("Failed initialize ASR Core native layer");
            }
        } catch (Exception e) {
            throw new Exception("Can not load so library");
        }
    }

    private void asrCallBack(BDSMessage bDSMessage, EventListener eventListener) {
        if (bDSMessage.m_messageName.equals(SpeechConstant.UPLOAD_CALLBACK_NAME)) {
            int i = ((BDSParamBase.BDSIntParam) bDSMessage.m_messageParams.get(SpeechConstant.CALLBACK_ERROR_DOMAIN)).iValue;
            int i2 = ((BDSParamBase.BDSIntParam) bDSMessage.m_messageParams.get(SpeechConstant.CALLBACK_ERROR_CODE)).iValue;
            HashMap hashMap = new HashMap();
            hashMap.put("errorDomain", Integer.valueOf(i));
            hashMap.put(MyLocationStyle.ERROR_CODE, Integer.valueOf(i2));
            hashMap.put(WXImage.ERRORDESC, (String) ((BDSParamBase.BDSObjectParam) bDSMessage.m_messageParams.get(SpeechConstant.CALLBACK_ERROR_DESC)).iValue);
            eventListener.onEvent(SpeechConstant.CALLBACK_EVENT_UPLOAD_FINISH, new JSONObject(hashMap).toString(), null, 0, 0);
        }
    }

    private BDSErrorDescription postEvent(BDSErrorDescription bDSErrorDescription, String str) {
        BDSMessage bDSMessage = new BDSMessage();
        bDSMessage.m_messageName = str;
        bDSMessage.m_messageParams = new HashMap<>();
        this.mParams.optString(SpeechConstant.APP_NAME, Policy.app(this.context));
        String optString = this.mParams.optString("pid");
        String optString2 = this.mParams.optString("url", "https://upl.baidu.com//words/add");
        String optString3 = this.mParams.optString("decoder-server.uid", Policy.uid(this.context));
        bDSMessage.m_messageParams.put(ASR_PARAM_KEY_PLATFORM, BDSParamBase.objectParam("Android", "java.lang.String"));
        bDSMessage.m_messageParams.put(ASR_PARAM_KEY_SDK_VERSION, BDSParamBase.objectParam("C++ ASR core", "java.lang.String"));
        bDSMessage.m_messageParams.put(UPLOADER_NET_STATUS_KEY, BDSParamBase.intParam(Utility.getWifiOr2gOr3G(this.context)));
        bDSMessage.m_messageParams.put(UPLOADER_PRODUCT_ID, BDSParamBase.objectParam(optString, "java.lang.String"));
        bDSMessage.m_messageParams.put(UPLOADER_URL, BDSParamBase.objectParam(optString2, "java.lang.String"));
        bDSMessage.m_messageParams.put(UPLOADER_CUID, BDSParamBase.objectParam(optString3, "java.lang.String"));
        int postMessage = this.m_Uploadcore.postMessage(bDSMessage);
        if (postMessage == 0) {
            return bDSErrorDescription;
        }
        BDSErrorDescription bDSErrorDescription2 = new BDSErrorDescription();
        bDSErrorDescription2.errorCode = -2;
        bDSErrorDescription2.errorDomain = 1;
        bDSErrorDescription2.errorDescription = "JNI: readyParamsAsrStart Call to Native layer returned error! err( " + postMessage + " )";
        return bDSErrorDescription2;
    }

    private BDSErrorDescription uploadSlotWords(BDSErrorDescription bDSErrorDescription, JSONObject jSONObject) {
        String optString = jSONObject.optString("name");
        JSONArray optJSONArray = jSONObject.optJSONArray(SpeechConstant.WP_WORDS);
        if (!this.m_Uploadcore.instanceInitialized()) {
            return bDSErrorDescription;
        }
        BDSMessage bDSMessage = new BDSMessage();
        bDSMessage.m_messageName = UPLOADER_CMD_CONFIG;
        bDSMessage.m_messageParams = new HashMap<>();
        Vector vector = new Vector();
        if (optJSONArray != null) {
            for (int i = 0; i < optJSONArray.length(); i++) {
                try {
                    vector.add(optJSONArray.getString(i));
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
        bDSMessage.m_messageParams.put(ASR_PARAM_KEY_PLATFORM, BDSParamBase.objectParam("Android", "java.lang.String"));
        bDSMessage.m_messageParams.put(ASR_PARAM_KEY_SDK_VERSION, BDSParamBase.objectParam("C++ ASR core", "java.lang.String"));
        bDSMessage.m_messageParams.put(UPLOADER_NET_STATUS_KEY, BDSParamBase.intParam(Utility.getWifiOr2gOr3G(this.context)));
        bDSMessage.m_messageParams.put(UPLOADER_SLOT_NAME_KEY, BDSParamBase.objectParam(optString, "java.lang.String"));
        bDSMessage.m_messageParams.put(UPLOADER_WORDS_KEY, BDSParamBase.objectParam(vector, "java.util.Vector;"));
        int postMessage = this.m_Uploadcore.postMessage(bDSMessage);
        if (postMessage == 0) {
            return bDSErrorDescription;
        }
        BDSErrorDescription bDSErrorDescription2 = new BDSErrorDescription();
        bDSErrorDescription2.errorCode = -2;
        bDSErrorDescription2.errorDomain = 1;
        bDSErrorDescription2.errorDescription = "JNI: readyParamsAsrStart Call to Native layer returned error! err( " + postMessage + " )";
        return bDSErrorDescription2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0047 A[RETURN] */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0048  */
    public BDSErrorDescription postEvent(String str, String str2) {
        if (!this.m_Uploadcore.instanceInitialized()) {
            BDSErrorDescription bDSErrorDescription = new BDSErrorDescription();
            bDSErrorDescription.errorCode = -1;
            bDSErrorDescription.errorDomain = 1;
            bDSErrorDescription.errorDescription = "JNI: ASR Core native layer is not initialized!";
            return bDSErrorDescription;
        }
        if (str2 != null) {
            try {
                if (!str2.equals("")) {
                    this.mParams = new JSONObject(str2);
                    BDSErrorDescription uploadSlotWords = uploadSlotWords(null, this.mParams);
                    return uploadSlotWords == null ? uploadSlotWords : postEvent(uploadSlotWords, str);
                }
            } catch (JSONException e) {
                e.printStackTrace();
                this.mParams = new JSONObject();
            }
        }
        this.mParams = new JSONObject();
        BDSErrorDescription uploadSlotWords2 = uploadSlotWords(null, this.mParams);
        if (uploadSlotWords2 == null) {
        }
    }

    @Override // com.baidu.speech.core.BDSSDKLoader.BDSCoreEventListener
    public void receiveCoreEvent(BDSMessage bDSMessage, BDSSDKLoader.BDSSDKInterface bDSSDKInterface) {
        EventListener eventListener = this.mListener;
        if (eventListener != null && bDSMessage != null) {
            asrCallBack(bDSMessage, eventListener);
        }
    }

    public void setListener(EventListener eventListener) {
        this.mListener = eventListener;
    }
}
