package com.coremedia.iso;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.coremedia.iso.boxes.UserBox;
import com.googlecode.mp4parser.util.CastUtils;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.util.logging.Logger;

public abstract class AbstractBoxParser implements BoxParser {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static Logger LOG = Logger.getLogger(AbstractBoxParser.class.getName());

    public abstract Box createBox(String str, byte[] bArr, String str2);

    @Override // com.coremedia.iso.BoxParser
    public Box parseBox(ReadableByteChannel byteChannel, ContainerBox parent) throws IOException {
        long size;
        long contentSize;
        byte[] usertype;
        long contentSize2;
        ByteBuffer header;
        ByteBuffer header2 = ChannelHelper.readFully(byteChannel, 8);
        long size2 = IsoTypeReader.readUInt32(header2);
        if (size2 >= 8 || size2 <= 1) {
            String type = IsoTypeReader.read4cc(header2);
            if (size2 == 1) {
                ByteBuffer bb = ByteBuffer.allocate(8);
                byteChannel.read(bb);
                bb.rewind();
                long size3 = IsoTypeReader.readUInt64(bb);
                contentSize = size3 - 16;
                size = size3;
            } else if (size2 != 0) {
                contentSize = size2 - 8;
                size = size2;
            } else if (byteChannel instanceof FileChannel) {
                long size4 = (((FileChannel) byteChannel).size() - ((FileChannel) byteChannel).position()) - 8;
                contentSize = size4 - 8;
                size = size4;
            } else {
                throw new RuntimeException("Only FileChannel inputs may use size == 0 (box reaches to the end of file)");
            }
            if (UserBox.TYPE.equals(type)) {
                ByteBuffer bb2 = ByteBuffer.allocate(16);
                byteChannel.read(bb2);
                bb2.rewind();
                contentSize2 = contentSize - 16;
                usertype = bb2.array();
            } else {
                contentSize2 = contentSize;
                usertype = null;
            }
            Box box = createBox(type, usertype, parent.getType());
            box.setParent(parent);
            LOG.finest("Parsing " + box.getType());
            if (CastUtils.l2i(size - contentSize2) == 8) {
                header2.rewind();
                header = header2;
            } else if (CastUtils.l2i(size - contentSize2) == 16) {
                ByteBuffer header3 = ByteBuffer.allocate(16);
                IsoTypeWriter.writeUInt32(header3, 1);
                header3.put(IsoFile.fourCCtoBytes(type));
                IsoTypeWriter.writeUInt64(header3, size);
                header = header3;
            } else if (CastUtils.l2i(size - contentSize2) == 24) {
                ByteBuffer header4 = ByteBuffer.allocate(24);
                IsoTypeWriter.writeUInt32(header4, size);
                header4.put(IsoFile.fourCCtoBytes(type));
                header4.put(usertype);
                header = header4;
            } else if (CastUtils.l2i(size - contentSize2) == 32) {
                ByteBuffer header5 = ByteBuffer.allocate(32);
                IsoTypeWriter.writeUInt32(header5, size);
                header5.put(IsoFile.fourCCtoBytes(type));
                IsoTypeWriter.writeUInt64(header5, size);
                header5.put(usertype);
                header = header5;
            } else {
                throw new RuntimeException("I didn't expect that");
            }
            box.parse(byteChannel, header, contentSize2, this);
            return box;
        }
        LOG.severe("Plausibility check failed: size < 8 (size = " + size2 + "). Stop parsing!");
        return null;
    }
}
