package com.coremedia.iso;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.MovieBox;
import com.googlecode.mp4parser.AbstractContainerBox;
import com.googlecode.mp4parser.annotations.DoNotParseDetail;
import com.taobao.weex.el.parse.Operators;
import java.io.Closeable;
import java.io.EOFException;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import net.lingala.zip4j.util.InternalZipConstants;

@DoNotParseDetail
public class IsoFile extends AbstractContainerBox implements Closeable {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    protected BoxParser boxParser;
    ReadableByteChannel byteChannel;

    public IsoFile() {
        super("");
        this.boxParser = new PropertyBoxParserImpl(new String[0]);
    }

    public IsoFile(File f) throws IOException {
        super("");
        this.boxParser = new PropertyBoxParserImpl(new String[0]);
        this.byteChannel = new FileInputStream(f).getChannel();
        this.boxParser = createBoxParser();
        parse();
    }

    public IsoFile(ReadableByteChannel byteChannel2) throws IOException {
        super("");
        this.boxParser = new PropertyBoxParserImpl(new String[0]);
        this.byteChannel = byteChannel2;
        this.boxParser = createBoxParser();
        parse();
    }

    public IsoFile(ReadableByteChannel byteChannel2, BoxParser boxParser2) throws IOException {
        super("");
        this.boxParser = new PropertyBoxParserImpl(new String[0]);
        this.byteChannel = byteChannel2;
        this.boxParser = boxParser2;
        parse();
    }

    /* access modifiers changed from: protected */
    public BoxParser createBoxParser() {
        return new PropertyBoxParserImpl(new String[0]);
    }

    @Override // com.googlecode.mp4parser.AbstractContainerBox, com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
    }

    public void parse(ReadableByteChannel inFC, ByteBuffer header, long contentSize, AbstractBoxParser abstractBoxParser) throws IOException {
        throw new IOException("This method is not meant to be called. Use #parse() directly.");
    }

    private void parse() throws IOException {
        boolean done = false;
        while (!done) {
            try {
                Box box = this.boxParser.parseBox(this.byteChannel, this);
                if (box != null) {
                    this.boxes.add(box);
                } else {
                    done = true;
                }
            } catch (EOFException e) {
                done = true;
            }
        }
    }

    @Override // com.googlecode.mp4parser.AbstractContainerBox
    @DoNotParseDetail
    public String toString() {
        StringBuilder buffer = new StringBuilder();
        buffer.append("IsoFile[");
        if (this.boxes == null) {
            buffer.append("unparsed");
        } else {
            for (int i = 0; i < this.boxes.size(); i++) {
                if (i > 0) {
                    buffer.append(i.b);
                }
                buffer.append(((Box) this.boxes.get(i)).toString());
            }
        }
        buffer.append(Operators.ARRAY_END_STR);
        return buffer.toString();
    }

    @DoNotParseDetail
    public static byte[] fourCCtoBytes(String fourCC) {
        byte[] result = new byte[4];
        if (fourCC != null) {
            for (int i = 0; i < Math.min(4, fourCC.length()); i++) {
                result[i] = (byte) fourCC.charAt(i);
            }
        }
        return result;
    }

    @DoNotParseDetail
    public static String bytesToFourCC(byte[] type) {
        byte[] result = {0, 0, 0, 0};
        if (type != null) {
            System.arraycopy(type, 0, result, 0, Math.min(type.length, 4));
        }
        try {
            return new String(result, InternalZipConstants.AES_HASH_CHARSET);
        } catch (UnsupportedEncodingException e) {
            throw new Error("Required character encoding is missing", e);
        }
    }

    @Override // com.googlecode.mp4parser.AbstractContainerBox, com.coremedia.iso.boxes.ContainerBox
    public long getNumOfBytesToFirstChild() {
        return 0;
    }

    @Override // com.coremedia.iso.boxes.Box, com.googlecode.mp4parser.AbstractBox
    public long getSize() {
        long size = 0;
        for (Box box : this.boxes) {
            size += box.getSize();
        }
        return size;
    }

    @Override // com.coremedia.iso.boxes.ContainerBox, com.googlecode.mp4parser.AbstractBox
    public IsoFile getIsoFile() {
        return this;
    }

    @DoNotParseDetail
    public MovieBox getMovieBox() {
        for (Box box : this.boxes) {
            if (box instanceof MovieBox) {
                return (MovieBox) box;
            }
        }
        return null;
    }

    @Override // com.coremedia.iso.boxes.Box, com.googlecode.mp4parser.AbstractBox
    public void getBox(WritableByteChannel os) throws IOException {
        for (Box box : this.boxes) {
            if (os instanceof FileChannel) {
                long startPos = ((FileChannel) os).position();
                box.getBox(os);
                long position = ((FileChannel) os).position() - startPos;
            } else {
                box.getBox(os);
            }
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this.byteChannel.close();
    }
}
