package com.coremedia.iso.boxes;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.Utf8;
import com.googlecode.mp4parser.AbstractFullBox;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;

public class AlbumBox extends AbstractFullBox {
    public static final String TYPE = "albm";
    private String albumTitle;
    private String language;
    private int trackNumber;

    public AlbumBox() {
        super(TYPE);
    }

    public String getLanguage() {
        return this.language;
    }

    public String getAlbumTitle() {
        return this.albumTitle;
    }

    public int getTrackNumber() {
        return this.trackNumber;
    }

    public void setLanguage(String language2) {
        this.language = language2;
    }

    public void setAlbumTitle(String albumTitle2) {
        this.albumTitle = albumTitle2;
    }

    public void setTrackNumber(int trackNumber2) {
        this.trackNumber = trackNumber2;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        int i = 1;
        int utf8StringLengthInBytes = Utf8.utf8StringLengthInBytes(this.albumTitle) + 6 + 1;
        if (this.trackNumber == -1) {
            i = 0;
        }
        return (long) (utf8StringLengthInBytes + i);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        this.language = IsoTypeReader.readIso639(content);
        this.albumTitle = IsoTypeReader.readString(content);
        if (content.remaining() > 0) {
            this.trackNumber = IsoTypeReader.readUInt8(content);
        } else {
            this.trackNumber = -1;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        IsoTypeWriter.writeIso639(byteBuffer, this.language);
        byteBuffer.put(Utf8.convert(this.albumTitle));
        byteBuffer.put((byte) 0);
        int i = this.trackNumber;
        if (i != -1) {
            IsoTypeWriter.writeUInt8(byteBuffer, i);
        }
    }

    public String toString() {
        StringBuilder buffer = new StringBuilder();
        buffer.append("AlbumBox[language=");
        buffer.append(getLanguage());
        buffer.append(i.b);
        buffer.append("albumTitle=");
        buffer.append(getAlbumTitle());
        if (this.trackNumber >= 0) {
            buffer.append(";trackNumber=");
            buffer.append(getTrackNumber());
        }
        buffer.append(Operators.ARRAY_END_STR);
        return buffer.toString();
    }
}
