package com.coremedia.iso.boxes;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractFullBox;
import com.googlecode.mp4parser.util.CastUtils;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class CompositionTimeToSample extends AbstractFullBox {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String TYPE = "ctts";
    List<Entry> entries = Collections.emptyList();

    public CompositionTimeToSample() {
        super(TYPE);
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return (long) ((this.entries.size() * 8) + 8);
    }

    public List<Entry> getEntries() {
        return this.entries;
    }

    public void setEntries(List<Entry> entries2) {
        this.entries = entries2;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        int numberOfEntries = CastUtils.l2i(IsoTypeReader.readUInt32(content));
        this.entries = new ArrayList(numberOfEntries);
        for (int i = 0; i < numberOfEntries; i++) {
            this.entries.add(new Entry(CastUtils.l2i(IsoTypeReader.readUInt32(content)), content.getInt()));
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        IsoTypeWriter.writeUInt32(byteBuffer, (long) this.entries.size());
        for (Entry entry : this.entries) {
            IsoTypeWriter.writeUInt32(byteBuffer, (long) entry.getCount());
            byteBuffer.putInt(entry.getOffset());
        }
    }

    public static class Entry {
        int count;
        int offset;

        public Entry(int count2, int offset2) {
            this.count = count2;
            this.offset = offset2;
        }

        public int getCount() {
            return this.count;
        }

        public int getOffset() {
            return this.offset;
        }

        public void setCount(int count2) {
            this.count = count2;
        }

        public void setOffset(int offset2) {
            this.offset = offset2;
        }

        public String toString() {
            return "Entry{count=" + this.count + ", offset=" + this.offset + Operators.BLOCK_END;
        }
    }

    public static int[] blowupCompositionTimes(List<Entry> entries2) {
        long numOfSamples = 0;
        for (Entry entry : entries2) {
            numOfSamples += (long) entry.getCount();
        }
        int[] decodingTime = new int[((int) numOfSamples)];
        int current = 0;
        for (Entry entry2 : entries2) {
            int i = 0;
            while (i < entry2.getCount()) {
                decodingTime[current] = entry2.getOffset();
                i++;
                current++;
            }
        }
        return decodingTime;
    }
}
