package com.coremedia.iso.boxes;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.IsoFile;
import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractBox;
import com.googlecode.mp4parser.annotations.DoNotParseDetail;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

public class FileTypeBox extends AbstractBox {
    public static final String TYPE = "ftyp";
    private List<String> compatibleBrands = Collections.emptyList();
    private String majorBrand;
    private long minorVersion;

    public FileTypeBox() {
        super(TYPE);
    }

    public FileTypeBox(String majorBrand2, long minorVersion2, List<String> compatibleBrands2) {
        super(TYPE);
        this.majorBrand = majorBrand2;
        this.minorVersion = minorVersion2;
        this.compatibleBrands = compatibleBrands2;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return (long) ((this.compatibleBrands.size() * 4) + 8);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        this.majorBrand = IsoTypeReader.read4cc(content);
        this.minorVersion = IsoTypeReader.readUInt32(content);
        int compatibleBrandsCount = content.remaining() / 4;
        this.compatibleBrands = new LinkedList();
        for (int i = 0; i < compatibleBrandsCount; i++) {
            this.compatibleBrands.add(IsoTypeReader.read4cc(content));
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        byteBuffer.put(IsoFile.fourCCtoBytes(this.majorBrand));
        IsoTypeWriter.writeUInt32(byteBuffer, this.minorVersion);
        for (String compatibleBrand : this.compatibleBrands) {
            byteBuffer.put(IsoFile.fourCCtoBytes(compatibleBrand));
        }
    }

    public String getMajorBrand() {
        return this.majorBrand;
    }

    public void setMajorBrand(String majorBrand2) {
        this.majorBrand = majorBrand2;
    }

    public void setMinorVersion(int minorVersion2) {
        this.minorVersion = (long) minorVersion2;
    }

    public long getMinorVersion() {
        return this.minorVersion;
    }

    public List<String> getCompatibleBrands() {
        return this.compatibleBrands;
    }

    public void setCompatibleBrands(List<String> compatibleBrands2) {
        this.compatibleBrands = compatibleBrands2;
    }

    @DoNotParseDetail
    public String toString() {
        StringBuilder result = new StringBuilder();
        result.append("FileTypeBox[");
        result.append("majorBrand=");
        result.append(getMajorBrand());
        result.append(i.b);
        result.append("minorVersion=");
        result.append(getMinorVersion());
        for (String compatibleBrand : this.compatibleBrands) {
            result.append(i.b);
            result.append("compatibleBrand=");
            result.append(compatibleBrand);
        }
        result.append(Operators.ARRAY_END_STR);
        return result.toString();
    }
}
