package com.coremedia.iso.boxes;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.Utf8;
import com.googlecode.mp4parser.AbstractFullBox;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;

public class KeywordsBox extends AbstractFullBox {
    public static final String TYPE = "kywd";
    private String[] keywords;
    private String language;

    public KeywordsBox() {
        super(TYPE);
    }

    public String getLanguage() {
        return this.language;
    }

    public String[] getKeywords() {
        return this.keywords;
    }

    public void setLanguage(String language2) {
        this.language = language2;
    }

    public void setKeywords(String[] keywords2) {
        this.keywords = keywords2;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long contentSize = 7;
        for (String keyword : this.keywords) {
            contentSize += (long) (Utf8.utf8StringLengthInBytes(keyword) + 1 + 1);
        }
        return contentSize;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        this.language = IsoTypeReader.readIso639(content);
        int keywordCount = IsoTypeReader.readUInt8(content);
        this.keywords = new String[keywordCount];
        for (int i = 0; i < keywordCount; i++) {
            IsoTypeReader.readUInt8(content);
            this.keywords[i] = IsoTypeReader.readString(content);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        IsoTypeWriter.writeIso639(byteBuffer, this.language);
        IsoTypeWriter.writeUInt8(byteBuffer, this.keywords.length);
        String[] strArr = this.keywords;
        for (String keyword : strArr) {
            IsoTypeWriter.writeUInt8(byteBuffer, Utf8.utf8StringLengthInBytes(keyword) + 1);
            byteBuffer.put(Utf8.convert(keyword));
        }
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer();
        buffer.append("KeywordsBox[language=");
        buffer.append(getLanguage());
        for (int i = 0; i < this.keywords.length; i++) {
            buffer.append(";keyword");
            buffer.append(i);
            buffer.append("=");
            buffer.append(this.keywords[i]);
        }
        buffer.append(Operators.ARRAY_END_STR);
        return buffer.toString();
    }
}
