package com.coremedia.iso.boxes;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractFullBox;
import com.googlecode.mp4parser.authoring.DateHelper;
import com.googlecode.mp4parser.util.Matrix;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.Date;

public class MovieHeaderBox extends AbstractFullBox {
    public static final String TYPE = "mvhd";
    private Date creationTime;
    private int currentTime;
    private long duration;
    private Matrix matrix = Matrix.ROTATE_0;
    private Date modificationTime;
    private long nextTrackId;
    private int posterTime;
    private int previewDuration;
    private int previewTime;
    private double rate = 1.0d;
    private int selectionDuration;
    private int selectionTime;
    private long timescale;
    private float volume = 1.0f;

    public MovieHeaderBox() {
        super(TYPE);
    }

    public Date getCreationTime() {
        return this.creationTime;
    }

    public Date getModificationTime() {
        return this.modificationTime;
    }

    public long getTimescale() {
        return this.timescale;
    }

    public long getDuration() {
        return this.duration;
    }

    public double getRate() {
        return this.rate;
    }

    public float getVolume() {
        return this.volume;
    }

    public Matrix getMatrix() {
        return this.matrix;
    }

    public long getNextTrackId() {
        return this.nextTrackId;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long contentSize;
        if (getVersion() == 1) {
            contentSize = 4 + 28;
        } else {
            contentSize = 4 + 16;
        }
        return contentSize + 80;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        if (getVersion() == 1) {
            this.creationTime = DateHelper.convert(IsoTypeReader.readUInt64(content));
            this.modificationTime = DateHelper.convert(IsoTypeReader.readUInt64(content));
            this.timescale = IsoTypeReader.readUInt32(content);
            this.duration = IsoTypeReader.readUInt64(content);
        } else {
            this.creationTime = DateHelper.convert(IsoTypeReader.readUInt32(content));
            this.modificationTime = DateHelper.convert(IsoTypeReader.readUInt32(content));
            this.timescale = IsoTypeReader.readUInt32(content);
            this.duration = IsoTypeReader.readUInt32(content);
        }
        this.rate = IsoTypeReader.readFixedPoint1616(content);
        this.volume = IsoTypeReader.readFixedPoint88(content);
        IsoTypeReader.readUInt16(content);
        IsoTypeReader.readUInt32(content);
        IsoTypeReader.readUInt32(content);
        this.matrix = Matrix.fromByteBuffer(content);
        this.previewTime = content.getInt();
        this.previewDuration = content.getInt();
        this.posterTime = content.getInt();
        this.selectionTime = content.getInt();
        this.selectionDuration = content.getInt();
        this.currentTime = content.getInt();
        this.nextTrackId = IsoTypeReader.readUInt32(content);
    }

    public String toString() {
        return "MovieHeaderBox[" + "creationTime=" + getCreationTime() + i.b + "modificationTime=" + getModificationTime() + i.b + "timescale=" + getTimescale() + i.b + "duration=" + getDuration() + i.b + "rate=" + getRate() + i.b + "volume=" + getVolume() + i.b + "matrix=" + this.matrix + i.b + "nextTrackId=" + getNextTrackId() + Operators.ARRAY_END_STR;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        if (getVersion() == 1) {
            IsoTypeWriter.writeUInt64(byteBuffer, DateHelper.convert(this.creationTime));
            IsoTypeWriter.writeUInt64(byteBuffer, DateHelper.convert(this.modificationTime));
            IsoTypeWriter.writeUInt32(byteBuffer, this.timescale);
            IsoTypeWriter.writeUInt64(byteBuffer, this.duration);
        } else {
            IsoTypeWriter.writeUInt32(byteBuffer, DateHelper.convert(this.creationTime));
            IsoTypeWriter.writeUInt32(byteBuffer, DateHelper.convert(this.modificationTime));
            IsoTypeWriter.writeUInt32(byteBuffer, this.timescale);
            IsoTypeWriter.writeUInt32(byteBuffer, this.duration);
        }
        IsoTypeWriter.writeFixedPoint1616(byteBuffer, this.rate);
        IsoTypeWriter.writeFixedPont88(byteBuffer, (double) this.volume);
        IsoTypeWriter.writeUInt16(byteBuffer, 0);
        IsoTypeWriter.writeUInt32(byteBuffer, 0);
        IsoTypeWriter.writeUInt32(byteBuffer, 0);
        this.matrix.getContent(byteBuffer);
        byteBuffer.putInt(this.previewTime);
        byteBuffer.putInt(this.previewDuration);
        byteBuffer.putInt(this.posterTime);
        byteBuffer.putInt(this.selectionTime);
        byteBuffer.putInt(this.selectionDuration);
        byteBuffer.putInt(this.currentTime);
        IsoTypeWriter.writeUInt32(byteBuffer, this.nextTrackId);
    }

    public void setCreationTime(Date creationTime2) {
        this.creationTime = creationTime2;
    }

    public void setModificationTime(Date modificationTime2) {
        this.modificationTime = modificationTime2;
    }

    public void setTimescale(long timescale2) {
        this.timescale = timescale2;
    }

    public void setDuration(long duration2) {
        this.duration = duration2;
    }

    public void setRate(double rate2) {
        this.rate = rate2;
    }

    public void setVolume(float volume2) {
        this.volume = volume2;
    }

    public void setMatrix(Matrix matrix2) {
        this.matrix = matrix2;
    }

    public void setNextTrackId(long nextTrackId2) {
        this.nextTrackId = nextTrackId2;
    }

    public int getPreviewTime() {
        return this.previewTime;
    }

    public void setPreviewTime(int previewTime2) {
        this.previewTime = previewTime2;
    }

    public int getPreviewDuration() {
        return this.previewDuration;
    }

    public void setPreviewDuration(int previewDuration2) {
        this.previewDuration = previewDuration2;
    }

    public int getPosterTime() {
        return this.posterTime;
    }

    public void setPosterTime(int posterTime2) {
        this.posterTime = posterTime2;
    }

    public int getSelectionTime() {
        return this.selectionTime;
    }

    public void setSelectionTime(int selectionTime2) {
        this.selectionTime = selectionTime2;
    }

    public int getSelectionDuration() {
        return this.selectionDuration;
    }

    public void setSelectionDuration(int selectionDuration2) {
        this.selectionDuration = selectionDuration2;
    }

    public int getCurrentTime() {
        return this.currentTime;
    }

    public void setCurrentTime(int currentTime2) {
        this.currentTime = currentTime2;
    }
}
