package com.coremedia.iso.boxes;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractFullBox;
import com.googlecode.mp4parser.util.CastUtils;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class TimeToSampleBox extends AbstractFullBox {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final String TYPE = "stts";
    List<Entry> entries = Collections.emptyList();

    public TimeToSampleBox() {
        super(TYPE);
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return (long) ((this.entries.size() * 8) + 8);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        int entryCount = CastUtils.l2i(IsoTypeReader.readUInt32(content));
        this.entries = new ArrayList(entryCount);
        for (int i = 0; i < entryCount; i++) {
            this.entries.add(new Entry(IsoTypeReader.readUInt32(content), IsoTypeReader.readUInt32(content)));
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        IsoTypeWriter.writeUInt32(byteBuffer, (long) this.entries.size());
        for (Entry entry : this.entries) {
            IsoTypeWriter.writeUInt32(byteBuffer, entry.getCount());
            IsoTypeWriter.writeUInt32(byteBuffer, entry.getDelta());
        }
    }

    public List<Entry> getEntries() {
        return this.entries;
    }

    public void setEntries(List<Entry> entries2) {
        this.entries = entries2;
    }

    public String toString() {
        return "TimeToSampleBox[entryCount=" + this.entries.size() + Operators.ARRAY_END_STR;
    }

    public static class Entry {
        long count;
        long delta;

        public Entry(long count2, long delta2) {
            this.count = count2;
            this.delta = delta2;
        }

        public long getCount() {
            return this.count;
        }

        public long getDelta() {
            return this.delta;
        }

        public void setCount(long count2) {
            this.count = count2;
        }

        public void setDelta(long delta2) {
            this.delta = delta2;
        }

        public String toString() {
            return "Entry{count=" + this.count + ", delta=" + this.delta + Operators.BLOCK_END;
        }
    }

    public static long[] blowupTimeToSamples(List<Entry> entries2) {
        long numOfSamples = 0;
        for (Entry entry : entries2) {
            numOfSamples += entry.getCount();
        }
        long[] decodingTime = new long[((int) numOfSamples)];
        int current = 0;
        for (Entry entry2 : entries2) {
            int i = 0;
            while (((long) i) < entry2.getCount()) {
                decodingTime[current] = entry2.getDelta();
                i++;
                current++;
            }
        }
        return decodingTime;
    }
}
