package com.coremedia.iso.boxes.apple;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.Utf8;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.googlecode.mp4parser.AbstractBox;
import com.googlecode.mp4parser.util.ByteBufferByteChannel;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.IApp;
import java.io.IOException;
import java.math.BigInteger;
import java.nio.ByteBuffer;
import java.util.Collections;
import java.util.List;
import java.util.logging.Logger;

public abstract class AbstractAppleMetaDataBox extends AbstractBox implements ContainerBox {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static Logger LOG = Logger.getLogger(AbstractAppleMetaDataBox.class.getName());
    AppleDataBox appleDataBox = new AppleDataBox();

    @Override // com.coremedia.iso.boxes.ContainerBox
    public List<Box> getBoxes() {
        return Collections.singletonList(this.appleDataBox);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public void setBoxes(List<Box> boxes) {
        if (boxes.size() != 1 || !(boxes.get(0) instanceof AppleDataBox)) {
            throw new IllegalArgumentException("This box only accepts one AppleDataBox child");
        }
        this.appleDataBox = (AppleDataBox) boxes.get(0);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz) {
        return getBoxes(clazz, false);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz, boolean recursive) {
        if (clazz.isAssignableFrom(this.appleDataBox.getClass())) {
            return Collections.singletonList(this.appleDataBox);
        }
        return null;
    }

    public AbstractAppleMetaDataBox(String type) {
        super(type);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        IsoTypeReader.readUInt32(content);
        IsoTypeReader.read4cc(content);
        AppleDataBox appleDataBox2 = new AppleDataBox();
        this.appleDataBox = appleDataBox2;
        try {
            appleDataBox2.parse(new ByteBufferByteChannel(content), null, (long) content.remaining(), null);
            this.appleDataBox.setParent(this);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return this.appleDataBox.getSize();
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        try {
            this.appleDataBox.getBox(new ByteBufferByteChannel(byteBuffer));
        } catch (IOException e) {
            throw new RuntimeException("The Channel is based on a ByteBuffer and therefore it shouldn't throw any exception");
        }
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public long getNumOfBytesToFirstChild() {
        return getSize() - this.appleDataBox.getSize();
    }

    public String toString() {
        return getClass().getSimpleName() + "{appleDataBox=" + getValue() + Operators.BLOCK_END;
    }

    static long toLong(byte b) {
        return b < 0 ? (long) (b + 256) : (long) b;
    }

    public void setValue(String value) {
        if (this.appleDataBox.getFlags() == 1) {
            AppleDataBox appleDataBox2 = new AppleDataBox();
            this.appleDataBox = appleDataBox2;
            appleDataBox2.setVersion(0);
            this.appleDataBox.setFlags(1);
            this.appleDataBox.setFourBytes(new byte[4]);
            this.appleDataBox.setData(Utf8.convert(value));
        } else if (this.appleDataBox.getFlags() == 21) {
            byte[] content = this.appleDataBox.getData();
            AppleDataBox appleDataBox3 = new AppleDataBox();
            this.appleDataBox = appleDataBox3;
            appleDataBox3.setVersion(0);
            this.appleDataBox.setFlags(21);
            this.appleDataBox.setFourBytes(new byte[4]);
            ByteBuffer bb = ByteBuffer.allocate(content.length);
            if (content.length == 1) {
                IsoTypeWriter.writeUInt8(bb, Byte.parseByte(value) & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
            } else if (content.length == 2) {
                IsoTypeWriter.writeUInt16(bb, Integer.parseInt(value));
            } else if (content.length == 4) {
                IsoTypeWriter.writeUInt32(bb, Long.parseLong(value));
            } else if (content.length == 8) {
                IsoTypeWriter.writeUInt64(bb, Long.parseLong(value));
            } else {
                throw new Error("The content length within the appleDataBox is neither 1, 2, 4 or 8. I can't handle that!");
            }
            this.appleDataBox.setData(bb.array());
        } else if (this.appleDataBox.getFlags() == 0) {
            AppleDataBox appleDataBox4 = new AppleDataBox();
            this.appleDataBox = appleDataBox4;
            appleDataBox4.setVersion(0);
            this.appleDataBox.setFlags(0);
            this.appleDataBox.setFourBytes(new byte[4]);
            this.appleDataBox.setData(hexStringToByteArray(value));
        } else {
            Logger logger = LOG;
            logger.warning("Don't know how to handle appleDataBox with flag=" + this.appleDataBox.getFlags());
        }
    }

    public String getValue() {
        if (this.appleDataBox.getFlags() == 1) {
            return Utf8.convert(this.appleDataBox.getData());
        }
        int i = 0;
        if (this.appleDataBox.getFlags() == 21) {
            byte[] content = this.appleDataBox.getData();
            long l = 0;
            int current = 1;
            int length = content.length;
            int length2 = content.length;
            while (i < length2) {
                l += toLong(content[i]) << ((length - current) * 8);
                i++;
                current++;
            }
            return "" + l;
        } else if (this.appleDataBox.getFlags() != 0) {
            return "unknown";
        } else {
            return String.format("%x", new BigInteger(this.appleDataBox.getData()));
        }
    }

    public static byte[] hexStringToByteArray(String s) {
        int len = s.length();
        byte[] data = new byte[(len / 2)];
        for (int i = 0; i < len; i += 2) {
            data[i / 2] = (byte) ((Character.digit(s.charAt(i), 16) << 4) + Character.digit(s.charAt(i + 1), 16));
        }
        return data;
    }
}
