package com.coremedia.iso.boxes.dece;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractFullBox;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.List;

public class TrickPlayBox extends AbstractFullBox {
    public static final String TYPE = "trik";
    private List<Entry> entries = new ArrayList();

    public TrickPlayBox() {
        super(TYPE);
    }

    public void setEntries(List<Entry> entries2) {
        this.entries = entries2;
    }

    public List<Entry> getEntries() {
        return this.entries;
    }

    public static class Entry {
        private int value;

        public Entry() {
        }

        public Entry(int value2) {
            this.value = value2;
        }

        public int getPicType() {
            return (this.value >> 6) & 3;
        }

        public void setPicType(int picType) {
            int i = this.value & 31;
            this.value = i;
            this.value = i | ((picType & 3) << 6);
        }

        public int getDependencyLevel() {
            return this.value & 63;
        }

        public void setDependencyLevel(int dependencyLevel) {
            this.value = (dependencyLevel & 63) | this.value;
        }

        public String toString() {
            return "Entry" + "{picType=" + getPicType() + ",dependencyLevel=" + getDependencyLevel() + Operators.BLOCK_END;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return (long) (this.entries.size() + 4);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        while (content.remaining() > 0) {
            this.entries.add(new Entry(IsoTypeReader.readUInt8(content)));
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        for (Entry entry : this.entries) {
            IsoTypeWriter.writeUInt8(byteBuffer, entry.value);
        }
    }

    public String toString() {
        return "TrickPlayBox" + "{entries=" + this.entries + Operators.BLOCK_END;
    }
}
