package com.coremedia.iso.boxes.mdat;

import com.coremedia.iso.BoxParser;
import com.coremedia.iso.ChannelHelper;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.googlecode.mp4parser.AbstractBox;
import com.googlecode.mp4parser.util.CastUtils;
import java.io.IOException;
import java.lang.ref.Reference;
import java.lang.ref.SoftReference;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Logger;

public final class MediaDataBox implements Box {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    public static final int BUFFER_SIZE = 10485760;
    private static Logger LOG = Logger.getLogger(MediaDataBox.class.getName());
    public static final String TYPE = "mdat";
    private Map<Long, Reference<ByteBuffer>> cache = new HashMap();
    private ByteBuffer content;
    private long contentSize;
    private FileChannel fileChannel;
    ByteBuffer header;
    ContainerBox parent;
    private long startPosition;

    @Override // com.coremedia.iso.boxes.Box
    public ContainerBox getParent() {
        return this.parent;
    }

    @Override // com.coremedia.iso.boxes.Box
    public void setParent(ContainerBox parent2) {
        this.parent = parent2;
    }

    @Override // com.coremedia.iso.boxes.Box
    public String getType() {
        return TYPE;
    }

    private static void transfer(FileChannel from, long position, long count, WritableByteChannel to) throws IOException {
        long offset = 0;
        while (offset < count) {
            offset += from.transferTo(position + offset, Math.min(67076096L, count - offset), to);
        }
    }

    @Override // com.coremedia.iso.boxes.Box
    public void getBox(WritableByteChannel writableByteChannel) throws IOException {
        FileChannel fileChannel2 = this.fileChannel;
        if (fileChannel2 != null) {
            transfer(fileChannel2, this.startPosition - ((long) this.header.limit()), this.contentSize + ((long) this.header.limit()), writableByteChannel);
            return;
        }
        this.header.rewind();
        writableByteChannel.write(this.header);
        writableByteChannel.write(this.content);
    }

    private boolean checkStillOk() {
        try {
            this.fileChannel.position(this.startPosition - ((long) this.header.limit()));
            ByteBuffer h2 = ByteBuffer.allocate(this.header.limit());
            this.fileChannel.read(h2);
            this.header.rewind();
            h2.rewind();
            return true;
        } catch (IOException e) {
            e.printStackTrace();
            return false;
        }
    }

    @Override // com.coremedia.iso.boxes.Box
    public long getSize() {
        return ((long) this.header.limit()) + this.contentSize;
    }

    @Override // com.coremedia.iso.boxes.Box
    public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header2, long contentSize2, BoxParser boxParser) throws IOException {
        this.header = header2;
        this.contentSize = contentSize2;
        if (!(readableByteChannel instanceof FileChannel) || contentSize2 <= ((long) AbstractBox.MEM_MAP_THRESHOLD)) {
            this.content = ChannelHelper.readFully(readableByteChannel, (long) CastUtils.l2i(contentSize2));
            this.cache.put(0L, new SoftReference(this.content));
            return;
        }
        this.fileChannel = (FileChannel) readableByteChannel;
        this.startPosition = ((FileChannel) readableByteChannel).position();
        ((FileChannel) readableByteChannel).position(((FileChannel) readableByteChannel).position() + contentSize2);
    }

    public synchronized ByteBuffer getContent(long offset, int length) {
        ByteBuffer cacheEntry;
        for (Long chacheEntryOffset : this.cache.keySet()) {
            if (chacheEntryOffset.longValue() <= offset && offset <= chacheEntryOffset.longValue() + 10485760 && (cacheEntry = this.cache.get(chacheEntryOffset).get()) != null && chacheEntryOffset.longValue() + ((long) cacheEntry.limit()) >= ((long) length) + offset) {
                cacheEntry.position((int) (offset - chacheEntryOffset.longValue()));
                ByteBuffer cachedSample = cacheEntry.slice();
                cachedSample.limit(length);
                return cachedSample;
            }
        }
        try {
            ByteBuffer cacheEntry2 = this.fileChannel.map(FileChannel.MapMode.READ_ONLY, this.startPosition + offset, Math.min(10485760L, this.contentSize - offset));
            this.cache.put(Long.valueOf(offset), new SoftReference(cacheEntry2));
            cacheEntry2.position(0);
            ByteBuffer cachedSample2 = cacheEntry2.slice();
            cachedSample2.limit(length);
            return cachedSample2;
        } catch (IOException e1) {
            Logger logger = LOG;
            logger.fine("Even mapping just 10MB of the source file into the memory failed. " + e1);
            throw new RuntimeException("Delayed reading of mdat content failed. Make sure not to close the FileChannel that has been used to create the IsoFile!", e1);
        }
    }

    public ByteBuffer getHeader() {
        return this.header;
    }
}
