package com.coremedia.iso.boxes.mdat;

import com.coremedia.iso.IsoFile;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ChunkOffsetBox;
import com.coremedia.iso.boxes.SampleSizeBox;
import com.coremedia.iso.boxes.SampleToChunkBox;
import com.coremedia.iso.boxes.TrackBox;
import com.coremedia.iso.boxes.fragment.MovieExtendsBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentBox;
import com.coremedia.iso.boxes.fragment.TrackExtendsBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentHeaderBox;
import com.coremedia.iso.boxes.fragment.TrackRunBox;
import com.googlecode.mp4parser.util.CastUtils;
import java.nio.ByteBuffer;
import java.util.AbstractList;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class SampleList extends AbstractList<ByteBuffer> {
    IsoFile isoFile;
    HashMap<MediaDataBox, Long> mdatEndCache;
    HashMap<MediaDataBox, Long> mdatStartCache;
    MediaDataBox[] mdats;
    long[] offsets;
    long[] sizes;

    public long[] getOffsetKeys() {
        return this.offsets;
    }

    public SampleList(TrackBox trackBox) {
        this.mdatStartCache = new HashMap<>();
        this.mdatEndCache = new HashMap<>();
        initIsoFile(trackBox.getIsoFile());
        SampleSizeBox sampleSizeBox = trackBox.getSampleTableBox().getSampleSizeBox();
        ChunkOffsetBox chunkOffsetBox = trackBox.getSampleTableBox().getChunkOffsetBox();
        SampleToChunkBox sampleToChunkBox = trackBox.getSampleTableBox().getSampleToChunkBox();
        long[] chunkOffsets = chunkOffsetBox != null ? chunkOffsetBox.getChunkOffsets() : new long[0];
        if (sampleToChunkBox != null && sampleToChunkBox.getEntries().size() > 0 && chunkOffsets.length > 0 && sampleSizeBox != null && sampleSizeBox.getSampleCount() > 0) {
            long[] numberOfSamplesInChunk = sampleToChunkBox.blowup(chunkOffsets.length);
            int sampleIndex = 0;
            if (sampleSizeBox.getSampleSize() > 0) {
                long[] jArr = new long[CastUtils.l2i(sampleSizeBox.getSampleCount())];
                this.sizes = jArr;
                Arrays.fill(jArr, sampleSizeBox.getSampleSize());
            } else {
                this.sizes = sampleSizeBox.getSampleSizes();
            }
            this.offsets = new long[this.sizes.length];
            for (int i = 0; i < numberOfSamplesInChunk.length; i++) {
                long thisChunksNumberOfSamples = numberOfSamplesInChunk[i];
                long sampleOffset = chunkOffsets[i];
                for (int j = 0; ((long) j) < thisChunksNumberOfSamples; j++) {
                    long sampleSize = this.sizes[sampleIndex];
                    this.offsets[sampleIndex] = sampleOffset;
                    sampleOffset += sampleSize;
                    sampleIndex++;
                }
            }
        }
        List<MovieExtendsBox> movieExtendsBoxes = trackBox.getParent().getBoxes(MovieExtendsBox.class);
        if (movieExtendsBoxes.size() > 0) {
            Map<Long, Long> offsets2Sizes = new HashMap<>();
            for (TrackExtendsBox trackExtendsBox : movieExtendsBoxes.get(0).getBoxes(TrackExtendsBox.class)) {
                if (trackExtendsBox.getTrackId() == trackBox.getTrackHeaderBox().getTrackId()) {
                    for (MovieFragmentBox movieFragmentBox : trackBox.getIsoFile().getBoxes(MovieFragmentBox.class)) {
                        offsets2Sizes.putAll(getOffsets(movieFragmentBox, trackBox.getTrackHeaderBox().getTrackId(), trackExtendsBox));
                    }
                }
            }
            if (this.sizes == null || this.offsets == null) {
                this.sizes = new long[0];
                this.offsets = new long[0];
            }
            splitToArrays(offsets2Sizes);
        }
    }

    private void splitToArrays(Map<Long, Long> offsets2Sizes) {
        List<Long> keys = new ArrayList<>(offsets2Sizes.keySet());
        Collections.sort(keys);
        long[] nuSizes = new long[(this.sizes.length + keys.size())];
        long[] jArr = this.sizes;
        System.arraycopy(jArr, 0, nuSizes, 0, jArr.length);
        long[] nuOffsets = new long[(this.offsets.length + keys.size())];
        long[] jArr2 = this.offsets;
        System.arraycopy(jArr2, 0, nuOffsets, 0, jArr2.length);
        for (int i = 0; i < keys.size(); i++) {
            nuOffsets[this.offsets.length + i] = keys.get(i).longValue();
            nuSizes[this.sizes.length + i] = offsets2Sizes.get(keys.get(i)).longValue();
        }
        this.sizes = nuSizes;
        this.offsets = nuOffsets;
    }

    public SampleList(TrackFragmentBox traf) {
        this.mdatStartCache = new HashMap<>();
        this.mdatEndCache = new HashMap<>();
        this.sizes = new long[0];
        this.offsets = new long[0];
        Map<Long, Long> offsets2Sizes = new HashMap<>();
        initIsoFile(traf.getIsoFile());
        List<MovieFragmentBox> movieFragmentBoxList = this.isoFile.getBoxes(MovieFragmentBox.class);
        long trackId = traf.getTrackFragmentHeaderBox().getTrackId();
        for (MovieFragmentBox moof : movieFragmentBoxList) {
            for (TrackFragmentHeaderBox tfhd : moof.getTrackFragmentHeaderBoxes()) {
                if (tfhd.getTrackId() == trackId) {
                    offsets2Sizes.putAll(getOffsets(moof, trackId, null));
                }
            }
        }
        splitToArrays(offsets2Sizes);
    }

    private void initIsoFile(IsoFile isoFile2) {
        this.isoFile = isoFile2;
        long currentOffset = 0;
        LinkedList<MediaDataBox> mdats2 = new LinkedList<>();
        for (Box b : this.isoFile.getBoxes()) {
            long currentSize = b.getSize();
            if (MediaDataBox.TYPE.equals(b.getType())) {
                if (b instanceof MediaDataBox) {
                    long contentOffset = ((long) ((MediaDataBox) b).getHeader().limit()) + currentOffset;
                    this.mdatStartCache.put((MediaDataBox) b, Long.valueOf(contentOffset));
                    this.mdatEndCache.put((MediaDataBox) b, Long.valueOf(contentOffset + currentSize));
                    mdats2.add((MediaDataBox) b);
                } else {
                    throw new RuntimeException("Sample need to be in mdats and mdats need to be instanceof MediaDataBox");
                }
            }
            currentOffset += currentSize;
        }
        this.mdats = (MediaDataBox[]) mdats2.toArray(new MediaDataBox[mdats2.size()]);
    }

    public int size() {
        return this.sizes.length;
    }

    @Override // java.util.List, java.util.AbstractList
    public ByteBuffer get(int index) {
        long offset = this.offsets[index];
        int sampleSize = CastUtils.l2i(this.sizes[index]);
        MediaDataBox[] mediaDataBoxArr = this.mdats;
        for (MediaDataBox mediaDataBox : mediaDataBoxArr) {
            long start = this.mdatStartCache.get(mediaDataBox).longValue();
            long end = this.mdatEndCache.get(mediaDataBox).longValue();
            if (start <= offset && ((long) sampleSize) + offset <= end) {
                return mediaDataBox.getContent(offset - start, sampleSize);
            }
        }
        throw new RuntimeException("The sample with offset " + offset + " and size " + sampleSize + " is NOT located within an mdat");
    }

    /* access modifiers changed from: package-private */
    public Map<Long, Long> getOffsets(MovieFragmentBox moof, long trackId, TrackExtendsBox trex) {
        long baseDataOffset;
        List<TrackFragmentBox> traf;
        Iterator<TrackFragmentBox> it;
        TrackFragmentBox trackFragmentBox;
        Map<Long, Long> offsets2Sizes = new HashMap<>();
        List<TrackFragmentBox> traf2 = moof.getBoxes(TrackFragmentBox.class);
        Iterator<TrackFragmentBox> it2 = traf2.iterator();
        while (it2.hasNext()) {
            TrackFragmentBox trackFragmentBox2 = it2.next();
            if (trackFragmentBox2.getTrackFragmentHeaderBox().getTrackId() == trackId) {
                if (trackFragmentBox2.getTrackFragmentHeaderBox().hasBaseDataOffset()) {
                    baseDataOffset = trackFragmentBox2.getTrackFragmentHeaderBox().getBaseDataOffset();
                } else {
                    baseDataOffset = moof.getOffset();
                }
                for (TrackRunBox trun : trackFragmentBox2.getBoxes(TrackRunBox.class)) {
                    long sampleBaseOffset = ((long) trun.getDataOffset()) + baseDataOffset;
                    TrackFragmentHeaderBox tfhd = ((TrackFragmentBox) trun.getParent()).getTrackFragmentHeaderBox();
                    long offset = 0;
                    for (TrackRunBox.Entry entry : trun.getEntries()) {
                        if (trun.isSampleSizePresent()) {
                            long sampleSize = entry.getSampleSize();
                            traf = traf2;
                            offsets2Sizes.put(Long.valueOf(offset + sampleBaseOffset), Long.valueOf(sampleSize));
                            offset += sampleSize;
                            it = it2;
                            trackFragmentBox = trackFragmentBox2;
                        } else {
                            traf = traf2;
                            if (tfhd.hasDefaultSampleSize()) {
                                long sampleSize2 = tfhd.getDefaultSampleSize();
                                it = it2;
                                trackFragmentBox = trackFragmentBox2;
                                offsets2Sizes.put(Long.valueOf(offset + sampleBaseOffset), Long.valueOf(sampleSize2));
                                offset += sampleSize2;
                            } else {
                                it = it2;
                                trackFragmentBox = trackFragmentBox2;
                                if (trex != null) {
                                    long sampleSize3 = trex.getDefaultSampleSize();
                                    offsets2Sizes.put(Long.valueOf(offset + sampleBaseOffset), Long.valueOf(sampleSize3));
                                    offset += sampleSize3;
                                } else {
                                    throw new RuntimeException("File doesn't contain trex box but track fragments aren't fully self contained. Cannot determine sample size.");
                                }
                            }
                        }
                        trackFragmentBox2 = trackFragmentBox;
                        it2 = it;
                        traf2 = traf;
                    }
                }
                continue;
            }
            it2 = it2;
            traf2 = traf2;
        }
        return offsets2Sizes;
    }
}
