package com.coremedia.iso.boxes.sampleentry;

import com.coremedia.iso.BoxParser;
import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;

public class AudioSampleEntry extends SampleEntry implements ContainerBox {
    public static final String TYPE1 = "samr";
    public static final String TYPE10 = "mlpa";
    public static final String TYPE11 = "dtsl";
    public static final String TYPE12 = "dtsh";
    public static final String TYPE13 = "dtse";
    public static final String TYPE2 = "sawb";
    public static final String TYPE3 = "mp4a";
    public static final String TYPE4 = "drms";
    public static final String TYPE5 = "alac";
    public static final String TYPE7 = "owma";
    public static final String TYPE8 = "ac-3";
    public static final String TYPE9 = "ec-3";
    public static final String TYPE_ENCRYPTED = "enca";
    private BoxParser boxParser;
    private long bytesPerFrame;
    private long bytesPerPacket;
    private long bytesPerSample;
    private int channelCount;
    private int compressionId;
    private int packetSize;
    private int reserved1;
    private long reserved2;
    private long sampleRate;
    private int sampleSize;
    private long samplesPerPacket;
    private int soundVersion;
    private byte[] soundVersion2Data;

    public AudioSampleEntry(String type) {
        super(type);
    }

    public int getChannelCount() {
        return this.channelCount;
    }

    public int getSampleSize() {
        return this.sampleSize;
    }

    public long getSampleRate() {
        return this.sampleRate;
    }

    public int getSoundVersion() {
        return this.soundVersion;
    }

    public int getCompressionId() {
        return this.compressionId;
    }

    public int getPacketSize() {
        return this.packetSize;
    }

    public long getSamplesPerPacket() {
        return this.samplesPerPacket;
    }

    public long getBytesPerPacket() {
        return this.bytesPerPacket;
    }

    public long getBytesPerFrame() {
        return this.bytesPerFrame;
    }

    public long getBytesPerSample() {
        return this.bytesPerSample;
    }

    public byte[] getSoundVersion2Data() {
        return this.soundVersion2Data;
    }

    public int getReserved1() {
        return this.reserved1;
    }

    public long getReserved2() {
        return this.reserved2;
    }

    public void setChannelCount(int channelCount2) {
        this.channelCount = channelCount2;
    }

    public void setSampleSize(int sampleSize2) {
        this.sampleSize = sampleSize2;
    }

    public void setSampleRate(long sampleRate2) {
        this.sampleRate = sampleRate2;
    }

    public void setSoundVersion(int soundVersion2) {
        this.soundVersion = soundVersion2;
    }

    public void setCompressionId(int compressionId2) {
        this.compressionId = compressionId2;
    }

    public void setPacketSize(int packetSize2) {
        this.packetSize = packetSize2;
    }

    public void setSamplesPerPacket(long samplesPerPacket2) {
        this.samplesPerPacket = samplesPerPacket2;
    }

    public void setBytesPerPacket(long bytesPerPacket2) {
        this.bytesPerPacket = bytesPerPacket2;
    }

    public void setBytesPerFrame(long bytesPerFrame2) {
        this.bytesPerFrame = bytesPerFrame2;
    }

    public void setBytesPerSample(long bytesPerSample2) {
        this.bytesPerSample = bytesPerSample2;
    }

    public void setReserved1(int reserved12) {
        this.reserved1 = reserved12;
    }

    public void setReserved2(long reserved22) {
        this.reserved2 = reserved22;
    }

    public void setSoundVersion2Data(byte[] soundVersion2Data2) {
        this.soundVersion2Data = soundVersion2Data2;
    }

    public void setBoxParser(BoxParser boxParser2) {
        this.boxParser = boxParser2;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        _parseReservedAndDataReferenceIndex(content);
        this.soundVersion = IsoTypeReader.readUInt16(content);
        this.reserved1 = IsoTypeReader.readUInt16(content);
        this.reserved2 = IsoTypeReader.readUInt32(content);
        this.channelCount = IsoTypeReader.readUInt16(content);
        this.sampleSize = IsoTypeReader.readUInt16(content);
        this.compressionId = IsoTypeReader.readUInt16(content);
        this.packetSize = IsoTypeReader.readUInt16(content);
        this.sampleRate = IsoTypeReader.readUInt32(content);
        if (!this.type.equals(TYPE10)) {
            this.sampleRate >>>= 16;
        }
        if (this.soundVersion > 0) {
            this.samplesPerPacket = IsoTypeReader.readUInt32(content);
            this.bytesPerPacket = IsoTypeReader.readUInt32(content);
            this.bytesPerFrame = IsoTypeReader.readUInt32(content);
            this.bytesPerSample = IsoTypeReader.readUInt32(content);
        }
        if (this.soundVersion == 2) {
            this.soundVersion2Data = new byte[20];
            content.get(20);
        }
        _parseChildBoxes(content);
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long j = 0;
        long contentSize = 28 + (this.soundVersion > 0 ? 16 : 0);
        if (this.soundVersion == 2) {
            j = 20;
        }
        long contentSize2 = contentSize + j;
        for (Box boxe : this.boxes) {
            contentSize2 += boxe.getSize();
        }
        return contentSize2;
    }

    public String toString() {
        return "AudioSampleEntry{bytesPerSample=" + this.bytesPerSample + ", bytesPerFrame=" + this.bytesPerFrame + ", bytesPerPacket=" + this.bytesPerPacket + ", samplesPerPacket=" + this.samplesPerPacket + ", packetSize=" + this.packetSize + ", compressionId=" + this.compressionId + ", soundVersion=" + this.soundVersion + ", sampleRate=" + this.sampleRate + ", sampleSize=" + this.sampleSize + ", channelCount=" + this.channelCount + ", boxes=" + getBoxes() + Operators.BLOCK_END;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        _writeReservedAndDataReferenceIndex(byteBuffer);
        IsoTypeWriter.writeUInt16(byteBuffer, this.soundVersion);
        IsoTypeWriter.writeUInt16(byteBuffer, this.reserved1);
        IsoTypeWriter.writeUInt32(byteBuffer, this.reserved2);
        IsoTypeWriter.writeUInt16(byteBuffer, this.channelCount);
        IsoTypeWriter.writeUInt16(byteBuffer, this.sampleSize);
        IsoTypeWriter.writeUInt16(byteBuffer, this.compressionId);
        IsoTypeWriter.writeUInt16(byteBuffer, this.packetSize);
        if (this.type.equals(TYPE10)) {
            IsoTypeWriter.writeUInt32(byteBuffer, getSampleRate());
        } else {
            IsoTypeWriter.writeUInt32(byteBuffer, getSampleRate() << 16);
        }
        if (this.soundVersion > 0) {
            IsoTypeWriter.writeUInt32(byteBuffer, this.samplesPerPacket);
            IsoTypeWriter.writeUInt32(byteBuffer, this.bytesPerPacket);
            IsoTypeWriter.writeUInt32(byteBuffer, this.bytesPerFrame);
            IsoTypeWriter.writeUInt32(byteBuffer, this.bytesPerSample);
        }
        if (this.soundVersion == 2) {
            byteBuffer.put(this.soundVersion2Data);
        }
        _writeChildBoxes(byteBuffer);
    }
}
