package com.dcloud.zxing2.datamatrix.encoder;

import com.alibaba.fastjson.asm.Opcodes;
import com.igexin.push.config.c;
import com.tencent.smtt.sdk.TbsListener;
import org.mozilla.universalchardet.prober.HebrewProber;
import org.mozilla.universalchardet.prober.contextanalysis.EUCJPContextAnalysis;
import org.mozilla.universalchardet.prober.distributionanalysis.EUCTWDistributionAnalysis;

public final class ErrorCorrection {
    private static final int[] ALOG = new int[255];
    private static final int[][] FACTORS = {new int[]{TbsListener.ErrorCode.INCR_ERROR_DETAIL, 48, 15, 111, 62}, new int[]{23, 68, 144, TbsListener.ErrorCode.DOWNLOAD_USER_PAUSE, 240, 92, 254}, new int[]{28, 24, Opcodes.INVOKEINTERFACE, Opcodes.IF_ACMPNE, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 248, 116, 255, 110, 61}, new int[]{175, 138, TbsListener.ErrorCode.UNZIP_DIR_ERROR, 12, 194, 168, 39, HebrewProber.FINAL_TSADI, 60, 97, 120}, new int[]{41, 153, Opcodes.IFLE, 91, 61, 42, EUCJPContextAnalysis.SINGLE_SHIFT_2, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 97, 178, 100, TbsListener.ErrorCode.TPATCH_ENABLE_EXCEPTION}, new int[]{156, 97, 192, 252, 95, 9, 157, 119, 138, 45, 18, 186, 83, Opcodes.INVOKEINTERFACE}, new int[]{83, 195, 100, 39, Opcodes.NEWARRAY, 75, 66, 61, 241, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 109, 129, 94, 254, 225, 48, 90, Opcodes.NEWARRAY}, new int[]{15, 195, 244, 9, TbsListener.ErrorCode.DECOUPLE_INSTLL_SUCCESS, 71, 168, 2, Opcodes.NEWARRAY, 160, 153, c.G, c.E, 79, 108, 82, 27, 174, 186, 172}, new int[]{52, 190, 88, TbsListener.ErrorCode.UNZIP_DIR_ERROR, 109, 39, 176, 21, TbsListener.ErrorCode.NO_NEED_STARTDOWNLOAD, 197, 251, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, TbsListener.ErrorCode.NO_NEED_STARTDOWNLOAD, 21, 5, 172, 254, 124, 12, Opcodes.PUTFIELD, Opcodes.INVOKESTATIC, 96, 50, Opcodes.INSTANCEOF}, new int[]{TbsListener.ErrorCode.EXCEED_COPY_RETRY_NUM, TbsListener.ErrorCode.RENAME_FAIL, 43, 97, 71, 96, 103, 174, 37, 151, 170, 53, 75, 34, 249, 121, 17, 138, 110, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 141, 136, 120, 151, TbsListener.ErrorCode.DECOUPLE_INSTLL_SUCCESS, 168, 93, 255}, new int[]{HebrewProber.FINAL_TSADI, 127, TbsListener.ErrorCode.TPATCH_ENABLE_EXCEPTION, 218, 130, 250, Opcodes.IF_ICMPGE, Opcodes.PUTFIELD, 102, 120, 84, 179, TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, 251, 80, Opcodes.INVOKEVIRTUAL, TbsListener.ErrorCode.INSTALL_FROM_UNZIP, 18, 2, 4, 68, 33, 101, 137, 95, 119, 115, 44, 175, Opcodes.INVOKESTATIC, 59, 25, 225, 98, 81, 112}, new int[]{77, Opcodes.INSTANCEOF, 137, 31, 19, 38, 22, 153, 247, 105, 122, 2, HebrewProber.FINAL_TSADI, 133, TbsListener.ErrorCode.TPATCH_ENABLE_EXCEPTION, 8, 175, 95, 100, 9, Opcodes.GOTO, 105, TbsListener.ErrorCode.COPY_TMPDIR_ERROR, 111, 57, 121, 21, 1, c.E, 57, 54, 101, 248, 202, 69, 50, 150, 177, TbsListener.ErrorCode.DEXOAT_EXCEPTION, 5, 9, 5}, new int[]{HebrewProber.FINAL_TSADI, TbsListener.ErrorCode.DOWNLOAD_CDN_URL_IS_NULL, 172, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 96, 32, 117, 22, 238, 133, 238, TbsListener.ErrorCode.RENAME_FAIL, TbsListener.ErrorCode.UNZIP_DIR_ERROR, Opcodes.NEWARRAY, 237, 87, 191, 106, 16, 147, 118, 23, 37, 90, 170, TbsListener.ErrorCode.UNZIP_DIR_ERROR, TbsListener.ErrorCode.DOWNLOAD_USER_CANCEL, 88, 120, 100, 66, 138, 186, 240, 82, 44, 176, 87, Opcodes.NEW, 147, 160, 175, 69, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 92, c.E, 225, 19}, new int[]{175, 9, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 238, 12, 17, TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, 208, 100, 29, 175, 170, TbsListener.ErrorCode.RENAME_SUCCESS, 192, 215, 235, 150, 159, 36, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 38, 200, TbsListener.ErrorCode.DOWNLOAD_CDN_URL_IS_NULL, 54, TbsListener.ErrorCode.INCR_ERROR_DETAIL, 146, 218, 234, 117, 203, 29, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, 144, 238, 22, 150, 201, 117, 62, TbsListener.ErrorCode.UNZIP_OTHER_ERROR, 164, 13, 137, HebrewProber.FINAL_TSADI, 127, 67, 247, 28, TbsListener.ErrorCode.NO_NEED_STARTDOWNLOAD, 43, 203, 107, TbsListener.ErrorCode.DECOUPLE_INSTLL_SUCCESS, 53, EUCJPContextAnalysis.SINGLE_SHIFT_3, 46}, new int[]{TbsListener.ErrorCode.TPATCH_ENABLE_EXCEPTION, 93, Opcodes.RET, 50, 144, TbsListener.ErrorCode.ROM_NOT_ENOUGH, 39, 118, 202, Opcodes.NEWARRAY, 201, 189, EUCJPContextAnalysis.SINGLE_SHIFT_3, 108, EUCTWDistributionAnalysis.HIGHBYTE_BEGIN, 37, Opcodes.INVOKEINTERFACE, 112, TbsListener.ErrorCode.DOWNLOAD_USER_PAUSE, TbsListener.ErrorCode.RENAME_SUCCESS, HebrewProber.FINAL_TSADI, 63, 197, 190, 250, 106, Opcodes.INVOKEINTERFACE, TbsListener.ErrorCode.INCRUPDATE_INSTALL_SUCCESS, 175, 64, 114, 71, 161, 44, 147, 6, 27, 218, 51, 63, 87, 10, 40, 130, Opcodes.NEWARRAY, 17, Opcodes.IF_ICMPGT, 31, 176, 170, 4, 107, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, 7, 94, Opcodes.IF_ACMPNE, 224, 124, 86, 47, 11, TbsListener.ErrorCode.APK_INVALID}, new int[]{TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, TbsListener.ErrorCode.INCR_ERROR_DETAIL, 173, 89, 251, Opcodes.FCMPL, 159, 56, 89, 33, 147, 244, 154, 36, 73, 127, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 136, 248, 180, 234, 197, Opcodes.IFLE, 177, 68, 122, 93, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, 15, 160, TbsListener.ErrorCode.HOST_CONTEXT_IS_NULL, TbsListener.ErrorCode.TPATCH_INSTALL_SUCCESS, 66, 139, 153, Opcodes.INVOKEINTERFACE, 202, Opcodes.GOTO, 179, 25, TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, 96, TbsListener.ErrorCode.ROM_NOT_ENOUGH, TbsListener.ErrorCode.RENAME_FAIL, 136, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 239, Opcodes.PUTFIELD, 241, 59, 52, 172, 25, 49, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, TbsListener.ErrorCode.EXCEED_COPY_RETRY_NUM, 189, 64, 54, 108, 153, TbsListener.ErrorCode.DOWNLOAD_CDN_URL_IS_NULL, 63, 96, 103, 82, 186}};
    private static final int[] FACTOR_SETS = {5, 7, 10, 11, 12, 14, 18, 20, 24, 28, 36, 42, 48, 56, 62, 68};
    private static final int[] LOG = new int[256];
    private static final int MODULO_VALUE = 301;

    static {
        int i = 1;
        for (int i2 = 0; i2 < 255; i2++) {
            ALOG[i2] = i;
            LOG[i] = i2;
            i *= 2;
            if (i >= 256) {
                i ^= 301;
            }
        }
    }

    private ErrorCorrection() {
    }

    private static String createECCBlock(CharSequence charSequence, int i) {
        return createECCBlock(charSequence, 0, charSequence.length(), i);
    }

    public static String encodeECC200(String str, SymbolInfo symbolInfo) {
        if (str.length() == symbolInfo.getDataCapacity()) {
            StringBuilder sb = new StringBuilder(symbolInfo.getDataCapacity() + symbolInfo.getErrorCodewords());
            sb.append(str);
            int interleavedBlockCount = symbolInfo.getInterleavedBlockCount();
            if (interleavedBlockCount == 1) {
                sb.append(createECCBlock(str, symbolInfo.getErrorCodewords()));
            } else {
                sb.setLength(sb.capacity());
                int[] iArr = new int[interleavedBlockCount];
                int[] iArr2 = new int[interleavedBlockCount];
                int[] iArr3 = new int[interleavedBlockCount];
                int i = 0;
                while (i < interleavedBlockCount) {
                    int i2 = i + 1;
                    iArr[i] = symbolInfo.getDataLengthForInterleavedBlock(i2);
                    iArr2[i] = symbolInfo.getErrorLengthForInterleavedBlock(i2);
                    iArr3[i] = 0;
                    if (i > 0) {
                        iArr3[i] = iArr3[i - 1] + iArr[i];
                    }
                    i = i2;
                }
                for (int i3 = 0; i3 < interleavedBlockCount; i3++) {
                    StringBuilder sb2 = new StringBuilder(iArr[i3]);
                    for (int i4 = i3; i4 < symbolInfo.getDataCapacity(); i4 += interleavedBlockCount) {
                        sb2.append(str.charAt(i4));
                    }
                    String createECCBlock = createECCBlock(sb2.toString(), iArr2[i3]);
                    int i5 = i3;
                    int i6 = 0;
                    while (i5 < iArr2[i3] * interleavedBlockCount) {
                        sb.setCharAt(symbolInfo.getDataCapacity() + i5, createECCBlock.charAt(i6));
                        i5 += interleavedBlockCount;
                        i6++;
                    }
                }
            }
            return sb.toString();
        }
        throw new IllegalArgumentException("The number of codewords does not match the selected symbol");
    }

    private static String createECCBlock(CharSequence charSequence, int i, int i2, int i3) {
        int i4 = 0;
        while (true) {
            int[] iArr = FACTOR_SETS;
            if (i4 >= iArr.length) {
                i4 = -1;
                break;
            } else if (iArr[i4] == i3) {
                break;
            } else {
                i4++;
            }
        }
        if (i4 >= 0) {
            int[] iArr2 = FACTORS[i4];
            char[] cArr = new char[i3];
            for (int i5 = 0; i5 < i3; i5++) {
                cArr[i5] = 0;
            }
            for (int i6 = i; i6 < i + i2; i6++) {
                int i7 = i3 - 1;
                int charAt = cArr[i7] ^ charSequence.charAt(i6);
                while (i7 > 0) {
                    if (charAt == 0 || iArr2[i7] == 0) {
                        cArr[i7] = cArr[i7 - 1];
                    } else {
                        char c = cArr[i7 - 1];
                        int[] iArr3 = ALOG;
                        int[] iArr4 = LOG;
                        cArr[i7] = (char) (c ^ iArr3[(iArr4[charAt] + iArr4[iArr2[i7]]) % 255]);
                    }
                    i7--;
                }
                if (charAt == 0 || iArr2[0] == 0) {
                    cArr[0] = 0;
                } else {
                    int[] iArr5 = ALOG;
                    int[] iArr6 = LOG;
                    cArr[0] = (char) iArr5[(iArr6[charAt] + iArr6[iArr2[0]]) % 255];
                }
            }
            char[] cArr2 = new char[i3];
            for (int i8 = 0; i8 < i3; i8++) {
                cArr2[i8] = cArr[(i3 - i8) - 1];
            }
            return String.valueOf(cArr2);
        }
        throw new IllegalArgumentException("Illegal number of error correction codewords specified: " + i3);
    }
}
