package com.facebook.fresco.ui.common;

import android.util.Log;
import com.facebook.fresco.ui.common.ControllerListener2;
import java.util.ArrayList;
import java.util.List;
import javax.annotation.Nullable;

public class ForwardingControllerListener2<I> extends BaseControllerListener2<I> {
    private static final String TAG = "FwdControllerListener2";
    private final List<ControllerListener2<I>> mListeners = new ArrayList(2);

    public synchronized void addListener(ControllerListener2<I> listener) {
        this.mListeners.add(listener);
    }

    public synchronized void removeListener(ControllerListener2<I> listener) {
        int index = this.mListeners.indexOf(listener);
        if (index != -1) {
            this.mListeners.remove(index);
        }
    }

    public synchronized void removeAllListeners() {
        this.mListeners.clear();
    }

    private synchronized void onException(String message, Throwable t) {
        Log.e(TAG, message, t);
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onSubmit(String id, @Nullable Object callerContext, @Nullable ControllerListener2.Extras extras) {
        int numberOfListeners = this.mListeners.size();
        for (int i = 0; i < numberOfListeners; i++) {
            try {
                ControllerListener2<I> listener = this.mListeners.get(i);
                if (listener != null) {
                    listener.onSubmit(id, callerContext, extras);
                }
            } catch (Exception exception) {
                onException("ForwardingControllerListener2 exception in onSubmit", exception);
            }
        }
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onFinalImageSet(String id, @Nullable I imageInfo, @Nullable ControllerListener2.Extras extraData) {
        int numberOfListeners = this.mListeners.size();
        for (int i = 0; i < numberOfListeners; i++) {
            try {
                ControllerListener2<I> listener = this.mListeners.get(i);
                if (listener != null) {
                    listener.onFinalImageSet(id, imageInfo, extraData);
                }
            } catch (Exception exception) {
                onException("ForwardingControllerListener2 exception in onFinalImageSet", exception);
            }
        }
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onFailure(String id, @Nullable Throwable throwable, @Nullable ControllerListener2.Extras extras) {
        int numberOfListeners = this.mListeners.size();
        for (int i = 0; i < numberOfListeners; i++) {
            try {
                ControllerListener2<I> listener = this.mListeners.get(i);
                if (listener != null) {
                    listener.onFailure(id, throwable, extras);
                }
            } catch (Exception exception) {
                onException("ForwardingControllerListener2 exception in onFailure", exception);
            }
        }
    }

    @Override // com.facebook.fresco.ui.common.ControllerListener2, com.facebook.fresco.ui.common.BaseControllerListener2
    public void onRelease(String id, @Nullable ControllerListener2.Extras extras) {
        int numberOfListeners = this.mListeners.size();
        for (int i = 0; i < numberOfListeners; i++) {
            try {
                ControllerListener2<I> listener = this.mListeners.get(i);
                if (listener != null) {
                    listener.onRelease(id, extras);
                }
            } catch (Exception exception) {
                onException("ForwardingControllerListener2 exception in onRelease", exception);
            }
        }
    }
}
