package com.facebook.imagepipeline.common;

import com.facebook.common.internal.Preconditions;
import com.facebook.common.util.HashCodeUtil;
import java.util.regex.Pattern;
import javax.annotation.Nullable;

public class BytesRange {
    public static final int TO_END_OF_CONTENT = Integer.MAX_VALUE;
    @Nullable
    private static Pattern sHeaderParsingRegEx;
    public final int from;
    public final int to;

    public BytesRange(int from2, int to2) {
        this.from = from2;
        this.to = to2;
    }

    public String toHttpRangeHeaderValue() {
        return String.format(null, "bytes=%s-%s", valueOrEmpty(this.from), valueOrEmpty(this.to));
    }

    public boolean contains(@Nullable BytesRange compare) {
        if (compare != null && this.from <= compare.from && this.to >= compare.to) {
            return true;
        }
        return false;
    }

    public String toString() {
        return String.format(null, "%s-%s", valueOrEmpty(this.from), valueOrEmpty(this.to));
    }

    private static String valueOrEmpty(int n) {
        if (n == Integer.MAX_VALUE) {
            return "";
        }
        return Integer.toString(n);
    }

    public boolean equals(@Nullable Object other) {
        if (other == this) {
            return true;
        }
        if (!(other instanceof BytesRange)) {
            return false;
        }
        BytesRange that = (BytesRange) other;
        if (this.from == that.from && this.to == that.to) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        return HashCodeUtil.hashCode(this.from, this.to);
    }

    public static BytesRange from(int from2) {
        Preconditions.checkArgument(Boolean.valueOf(from2 >= 0));
        return new BytesRange(from2, Integer.MAX_VALUE);
    }

    public static BytesRange toMax(int to2) {
        Preconditions.checkArgument(Boolean.valueOf(to2 > 0));
        return new BytesRange(0, to2);
    }

    @Nullable
    public static BytesRange fromContentRangeHeader(@Nullable String header) throws IllegalArgumentException {
        if (header == null) {
            return null;
        }
        if (sHeaderParsingRegEx == null) {
            sHeaderParsingRegEx = Pattern.compile("[-/ ]");
        }
        try {
            String[] headerParts = sHeaderParsingRegEx.split(header);
            Preconditions.checkArgument(Boolean.valueOf(headerParts.length == 4));
            Preconditions.checkArgument(Boolean.valueOf(headerParts[0].equals("bytes")));
            int from2 = Integer.parseInt(headerParts[1]);
            int to2 = Integer.parseInt(headerParts[2]);
            int length = Integer.parseInt(headerParts[3]);
            Preconditions.checkArgument(Boolean.valueOf(to2 > from2));
            Preconditions.checkArgument(Boolean.valueOf(length > to2));
            if (to2 < length - 1) {
                return new BytesRange(from2, to2);
            }
            return new BytesRange(from2, Integer.MAX_VALUE);
        } catch (IllegalArgumentException x) {
            throw new IllegalArgumentException(String.format(null, "Invalid Content-Range header value: \"%s\"", header), x);
        }
    }
}
