package com.facebook.imagepipeline.image;

import com.facebook.imagepipeline.animated.base.AnimatedImage;
import com.facebook.imagepipeline.animated.base.AnimatedImageResult;
import javax.annotation.Nullable;

public class CloseableAnimatedImage extends CloseableImage {
    @Nullable
    private AnimatedImageResult mImageResult;
    private boolean mIsStateful;

    public CloseableAnimatedImage(AnimatedImageResult imageResult) {
        this(imageResult, true);
    }

    public CloseableAnimatedImage(AnimatedImageResult imageResult, boolean isStateful) {
        this.mImageResult = imageResult;
        this.mIsStateful = isStateful;
    }

    @Override // com.facebook.imagepipeline.image.ImageInfo
    public synchronized int getWidth() {
        return this.mImageResult == null ? 0 : this.mImageResult.getImage().getWidth();
    }

    @Override // com.facebook.imagepipeline.image.ImageInfo
    public synchronized int getHeight() {
        return this.mImageResult == null ? 0 : this.mImageResult.getImage().getHeight();
    }

    @Override // java.io.Closeable, com.facebook.imagepipeline.image.CloseableImage, java.lang.AutoCloseable
    public void close() {
        synchronized (this) {
            if (this.mImageResult != null) {
                AnimatedImageResult imageResult = this.mImageResult;
                this.mImageResult = null;
                imageResult.dispose();
            }
        }
    }

    @Override // com.facebook.imagepipeline.image.CloseableImage
    public synchronized boolean isClosed() {
        return this.mImageResult == null;
    }

    @Override // com.facebook.imagepipeline.image.CloseableImage
    public synchronized int getSizeInBytes() {
        return this.mImageResult == null ? 0 : this.mImageResult.getImage().getSizeInBytes();
    }

    @Override // com.facebook.imagepipeline.image.CloseableImage
    public boolean isStateful() {
        return this.mIsStateful;
    }

    @Nullable
    public synchronized AnimatedImageResult getImageResult() {
        return this.mImageResult;
    }

    @Nullable
    public synchronized AnimatedImage getImage() {
        return this.mImageResult == null ? null : this.mImageResult.getImage();
    }
}
