package com.facebook.soloader;

import android.util.Log;
import com.tencent.smtt.export.external.interfaces.ISelectionInterface;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.channels.ClosedByInterruptException;
import java.nio.channels.FileChannel;
import net.lingala.zip4j.util.InternalZipConstants;
import tv.cjump.jni.DeviceUtils;

public final class MinElf {
    public static final int DT_NEEDED = 1;
    public static final int DT_NULL = 0;
    public static final int DT_STRTAB = 5;
    public static final int ELF_MAGIC = 1179403647;
    public static final int PN_XNUM = 65535;
    public static final int PT_DYNAMIC = 2;
    public static final int PT_LOAD = 1;
    private static final String TAG = "MinElf";

    public enum ISA {
        NOT_SO("not_so"),
        X86(DeviceUtils.ABI_X86),
        ARM("armeabi-v7a"),
        X86_64("x86_64"),
        AARCH64("arm64-v8a"),
        OTHERS(AbsURIAdapter.OTHERS);
        
        private final String value;

        private ISA(String value2) {
            this.value = value2;
        }

        public String toString() {
            return this.value;
        }
    }

    public static String[] extract_DT_NEEDED(File elfFile) throws IOException {
        int failureCount = 0;
        while (true) {
            FileInputStream is = new FileInputStream(elfFile);
            try {
                return extract_DT_NEEDED(is.getChannel());
            } catch (ClosedByInterruptException e) {
                failureCount++;
                if (failureCount <= 3) {
                    Thread.interrupted();
                    Log.e(TAG, "retrying extract_DT_NEEDED due to ClosedByInterruptException", e);
                } else {
                    throw e;
                }
            } finally {
                is.close();
            }
        }
    }

    public static String[] extract_DT_NEEDED(FileChannel fc) throws IOException {
        long j;
        long phdr;
        long d_tag;
        String str;
        long d_tag2;
        long dynStart;
        long d_tag3;
        String str2;
        long e_phnum;
        long p_type;
        long p_type2;
        long d_tag4;
        long p_offset;
        long j2;
        long p_type3;
        long p_offset2;
        long sh_info;
        ByteBuffer bb = ByteBuffer.allocate(8);
        bb.order(ByteOrder.LITTLE_ENDIAN);
        long magic = getu32(fc, bb, 0);
        if (magic == 1179403647) {
            boolean is32 = true;
            if (getu8(fc, bb, 4) != 1) {
                is32 = false;
            }
            if (getu8(fc, bb, 5) == 2) {
                bb.order(ByteOrder.BIG_ENDIAN);
            }
            long e_phoff = is32 ? getu32(fc, bb, 28) : get64(fc, bb, 32);
            long e_phnum2 = (long) (is32 ? getu16(fc, bb, 44) : getu16(fc, bb, 56));
            if (is32) {
                j = 42;
            } else {
                j = 54;
            }
            int e_phentsize = getu16(fc, bb, j);
            if (e_phnum2 == 65535) {
                long e_shoff = is32 ? getu32(fc, bb, 32) : get64(fc, bb, 40);
                if (is32) {
                    sh_info = getu32(fc, bb, 28 + e_shoff);
                } else {
                    sh_info = getu32(fc, bb, 44 + e_shoff);
                }
                e_phnum2 = sh_info;
            }
            long dynStart2 = 0;
            long phdr2 = e_phoff;
            long i = 0;
            while (true) {
                if (i >= e_phnum2) {
                    break;
                }
                if (is32) {
                    p_type3 = getu32(fc, bb, phdr2 + 0);
                } else {
                    p_type3 = getu32(fc, bb, phdr2 + 0);
                }
                if (p_type3 == 2) {
                    if (is32) {
                        p_offset2 = getu32(fc, bb, phdr2 + 4);
                    } else {
                        p_offset2 = get64(fc, bb, phdr2 + 8);
                    }
                    dynStart2 = p_offset2;
                } else {
                    phdr2 += (long) e_phentsize;
                    i++;
                }
            }
            if (dynStart2 != 0) {
                int nr_DT_NEEDED = 0;
                long dyn = dynStart2;
                long ptr_DT_STRTAB = 0;
                while (true) {
                    if (is32) {
                        phdr = phdr2;
                        d_tag = getu32(fc, bb, dyn + 0);
                    } else {
                        phdr = phdr2;
                        d_tag = get64(fc, bb, dyn + 0);
                    }
                    if (d_tag == 1) {
                        if (nr_DT_NEEDED != Integer.MAX_VALUE) {
                            nr_DT_NEEDED++;
                            str = "malformed DT_NEEDED section";
                        } else {
                            throw new ElfError("malformed DT_NEEDED section");
                        }
                    } else if (d_tag == 5) {
                        if (is32) {
                            str = "malformed DT_NEEDED section";
                            j2 = getu32(fc, bb, dyn + 4);
                        } else {
                            str = "malformed DT_NEEDED section";
                            j2 = get64(fc, bb, dyn + 8);
                        }
                        ptr_DT_STRTAB = j2;
                    } else {
                        str = "malformed DT_NEEDED section";
                    }
                    long dyn2 = dyn + (is32 ? 8 : 16);
                    if (d_tag != 0) {
                        phdr2 = phdr;
                        magic = magic;
                        dyn = dyn2;
                    } else if (ptr_DT_STRTAB != 0) {
                        long off_DT_STRTAB = 0;
                        long phdr3 = e_phoff;
                        int i2 = 0;
                        while (true) {
                            if (((long) i2) >= e_phnum2) {
                                d_tag2 = d_tag;
                                break;
                            }
                            if (is32) {
                                e_phnum = e_phnum2;
                                p_type = getu32(fc, bb, phdr3 + 0);
                            } else {
                                e_phnum = e_phnum2;
                                p_type = getu32(fc, bb, phdr3 + 0);
                            }
                            if (p_type == 1) {
                                if (is32) {
                                    p_type2 = getu32(fc, bb, phdr3 + 8);
                                } else {
                                    p_type2 = get64(fc, bb, phdr3 + 16);
                                }
                                if (is32) {
                                    d_tag2 = d_tag;
                                    d_tag4 = getu32(fc, bb, phdr3 + 20);
                                } else {
                                    d_tag2 = d_tag;
                                    d_tag4 = get64(fc, bb, phdr3 + 40);
                                }
                                if (p_type2 <= ptr_DT_STRTAB && ptr_DT_STRTAB < p_type2 + d_tag4) {
                                    if (is32) {
                                        p_offset = getu32(fc, bb, phdr3 + 4);
                                    } else {
                                        p_offset = get64(fc, bb, phdr3 + 8);
                                    }
                                    off_DT_STRTAB = p_offset + (ptr_DT_STRTAB - p_type2);
                                }
                            } else {
                                d_tag2 = d_tag;
                            }
                            phdr3 += (long) e_phentsize;
                            i2++;
                            d_tag = d_tag2;
                            dyn2 = dyn2;
                            e_phnum2 = e_phnum;
                        }
                        if (off_DT_STRTAB != 0) {
                            String[] needed = new String[nr_DT_NEEDED];
                            int nr_DT_NEEDED2 = 0;
                            long dyn3 = dynStart2;
                            while (true) {
                                if (is32) {
                                    dynStart = dynStart2;
                                    d_tag3 = getu32(fc, bb, dyn3 + 0);
                                } else {
                                    dynStart = dynStart2;
                                    d_tag3 = get64(fc, bb, dyn3 + 0);
                                }
                                if (d_tag3 == 1) {
                                    needed[nr_DT_NEEDED2] = getSz(fc, bb, off_DT_STRTAB + (is32 ? getu32(fc, bb, dyn3 + 4) : get64(fc, bb, dyn3 + 8)));
                                    if (nr_DT_NEEDED2 != Integer.MAX_VALUE) {
                                        nr_DT_NEEDED2++;
                                        str2 = str;
                                    } else {
                                        throw new ElfError(str);
                                    }
                                } else {
                                    str2 = str;
                                }
                                dyn3 += is32 ? 8 : 16;
                                if (d_tag3 != 0) {
                                    str = str2;
                                    dynStart2 = dynStart;
                                } else if (nr_DT_NEEDED2 == needed.length) {
                                    return needed;
                                } else {
                                    throw new ElfError(str2);
                                }
                            }
                        } else {
                            throw new ElfError("did not find file offset of DT_STRTAB table");
                        }
                    } else {
                        throw new ElfError("Dynamic section string-table not found");
                    }
                }
            } else {
                throw new ElfError("ELF file does not contain dynamic linking information");
            }
        } else {
            throw new ElfError("file is not ELF: 0x" + Long.toHexString(magic));
        }
    }

    private static String getSz(FileChannel fc, ByteBuffer bb, long offset) throws IOException {
        StringBuilder sb = new StringBuilder();
        while (true) {
            long offset2 = 1 + offset;
            short b = getu8(fc, bb, offset);
            if (b == 0) {
                return sb.toString();
            }
            sb.append((char) b);
            offset = offset2;
        }
    }

    private static void read(FileChannel fc, ByteBuffer bb, int sz, long offset) throws IOException {
        int numBytesRead;
        bb.position(0);
        bb.limit(sz);
        while (bb.remaining() > 0 && (numBytesRead = fc.read(bb, offset)) != -1) {
            offset += (long) numBytesRead;
        }
        if (bb.remaining() <= 0) {
            bb.position(0);
            return;
        }
        throw new ElfError("ELF file truncated");
    }

    private static long get64(FileChannel fc, ByteBuffer bb, long offset) throws IOException {
        read(fc, bb, 8, offset);
        return bb.getLong();
    }

    private static long getu32(FileChannel fc, ByteBuffer bb, long offset) throws IOException {
        read(fc, bb, 4, offset);
        return ((long) bb.getInt()) & InternalZipConstants.ZIP_64_SIZE_LIMIT;
    }

    private static int getu16(FileChannel fc, ByteBuffer bb, long offset) throws IOException {
        read(fc, bb, 2, offset);
        return bb.getShort() & ISelectionInterface.HELD_NOTHING;
    }

    private static short getu8(FileChannel fc, ByteBuffer bb, long offset) throws IOException {
        read(fc, bb, 1, offset);
        return (short) (bb.get() & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    /* access modifiers changed from: private */
    public static class ElfError extends RuntimeException {
        ElfError(String why) {
            super(why);
        }
    }
}
