package com.facebook.soloader;

import android.content.Context;
import android.os.Build;
import android.os.StrictMode;
import android.text.TextUtils;
import android.util.Log;
import com.facebook.soloader.nativeloader.NativeLoader;
import com.taobao.weex.el.parse.Operators;
import com.xiaomi.mipush.sdk.Constants;
import dalvik.system.BaseDexClassLoader;
import io.dcloud.common.util.Md5Utils;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.locks.ReentrantReadWriteLock;
import javax.annotation.Nullable;

public class SoLoader {
    static final boolean DEBUG = false;
    public static final int SOLOADER_ALLOW_ASYNC_INIT = 2;
    public static final int SOLOADER_DISABLE_BACKUP_SOSOURCE = 8;
    public static final int SOLOADER_DONT_TREAT_AS_SYSTEMAPP = 32;
    public static final int SOLOADER_ENABLE_EXOPACKAGE = 1;
    public static final int SOLOADER_LOOK_IN_ZIP = 4;
    public static final int SOLOADER_SKIP_MERGED_JNI_ONLOAD = 16;
    private static final String SO_STORE_NAME_MAIN = "lib-main";
    private static final String SO_STORE_NAME_SPLIT = "lib-";
    static final boolean SYSTRACE_LIBRARY_LOADING;
    static final String TAG = "SoLoader";
    private static boolean isSystemApp;
    @Nullable
    private static ApplicationSoSource sApplicationSoSource;
    @Nullable
    private static UnpackingSoSource[] sBackupSoSources;
    private static int sFlags;
    private static final Set<String> sLoadedAndMergedLibraries = Collections.newSetFromMap(new ConcurrentHashMap());
    private static final HashSet<String> sLoadedLibraries = new HashSet<>();
    private static final Map<String, Object> sLoadingLibraries = new HashMap();
    @Nullable
    static SoFileLoader sSoFileLoader;
    @Nullable
    private static SoSource[] sSoSources = null;
    private static final ReentrantReadWriteLock sSoSourcesLock = new ReentrantReadWriteLock();
    private static volatile int sSoSourcesVersion = 0;
    @Nullable
    private static SystemLoadLibraryWrapper sSystemLoadLibraryWrapper = null;

    static /* synthetic */ int access$208() {
        int i = sSoSourcesVersion;
        sSoSourcesVersion = i + 1;
        return i;
    }

    static {
        boolean z = false;
        boolean shouldSystrace = false;
        try {
            if (Build.VERSION.SDK_INT >= 18) {
                z = true;
            }
            shouldSystrace = z;
        } catch (NoClassDefFoundError | UnsatisfiedLinkError e) {
        }
        SYSTRACE_LIBRARY_LOADING = shouldSystrace;
    }

    public static void init(Context context, int flags) throws IOException {
        init(context, flags, null);
    }

    public static void init(Context context, int flags, @Nullable SoFileLoader soFileLoader) throws IOException {
        StrictMode.ThreadPolicy oldPolicy = StrictMode.allowThreadDiskWrites();
        try {
            isSystemApp = checkIfSystemApp(context, flags);
            initSoLoader(soFileLoader);
            initSoSources(context, flags, soFileLoader);
            NativeLoader.initIfUninitialized(new NativeLoaderToSoLoaderDelegate());
        } finally {
            StrictMode.setThreadPolicy(oldPolicy);
        }
    }

    public static void init(Context context, boolean nativeExopackage) {
        try {
            init(context, nativeExopackage ? 1 : 0);
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    private static void initSoSources(Context context, int flags, @Nullable SoFileLoader soFileLoader) throws IOException {
        int apkSoSourceFlags;
        sSoSourcesLock.writeLock().lock();
        try {
            if (sSoSources == null) {
                Log.d(TAG, "init start");
                sFlags = flags;
                ArrayList<SoSource> soSources = new ArrayList<>();
                String LD_LIBRARY_PATH = System.getenv("LD_LIBRARY_PATH");
                if (LD_LIBRARY_PATH == null) {
                    LD_LIBRARY_PATH = SysUtil.is64Bit() ? "/vendor/lib64:/system/lib64" : "/vendor/lib:/system/lib";
                }
                String[] split = LD_LIBRARY_PATH.split(Constants.COLON_SEPARATOR);
                for (String systemLibraryDirectory : split) {
                    Log.d(TAG, "adding system library source: " + systemLibraryDirectory);
                    soSources.add(new DirectorySoSource(new File(systemLibraryDirectory), 2));
                }
                if (context != null) {
                    if ((flags & 1) != 0) {
                        sBackupSoSources = null;
                        Log.d(TAG, "adding exo package source: lib-main");
                        soSources.add(0, new ExoSoSource(context, SO_STORE_NAME_MAIN));
                    } else {
                        if (isSystemApp) {
                            apkSoSourceFlags = 0;
                        } else {
                            apkSoSourceFlags = 1;
                            int ourSoSourceFlags = 0;
                            if (Build.VERSION.SDK_INT <= 17) {
                                ourSoSourceFlags = 0 | 1;
                            }
                            sApplicationSoSource = new ApplicationSoSource(context, ourSoSourceFlags);
                            Log.d(TAG, "adding application source: " + sApplicationSoSource.toString());
                            soSources.add(0, sApplicationSoSource);
                        }
                        if ((sFlags & 8) != 0) {
                            sBackupSoSources = null;
                        } else {
                            File mainApkDir = new File(context.getApplicationInfo().sourceDir);
                            ArrayList<UnpackingSoSource> backupSources = new ArrayList<>();
                            ApkSoSource mainApkSource = new ApkSoSource(context, mainApkDir, SO_STORE_NAME_MAIN, apkSoSourceFlags);
                            backupSources.add(mainApkSource);
                            Log.d(TAG, "adding backup source from : " + mainApkSource.toString());
                            if (Build.VERSION.SDK_INT >= 21) {
                                if (context.getApplicationInfo().splitSourceDirs != null) {
                                    Log.d(TAG, "adding backup sources from split apks");
                                    int splitIndex = 0;
                                    String[] strArr = context.getApplicationInfo().splitSourceDirs;
                                    int length = strArr.length;
                                    int i = 0;
                                    while (i < length) {
                                        ApkSoSource splitApkSource = new ApkSoSource(context, new File(strArr[i]), SO_STORE_NAME_SPLIT + splitIndex, apkSoSourceFlags);
                                        Log.d(TAG, "adding backup source: " + splitApkSource.toString());
                                        backupSources.add(splitApkSource);
                                        i++;
                                        splitIndex++;
                                        LD_LIBRARY_PATH = LD_LIBRARY_PATH;
                                        mainApkSource = mainApkSource;
                                    }
                                }
                            }
                            sBackupSoSources = (UnpackingSoSource[]) backupSources.toArray(new UnpackingSoSource[backupSources.size()]);
                            soSources.addAll(0, backupSources);
                        }
                    }
                }
                SoSource[] finalSoSources = (SoSource[]) soSources.toArray(new SoSource[soSources.size()]);
                int prepareFlags = makePrepareFlags();
                int i2 = finalSoSources.length;
                while (true) {
                    int i3 = i2 - 1;
                    if (i2 <= 0) {
                        break;
                    }
                    Log.d(TAG, "Preparing SO source: " + finalSoSources[i3]);
                    finalSoSources[i3].prepare(prepareFlags);
                    i2 = i3;
                }
                sSoSources = finalSoSources;
                sSoSourcesVersion++;
                Log.d(TAG, "init finish: " + sSoSources.length + " SO sources prepared");
            }
        } finally {
            Log.d(TAG, "init exiting");
            sSoSourcesLock.writeLock().unlock();
        }
    }

    private static int makePrepareFlags() {
        int prepareFlags = 0;
        sSoSourcesLock.writeLock().lock();
        try {
            if ((sFlags & 2) != 0) {
                prepareFlags = 0 | 1;
            }
            return prepareFlags;
        } finally {
            sSoSourcesLock.writeLock().unlock();
        }
    }

    private static synchronized void initSoLoader(@Nullable SoFileLoader soFileLoader) {
        synchronized (SoLoader.class) {
            if (soFileLoader != null) {
                sSoFileLoader = soFileLoader;
                return;
            }
            final Runtime runtime = Runtime.getRuntime();
            final Method nativeLoadRuntimeMethod = getNativeLoadRuntimeMethod();
            final boolean hasNativeLoadMethod = nativeLoadRuntimeMethod != null;
            final String localLdLibraryPath = hasNativeLoadMethod ? Api14Utils.getClassLoaderLdLoadLibrary() : null;
            final String localLdLibraryPathNoZips = makeNonZipPath(localLdLibraryPath);
            sSoFileLoader = new SoFileLoader() {
                /* class com.facebook.soloader.SoLoader.AnonymousClass1 */

                @Override // com.facebook.soloader.SoFileLoader
                public void load(String pathToSoFile, int loadFlags) {
                    String error;
                    if (hasNativeLoadMethod) {
                        String path = (loadFlags & 4) == 4 ? localLdLibraryPath : localLdLibraryPathNoZips;
                        try {
                            synchronized (runtime) {
                                error = (String) nativeLoadRuntimeMethod.invoke(runtime, pathToSoFile, SoLoader.class.getClassLoader(), path);
                                if (error != null) {
                                    throw new UnsatisfiedLinkError(error);
                                }
                            }
                            if (error != null) {
                                Log.e(SoLoader.TAG, "Error when loading lib: " + error + " lib hash: " + getLibHash(pathToSoFile) + " search path is " + path);
                            }
                        } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException e) {
                            throw new RuntimeException("Error: Cannot load " + pathToSoFile, e);
                        } catch (Throwable th) {
                            if (0 != 0) {
                                Log.e(SoLoader.TAG, "Error when loading lib: " + ((String) null) + " lib hash: " + getLibHash(pathToSoFile) + " search path is " + path);
                            }
                            throw th;
                        }
                    } else {
                        System.load(pathToSoFile);
                    }
                }

                /* JADX WARNING: Code restructure failed: missing block: B:13:0x003b, code lost:
                    r4 = move-exception;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:15:?, code lost:
                    r2.close();
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:16:0x0040, code lost:
                    r5 = move-exception;
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:17:0x0041, code lost:
                    r3.addSuppressed(r5);
                 */
                /* JADX WARNING: Code restructure failed: missing block: B:18:0x0044, code lost:
                    throw r4;
                 */
                private String getLibHash(String libPath) {
                    try {
                        File libFile = new File(libPath);
                        MessageDigest digest = MessageDigest.getInstance(Md5Utils.ALGORITHM);
                        InputStream libInStream = new FileInputStream(libFile);
                        byte[] buffer = new byte[4096];
                        while (true) {
                            int bytesRead = libInStream.read(buffer);
                            if (bytesRead > 0) {
                                digest.update(buffer, 0, bytesRead);
                            } else {
                                String digestStr = String.format("%32x", new BigInteger(1, digest.digest()));
                                libInStream.close();
                                return digestStr;
                            }
                        }
                    } catch (IOException e) {
                        return e.toString();
                    } catch (SecurityException e2) {
                        return e2.toString();
                    } catch (NoSuchAlgorithmException e3) {
                        return e3.toString();
                    }
                }
            };
        }
    }

    @Nullable
    private static Method getNativeLoadRuntimeMethod() {
        if (Build.VERSION.SDK_INT < 23 || Build.VERSION.SDK_INT > 27) {
            return null;
        }
        try {
            Method method = Runtime.class.getDeclaredMethod("nativeLoad", String.class, ClassLoader.class, String.class);
            method.setAccessible(true);
            return method;
        } catch (NoSuchMethodException | SecurityException e) {
            Log.w(TAG, "Cannot get nativeLoad method", e);
            return null;
        }
    }

    private static boolean checkIfSystemApp(Context context, int flags) {
        if ((flags & 32) != 0 || context == null || (context.getApplicationInfo().flags & 129) == 0) {
            return false;
        }
        return true;
    }

    public static void setInTestMode() {
        TestOnlyUtils.setSoSources(new SoSource[]{new NoopSoSource()});
    }

    public static void deinitForTest() {
        TestOnlyUtils.setSoSources(null);
    }

    static class TestOnlyUtils {
        TestOnlyUtils() {
        }

        static void setSoSources(SoSource[] sources) {
            SoLoader.sSoSourcesLock.writeLock().lock();
            try {
                SoSource[] unused = SoLoader.sSoSources = sources;
                SoLoader.access$208();
            } finally {
                SoLoader.sSoSourcesLock.writeLock().unlock();
            }
        }

        static void setSoFileLoader(SoFileLoader loader) {
            SoLoader.sSoFileLoader = loader;
        }

        static void resetStatus() {
            synchronized (SoLoader.class) {
                SoLoader.sLoadedLibraries.clear();
                SoLoader.sLoadingLibraries.clear();
                SoLoader.sSoFileLoader = null;
            }
            setSoSources(null);
        }
    }

    public static void setSystemLoadLibraryWrapper(SystemLoadLibraryWrapper wrapper) {
        sSystemLoadLibraryWrapper = wrapper;
    }

    public static final class WrongAbiError extends UnsatisfiedLinkError {
        WrongAbiError(Throwable cause, String machine) {
            super("APK was built for a different platform. Supported ABIs: " + Arrays.toString(SysUtil.getSupportedAbis()) + " error: " + machine);
            initCause(cause);
        }
    }

    @Nullable
    public static String getLibraryPath(String libName) throws IOException {
        String libPath = null;
        sSoSourcesLock.readLock().lock();
        try {
            if (sSoSources != null) {
                int i = 0;
                while (libPath == null && i < sSoSources.length) {
                    libPath = sSoSources[i].getLibraryPath(libName);
                    i++;
                }
            }
            return libPath;
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    @Nullable
    public static String[] getLibraryDependencies(String libName) throws IOException {
        String[] deps = null;
        sSoSourcesLock.readLock().lock();
        try {
            if (sSoSources != null) {
                int i = 0;
                while (deps == null && i < sSoSources.length) {
                    deps = sSoSources[i].getLibraryDependencies(libName);
                    i++;
                }
            }
            return deps;
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    public static boolean loadLibrary(String shortName) {
        return loadLibrary(shortName, 0);
    }

    /* JADX INFO: finally extract failed */
    public static boolean loadLibrary(String shortName, int loadFlags) throws UnsatisfiedLinkError {
        SystemLoadLibraryWrapper systemLoadLibraryWrapper;
        boolean needsLoad;
        sSoSourcesLock.readLock().lock();
        try {
            if (sSoSources == null) {
                if ("http://www.android.com/".equals(System.getProperty("java.vendor.url"))) {
                    assertInitialized();
                } else {
                    synchronized (SoLoader.class) {
                        needsLoad = true ^ sLoadedLibraries.contains(shortName);
                        if (needsLoad) {
                            if (sSystemLoadLibraryWrapper != null) {
                                sSystemLoadLibraryWrapper.loadLibrary(shortName);
                            } else {
                                System.loadLibrary(shortName);
                            }
                        }
                    }
                    sSoSourcesLock.readLock().unlock();
                    return needsLoad;
                }
            }
            sSoSourcesLock.readLock().unlock();
            if (!isSystemApp || (systemLoadLibraryWrapper = sSystemLoadLibraryWrapper) == null) {
                String mergedLibName = MergedSoMapping.mapLibName(shortName);
                return loadLibraryBySoName(System.mapLibraryName(mergedLibName != null ? mergedLibName : shortName), shortName, mergedLibName, loadFlags, null);
            }
            systemLoadLibraryWrapper.loadLibrary(shortName);
            return true;
        } catch (Throwable th) {
            sSoSourcesLock.readLock().unlock();
            throw th;
        }
    }

    static void loadLibraryBySoName(String soName, int loadFlags, StrictMode.ThreadPolicy oldPolicy) {
        loadLibraryBySoNameImpl(soName, null, null, loadFlags, oldPolicy);
    }

    private static boolean loadLibraryBySoName(String soName, @Nullable String shortName, @Nullable String mergedLibName, int loadFlags, @Nullable StrictMode.ThreadPolicy oldPolicy) {
        boolean retry;
        boolean ret = false;
        do {
            retry = false;
            try {
                ret = loadLibraryBySoNameImpl(soName, shortName, mergedLibName, loadFlags, oldPolicy);
                continue;
            } catch (UnsatisfiedLinkError e) {
                int currentVersion = sSoSourcesVersion;
                sSoSourcesLock.writeLock().lock();
                try {
                    if (sApplicationSoSource != null && sApplicationSoSource.checkAndMaybeUpdate()) {
                        Log.w(TAG, "sApplicationSoSource updated during load: " + soName + ", attempting load again.");
                        sSoSourcesVersion = sSoSourcesVersion + 1;
                        retry = true;
                    }
                    sSoSourcesLock.writeLock().unlock();
                    if (sSoSourcesVersion == currentVersion) {
                        throw e;
                    }
                } catch (IOException ex) {
                    throw new RuntimeException(ex);
                } catch (Throwable th) {
                    sSoSourcesLock.writeLock().unlock();
                    throw th;
                }
            }
        } while (retry);
        return ret;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:19:0x003b, code lost:
        com.facebook.soloader.SoLoader.sSoSourcesLock.readLock().lock();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:?, code lost:
        monitor-enter(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0045, code lost:
        if (r1 != false) goto L_0x00c1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:?, code lost:
        monitor-enter(com.facebook.soloader.SoLoader.class);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x004e, code lost:
        if (com.facebook.soloader.SoLoader.sLoadedLibraries.contains(r7) == false) goto L_0x005f;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0050, code lost:
        if (r9 != null) goto L_0x005e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:29:0x0052, code lost:
        monitor-exit(com.facebook.soloader.SoLoader.class);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0053, code lost:
        monitor-exit(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x005d, code lost:
        return false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x005e, code lost:
        r1 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:0x005f, code lost:
        monitor-exit(com.facebook.soloader.SoLoader.class);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0060, code lost:
        if (r1 != false) goto L_0x00c1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:38:?, code lost:
        android.util.Log.d(com.facebook.soloader.SoLoader.TAG, "About to load: " + r7);
        doLoadLibraryBySoName(r7, r10, r11);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:39:0x007c, code lost:
        monitor-enter(com.facebook.soloader.SoLoader.class);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:?, code lost:
        android.util.Log.d(com.facebook.soloader.SoLoader.TAG, "Loaded: " + r7);
        com.facebook.soloader.SoLoader.sLoadedLibraries.add(r7);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x0098, code lost:
        monitor-exit(com.facebook.soloader.SoLoader.class);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x009d, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:49:0x009e, code lost:
        r2 = r0.getMessage();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:50:0x00a2, code lost:
        if (r2 == null) goto L_0x00bd;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:54:0x00bb, code lost:
        throw new com.facebook.soloader.SoLoader.WrongAbiError(r0, r2.substring(r2.lastIndexOf("unexpected e_machine:")));
     */
    /* JADX WARNING: Code restructure failed: missing block: B:55:0x00bd, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x00c3, code lost:
        if ((r10 & 16) != 0) goto L_0x0143;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x00ca, code lost:
        if (android.text.TextUtils.isEmpty(r8) != false) goto L_0x00d5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x00d2, code lost:
        if (com.facebook.soloader.SoLoader.sLoadedAndMergedLibraries.contains(r8) == false) goto L_0x00d5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x00d4, code lost:
        r2 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:67:0x00d6, code lost:
        if (r9 == null) goto L_0x0143;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:68:0x00d8, code lost:
        if (r2 != false) goto L_0x0143;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:70:0x00dc, code lost:
        if (com.facebook.soloader.SoLoader.SYSTRACE_LIBRARY_LOADING == false) goto L_0x00e5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x00de, code lost:
        com.facebook.soloader.Api18TraceUtils.beginTraceSection("MergedSoMapping.invokeJniOnload[", r8, com.taobao.weex.el.parse.Operators.ARRAY_END_STR);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:74:?, code lost:
        android.util.Log.d(com.facebook.soloader.SoLoader.TAG, "About to merge: " + r8 + " / " + r7);
        com.facebook.soloader.MergedSoMapping.invokeJniOnload(r8);
        com.facebook.soloader.SoLoader.sLoadedAndMergedLibraries.add(r8);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:76:0x010d, code lost:
        if (com.facebook.soloader.SoLoader.SYSTRACE_LIBRARY_LOADING == false) goto L_0x0143;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:77:0x010f, code lost:
        com.facebook.soloader.Api18TraceUtils.endSection();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:78:0x0113, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:79:0x0115, code lost:
        r2 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:82:0x0139, code lost:
        throw new java.lang.RuntimeException("Failed to call JNI_OnLoad from '" + r8 + "', which has been merged into '" + r7 + "'.  See comment for details.", r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:84:0x013c, code lost:
        if (com.facebook.soloader.SoLoader.SYSTRACE_LIBRARY_LOADING != false) goto L_0x013e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:85:0x013e, code lost:
        com.facebook.soloader.Api18TraceUtils.endSection();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:86:0x0142, code lost:
        throw r2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:87:0x0143, code lost:
        monitor-exit(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:88:0x0144, code lost:
        com.facebook.soloader.SoLoader.sSoSourcesLock.readLock().unlock();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:89:0x0150, code lost:
        return !r1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:93:0x0154, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:94:0x0155, code lost:
        com.facebook.soloader.SoLoader.sSoSourcesLock.readLock().unlock();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:95:0x015e, code lost:
        throw r0;
     */
    private static boolean loadLibraryBySoNameImpl(String soName, @Nullable String shortName, @Nullable String mergedLibName, int loadFlags, @Nullable StrictMode.ThreadPolicy oldPolicy) {
        Object loadingLibLock;
        boolean isAlreadyMerged = false;
        if (!TextUtils.isEmpty(shortName) && sLoadedAndMergedLibraries.contains(shortName)) {
            return false;
        }
        boolean loaded = false;
        synchronized (SoLoader.class) {
            if (sLoadedLibraries.contains(soName)) {
                if (mergedLibName == null) {
                    return false;
                }
                loaded = true;
            }
            if (sLoadingLibraries.containsKey(soName)) {
                loadingLibLock = sLoadingLibraries.get(soName);
            } else {
                loadingLibLock = new Object();
                sLoadingLibraries.put(soName, loadingLibLock);
            }
        }
    }

    public static File unpackLibraryAndDependencies(String shortName) throws UnsatisfiedLinkError {
        assertInitialized();
        try {
            return unpackLibraryBySoName(System.mapLibraryName(shortName));
        } catch (IOException ex) {
            throw new RuntimeException(ex);
        }
    }

    /* JADX INFO: finally extract failed */
    /* JADX INFO: Multiple debug info for r5v6 'result'  int: [D('result' int), D('resultFromBackup' int)] */
    private static void doLoadLibraryBySoName(String soName, int loadFlags, @Nullable StrictMode.ThreadPolicy oldPolicy) throws UnsatisfiedLinkError {
        boolean restoreOldPolicy;
        StrictMode.ThreadPolicy oldPolicy2;
        Throwable th;
        int i = loadFlags;
        int result = 0;
        sSoSourcesLock.readLock().lock();
        try {
            if (sSoSources != null) {
                sSoSourcesLock.readLock().unlock();
                if (oldPolicy == null) {
                    oldPolicy2 = StrictMode.allowThreadDiskReads();
                    restoreOldPolicy = true;
                } else {
                    oldPolicy2 = oldPolicy;
                    restoreOldPolicy = false;
                }
                if (SYSTRACE_LIBRARY_LOADING) {
                    Api18TraceUtils.beginTraceSection("SoLoader.loadLibrary[", soName, Operators.ARRAY_END_STR);
                }
                Throwable error = null;
                int i2 = 3;
                try {
                    sSoSourcesLock.readLock().lock();
                    int i3 = 0;
                    while (true) {
                        if (result != 0) {
                            break;
                        }
                        try {
                            if (i3 >= sSoSources.length) {
                                break;
                            }
                            result = sSoSources[i3].loadLibrary(soName, i, oldPolicy2);
                            if (result == i2) {
                                try {
                                    if (sBackupSoSources != null) {
                                        Log.d(TAG, "Trying backup SoSource for " + soName);
                                        UnpackingSoSource[] unpackingSoSourceArr = sBackupSoSources;
                                        int length = unpackingSoSourceArr.length;
                                        int i4 = 0;
                                        while (true) {
                                            if (i4 >= length) {
                                                break;
                                            }
                                            UnpackingSoSource backupSoSource = unpackingSoSourceArr[i4];
                                            backupSoSource.prepare(soName);
                                            result = backupSoSource.loadLibrary(soName, i, oldPolicy2);
                                            if (result == 1) {
                                                break;
                                            }
                                            i4++;
                                            i = loadFlags;
                                            result = result;
                                        }
                                    }
                                } catch (Throwable th2) {
                                    th = th2;
                                    sSoSourcesLock.readLock().unlock();
                                    throw th;
                                }
                            }
                            i3++;
                            i = loadFlags;
                            result = result;
                            i2 = 3;
                        } catch (Throwable th3) {
                            th = th3;
                            sSoSourcesLock.readLock().unlock();
                            throw th;
                        }
                    }
                    sSoSourcesLock.readLock().unlock();
                    if (SYSTRACE_LIBRARY_LOADING) {
                        Api18TraceUtils.endSection();
                    }
                    if (restoreOldPolicy) {
                        StrictMode.setThreadPolicy(oldPolicy2);
                    }
                    if (result == 0 || result == 3) {
                        StringBuilder sb = new StringBuilder();
                        sb.append("couldn't find DSO to load: ");
                        StringBuilder sb2 = sb.append(soName);
                        if (0 != 0) {
                            String cause = error.getMessage();
                            if (cause == null) {
                                cause = error.toString();
                            }
                            sb2.append(" caused by: ");
                            sb2.append(cause);
                            error.printStackTrace();
                        } else {
                            sSoSourcesLock.readLock().lock();
                            for (int i5 = 0; i5 < sSoSources.length; i5++) {
                                sb2.append("\n\tSoSource ");
                                sb2.append(i5);
                                sb2.append(": ");
                                sb2.append(sSoSources[i5].toString());
                            }
                            ApplicationSoSource applicationSoSource = sApplicationSoSource;
                            if (applicationSoSource != null) {
                                File updatedNativeLibDir = ApplicationSoSource.getNativeLibDirFromContext(applicationSoSource.getUpdatedContext());
                                sb2.append("\n\tNative lib dir: ");
                                sb2.append(updatedNativeLibDir.getAbsolutePath());
                                sb2.append("\n");
                            }
                            sSoSourcesLock.readLock().unlock();
                        }
                        sb2.append(" result: ");
                        sb2.append(result);
                        String message = sb2.toString();
                        Log.e(TAG, message);
                        UnsatisfiedLinkError err = new UnsatisfiedLinkError(message);
                        if (0 != 0) {
                            err.initCause(null);
                        }
                        throw err;
                    }
                } catch (Throwable t) {
                    if (SYSTRACE_LIBRARY_LOADING) {
                        Api18TraceUtils.endSection();
                    }
                    if (restoreOldPolicy) {
                        StrictMode.setThreadPolicy(oldPolicy2);
                    }
                    if (0 == 0 || 0 == 3) {
                        StringBuilder sb3 = new StringBuilder();
                        sb3.append("couldn't find DSO to load: ");
                        StringBuilder sb4 = sb3.append(soName);
                        String cause2 = t.getMessage();
                        if (cause2 == null) {
                            cause2 = t.toString();
                        }
                        sb4.append(" caused by: ");
                        sb4.append(cause2);
                        t.printStackTrace();
                        sb4.append(" result: ");
                        sb4.append(0);
                        String message2 = sb4.toString();
                        Log.e(TAG, message2);
                        UnsatisfiedLinkError err2 = new UnsatisfiedLinkError(message2);
                        err2.initCause(t);
                        throw err2;
                    }
                }
            } else {
                Log.e(TAG, "Could not load: " + soName + " because no SO source exists");
                throw new UnsatisfiedLinkError("couldn't find DSO to load: " + soName);
            }
        } catch (Throwable th4) {
            sSoSourcesLock.readLock().unlock();
            throw th4;
        }
    }

    @Nullable
    public static String makeNonZipPath(String localLdLibraryPath) {
        if (localLdLibraryPath == null) {
            return null;
        }
        String[] paths = localLdLibraryPath.split(Constants.COLON_SEPARATOR);
        ArrayList<String> pathsWithoutZip = new ArrayList<>(paths.length);
        for (String path : paths) {
            if (!path.contains(Operators.AND_NOT)) {
                pathsWithoutZip.add(path);
            }
        }
        return TextUtils.join(Constants.COLON_SEPARATOR, pathsWithoutZip);
    }

    static File unpackLibraryBySoName(String soName) throws IOException {
        sSoSourcesLock.readLock().lock();
        try {
            for (SoSource soSource : sSoSources) {
                File unpacked = soSource.unpackLibrary(soName);
                if (unpacked != null) {
                    return unpacked;
                }
            }
            sSoSourcesLock.readLock().unlock();
            throw new FileNotFoundException(soName);
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    private static void assertInitialized() {
        if (!isInitialized()) {
            throw new IllegalStateException("SoLoader.init() not yet called");
        }
    }

    public static boolean isInitialized() {
        sSoSourcesLock.readLock().lock();
        try {
            return sSoSources != null;
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    public static int getSoSourcesVersion() {
        return sSoSourcesVersion;
    }

    public static void prependSoSource(SoSource extraSoSource) throws IOException {
        sSoSourcesLock.writeLock().lock();
        try {
            Log.d(TAG, "Prepending to SO sources: " + extraSoSource);
            assertInitialized();
            extraSoSource.prepare(makePrepareFlags());
            SoSource[] newSoSources = new SoSource[(sSoSources.length + 1)];
            newSoSources[0] = extraSoSource;
            System.arraycopy(sSoSources, 0, newSoSources, 1, sSoSources.length);
            sSoSources = newSoSources;
            sSoSourcesVersion++;
            Log.d(TAG, "Prepended to SO sources: " + extraSoSource);
        } finally {
            sSoSourcesLock.writeLock().unlock();
        }
    }

    public static String makeLdLibraryPath() {
        sSoSourcesLock.readLock().lock();
        try {
            assertInitialized();
            Log.d(TAG, "makeLdLibraryPath");
            ArrayList<String> pathElements = new ArrayList<>();
            SoSource[] soSources = sSoSources;
            if (soSources != null) {
                for (SoSource soSource : soSources) {
                    soSource.addToLdLibraryPath(pathElements);
                }
            }
            String joinedPaths = TextUtils.join(Constants.COLON_SEPARATOR, pathElements);
            Log.d(TAG, "makeLdLibraryPath final path: " + joinedPaths);
            return joinedPaths;
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    public static boolean areSoSourcesAbisSupported() {
        sSoSourcesLock.readLock().lock();
        try {
            if (sSoSources == null) {
                return false;
            }
            String[] supportedAbis = SysUtil.getSupportedAbis();
            for (SoSource soSource : sSoSources) {
                String[] soSourceAbis = soSource.getSoSourceAbis();
                for (String soSourceAbi : soSourceAbis) {
                    boolean soSourceSupported = false;
                    for (int k = 0; k < supportedAbis.length && !soSourceSupported; k++) {
                        soSourceSupported = soSourceAbi.equals(supportedAbis[k]);
                    }
                    if (!soSourceSupported) {
                        Log.e(TAG, "abi not supported: " + soSourceAbi);
                        sSoSourcesLock.readLock().unlock();
                        return false;
                    }
                }
            }
            sSoSourcesLock.readLock().unlock();
            return true;
        } finally {
            sSoSourcesLock.readLock().unlock();
        }
    }

    /* access modifiers changed from: private */
    public static class Api14Utils {
        private Api14Utils() {
        }

        public static String getClassLoaderLdLoadLibrary() {
            ClassLoader classLoader = SoLoader.class.getClassLoader();
            if (classLoader == null || (classLoader instanceof BaseDexClassLoader)) {
                try {
                    return (String) BaseDexClassLoader.class.getMethod("getLdLibraryPath", new Class[0]).invoke((BaseDexClassLoader) classLoader, new Object[0]);
                } catch (Exception e) {
                    throw new RuntimeException("Cannot call getLdLibraryPath", e);
                }
            } else {
                throw new IllegalStateException("ClassLoader " + classLoader.getClass().getName() + " should be of type BaseDexClassLoader");
            }
        }
    }
}
