package com.getui.gtc.base.crypt;

import android.util.Base64;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.Key;
import java.security.KeyFactory;
import java.security.KeyPair;
import java.security.KeyPairGenerator;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.PublicKey;
import java.security.Signature;
import java.security.SignatureException;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;
import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.CipherInputStream;
import javax.crypto.CipherOutputStream;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.KeyGenerator;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;

public class CryptTools {
    public static InputStream decrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, InputStream inputStream) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException, InvalidAlgorithmParameterException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(2, secretKey, ivParameterSpec);
        return new CipherInputStream(inputStream, instance);
    }

    public static OutputStream decrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, OutputStream outputStream) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException, InvalidAlgorithmParameterException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(2, secretKey, ivParameterSpec);
        return new CipherOutputStream(outputStream, instance);
    }

    public static byte[] decrypt(String str, PrivateKey privateKey, byte[] bArr) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(2, privateKey);
        return instance.doFinal(bArr);
    }

    public static byte[] decrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, byte[] bArr) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidAlgorithmParameterException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(2, secretKey, ivParameterSpec);
        return instance.doFinal(bArr);
    }

    public static byte[] digest(String str, byte[] bArr) throws NoSuchAlgorithmException {
        MessageDigest instance = MessageDigest.getInstance(str);
        instance.update(bArr);
        return instance.digest();
    }

    public static String digestToHexString(String str, byte[] bArr) throws NoSuchAlgorithmException {
        byte[] digest = digest(str, bArr);
        StringBuilder sb = new StringBuilder();
        for (byte b : digest) {
            int i = b;
            if (b < 0) {
                i = b + 256;
            }
            if (i < 16) {
                sb.append("0");
            }
            sb.append(Integer.toHexString(i == 1 ? 1 : 0));
        }
        return sb.toString();
    }

    public static InputStream encrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, InputStream inputStream) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException, InvalidAlgorithmParameterException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(1, secretKey, ivParameterSpec);
        return new CipherInputStream(inputStream, instance);
    }

    public static OutputStream encrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, OutputStream outputStream) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException, InvalidAlgorithmParameterException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(1, secretKey, ivParameterSpec);
        return new CipherOutputStream(outputStream, instance);
    }

    public static byte[] encrypt(String str, PublicKey publicKey, byte[] bArr) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(1, publicKey);
        return instance.doFinal(bArr);
    }

    public static byte[] encrypt(String str, SecretKey secretKey, IvParameterSpec ivParameterSpec, byte[] bArr) throws NoSuchPaddingException, NoSuchAlgorithmException, InvalidKeyException, BadPaddingException, IllegalBlockSizeException, InvalidAlgorithmParameterException {
        Cipher instance = Cipher.getInstance(str);
        instance.init(1, secretKey, ivParameterSpec);
        return instance.doFinal(bArr);
    }

    public static SecretKey generateKey(String str, int i) throws NoSuchAlgorithmException {
        KeyGenerator instance = KeyGenerator.getInstance(str);
        instance.init(i);
        return instance.generateKey();
    }

    public static KeyPair generateKeyPair(String str, int i) throws NoSuchAlgorithmException {
        KeyPairGenerator instance = KeyPairGenerator.getInstance(str);
        instance.initialize(i);
        return instance.generateKeyPair();
    }

    public static String keyToString(Key key) {
        byte[] encoded = key.getEncoded();
        if (encoded != null) {
            return Base64.encodeToString(encoded, 0);
        }
        throw new RuntimeException("can not transform key to string");
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x003f  */
    public static PrivateKey parsePrivateKey(String str, File file) throws NoSuchAlgorithmException, InvalidKeySpecException, IOException {
        Throwable th;
        BufferedReader bufferedReader = null;
        try {
            BufferedReader bufferedReader2 = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
            try {
                StringBuilder sb = new StringBuilder();
                while (true) {
                    String readLine = bufferedReader2.readLine();
                    if (readLine == null) {
                        PrivateKey parsePrivateKey = parsePrivateKey(str, sb.toString());
                        bufferedReader2.close();
                        return parsePrivateKey;
                    } else if (readLine.charAt(0) != '-') {
                        sb.append(readLine);
                        sb.append('\r');
                    }
                }
            } catch (Throwable th2) {
                th = th2;
                bufferedReader = bufferedReader2;
                if (bufferedReader != null) {
                    bufferedReader.close();
                }
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            if (bufferedReader != null) {
            }
            throw th;
        }
    }

    public static PrivateKey parsePrivateKey(String str, String str2) throws NoSuchAlgorithmException, InvalidKeySpecException {
        return KeyFactory.getInstance(str).generatePrivate(new PKCS8EncodedKeySpec(Base64.decode(str2, 0)));
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x003f  */
    public static PublicKey parsePublicKey(String str, File file) throws NoSuchAlgorithmException, InvalidKeySpecException, IOException {
        Throwable th;
        BufferedReader bufferedReader = null;
        try {
            BufferedReader bufferedReader2 = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
            try {
                StringBuilder sb = new StringBuilder();
                while (true) {
                    String readLine = bufferedReader2.readLine();
                    if (readLine == null) {
                        PublicKey parsePublicKey = parsePublicKey(str, sb.toString());
                        bufferedReader2.close();
                        return parsePublicKey;
                    } else if (readLine.charAt(0) != '-') {
                        sb.append(readLine);
                        sb.append('\r');
                    }
                }
            } catch (Throwable th2) {
                th = th2;
                bufferedReader = bufferedReader2;
                if (bufferedReader != null) {
                    bufferedReader.close();
                }
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            if (bufferedReader != null) {
            }
            throw th;
        }
    }

    public static PublicKey parsePublicKey(String str, String str2) throws NoSuchAlgorithmException, InvalidKeySpecException {
        return KeyFactory.getInstance(str).generatePublic(new X509EncodedKeySpec(Base64.decode(str2, 0)));
    }

    public static SecretKey parseSecretKey(String str, String str2) {
        return wrapperKey(str, Base64.decode(str2, 0));
    }

    public static byte[] sign(String str, PrivateKey privateKey, byte[] bArr) throws NoSuchAlgorithmException, InvalidKeyException, SignatureException {
        Signature instance = Signature.getInstance(str);
        instance.initSign(privateKey);
        instance.update(bArr);
        return instance.sign();
    }

    public static boolean verify(String str, PublicKey publicKey, byte[] bArr, byte[] bArr2) throws InvalidKeyException, NoSuchAlgorithmException, SignatureException {
        Signature instance = Signature.getInstance(str);
        instance.initVerify(publicKey);
        instance.update(bArr);
        return instance.verify(bArr2);
    }

    public static SecretKey wrapperKey(String str, byte[] bArr) {
        return new SecretKeySpec(bArr, str);
    }
}
