package com.getui.gtc.base.http;

import com.efs.sdk.base.Constants;
import com.getui.gtc.base.http.Interceptor;
import com.getui.gtc.base.http.Request;
import com.getui.gtc.base.http.Response;
import io.dcloud.common.util.net.NetWork;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.util.zip.GZIPInputStream;

public class BridgeInterceptor implements Interceptor {
    @Override // com.getui.gtc.base.http.Interceptor
    public Response intercept(Interceptor.Chain chain) throws IOException {
        Request request = chain.request();
        Request.Builder builder = new Request.Builder(request);
        HttpURLConnection httpURLConnection = (HttpURLConnection) request.url().openConnection();
        RequestBody body = request.body();
        if (body != null) {
            MediaType contentType = body.contentType();
            if (contentType != null) {
                builder.addHeader(NetWork.CONTENT_TYPE, contentType.toString());
            }
            long contentLength = body.contentLength();
            if (contentLength != -1) {
                builder.addHeader("Content-Length", Long.toString(contentLength)).removeHeader("Transfer-Encoding");
            } else {
                builder.addHeader("Transfer-Encoding", "chunked").removeHeader("Content-Length");
            }
        }
        if (request.header("Host") == null) {
            builder.addHeader("Host", request.url().getHost());
        }
        if (request.header("Connection") == null) {
            builder.addHeader("Connection", "Keep-Alive");
        }
        boolean z = false;
        if (request.header("Accept-Encoding") == null && request.header("Range") == null) {
            z = true;
            builder.addHeader("Accept-Encoding", Constants.CP_GZIP);
        }
        Response proceed = ((RealInterceptorChain) chain).proceed(builder.build(), httpURLConnection);
        Response.Builder request2 = new Response.Builder(proceed).request(request);
        if (z && Constants.CP_GZIP.equalsIgnoreCase(proceed.header("Content-Encoding")) && proceed.body() != null) {
            request2.body(ResponseBody.create(proceed.body().contentType(), -1, new GZIPInputStream(proceed.body().byteStream()))).removeHeader("Content-Encoding").removeHeader("Content-Length");
        }
        return request2.build();
    }
}
