package com.getui.gtc.base.http;

import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;

final class BufferedSink {
    public final OutputStream sink;
    private long size;

    BufferedSink(OutputStream outputStream) {
        if (outputStream != null) {
            this.sink = outputStream;
            this.size = 0;
            return;
        }
        throw new NullPointerException("sink == null");
    }

    public final void close() throws IOException {
        this.sink.close();
    }

    public final long size() {
        return this.size;
    }

    public final BufferedSink write(String str) throws IOException {
        byte[] bytes = str.getBytes();
        this.sink.write(bytes);
        this.size += (long) bytes.length;
        return this;
    }

    public final BufferedSink write(ByteBuffer byteBuffer) throws IOException {
        byte[] array = byteBuffer.array();
        this.sink.write(array);
        this.size += (long) array.length;
        return this;
    }

    public final BufferedSink write(byte[] bArr) throws IOException {
        this.sink.write(bArr);
        this.size += (long) bArr.length;
        return this;
    }

    public final BufferedSink writeLong(long j) throws IOException {
        byte[] bytes = String.valueOf(j).getBytes();
        this.sink.write(bytes);
        this.size += (long) bytes.length;
        return this;
    }

    public final BufferedSink writeUtf8(String str) throws IOException {
        byte[] bytes = str.getBytes();
        this.sink.write(bytes);
        this.size += (long) bytes.length;
        return this;
    }
}
