package com.getui.gtc.base.http;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.charset.Charset;

public abstract class RequestBody {
    public static RequestBody create(final MediaType mediaType, final File file) {
        if (file != null) {
            return new RequestBody() {
                /* class com.getui.gtc.base.http.RequestBody.AnonymousClass2 */

                @Override // com.getui.gtc.base.http.RequestBody
                public final long contentLength() {
                    return file.length();
                }

                @Override // com.getui.gtc.base.http.RequestBody
                public final MediaType contentType() {
                    return mediaType;
                }

                @Override // com.getui.gtc.base.http.RequestBody
                public final void writeTo(OutputStream outputStream) throws IOException {
                    Throwable th;
                    FileInputStream fileInputStream = null;
                    try {
                        FileInputStream fileInputStream2 = new FileInputStream(file);
                        try {
                            byte[] bArr = new byte[1024];
                            while (true) {
                                int read = fileInputStream2.read(bArr);
                                if (read != -1) {
                                    outputStream.write(bArr, 0, read);
                                } else {
                                    Util.closeQuietly(fileInputStream2);
                                    return;
                                }
                            }
                        } catch (Throwable th2) {
                            th = th2;
                            fileInputStream = fileInputStream2;
                            Util.closeQuietly(fileInputStream);
                            throw th;
                        }
                    } catch (Throwable th3) {
                        th = th3;
                        Util.closeQuietly(fileInputStream);
                        throw th;
                    }
                }
            };
        }
        throw new NullPointerException("content == null");
    }

    public static RequestBody create(MediaType mediaType, String str) {
        Charset charset = Util.UTF_8;
        if (mediaType != null && (charset = mediaType.charset()) == null) {
            charset = Util.UTF_8;
            mediaType = MediaType.parse(mediaType + "; charset=utf-8");
        }
        return create(mediaType, str.getBytes(charset));
    }

    public static RequestBody create(MediaType mediaType, byte[] bArr) {
        return create(mediaType, bArr, 0, bArr.length);
    }

    public static RequestBody create(final MediaType mediaType, final byte[] bArr, final int i, final int i2) {
        if (bArr != null) {
            Util.checkOffsetAndCount((long) bArr.length, (long) i, (long) i2);
            return new RequestBody() {
                /* class com.getui.gtc.base.http.RequestBody.AnonymousClass1 */

                @Override // com.getui.gtc.base.http.RequestBody
                public final long contentLength() {
                    return (long) i2;
                }

                @Override // com.getui.gtc.base.http.RequestBody
                public final MediaType contentType() {
                    return mediaType;
                }

                @Override // com.getui.gtc.base.http.RequestBody
                public final void writeTo(OutputStream outputStream) throws IOException {
                    outputStream.write(bArr, i, i2);
                }
            };
        }
        throw new NullPointerException("content == null");
    }

    public abstract long contentLength();

    public abstract MediaType contentType();

    public abstract void writeTo(OutputStream outputStream) throws IOException;
}
