package com.getui.gtc.base.util;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;

public abstract class OnForegroundChangedListener implements Application.ActivityLifecycleCallbacks {
    private boolean isForeground = false;
    private int resumedCounter = 0;

    private void checkForegroundChanged() {
        try {
            if (this.isForeground && this.resumedCounter == 0) {
                this.isForeground = false;
                onForegroundChanged(false);
            }
            if (!this.isForeground && this.resumedCounter > 0) {
                this.isForeground = true;
                onForegroundChanged(true);
            }
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    public void onActivityCreated(Activity activity, Bundle bundle) {
    }

    public void onActivityDestroyed(Activity activity) {
    }

    public void onActivityPaused(Activity activity) {
        int i = this.resumedCounter;
        if (i > 0) {
            this.resumedCounter = i - 1;
        }
    }

    public void onActivityResumed(Activity activity) {
        this.resumedCounter++;
        checkForegroundChanged();
    }

    public void onActivitySaveInstanceState(Activity activity, Bundle bundle) {
    }

    public void onActivityStarted(Activity activity) {
    }

    public void onActivityStopped(Activity activity) {
        checkForegroundChanged();
    }

    /* access modifiers changed from: protected */
    public abstract void onForegroundChanged(boolean z);
}
