package com.getui.gtc.dim;

import android.os.Parcel;
import android.os.Parcelable;
import com.taobao.weex.el.parse.Operators;

public class DimRequest implements Parcelable {
    public static final Parcelable.Creator<DimRequest> CREATOR = new Parcelable.Creator<DimRequest>() {
        /* class com.getui.gtc.dim.DimRequest.AnonymousClass1 */

        @Override // android.os.Parcelable.Creator
        public final DimRequest createFromParcel(Parcel parcel) {
            return new DimRequest(parcel);
        }

        @Override // android.os.Parcelable.Creator
        public final DimRequest[] newArray(int i) {
            return new DimRequest[i];
        }
    };
    private AllowSysCall allowSysCall;
    private Caller caller;
    private String key;
    private long ramCacheValidTime;
    private long storageCacheValidTime;
    private boolean useExpiredCacheForReserve;

    public static class Builder {
        private AllowSysCall allowSysCall = AllowSysCall.ALL_ALLOW;
        private Caller caller;
        private String key;
        private long ramCacheValidTime = 60000;
        private long storageCacheValidTime = 60000;
        private boolean useExpiredCacheForReserve = false;

        public Builder() {
        }

        public Builder(DimRequest dimRequest) {
            this.key = dimRequest.key;
            this.ramCacheValidTime = dimRequest.ramCacheValidTime;
            this.storageCacheValidTime = dimRequest.storageCacheValidTime;
            this.allowSysCall = dimRequest.allowSysCall;
            this.useExpiredCacheForReserve = dimRequest.useExpiredCacheForReserve;
            this.caller = dimRequest.caller;
        }

        @Deprecated
        public Builder allowSysCall(AllowSysCall allowSysCall2) {
            this.allowSysCall = allowSysCall2;
            return this;
        }

        @Deprecated
        public Builder allowSysCall(boolean z) {
            this.allowSysCall = z ? AllowSysCall.ALL_ALLOW : AllowSysCall.NOT_ALLOW;
            return this;
        }

        public DimRequest build() {
            return new DimRequest(this);
        }

        public Builder caller(Caller caller2) {
            this.caller = caller2;
            return this;
        }

        public Builder key(String str) {
            this.key = str;
            return this;
        }

        @Deprecated
        public Builder ramCacheValidTime(long j) {
            this.ramCacheValidTime = j;
            return this;
        }

        @Deprecated
        public Builder storageCacheValidTime(long j) {
            this.storageCacheValidTime = j;
            return this;
        }

        @Deprecated
        public Builder useExpiredCacheForReserve(boolean z) {
            this.useExpiredCacheForReserve = z;
            return this;
        }
    }

    private DimRequest() {
    }

    protected DimRequest(Parcel parcel) {
        this.key = parcel.readString();
        this.ramCacheValidTime = parcel.readLong();
        this.storageCacheValidTime = parcel.readLong();
        this.allowSysCall = AllowSysCall.valueOf(parcel.readInt());
        this.useExpiredCacheForReserve = parcel.readByte() != 0;
        int readInt = parcel.readInt();
        if (readInt >= 0) {
            this.caller = Caller.values()[readInt];
        }
    }

    private DimRequest(Builder builder) {
        this.key = builder.key;
        this.ramCacheValidTime = builder.ramCacheValidTime;
        this.storageCacheValidTime = builder.storageCacheValidTime;
        this.allowSysCall = builder.allowSysCall;
        this.useExpiredCacheForReserve = builder.useExpiredCacheForReserve;
        this.caller = builder.caller;
    }

    public int describeContents() {
        return 0;
    }

    @Deprecated
    public AllowSysCall getAllowSysCall() {
        return this.allowSysCall;
    }

    public Caller getCaller() {
        return this.caller;
    }

    public String getKey() {
        return this.key;
    }

    @Deprecated
    public long getRamCacheValidTime() {
        return this.ramCacheValidTime;
    }

    @Deprecated
    public long getStorageCacheValidTime() {
        return this.storageCacheValidTime;
    }

    @Deprecated
    public boolean isUseExpiredCacheForReserve() {
        return this.useExpiredCacheForReserve;
    }

    @Deprecated
    public void setAllowSysCall(AllowSysCall allowSysCall2) {
        this.allowSysCall = allowSysCall2;
    }

    public void setKey(String str) {
        this.key = str;
    }

    @Deprecated
    public void setRamCacheValidTime(long j) {
        this.ramCacheValidTime = j;
    }

    @Deprecated
    public void setStorageCacheValidTime(long j) {
        this.storageCacheValidTime = j;
    }

    @Deprecated
    public void setUseExpiredCacheForReserve(boolean z) {
        this.useExpiredCacheForReserve = z;
    }

    public String toString() {
        return "DimRequest{key='" + this.key + Operators.SINGLE_QUOTE + ", ramCacheValidTime=" + this.ramCacheValidTime + ", storageCacheValidTime=" + this.storageCacheValidTime + ", allowSysCall=" + this.allowSysCall + ", useExpiredCacheForReserve=" + this.useExpiredCacheForReserve + ", caller=" + this.caller + Operators.BLOCK_END;
    }

    public void writeToParcel(Parcel parcel, int i) {
        parcel.writeString(this.key);
        parcel.writeLong(this.ramCacheValidTime);
        parcel.writeLong(this.storageCacheValidTime);
        parcel.writeInt(this.allowSysCall.getValue());
        parcel.writeByte(this.useExpiredCacheForReserve ? (byte) 1 : 0);
        Caller caller2 = this.caller;
        parcel.writeInt(caller2 != null ? caller2.ordinal() : -1);
    }
}
