package com.getui.gtc.server;

import android.content.Context;
import android.text.TextUtils;
import android.util.Base64;
import com.getui.gtc.base.crypt.SecureCryptTools;
import com.getui.gtc.base.util.ScheduleQueue;
import com.getui.gtc.e.c;
import com.getui.gtc.e.d;
import com.getui.gtc.f.b;
import com.getui.gtc.h.e;
import com.getui.gtc.i.c.a;
import com.heytap.mcssdk.constant.Constants;
import java.io.StringReader;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.concurrent.ConcurrentHashMap;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class ServerManager {
    private static final long SERVERS_REFRESH_PERIOD = 86400000;
    private static Map<String, List<String>> availableServerMap;
    private static final Map<String, List<String>> buildInServerMap = new ConcurrentHashMap();
    private static Map<String, List<String>> configServerMap;
    private static Map<String, String> runningServerMap;
    private static final Map<String, List<String>> unavailableServerMap = new ConcurrentHashMap();

    public static synchronized void addBuildInServerMap(Map<String, List<String>> map) {
        synchronized (ServerManager.class) {
            buildInServerMap.putAll(map);
        }
    }

    public static synchronized void confirmServer(String str, String str2) {
        synchronized (ServerManager.class) {
            List<String> list = unavailableServerMap.get(str);
            if (list != null) {
                list.remove(str2);
            }
            String str3 = c.a.a.a.h;
            try {
                Properties properties = new Properties();
                if (!TextUtils.isEmpty(str3)) {
                    properties.load(new StringReader(str3));
                }
                properties.put(str, str2);
                StringBuilder sb = new StringBuilder();
                for (Map.Entry entry : properties.entrySet()) {
                    sb.append((String) entry.getKey());
                    sb.append("=");
                    sb.append((String) entry.getValue());
                    sb.append("\n");
                }
                d dVar = c.a.a.a;
                String sb2 = sb.toString();
                try {
                    if (dVar.a(13, Base64.encodeToString(SecureCryptTools.getInstance().encrypt(sb2.getBytes()), 0))) {
                        dVar.h = sb2;
                    }
                } catch (Throwable th) {
                    a.b(th);
                }
            } catch (Throwable th2) {
                a.a(th2);
            }
        }
    }

    /* access modifiers changed from: private */
    public static Map<String, List<String>> getAvailableServerMap() {
        Map<String, List<String>> map = availableServerMap;
        if (map != null) {
            return map;
        }
        availableServerMap = new HashMap();
        parseServerProperties(c.a.a.a.g, availableServerMap);
        return availableServerMap;
    }

    public static synchronized List<String> getBuildInServers(String str) {
        List<String> list;
        synchronized (ServerManager.class) {
            list = buildInServerMap.get(str);
        }
        return list;
    }

    public static synchronized List<String> getConfigServerMap(String str) {
        List<String> list;
        synchronized (ServerManager.class) {
            list = getConfigServerMap().get(str);
        }
        return list;
    }

    /* access modifiers changed from: private */
    public static Map<String, List<String>> getConfigServerMap() {
        Map<String, List<String>> map = configServerMap;
        if (map != null) {
            return map;
        }
        configServerMap = new HashMap();
        parseServerProperties(c.a.a.a.f, configServerMap);
        return configServerMap;
    }

    private static Map<String, String> getRunningServerMap() {
        Map<String, String> map = runningServerMap;
        if (map != null) {
            return map;
        }
        runningServerMap = new HashMap();
        try {
            String str = c.a.a.a.h;
            if (!TextUtils.isEmpty(str)) {
                Properties properties = new Properties();
                properties.load(new StringReader(str));
                for (Map.Entry entry : properties.entrySet()) {
                    runningServerMap.put((String) entry.getKey(), (String) entry.getValue());
                }
            }
        } catch (Throwable th) {
            a.a(th);
        }
        return runningServerMap;
    }

    public static synchronized String getServer(String str) {
        List<String> list;
        synchronized (ServerManager.class) {
            String str2 = getRunningServerMap().get(str);
            if (TextUtils.isEmpty(str2) && (list = buildInServerMap.get(str)) != null && list.size() > 0) {
                str2 = list.get(0);
            }
            List<String> list2 = getAvailableServerMap().get(str);
            if (list2 != null && list2.size() > 0) {
                if (!list2.contains(str2)) {
                    String str3 = list2.get(0);
                    getRunningServerMap().put(str, str3);
                    return str3;
                }
            }
            if (str2 != null) {
                getRunningServerMap().put(str, str2);
            }
            return str2;
        }
    }

    @Deprecated
    public static void initServerMap(Context context) {
    }

    /* access modifiers changed from: private */
    public static void parseServerProperties(String str, Map<String, List<String>> map) {
        if (map != null) {
            map.clear();
            try {
                if (!TextUtils.isEmpty(str)) {
                    Properties properties = new Properties();
                    properties.load(new StringReader(str));
                    for (Map.Entry entry : properties.entrySet()) {
                        ArrayList arrayList = new ArrayList();
                        map.put((String) entry.getKey(), arrayList);
                        JSONObject jSONObject = new JSONObject((String) entry.getValue());
                        Iterator<String> keys = jSONObject.keys();
                        HashMap hashMap = new HashMap();
                        ArrayList<String> arrayList2 = new ArrayList();
                        while (keys.hasNext()) {
                            String next = keys.next();
                            JSONArray jSONArray = jSONObject.getJSONArray(next);
                            arrayList2.add(next);
                            ArrayList arrayList3 = new ArrayList();
                            hashMap.put(next, arrayList3);
                            for (int i = 0; i < jSONArray.length(); i++) {
                                String str2 = (String) jSONArray.opt(i);
                                if (!TextUtils.isEmpty(str2) && !arrayList3.contains(str2)) {
                                    arrayList3.add(str2);
                                }
                            }
                        }
                        Collections.sort(arrayList2);
                        for (String str3 : arrayList2) {
                            arrayList.addAll((Collection) hashMap.get(str3));
                        }
                    }
                }
            } catch (Throwable th) {
                a.a(th);
            }
        }
    }

    /* access modifiers changed from: private */
    public static void saveAvailableConfigServers() {
        StringBuilder sb = new StringBuilder();
        for (Map.Entry<String, List<String>> entry : availableServerMap.entrySet()) {
            sb.append(entry.getKey());
            sb.append("=");
            try {
                JSONObject jSONObject = new JSONObject();
                JSONArray jSONArray = new JSONArray();
                jSONObject.put("1", jSONArray);
                for (String str : entry.getValue()) {
                    jSONArray.put(str);
                }
                sb.append(jSONObject.toString());
            } catch (JSONException e) {
                a.a(e);
            }
            sb.append("\n");
        }
        c.a.a.a.c(sb.toString());
    }

    public static synchronized boolean switchServer(String str, String str2) {
        synchronized (ServerManager.class) {
            List<String> list = unavailableServerMap.get(str);
            if (list == null) {
                list = new ArrayList<>();
                unavailableServerMap.put(str, list);
            }
            if (!list.contains(str2)) {
                list.add(str2);
            }
            List<String> list2 = getAvailableServerMap().get(str);
            if (list2 != null) {
                list2.remove(str2);
                saveAvailableConfigServers();
            }
            if (!TextUtils.equals(str2, getRunningServerMap().get(str))) {
                return true;
            }
            if (list2 == null || list2.size() <= 0) {
                List<String> list3 = buildInServerMap.get(str);
                if (list3 == null || list3.size() <= 0) {
                    return false;
                }
                for (String str3 : list3) {
                    if (!(list.contains(str3) || TextUtils.equals(str3, str2))) {
                        getRunningServerMap().put(str, str3);
                        return true;
                    }
                }
                return false;
            }
            getRunningServerMap().put(str, list2.get(0));
            return true;
        }
    }

    public static synchronized void updateConfigServerMap() {
        synchronized (ServerManager.class) {
            ScheduleQueue.getInstance().addSchedule(new Runnable() {
                /* class com.getui.gtc.server.ServerManager.AnonymousClass1 */

                public final void run() {
                    synchronized (ServerManager.class) {
                        long currentTimeMillis = System.currentTimeMillis();
                        if (currentTimeMillis - c.a.a.a.i > 86400000) {
                            d dVar = c.a.a.a;
                            if (dVar.a(14, currentTimeMillis)) {
                                dVar.i = currentTimeMillis;
                            }
                            ServerManager.getAvailableServerMap().clear();
                            ServerManager.getAvailableServerMap().putAll(ServerManager.getConfigServerMap());
                            ServerManager.saveAvailableConfigServers();
                        }
                        Map<String, String> a = b.a((long) Constants.MILLS_OF_LAUNCH_INTERVAL, new com.getui.gtc.f.d() {
                            /* class com.getui.gtc.server.ServerManager.AnonymousClass1.AnonymousClass1 */

                            @Override // com.getui.gtc.f.d
                            public final void a(String str) {
                            }

                            @Override // com.getui.gtc.f.d
                            public final void a(Map<String, String> map, Map<String, String> map2) {
                                if (map2 != null && map2.size() > 0) {
                                    final String str = map2.get("sdk.gtc.hosts.url");
                                    if (map != null && map.size() > 0) {
                                        String str2 = map.get("sdk.gtc.hosts.url");
                                        if (TextUtils.isEmpty(str) || str.equalsIgnoreCase(str2)) {
                                            return;
                                        }
                                    }
                                    String str3 = c.a.a.a.e;
                                    if (!TextUtils.isEmpty(str) && !str.equalsIgnoreCase(str3)) {
                                        e.a(str, map2.get("sdk.gtc.hosts.key"), new e.a() {
                                            /* class com.getui.gtc.server.ServerManager.AnonymousClass1.AnonymousClass1.AnonymousClass1 */

                                            @Override // com.getui.gtc.h.e.a
                                            public final void a(String str) {
                                                c.a.a.a.a(str);
                                                c.a.a.a.b(str);
                                                c.a.a.a.c(str);
                                                ServerManager.parseServerProperties(str, ServerManager.getConfigServerMap());
                                                ServerManager.parseServerProperties(str, ServerManager.getAvailableServerMap());
                                            }
                                        });
                                    }
                                }
                            }
                        });
                        if (a != null) {
                            if (a.size() > 0) {
                                final String str = a.get("sdk.gtc.hosts.url");
                                String str2 = c.a.a.a.e;
                                if (!TextUtils.isEmpty(str)) {
                                    if (!str.equalsIgnoreCase(str2)) {
                                        e.a(str, a.get("sdk.gtc.hosts.key"), new e.a() {
                                            /* class com.getui.gtc.server.ServerManager.AnonymousClass1.AnonymousClass2 */

                                            @Override // com.getui.gtc.h.e.a
                                            public final void a(String str) {
                                                c.a.a.a.a(str);
                                                c.a.a.a.b(str);
                                                c.a.a.a.c(str);
                                                ServerManager.parseServerProperties(str, ServerManager.getConfigServerMap());
                                                ServerManager.parseServerProperties(str, ServerManager.getAvailableServerMap());
                                            }
                                        });
                                    }
                                }
                            }
                        }
                    }
                }
            });
        }
    }
}
