package com.github.faucamp.simplertmp;

import android.util.Log;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import javax.crypto.Mac;
import javax.crypto.spec.SecretKeySpec;

public class Crypto {
    private static final String TAG = "Crypto";
    private Mac hmacSHA256;

    public Crypto() {
        try {
            this.hmacSHA256 = Mac.getInstance("HmacSHA256");
        } catch (SecurityException e) {
            Log.e(TAG, "Security exception when getting HMAC", e);
        } catch (NoSuchAlgorithmException e2) {
            Log.e(TAG, "HMAC SHA256 does not exist");
        }
    }

    public byte[] calculateHmacSHA256(byte[] input, byte[] key) {
        try {
            this.hmacSHA256.init(new SecretKeySpec(key, "HmacSHA256"));
            return this.hmacSHA256.doFinal(input);
        } catch (InvalidKeyException e) {
            Log.e(TAG, "Invalid key", e);
            return null;
        }
    }

    public byte[] calculateHmacSHA256(byte[] input, byte[] key, int length) {
        try {
            this.hmacSHA256.init(new SecretKeySpec(key, 0, length, "HmacSHA256"));
            return this.hmacSHA256.doFinal(input);
        } catch (InvalidKeyException e) {
            Log.e(TAG, "Invalid key", e);
            return null;
        }
    }
}
