package com.github.faucamp.simplertmp;

import com.umeng.analytics.pro.cv;
import io.dcloud.common.DHInterface.IApp;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public class Util {
    private static final String HEXES = "0123456789ABCDEF";

    public static void writeUnsignedInt32(OutputStream out, int value) throws IOException {
        out.write((byte) (value >>> 24));
        out.write((byte) (value >>> 16));
        out.write((byte) (value >>> 8));
        out.write((byte) value);
    }

    public static int readUnsignedInt32(InputStream in) throws IOException {
        return ((in.read() & 255) << 24) | ((in.read() & 255) << 16) | ((in.read() & 255) << 8) | (in.read() & 255);
    }

    public static int readUnsignedInt24(InputStream in) throws IOException {
        return ((in.read() & 255) << 16) | ((in.read() & 255) << 8) | (in.read() & 255);
    }

    public static int readUnsignedInt16(InputStream in) throws IOException {
        return ((in.read() & 255) << 8) | (in.read() & 255);
    }

    public static void writeUnsignedInt24(OutputStream out, int value) throws IOException {
        out.write((byte) (value >>> 16));
        out.write((byte) (value >>> 8));
        out.write((byte) value);
    }

    public static void writeUnsignedInt16(OutputStream out, int value) throws IOException {
        out.write((byte) (value >>> 8));
        out.write((byte) value);
    }

    public static int toUnsignedInt32(byte[] bytes) {
        return ((bytes[0] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 24) | ((bytes[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bytes[2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bytes[3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    public static int toUnsignedInt32LittleEndian(byte[] bytes) {
        return ((bytes[3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 24) | ((bytes[2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bytes[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bytes[0] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    public static void writeUnsignedInt32LittleEndian(OutputStream out, int value) throws IOException {
        out.write((byte) value);
        out.write((byte) (value >>> 8));
        out.write((byte) (value >>> 16));
        out.write((byte) (value >>> 24));
    }

    public static int toUnsignedInt24(byte[] bytes) {
        return ((bytes[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16) | ((bytes[2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bytes[3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    public static int toUnsignedInt16(byte[] bytes) {
        return ((bytes[2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) | (bytes[3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
    }

    public static String toHexString(byte[] raw) {
        if (raw == null) {
            return null;
        }
        StringBuilder hex = new StringBuilder(raw.length * 2);
        for (byte b : raw) {
            hex.append("0123456789ABCDEF".charAt((b & 240) >> 4));
            hex.append("0123456789ABCDEF".charAt(b & cv.m));
        }
        return hex.toString();
    }

    public static String toHexString(byte b) {
        StringBuilder sb = new StringBuilder();
        sb.append("0123456789ABCDEF".charAt((b & 240) >> 4));
        sb.append("0123456789ABCDEF".charAt(b & cv.m));
        return sb.toString();
    }

    public static void readBytesUntilFull(InputStream in, byte[] targetBuffer) throws IOException {
        int totalBytesRead = 0;
        int targetBytes = targetBuffer.length;
        do {
            int read = in.read(targetBuffer, totalBytesRead, targetBytes - totalBytesRead);
            if (read != -1) {
                totalBytesRead += read;
            } else {
                throw new IOException("Unexpected EOF reached before read buffer was filled");
            }
        } while (totalBytesRead < targetBytes);
    }

    public static byte[] toByteArray(double d) {
        long l = Double.doubleToRawLongBits(d);
        return new byte[]{(byte) ((int) ((l >> 56) & 255)), (byte) ((int) ((l >> 48) & 255)), (byte) ((int) ((l >> 40) & 255)), (byte) ((int) ((l >> 32) & 255)), (byte) ((int) ((l >> 24) & 255)), (byte) ((int) ((l >> 16) & 255)), (byte) ((int) ((l >> 8) & 255)), (byte) ((int) (l & 255))};
    }

    public static byte[] unsignedInt32ToByteArray(int value) throws IOException {
        return new byte[]{(byte) (value >>> 24), (byte) (value >>> 16), (byte) (value >>> 8), (byte) value};
    }

    public static double readDouble(InputStream in) throws IOException {
        return Double.longBitsToDouble((((long) (in.read() & 255)) << 56) | (((long) (in.read() & 255)) << 48) | (((long) (in.read() & 255)) << 40) | (((long) (in.read() & 255)) << 32) | ((long) ((in.read() & 255) << 24)) | ((long) ((in.read() & 255) << 16)) | ((long) ((in.read() & 255) << 8)) | ((long) (in.read() & 255)));
    }

    public static void writeDouble(OutputStream out, double d) throws IOException {
        long l = Double.doubleToRawLongBits(d);
        out.write(new byte[]{(byte) ((int) ((l >> 56) & 255)), (byte) ((int) ((l >> 48) & 255)), (byte) ((int) ((l >> 40) & 255)), (byte) ((int) ((l >> 32) & 255)), (byte) ((int) ((l >> 24) & 255)), (byte) ((int) ((l >> 16) & 255)), (byte) ((int) ((l >> 8) & 255)), (byte) ((int) (l & 255))});
    }
}
