package com.github.faucamp.simplertmp.amf;

import android.util.Log;
import com.github.faucamp.simplertmp.Util;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;

public class AmfString implements AmfData {
    private static final String TAG = "AmfString";
    private boolean key;
    private int size;
    private String value;

    public AmfString() {
        this.size = -1;
    }

    public AmfString(String value2, boolean isKey) {
        this.size = -1;
        this.value = value2;
        this.key = isKey;
    }

    public AmfString(String value2) {
        this(value2, false);
    }

    public AmfString(boolean isKey) {
        this.size = -1;
        this.key = isKey;
    }

    public String getValue() {
        return this.value;
    }

    public void setValue(String value2) {
        this.value = value2;
    }

    public boolean isKey() {
        return this.key;
    }

    public void setKey(boolean key2) {
        this.key = key2;
    }

    @Override // com.github.faucamp.simplertmp.amf.AmfData
    public void writeTo(OutputStream out) throws IOException {
        byte[] byteValue = this.value.getBytes("ASCII");
        if (!this.key) {
            out.write(AmfType.STRING.getValue());
        }
        Util.writeUnsignedInt16(out, byteValue.length);
        out.write(byteValue);
    }

    @Override // com.github.faucamp.simplertmp.amf.AmfData
    public void readFrom(InputStream in) throws IOException {
        int length = Util.readUnsignedInt16(in);
        this.size = length + 3;
        byte[] byteValue = new byte[length];
        Util.readBytesUntilFull(in, byteValue);
        this.value = new String(byteValue, "ASCII");
    }

    public static String readStringFrom(InputStream in, boolean isKey) throws IOException {
        if (!isKey) {
            in.read();
        }
        byte[] byteValue = new byte[Util.readUnsignedInt16(in)];
        Util.readBytesUntilFull(in, byteValue);
        return new String(byteValue, "ASCII");
    }

    public static void writeStringTo(OutputStream out, String string, boolean isKey) throws IOException {
        byte[] byteValue = string.getBytes("ASCII");
        if (!isKey) {
            out.write(AmfType.STRING.getValue());
        }
        Util.writeUnsignedInt16(out, byteValue.length);
        out.write(byteValue);
    }

    @Override // com.github.faucamp.simplertmp.amf.AmfData
    public int getSize() {
        if (this.size == -1) {
            try {
                this.size = (isKey() ? 0 : 1) + 2 + this.value.getBytes("ASCII").length;
            } catch (UnsupportedEncodingException ex) {
                Log.e(TAG, "AmfString.getSize(): caught exception", ex);
                throw new RuntimeException(ex);
            }
        }
        return this.size;
    }

    public static int sizeOf(String string, boolean isKey) {
        try {
            return (isKey ? 0 : 1) + 2 + string.getBytes("ASCII").length;
        } catch (UnsupportedEncodingException ex) {
            Log.e(TAG, "AmfString.SizeOf(): caught exception", ex);
            throw new RuntimeException(ex);
        }
    }
}
