package com.github.faucamp.simplertmp.io;

import com.github.faucamp.simplertmp.Util;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class ChunkStreamInfo {
    public static final byte RTMP_CID_AUDIO = 7;
    public static final byte RTMP_CID_OVER_CONNECTION = 3;
    public static final byte RTMP_CID_OVER_CONNECTION2 = 4;
    public static final byte RTMP_CID_OVER_STREAM = 5;
    public static final byte RTMP_CID_PROTOCOL_CONTROL = 2;
    public static final byte RTMP_CID_VIDEO = 6;
    private static long sessionBeginTimestamp;
    private ByteArrayOutputStream baos = new ByteArrayOutputStream(131072);
    private RtmpHeader prevHeaderRx;
    private RtmpHeader prevHeaderTx;
    private long realLastTimestamp = (System.nanoTime() / 1000000);

    public RtmpHeader prevHeaderRx() {
        return this.prevHeaderRx;
    }

    public void setPrevHeaderRx(RtmpHeader previousHeader) {
        this.prevHeaderRx = previousHeader;
    }

    public RtmpHeader getPrevHeaderTx() {
        return this.prevHeaderTx;
    }

    public boolean canReusePrevHeaderTx(RtmpHeader.MessageType forMessageType) {
        RtmpHeader rtmpHeader = this.prevHeaderTx;
        return rtmpHeader != null && rtmpHeader.getMessageType() == forMessageType;
    }

    public void setPrevHeaderTx(RtmpHeader prevHeaderTx2) {
        this.prevHeaderTx = prevHeaderTx2;
    }

    public static void markSessionTimestampTx() {
        sessionBeginTimestamp = System.nanoTime() / 1000000;
    }

    public long markAbsoluteTimestampTx() {
        return (System.nanoTime() / 1000000) - sessionBeginTimestamp;
    }

    public long markDeltaTimestampTx() {
        long currentTimestamp = System.nanoTime() / 1000000;
        long diffTimestamp = currentTimestamp - this.realLastTimestamp;
        this.realLastTimestamp = currentTimestamp;
        return diffTimestamp;
    }

    public boolean storePacketChunk(InputStream in, int chunkSize) throws IOException {
        byte[] chunk = new byte[Math.min(this.prevHeaderRx.getPacketLength() - this.baos.size(), chunkSize)];
        Util.readBytesUntilFull(in, chunk);
        this.baos.write(chunk);
        return this.baos.size() == this.prevHeaderRx.getPacketLength();
    }

    public ByteArrayInputStream getStoredPacketInputStream() {
        ByteArrayInputStream bis = new ByteArrayInputStream(this.baos.toByteArray());
        this.baos.reset();
        return bis;
    }

    public void clearStoredChunks() {
        this.baos.reset();
    }
}
