package com.github.faucamp.simplertmp.io;

import com.github.faucamp.simplertmp.packets.RtmpPacket;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class RtmpSessionInfo {
    private int acknowledgementWindowSize = Integer.MAX_VALUE;
    private Map<Integer, ChunkStreamInfo> chunkChannels = new HashMap();
    private Map<Integer, String> invokedMethods = new ConcurrentHashMap();
    private int rxChunkSize = 128;
    private int totalBytesRead = 0;
    private int txChunkSize = 128;
    private int windowBytesRead;

    public ChunkStreamInfo getChunkStreamInfo(int chunkStreamId) {
        ChunkStreamInfo chunkStreamInfo = this.chunkChannels.get(Integer.valueOf(chunkStreamId));
        if (chunkStreamInfo != null) {
            return chunkStreamInfo;
        }
        ChunkStreamInfo chunkStreamInfo2 = new ChunkStreamInfo();
        this.chunkChannels.put(Integer.valueOf(chunkStreamId), chunkStreamInfo2);
        return chunkStreamInfo2;
    }

    public String takeInvokedCommand(int transactionId) {
        return this.invokedMethods.remove(Integer.valueOf(transactionId));
    }

    public String addInvokedCommand(int transactionId, String commandName) {
        return this.invokedMethods.put(Integer.valueOf(transactionId), commandName);
    }

    public int getRxChunkSize() {
        return this.rxChunkSize;
    }

    public void setRxChunkSize(int chunkSize) {
        this.rxChunkSize = chunkSize;
    }

    public int getTxChunkSize() {
        return this.txChunkSize;
    }

    public void setTxChunkSize(int chunkSize) {
        this.txChunkSize = chunkSize;
    }

    public int getAcknowledgementWindowSize() {
        return this.acknowledgementWindowSize;
    }

    public void setAcknowledgmentWindowSize(int acknowledgementWindowSize2) {
        this.acknowledgementWindowSize = acknowledgementWindowSize2;
    }

    public final void addToWindowBytesRead(int numBytes, RtmpPacket packet) throws WindowAckRequired {
        int i = this.windowBytesRead + numBytes;
        this.windowBytesRead = i;
        this.totalBytesRead += numBytes;
        int i2 = this.acknowledgementWindowSize;
        if (i >= i2) {
            this.windowBytesRead = i - i2;
            throw new WindowAckRequired(this.totalBytesRead, packet);
        }
    }
}
