package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.io.ChunkStreamInfo;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public abstract class RtmpPacket {
    protected RtmpHeader header;

    /* access modifiers changed from: protected */
    public abstract byte[] array();

    public abstract void readBody(InputStream inputStream) throws IOException;

    /* access modifiers changed from: protected */
    public abstract int size();

    /* access modifiers changed from: protected */
    public abstract void writeBody(OutputStream outputStream) throws IOException;

    public RtmpPacket(RtmpHeader header2) {
        this.header = header2;
    }

    public RtmpHeader getHeader() {
        return this.header;
    }

    public void writeTo(OutputStream out, int chunkSize, ChunkStreamInfo chunkStreamInfo) throws IOException {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        writeBody(baos);
        byte[] body = this instanceof ContentData ? array() : baos.toByteArray();
        int length = this instanceof ContentData ? size() : body.length;
        this.header.setPacketLength(length);
        this.header.writeTo(out, RtmpHeader.ChunkType.TYPE_0_FULL, chunkStreamInfo);
        int pos = 0;
        while (length > chunkSize) {
            out.write(body, pos, chunkSize);
            length -= chunkSize;
            pos += chunkSize;
            this.header.writeTo(out, RtmpHeader.ChunkType.TYPE_3_RELATIVE_SINGLE_BYTE, chunkStreamInfo);
        }
        out.write(body, pos, length);
    }
}
