package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.amf.AmfBoolean;
import com.github.faucamp.simplertmp.amf.AmfData;
import com.github.faucamp.simplertmp.amf.AmfDecoder;
import com.github.faucamp.simplertmp.amf.AmfNull;
import com.github.faucamp.simplertmp.amf.AmfNumber;
import com.github.faucamp.simplertmp.amf.AmfString;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;

public abstract class VariableBodyRtmpPacket extends RtmpPacket {
    protected List<AmfData> data;

    public VariableBodyRtmpPacket(RtmpHeader header) {
        super(header);
    }

    public List<AmfData> getData() {
        return this.data;
    }

    public void addData(String string) {
        addData(new AmfString(string));
    }

    public void addData(double number) {
        addData(new AmfNumber(number));
    }

    public void addData(boolean bool) {
        addData(new AmfBoolean(bool));
    }

    public void addData(AmfData dataItem) {
        if (this.data == null) {
            this.data = new ArrayList();
        }
        if (dataItem == null) {
            dataItem = new AmfNull();
        }
        this.data.add(dataItem);
    }

    /* access modifiers changed from: protected */
    public void readVariableData(InputStream in, int bytesAlreadyRead) throws IOException {
        do {
            AmfData dataItem = AmfDecoder.readFrom(in);
            addData(dataItem);
            bytesAlreadyRead += dataItem.getSize();
        } while (bytesAlreadyRead < this.header.getPacketLength());
    }

    /* access modifiers changed from: protected */
    public void writeVariableData(OutputStream out) throws IOException {
        List<AmfData> list = this.data;
        if (list != null) {
            for (AmfData dataItem : list) {
                dataItem.writeTo(out);
            }
            return;
        }
        AmfNull.writeNullTo(out);
    }
}
