package com.googlecode.mp4parser;

import com.coremedia.iso.BoxParser;
import com.coremedia.iso.ChannelHelper;
import com.coremedia.iso.Hex;
import com.coremedia.iso.IsoFile;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.coremedia.iso.boxes.UserBox;
import com.googlecode.mp4parser.annotations.DoNotParseDetail;
import com.googlecode.mp4parser.util.CastUtils;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.logging.Logger;

public abstract class AbstractBox implements Box {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static Logger LOG = Logger.getLogger(AbstractBox.class.getName());
    public static int MEM_MAP_THRESHOLD = 102400;
    private ByteBuffer content;
    private ByteBuffer deadBytes = null;
    private ContainerBox parent;
    protected String type;
    private byte[] userType;

    /* access modifiers changed from: protected */
    public abstract void _parseDetails(ByteBuffer byteBuffer);

    /* access modifiers changed from: protected */
    public abstract void getContent(ByteBuffer byteBuffer);

    /* access modifiers changed from: protected */
    public abstract long getContentSize();

    protected AbstractBox(String type2) {
        this.type = type2;
    }

    protected AbstractBox(String type2, byte[] userType2) {
        this.type = type2;
        this.userType = userType2;
    }

    @Override // com.coremedia.iso.boxes.Box
    @DoNotParseDetail
    public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header, long contentSize, BoxParser boxParser) throws IOException {
        if (!(readableByteChannel instanceof FileChannel) || contentSize <= ((long) MEM_MAP_THRESHOLD)) {
            this.content = ChannelHelper.readFully(readableByteChannel, contentSize);
        } else {
            this.content = ((FileChannel) readableByteChannel).map(FileChannel.MapMode.READ_ONLY, ((FileChannel) readableByteChannel).position(), contentSize);
            ((FileChannel) readableByteChannel).position(((FileChannel) readableByteChannel).position() + contentSize);
        }
        if (!isParsed()) {
            parseDetails();
        }
    }

    @Override // com.coremedia.iso.boxes.Box
    public void getBox(WritableByteChannel os) throws IOException {
        ByteBuffer bb = ByteBuffer.allocate(CastUtils.l2i(getSize()));
        getHeader(bb);
        ByteBuffer byteBuffer = this.content;
        if (byteBuffer == null) {
            getContent(bb);
            ByteBuffer byteBuffer2 = this.deadBytes;
            if (byteBuffer2 != null) {
                byteBuffer2.rewind();
                while (this.deadBytes.remaining() > 0) {
                    bb.put(this.deadBytes);
                }
            }
        } else {
            byteBuffer.rewind();
            bb.put(this.content);
        }
        bb.rewind();
        os.write(bb);
    }

    /* access modifiers changed from: package-private */
    public final synchronized void parseDetails() {
        if (this.content != null) {
            ByteBuffer content2 = this.content;
            this.content = null;
            content2.rewind();
            _parseDetails(content2);
            if (content2.remaining() > 0) {
                this.deadBytes = content2.slice();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void setDeadBytes(ByteBuffer newDeadBytes) {
        this.deadBytes = newDeadBytes;
    }

    @Override // com.coremedia.iso.boxes.Box
    public long getSize() {
        ByteBuffer byteBuffer = this.content;
        long size = byteBuffer == null ? getContentSize() : (long) byteBuffer.limit();
        int i = 0;
        long size2 = size + ((long) ((size >= 4294967288L ? 8 : 0) + 8 + (UserBox.TYPE.equals(getType()) ? 16 : 0)));
        ByteBuffer byteBuffer2 = this.deadBytes;
        if (byteBuffer2 != null) {
            i = byteBuffer2.limit();
        }
        return size2 + ((long) i);
    }

    @Override // com.coremedia.iso.boxes.Box
    @DoNotParseDetail
    public String getType() {
        return this.type;
    }

    @DoNotParseDetail
    public byte[] getUserType() {
        return this.userType;
    }

    @Override // com.coremedia.iso.boxes.Box
    @DoNotParseDetail
    public ContainerBox getParent() {
        return this.parent;
    }

    @Override // com.coremedia.iso.boxes.Box
    @DoNotParseDetail
    public void setParent(ContainerBox parent2) {
        this.parent = parent2;
    }

    @DoNotParseDetail
    public IsoFile getIsoFile() {
        return this.parent.getIsoFile();
    }

    public boolean isParsed() {
        return this.content == null;
    }

    private boolean verify(ByteBuffer content2) {
        long contentSize = getContentSize();
        ByteBuffer byteBuffer = this.deadBytes;
        ByteBuffer bb = ByteBuffer.allocate(CastUtils.l2i(contentSize + ((long) (byteBuffer != null ? byteBuffer.limit() : 0))));
        getContent(bb);
        ByteBuffer byteBuffer2 = this.deadBytes;
        if (byteBuffer2 != null) {
            byteBuffer2.rewind();
            while (this.deadBytes.remaining() > 0) {
                bb.put(this.deadBytes);
            }
        }
        content2.rewind();
        bb.rewind();
        if (content2.remaining() != bb.remaining()) {
            LOG.severe(getType() + ": remaining differs " + content2.remaining() + " vs. " + bb.remaining());
            return false;
        }
        int p = content2.position();
        int i = content2.limit() - 1;
        int j = bb.limit() - 1;
        while (i >= p) {
            byte v1 = content2.get(i);
            byte v2 = bb.get(j);
            if (v1 != v2) {
                LOG.severe(String.format("%s: buffers differ at %d: %2X/%2X", getType(), Integer.valueOf(i), Byte.valueOf(v1), Byte.valueOf(v2)));
                byte[] b1 = new byte[content2.remaining()];
                byte[] b2 = new byte[bb.remaining()];
                content2.get(b1);
                bb.get(b2);
                System.err.println("original      : " + Hex.encodeHex(b1, 4));
                System.err.println("reconstructed : " + Hex.encodeHex(b2, 4));
                return false;
            }
            i--;
            j--;
        }
        return true;
    }

    private boolean isSmallBox() {
        long j;
        ByteBuffer byteBuffer = this.content;
        if (byteBuffer == null) {
            long contentSize = getContentSize();
            ByteBuffer byteBuffer2 = this.deadBytes;
            j = contentSize + ((long) (byteBuffer2 != null ? byteBuffer2.limit() : 0)) + 8;
        } else {
            j = (long) byteBuffer.limit();
        }
        return j < 4294967296L;
    }

    private void getHeader(ByteBuffer byteBuffer) {
        if (isSmallBox()) {
            IsoTypeWriter.writeUInt32(byteBuffer, getSize());
            byteBuffer.put(IsoFile.fourCCtoBytes(getType()));
        } else {
            IsoTypeWriter.writeUInt32(byteBuffer, 1);
            byteBuffer.put(IsoFile.fourCCtoBytes(getType()));
            IsoTypeWriter.writeUInt64(byteBuffer, getSize());
        }
        if (UserBox.TYPE.equals(getType())) {
            byteBuffer.put(getUserType());
        }
    }
}
