package com.googlecode.mp4parser;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.BoxParser;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.googlecode.mp4parser.util.ByteBufferByteChannel;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.Logger;

public abstract class AbstractContainerBox extends AbstractBox implements ContainerBox {
    private static Logger LOG = Logger.getLogger(AbstractContainerBox.class.getName());
    protected BoxParser boxParser;
    protected List<Box> boxes = new LinkedList();

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long contentSize = 0;
        for (Box boxe : this.boxes) {
            contentSize += boxe.getSize();
        }
        return contentSize;
    }

    public AbstractContainerBox(String type) {
        super(type);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public List<Box> getBoxes() {
        return Collections.unmodifiableList(this.boxes);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public void setBoxes(List<Box> boxes2) {
        this.boxes = new LinkedList(boxes2);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz) {
        return getBoxes(clazz, false);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz, boolean recursive) {
        ArrayList arrayList = new ArrayList(2);
        for (Box boxe : this.boxes) {
            if (clazz.isInstance(boxe)) {
                arrayList.add(boxe);
            }
            if (recursive && (boxe instanceof ContainerBox)) {
                arrayList.addAll(((ContainerBox) boxe).getBoxes(clazz, recursive));
            }
        }
        return arrayList;
    }

    public void addBox(Box b) {
        b.setParent(this);
        this.boxes.add(b);
    }

    public void removeBox(Box b) {
        b.setParent(this);
        this.boxes.remove(b);
    }

    @Override // com.coremedia.iso.boxes.Box, com.googlecode.mp4parser.AbstractBox
    public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header, long contentSize, BoxParser boxParser2) throws IOException {
        this.boxParser = boxParser2;
        super.parse(readableByteChannel, header, contentSize, boxParser2);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseChildBoxes(content);
    }

    public String toString() {
        StringBuilder buffer = new StringBuilder();
        buffer.append(getClass().getSimpleName());
        buffer.append(Operators.ARRAY_START_STR);
        for (int i = 0; i < this.boxes.size(); i++) {
            if (i > 0) {
                buffer.append(i.b);
            }
            buffer.append(this.boxes.get(i).toString());
        }
        buffer.append(Operators.ARRAY_END_STR);
        return buffer.toString();
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public long getNumOfBytesToFirstChild() {
        return 8;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeChildBoxes(byteBuffer);
    }

    /* access modifiers changed from: protected */
    public final void parseChildBoxes(ByteBuffer content) {
        while (content.remaining() >= 8) {
            try {
                this.boxes.add(this.boxParser.parseBox(new ByteBufferByteChannel(content), this));
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        if (content.remaining() != 0) {
            setDeadBytes(content.slice());
            LOG.warning("Something's wrong with the sizes. There are dead bytes in a container box.");
        }
    }

    /* access modifiers changed from: protected */
    public final void writeChildBoxes(ByteBuffer bb) {
        WritableByteChannel wbc = new ByteBufferByteChannel(bb);
        for (Box box : this.boxes) {
            try {
                box.getBox(wbc);
            } catch (IOException e) {
                throw new RuntimeException("Cannot happen to me", e);
            }
        }
    }
}
