package com.googlecode.mp4parser;

import com.alipay.sdk.m.u.i;
import com.coremedia.iso.BoxParser;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.googlecode.mp4parser.util.ByteBufferByteChannel;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.Logger;

public abstract class FullContainerBox extends AbstractFullBox implements ContainerBox {
    private static Logger LOG = Logger.getLogger(FullContainerBox.class.getName());
    BoxParser boxParser;
    protected List<Box> boxes = new LinkedList();

    @Override // com.coremedia.iso.boxes.ContainerBox
    public void setBoxes(List<Box> boxes2) {
        this.boxes = new LinkedList(boxes2);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz) {
        return getBoxes(clazz, false);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public <T extends Box> List<T> getBoxes(Class<T> clazz, boolean recursive) {
        ArrayList arrayList = new ArrayList(2);
        for (Box boxe : this.boxes) {
            if (clazz == boxe.getClass()) {
                arrayList.add(boxe);
            }
            if (recursive && (boxe instanceof ContainerBox)) {
                arrayList.addAll(((ContainerBox) boxe).getBoxes(clazz, recursive));
            }
        }
        return arrayList;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long contentSize = 4;
        for (Box boxe : this.boxes) {
            contentSize += boxe.getSize();
        }
        return contentSize;
    }

    public void addBox(Box b) {
        b.setParent(this);
        this.boxes.add(b);
    }

    public void removeBox(Box b) {
        b.setParent(null);
        this.boxes.remove(b);
    }

    public FullContainerBox(String type) {
        super(type);
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public List<Box> getBoxes() {
        return this.boxes;
    }

    @Override // com.coremedia.iso.boxes.Box, com.googlecode.mp4parser.AbstractBox
    public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header, long contentSize, BoxParser boxParser2) throws IOException {
        this.boxParser = boxParser2;
        super.parse(readableByteChannel, header, contentSize, boxParser2);
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        parseChildBoxes(content);
    }

    /* access modifiers changed from: protected */
    public final void parseChildBoxes(ByteBuffer content) {
        while (content.remaining() >= 8) {
            try {
                this.boxes.add(this.boxParser.parseBox(new ByteBufferByteChannel(content), this));
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }
        if (content.remaining() != 0) {
            setDeadBytes(content.slice());
            LOG.severe("Some sizes are wrong");
        }
    }

    public String toString() {
        StringBuilder buffer = new StringBuilder();
        buffer.append(getClass().getSimpleName());
        buffer.append(Operators.ARRAY_START_STR);
        for (int i = 0; i < this.boxes.size(); i++) {
            if (i > 0) {
                buffer.append(i.b);
            }
            buffer.append(this.boxes.get(i).toString());
        }
        buffer.append(Operators.ARRAY_END_STR);
        return buffer.toString();
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        writeChildBoxes(byteBuffer);
    }

    /* access modifiers changed from: protected */
    public final void writeChildBoxes(ByteBuffer bb) {
        WritableByteChannel wbc = new ByteBufferByteChannel(bb);
        for (Box box : this.boxes) {
            try {
                box.getBox(wbc);
            } catch (IOException e) {
                throw new RuntimeException("Cannot happen.", e);
            }
        }
    }

    @Override // com.coremedia.iso.boxes.ContainerBox
    public long getNumOfBytesToFirstChild() {
        long sizeOfChildren = 0;
        for (Box box : this.boxes) {
            sizeOfChildren += box.getSize();
        }
        return getSize() - sizeOfChildren;
    }
}
