package com.googlecode.mp4parser.authoring.adaptivestreaming;

import com.coremedia.iso.Hex;
import com.coremedia.iso.boxes.SoundMediaHeaderBox;
import com.coremedia.iso.boxes.VideoMediaHeaderBox;
import com.coremedia.iso.boxes.h264.AvcConfigurationBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.Version;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.builder.FragmentIntersectionFinder;
import com.googlecode.mp4parser.boxes.DTSSpecificBox;
import com.googlecode.mp4parser.boxes.EC3SpecificBox;
import com.googlecode.mp4parser.boxes.mp4.ESDescriptorBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.AudioSpecificConfig;
import com.umeng.analytics.pro.cv;
import io.dcloud.common.util.ExifInterface;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.StringWriter;
import java.nio.ByteBuffer;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.Logger;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import org.mozilla.universalchardet.prober.HebrewProber;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class FlatManifestWriterImpl extends AbstractManifestWriter {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final Logger LOG = Logger.getLogger(FlatManifestWriterImpl.class.getName());

    protected FlatManifestWriterImpl(FragmentIntersectionFinder intersectionFinder) {
        super(intersectionFinder);
    }

    /* access modifiers changed from: protected */
    public Document customizeManifest(Document manifest) {
        return manifest;
    }

    @Override // com.googlecode.mp4parser.authoring.adaptivestreaming.ManifestWriter
    public String getManifest(Movie movie) throws IOException {
        String str;
        LinkedList<AudioQuality> audioQualities;
        String str2;
        String str3;
        LinkedList<VideoQuality> videoQualities = new LinkedList<>();
        long videoTimescale = -1;
        LinkedList<AudioQuality> audioQualities2 = new LinkedList<>();
        long audioTimescale = -1;
        for (Track track : movie.getTracks()) {
            if (track.getMediaHeaderBox() instanceof VideoMediaHeaderBox) {
                this.videoFragmentsDurations = checkFragmentsAlign(this.videoFragmentsDurations, calculateFragmentDurations(track, movie));
                videoQualities.add(getVideoQuality(track, (VisualSampleEntry) track.getSampleDescriptionBox().getSampleEntry()));
                if (videoTimescale == -1) {
                    videoTimescale = track.getTrackMetaData().getTimescale();
                }
            }
            if (track.getMediaHeaderBox() instanceof SoundMediaHeaderBox) {
                this.audioFragmentsDurations = checkFragmentsAlign(this.audioFragmentsDurations, calculateFragmentDurations(track, movie));
                audioQualities2.add(getAudioQuality(track, (AudioSampleEntry) track.getSampleDescriptionBox().getSampleEntry()));
                if (audioTimescale == -1) {
                    audioTimescale = track.getTrackMetaData().getTimescale();
                }
            }
        }
        try {
            DocumentBuilder documentBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            Document document = documentBuilder.newDocument();
            Element smoothStreamingMedia = document.createElement("SmoothStreamingMedia");
            document.appendChild(smoothStreamingMedia);
            smoothStreamingMedia.setAttribute("MajorVersion", "2");
            smoothStreamingMedia.setAttribute("MinorVersion", "1");
            smoothStreamingMedia.setAttribute("Duration", "0");
            smoothStreamingMedia.appendChild(document.createComment(Version.VERSION));
            Element videoStreamIndex = document.createElement("StreamIndex");
            videoStreamIndex.setAttribute("Type", "video");
            String str4 = "TimeScale";
            videoStreamIndex.setAttribute(str4, Long.toString(videoTimescale));
            String str5 = "Chunks";
            videoStreamIndex.setAttribute(str5, Integer.toString(this.videoFragmentsDurations.length));
            String str6 = "Url";
            videoStreamIndex.setAttribute(str6, "video/{bitrate}/{start time}");
            String str7 = "QualityLevels";
            videoStreamIndex.setAttribute(str7, Integer.toString(videoQualities.size()));
            smoothStreamingMedia.appendChild(videoStreamIndex);
            int i = 0;
            while (true) {
                str = "CodecPrivateData";
                audioQualities = audioQualities2;
                str2 = "Index";
                str3 = "QualityLevel";
                if (i >= videoQualities.size()) {
                    break;
                }
                VideoQuality vq = videoQualities.get(i);
                Element qualityLevel = document.createElement(str3);
                qualityLevel.setAttribute(str2, Integer.toString(i));
                qualityLevel.setAttribute("Bitrate", Long.toString(vq.bitrate));
                qualityLevel.setAttribute("FourCC", vq.fourCC);
                qualityLevel.setAttribute("MaxWidth", Long.toString((long) vq.width));
                qualityLevel.setAttribute("MaxHeight", Long.toString((long) vq.height));
                qualityLevel.setAttribute(str, vq.codecPrivateData);
                qualityLevel.setAttribute("NALUnitLengthField", Integer.toString(vq.nalLength));
                videoStreamIndex.appendChild(qualityLevel);
                i++;
                documentBuilder = documentBuilder;
                smoothStreamingMedia = smoothStreamingMedia;
                str7 = str7;
                audioQualities2 = audioQualities;
                str6 = str6;
                str5 = str5;
                videoQualities = videoQualities;
                str4 = str4;
            }
            int i2 = 0;
            while (i2 < this.videoFragmentsDurations.length) {
                Element c = document.createElement("c");
                c.setAttribute("n", Integer.toString(i2));
                c.setAttribute("d", Long.toString(this.videoFragmentsDurations[i2]));
                videoStreamIndex.appendChild(c);
                i2++;
                str = str;
            }
            if (this.audioFragmentsDurations != null) {
                Element audioStreamIndex = document.createElement("StreamIndex");
                audioStreamIndex.setAttribute("Type", "audio");
                audioStreamIndex.setAttribute(str4, Long.toString(audioTimescale));
                audioStreamIndex.setAttribute(str5, Integer.toString(this.audioFragmentsDurations.length));
                audioStreamIndex.setAttribute(str6, "audio/{bitrate}/{start time}");
                audioStreamIndex.setAttribute(str7, Integer.toString(audioQualities.size()));
                Element smoothStreamingMedia2 = smoothStreamingMedia;
                smoothStreamingMedia2.appendChild(audioStreamIndex);
                int i3 = 0;
                while (i3 < audioQualities.size()) {
                    AudioQuality aq = audioQualities.get(i3);
                    Element qualityLevel2 = document.createElement(str3);
                    qualityLevel2.setAttribute(str2, Integer.toString(i3));
                    qualityLevel2.setAttribute("FourCC", aq.fourCC);
                    qualityLevel2.setAttribute("Bitrate", Long.toString(aq.bitrate));
                    qualityLevel2.setAttribute("AudioTag", Integer.toString(aq.audioTag));
                    qualityLevel2.setAttribute("SamplingRate", Long.toString(aq.samplingRate));
                    qualityLevel2.setAttribute("Channels", Integer.toString(aq.channels));
                    qualityLevel2.setAttribute(ExifInterface.TAG_BITS_PER_SAMPLE, Integer.toString(aq.bitPerSample));
                    qualityLevel2.setAttribute("PacketSize", Integer.toString(aq.packetSize));
                    qualityLevel2.setAttribute(str, aq.codecPrivateData);
                    audioStreamIndex.appendChild(qualityLevel2);
                    i3++;
                    str3 = str3;
                    str2 = str2;
                    smoothStreamingMedia2 = smoothStreamingMedia2;
                    audioTimescale = audioTimescale;
                    audioQualities = audioQualities;
                }
                for (int i4 = 0; i4 < this.audioFragmentsDurations.length; i4++) {
                    Element c2 = document.createElement("c");
                    c2.setAttribute("n", Integer.toString(i4));
                    c2.setAttribute("d", Long.toString(this.audioFragmentsDurations[i4]));
                    audioStreamIndex.appendChild(c2);
                }
            }
            document.setXmlStandalone(true);
            Source source = new DOMSource(document);
            StringWriter stringWriter = new StringWriter();
            Result result = new StreamResult(stringWriter);
            try {
                Transformer transformer = TransformerFactory.newInstance().newTransformer();
                transformer.setOutputProperty("indent", "yes");
                transformer.transform(source, result);
                return stringWriter.getBuffer().toString();
            } catch (TransformerConfigurationException e) {
                throw new IOException(e);
            } catch (TransformerException e2) {
                throw new IOException(e2);
            }
        } catch (ParserConfigurationException e3) {
            throw new IOException(e3);
        }
    }

    private AudioQuality getAudioQuality(Track track, AudioSampleEntry ase) {
        if (getFormat(ase).equals(AudioSampleEntry.TYPE3)) {
            return getAacAudioQuality(track, ase);
        }
        if (getFormat(ase).equals(AudioSampleEntry.TYPE9)) {
            return getEc3AudioQuality(track, ase);
        }
        if (getFormat(ase).startsWith("dts")) {
            return getDtsAudioQuality(track, ase);
        }
        throw new InternalError("I don't know what to do with audio of type " + getFormat(ase));
    }

    private AudioQuality getAacAudioQuality(Track track, AudioSampleEntry ase) {
        AudioQuality l = new AudioQuality();
        AudioSpecificConfig audioSpecificConfig = ((ESDescriptorBox) ase.getBoxes(ESDescriptorBox.class).get(0)).getEsDescriptor().getDecoderConfigDescriptor().getAudioSpecificInfo();
        if (audioSpecificConfig.getSbrPresentFlag() == 1) {
            l.fourCC = "AACH";
        } else if (audioSpecificConfig.getPsPresentFlag() == 1) {
            l.fourCC = "AACP";
        } else {
            l.fourCC = "AACL";
        }
        l.bitrate = getBitrate(track);
        l.audioTag = 255;
        l.samplingRate = ase.getSampleRate();
        l.channels = ase.getChannelCount();
        l.bitPerSample = ase.getSampleSize();
        l.packetSize = 4;
        l.codecPrivateData = getAudioCodecPrivateData(audioSpecificConfig);
        return l;
    }

    private AudioQuality getEc3AudioQuality(Track track, AudioSampleEntry ase) {
        EC3SpecificBox ec3SpecificBox = (EC3SpecificBox) ase.getBoxes(EC3SpecificBox.class).get(0);
        if (ec3SpecificBox != null) {
            short nfchans = 0;
            short lfechans = 0;
            byte dWChannelMaskFirstByte = 0;
            byte dWChannelMaskSecondByte = 0;
            for (EC3SpecificBox.Entry entry : ec3SpecificBox.getEntries()) {
                switch (entry.acmod) {
                    case 0:
                        short s = (short) (nfchans + 2);
                        throw new RuntimeException("Smooth Streaming doesn't support DDP 1+1 mode");
                    case 1:
                        nfchans = (short) (nfchans + 1);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | HebrewProber.SPACE);
                            break;
                        }
                    case 2:
                        nfchans = (short) (nfchans + 2);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask2 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask2.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask2.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 192);
                            break;
                        }
                    case 3:
                        nfchans = (short) (nfchans + 3);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask3 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask3.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask3.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 224);
                            break;
                        }
                    case 4:
                        nfchans = (short) (nfchans + 3);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask4 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask4.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask4.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 192);
                            dWChannelMaskSecondByte = (byte) (dWChannelMaskSecondByte | 128);
                            break;
                        }
                    case 5:
                        nfchans = (short) (nfchans + 4);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask5 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask5.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask5.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 224);
                            dWChannelMaskSecondByte = (byte) (dWChannelMaskSecondByte | 128);
                            break;
                        }
                    case 6:
                        nfchans = (short) (nfchans + 4);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask6 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask6.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask6.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 204);
                            break;
                        }
                    case 7:
                        nfchans = (short) (nfchans + 5);
                        if (entry.num_dep_sub > 0) {
                            DependentSubstreamMask dependentSubstreamMask7 = new DependentSubstreamMask(dWChannelMaskFirstByte, dWChannelMaskSecondByte, entry).process();
                            dWChannelMaskFirstByte = (byte) (dependentSubstreamMask7.getdWChannelMaskFirstByte() | dWChannelMaskFirstByte);
                            dWChannelMaskSecondByte = (byte) (dependentSubstreamMask7.getdWChannelMaskSecondByte() | dWChannelMaskSecondByte);
                            break;
                        } else {
                            dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | 236);
                            break;
                        }
                }
                if (entry.lfeon == 1) {
                    lfechans = (short) (lfechans + 1);
                    dWChannelMaskFirstByte = (byte) (dWChannelMaskFirstByte | cv.n);
                }
            }
            ByteBuffer waveformatex = ByteBuffer.allocate(22);
            waveformatex.put(new byte[]{0, 6});
            waveformatex.put(dWChannelMaskFirstByte);
            waveformatex.put(dWChannelMaskSecondByte);
            waveformatex.put(new byte[]{0, 0});
            waveformatex.put(new byte[]{-81, -121, -5, -89, 2, 45, -5, 66, -92, -44, 5, -51, -109, -124, 59, -35});
            ByteBuffer dec3Content = ByteBuffer.allocate((int) ec3SpecificBox.getContentSize());
            ec3SpecificBox.getContent(dec3Content);
            AudioQuality l = new AudioQuality();
            l.fourCC = "EC-3";
            l.bitrate = getBitrate(track);
            l.audioTag = 65534;
            l.samplingRate = ase.getSampleRate();
            l.channels = nfchans + lfechans;
            l.bitPerSample = 16;
            l.packetSize = track.getSamples().get(0).limit();
            l.codecPrivateData = Hex.encodeHex(waveformatex.array()) + Hex.encodeHex(dec3Content.array());
            return l;
        }
        throw new RuntimeException("EC-3 track misses EC3SpecificBox!");
    }

    private AudioQuality getDtsAudioQuality(Track track, AudioSampleEntry ase) {
        DTSSpecificBox dtsSpecificBox = (DTSSpecificBox) ase.getBoxes(DTSSpecificBox.class).get(0);
        if (dtsSpecificBox != null) {
            ByteBuffer waveformatex = ByteBuffer.allocate(22);
            int frameDuration = dtsSpecificBox.getFrameDuration();
            short samplesPerBlock = 0;
            if (frameDuration == 0) {
                samplesPerBlock = 512;
            } else if (frameDuration == 1) {
                samplesPerBlock = 1024;
            } else if (frameDuration == 2) {
                samplesPerBlock = 2048;
            } else if (frameDuration == 3) {
                samplesPerBlock = 4096;
            }
            waveformatex.put((byte) (samplesPerBlock & 255));
            waveformatex.put((byte) (samplesPerBlock >>> 8));
            int dwChannelMask = getNumChannelsAndMask(dtsSpecificBox)[1];
            waveformatex.put((byte) (dwChannelMask & 255));
            waveformatex.put((byte) (dwChannelMask >>> 8));
            waveformatex.put((byte) (dwChannelMask >>> 16));
            waveformatex.put((byte) (dwChannelMask >>> 24));
            waveformatex.put(new byte[]{-82, -28, -65, 94, 97, 94, 65, -121, -110, -4, -92, -127, 38, -103, 2, 17});
            ByteBuffer dtsCodecPrivateData = ByteBuffer.allocate(8);
            dtsCodecPrivateData.put((byte) dtsSpecificBox.getStreamConstruction());
            int channelLayout = dtsSpecificBox.getChannelLayout();
            dtsCodecPrivateData.put((byte) (channelLayout & 255));
            dtsCodecPrivateData.put((byte) (channelLayout >>> 8));
            dtsCodecPrivateData.put((byte) (channelLayout >>> 16));
            dtsCodecPrivateData.put((byte) (channelLayout >>> 24));
            dtsCodecPrivateData.put((byte) (dtsSpecificBox.getLBRDurationMod() | ((byte) (dtsSpecificBox.getMultiAssetFlag() << 1))));
            dtsCodecPrivateData.put(new byte[]{0, 0});
            AudioQuality l = new AudioQuality();
            l.fourCC = getFormat(ase);
            l.bitrate = dtsSpecificBox.getAvgBitRate();
            l.audioTag = 65534;
            l.samplingRate = dtsSpecificBox.getDTSSamplingFrequency();
            l.channels = getNumChannelsAndMask(dtsSpecificBox)[0];
            l.bitPerSample = 16;
            l.packetSize = track.getSamples().get(0).limit();
            l.codecPrivateData = Hex.encodeHex(waveformatex.array()) + Hex.encodeHex(dtsCodecPrivateData.array());
            return l;
        }
        throw new RuntimeException("DTS track misses DTSSpecificBox!");
    }

    private int[] getNumChannelsAndMask(DTSSpecificBox dtsSpecificBox) {
        int channelLayout = dtsSpecificBox.getChannelLayout();
        int numChannels = 0;
        int dwChannelMask = 0;
        if ((channelLayout & 1) == 1) {
            numChannels = 0 + 1;
            dwChannelMask = 0 | 4;
        }
        if ((channelLayout & 2) == 2) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 1 | 2;
        }
        if ((channelLayout & 4) == 4) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 16 | 32;
        }
        if ((channelLayout & 8) == 8) {
            numChannels++;
            dwChannelMask |= 8;
        }
        if ((channelLayout & 16) == 16) {
            numChannels++;
            dwChannelMask |= 256;
        }
        if ((channelLayout & 32) == 32) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 4096 | 16384;
        }
        if ((channelLayout & 64) == 64) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 16 | 32;
        }
        if ((channelLayout & 128) == 128) {
            numChannels++;
            dwChannelMask |= 8192;
        }
        if ((channelLayout & 256) == 256) {
            numChannels++;
            dwChannelMask |= 2048;
        }
        if ((channelLayout & 512) == 512) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 64 | 128;
        }
        if ((channelLayout & 1024) == 1024) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 512 | 1024;
        }
        if ((channelLayout & 2048) == 2048) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 16 | 32;
        }
        if ((channelLayout & 4096) == 4096) {
            numChannels++;
            dwChannelMask |= 8;
        }
        if ((channelLayout & 8192) == 8192) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 16 | 32;
        }
        if ((channelLayout & 16384) == 16384) {
            numChannels++;
            dwChannelMask |= 65536;
        }
        if ((channelLayout & 32768) == 32768) {
            numChannels += 2;
            dwChannelMask = dwChannelMask | 32768 | 131072;
        }
        if ((channelLayout & 65536) == 65536) {
            numChannels++;
        }
        if ((channelLayout & 131072) == 131072) {
            numChannels += 2;
        }
        return new int[]{numChannels, dwChannelMask};
    }

    private String getAudioCodecPrivateData(AudioSpecificConfig audioSpecificConfig) {
        return Hex.encodeHex(audioSpecificConfig.getConfigBytes());
    }

    private VideoQuality getVideoQuality(Track track, VisualSampleEntry vse) {
        if (VisualSampleEntry.TYPE3.equals(getFormat(vse))) {
            AvcConfigurationBox avcConfigurationBox = (AvcConfigurationBox) vse.getBoxes(AvcConfigurationBox.class).get(0);
            VideoQuality l = new VideoQuality();
            l.bitrate = getBitrate(track);
            l.codecPrivateData = Hex.encodeHex(getAvcCodecPrivateData(avcConfigurationBox));
            l.fourCC = "AVC1";
            l.width = vse.getWidth();
            l.height = vse.getHeight();
            l.nalLength = avcConfigurationBox.getLengthSizeMinusOne() + 1;
            return l;
        }
        throw new InternalError("I don't know how to handle video of type " + getFormat(vse));
    }

    private byte[] getAvcCodecPrivateData(AvcConfigurationBox avcConfigurationBox) {
        List<byte[]> sps = avcConfigurationBox.getSequenceParameterSets();
        List<byte[]> pps = avcConfigurationBox.getPictureParameterSets();
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        try {
            baos.write(new byte[]{0, 0, 0, 1});
            for (byte[] sp : sps) {
                baos.write(sp);
            }
            baos.write(new byte[]{0, 0, 0, 1});
            for (byte[] pp : pps) {
                baos.write(pp);
            }
            return baos.toByteArray();
        } catch (IOException e) {
            throw new RuntimeException("ByteArrayOutputStream do not throw IOException ?!?!?");
        }
    }

    /* access modifiers changed from: private */
    public class DependentSubstreamMask {
        private byte dWChannelMaskFirstByte;
        private byte dWChannelMaskSecondByte;
        private EC3SpecificBox.Entry entry;

        public DependentSubstreamMask(byte dWChannelMaskFirstByte2, byte dWChannelMaskSecondByte2, EC3SpecificBox.Entry entry2) {
            this.dWChannelMaskFirstByte = dWChannelMaskFirstByte2;
            this.dWChannelMaskSecondByte = dWChannelMaskSecondByte2;
            this.entry = entry2;
        }

        public byte getdWChannelMaskFirstByte() {
            return this.dWChannelMaskFirstByte;
        }

        public byte getdWChannelMaskSecondByte() {
            return this.dWChannelMaskSecondByte;
        }

        public DependentSubstreamMask process() {
            int i = this.entry.chan_loc;
            if (i == 0) {
                this.dWChannelMaskFirstByte = (byte) (this.dWChannelMaskFirstByte | 3);
            } else if (i == 1) {
                this.dWChannelMaskFirstByte = (byte) (this.dWChannelMaskFirstByte | 12);
            } else if (i == 2) {
                this.dWChannelMaskSecondByte = (byte) (this.dWChannelMaskSecondByte | 128);
            } else if (i == 3) {
                this.dWChannelMaskSecondByte = (byte) (this.dWChannelMaskSecondByte | 8);
            } else if (i == 6) {
                this.dWChannelMaskSecondByte = (byte) (this.dWChannelMaskSecondByte | 5);
            } else if (i == 7) {
                this.dWChannelMaskSecondByte = (byte) (this.dWChannelMaskSecondByte | 2);
            }
            return this;
        }
    }
}
