package com.googlecode.mp4parser.authoring.adaptivestreaming;

import com.coremedia.iso.IsoFile;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.SoundMediaHeaderBox;
import com.coremedia.iso.boxes.VideoMediaHeaderBox;
import com.coremedia.iso.boxes.fragment.MovieFragmentBox;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.builder.DefaultMp4Builder;
import com.googlecode.mp4parser.authoring.builder.FragmentIntersectionFinder;
import com.googlecode.mp4parser.authoring.builder.FragmentedMp4Builder;
import com.googlecode.mp4parser.authoring.builder.SyncSampleIntersectFinderImpl;
import com.googlecode.mp4parser.authoring.tracks.ChangeTimeScaleTrack;
import java.io.File;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintStream;
import java.nio.channels.FileChannel;
import java.util.Iterator;
import java.util.logging.Logger;

public class FlatPackageWriterImpl implements PackageWriter {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static Logger LOG = Logger.getLogger(FlatPackageWriterImpl.class.getName());
    private boolean debugOutput;
    private FragmentedMp4Builder ismvBuilder = new FragmentedMp4Builder();
    ManifestWriter manifestWriter;
    private File outputDirectory;
    long timeScale = 10000000;

    public FlatPackageWriterImpl() {
        FragmentIntersectionFinder intersectionFinder = new SyncSampleIntersectFinderImpl();
        this.ismvBuilder.setIntersectionFinder(intersectionFinder);
        this.manifestWriter = new FlatManifestWriterImpl(intersectionFinder);
    }

    public FlatPackageWriterImpl(int minFragmentDuration) {
        FragmentIntersectionFinder intersectionFinder = new SyncSampleIntersectFinderImpl(minFragmentDuration);
        this.ismvBuilder.setIntersectionFinder(intersectionFinder);
        this.manifestWriter = new FlatManifestWriterImpl(intersectionFinder);
    }

    public void setOutputDirectory(File outputDirectory2) {
        this.outputDirectory = outputDirectory2;
    }

    public void setDebugOutput(boolean debugOutput2) {
        this.debugOutput = debugOutput2;
    }

    public void setIsmvBuilder(FragmentedMp4Builder ismvBuilder2) {
        this.ismvBuilder = ismvBuilder2;
        this.manifestWriter = new FlatManifestWriterImpl(ismvBuilder2.getFragmentIntersectionFinder());
    }

    public void setManifestWriter(ManifestWriter manifestWriter2) {
        this.manifestWriter = manifestWriter2;
    }

    @Override // com.googlecode.mp4parser.authoring.adaptivestreaming.PackageWriter
    public void write(Movie source) throws IOException {
        File mediaOutDir;
        Iterator<Track> it;
        IsoFile isoFile;
        if (this.debugOutput) {
            this.outputDirectory.mkdirs();
            IsoFile muxed = new DefaultMp4Builder().build(source);
            FileOutputStream muxedFileOutputStream = new FileOutputStream(new File(this.outputDirectory, "debug_1_muxed.mp4"));
            muxed.getBox(muxedFileOutputStream.getChannel());
            muxedFileOutputStream.close();
        }
        Movie cleanedSource = removeUnknownTracks(source);
        Movie movieWithAdjustedTimescale = correctTimescale(cleanedSource);
        if (this.debugOutput) {
            IsoFile muxed2 = new DefaultMp4Builder().build(movieWithAdjustedTimescale);
            FileOutputStream muxedFileOutputStream2 = new FileOutputStream(new File(this.outputDirectory, "debug_2_timescale.mp4"));
            muxed2.getBox(muxedFileOutputStream2.getChannel());
            muxedFileOutputStream2.close();
        }
        IsoFile isoFile2 = this.ismvBuilder.build(movieWithAdjustedTimescale);
        if (this.debugOutput) {
            FileOutputStream allQualis = new FileOutputStream(new File(this.outputDirectory, "debug_3_fragmented.mp4"));
            isoFile2.getBox(allQualis.getChannel());
            allQualis.close();
        }
        Iterator<Track> it2 = movieWithAdjustedTimescale.getTracks().iterator();
        while (it2.hasNext()) {
            Track track = it2.next();
            String bitrate = Long.toString(this.manifestWriter.getBitrate(track));
            long trackId = track.getTrackMetaData().getTrackId();
            Iterator<Box> boxIt = isoFile2.getBoxes().iterator();
            if (track.getMediaHeaderBox() instanceof SoundMediaHeaderBox) {
                mediaOutDir = new File(this.outputDirectory, "audio");
            } else if (track.getMediaHeaderBox() instanceof VideoMediaHeaderBox) {
                mediaOutDir = new File(this.outputDirectory, "video");
            } else {
                PrintStream printStream = System.err;
                printStream.println("Skipping Track with handler " + track.getHandler() + " and " + track.getMediaHeaderBox().getClass().getSimpleName());
                isoFile2 = isoFile2;
                cleanedSource = cleanedSource;
            }
            File bitRateOutputDir = new File(mediaOutDir, bitrate);
            bitRateOutputDir.mkdirs();
            Logger logger = LOG;
            logger.finer("Created : " + bitRateOutputDir.getCanonicalPath());
            long[] fragmentTimes = this.manifestWriter.calculateFragmentDurations(track, movieWithAdjustedTimescale);
            long startTime = 0;
            int currentFragment = 0;
            while (boxIt.hasNext()) {
                Box b = boxIt.next();
                if (!(b instanceof MovieFragmentBox)) {
                    isoFile = isoFile2;
                    it = it2;
                } else if (((MovieFragmentBox) b).getTrackNumbers()[0] == trackId) {
                    isoFile = isoFile2;
                    it = it2;
                    FileOutputStream fos = new FileOutputStream(new File(bitRateOutputDir, Long.toString(startTime)));
                    startTime += fragmentTimes[currentFragment];
                    FileChannel fc = fos.getChannel();
                    b.getBox(fc);
                    boxIt.next().getBox(fc);
                    fc.truncate(fc.position());
                    fc.close();
                    currentFragment++;
                } else {
                    isoFile = isoFile2;
                    it = it2;
                }
                isoFile2 = isoFile;
                cleanedSource = cleanedSource;
                it2 = it;
            }
        }
        FileWriter fw = new FileWriter(new File(this.outputDirectory, "Manifest"));
        fw.write(this.manifestWriter.getManifest(movieWithAdjustedTimescale));
        fw.close();
    }

    private Movie removeUnknownTracks(Movie source) {
        Movie nuMovie = new Movie();
        for (Track track : source.getTracks()) {
            if ("vide".equals(track.getHandler()) || "soun".equals(track.getHandler())) {
                nuMovie.addTrack(track);
            } else {
                Logger logger = LOG;
                logger.fine("Removed track " + track);
            }
        }
        return nuMovie;
    }

    public Movie correctTimescale(Movie movie) {
        Movie nuMovie = new Movie();
        for (Track track : movie.getTracks()) {
            nuMovie.addTrack(new ChangeTimeScaleTrack(track, this.timeScale, this.ismvBuilder.getFragmentIntersectionFinder().sampleNumbers(track, movie)));
        }
        return nuMovie;
    }
}
