package com.googlecode.mp4parser.authoring.builder;

import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.util.Math;
import com.taobao.weex.el.parse.Operators;
import java.util.Arrays;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.concurrent.ConcurrentHashMap;
import java.util.logging.Logger;

public class SyncSampleIntersectFinderImpl implements FragmentIntersectionFinder {
    private static Logger LOG = Logger.getLogger(SyncSampleIntersectFinderImpl.class.getName());
    private static Map<CacheTuple, long[]> getSampleNumbersCache = new ConcurrentHashMap();
    private static Map<CacheTuple, long[]> getTimesCache = new ConcurrentHashMap();
    private final int minFragmentDurationSeconds;

    public SyncSampleIntersectFinderImpl() {
        this.minFragmentDurationSeconds = 0;
    }

    public SyncSampleIntersectFinderImpl(int minFragmentDurationSeconds2) {
        this.minFragmentDurationSeconds = minFragmentDurationSeconds2;
    }

    @Override // com.googlecode.mp4parser.authoring.builder.FragmentIntersectionFinder
    public long[] sampleNumbers(Track track, Movie movie) {
        CacheTuple key = new CacheTuple(track, movie);
        long[] result = getSampleNumbersCache.get(key);
        if (result != null) {
            return result;
        }
        if ("vide".equals(track.getHandler())) {
            if (track.getSyncSamples() == null || track.getSyncSamples().length <= 0) {
                throw new RuntimeException("Video Tracks need sync samples. Only tracks other than video may have no sync samples.");
            }
            List<long[]> times = getSyncSamplesTimestamps(movie, track);
            long[] commonIndices = getCommonIndices(track.getSyncSamples(), getTimes(track, movie), track.getTrackMetaData().getTimescale(), (long[][]) times.toArray(new long[times.size()][]));
            getSampleNumbersCache.put(key, commonIndices);
            return commonIndices;
        } else if ("soun".equals(track.getHandler())) {
            Track referenceTrack = null;
            for (Track candidate : movie.getTracks()) {
                if (candidate.getSyncSamples() != null && "vide".equals(candidate.getHandler()) && candidate.getSyncSamples().length > 0) {
                    referenceTrack = candidate;
                }
            }
            if (referenceTrack != null) {
                long[] refSyncSamples = sampleNumbers(referenceTrack, movie);
                int refSampleCount = referenceTrack.getSamples().size();
                long[] syncSamples = new long[refSyncSamples.length];
                long minSampleRate = 192000;
                Iterator<Track> it = movie.getTracks().iterator();
                while (true) {
                    if (!it.hasNext()) {
                        break;
                    }
                    Track testTrack = it.next();
                    if ("soun".equals(testTrack.getHandler())) {
                        AudioSampleEntry ase = (AudioSampleEntry) testTrack.getSampleDescriptionBox().getSampleEntry();
                        if (ase.getSampleRate() < 192000) {
                            long minSampleRate2 = ase.getSampleRate();
                            double stretch = ((double) ((long) testTrack.getSamples().size())) / ((double) refSampleCount);
                            TimeToSampleBox.Entry sttsEntry = testTrack.getDecodingTimeEntries().get(0);
                            long samplesPerFrame = sttsEntry.getDelta();
                            int i = 0;
                            while (i < syncSamples.length) {
                                syncSamples[i] = (long) Math.ceil(((double) (refSyncSamples[i] - 1)) * stretch * ((double) samplesPerFrame));
                                i++;
                                referenceTrack = referenceTrack;
                                refSampleCount = refSampleCount;
                                sttsEntry = sttsEntry;
                                refSyncSamples = refSyncSamples;
                            }
                            minSampleRate = minSampleRate2;
                        }
                    }
                    referenceTrack = referenceTrack;
                    refSampleCount = refSampleCount;
                    refSyncSamples = refSyncSamples;
                }
                AudioSampleEntry ase2 = (AudioSampleEntry) track.getSampleDescriptionBox().getSampleEntry();
                TimeToSampleBox.Entry sttsEntry2 = track.getDecodingTimeEntries().get(0);
                long samplesPerFrame2 = sttsEntry2.getDelta();
                double factor = ((double) ase2.getSampleRate()) / ((double) minSampleRate);
                if (factor == Math.rint(factor)) {
                    int i2 = 0;
                    while (i2 < syncSamples.length) {
                        syncSamples[i2] = (long) (((((double) syncSamples[i2]) * factor) / ((double) samplesPerFrame2)) + 1.0d);
                        i2++;
                        ase2 = ase2;
                        sttsEntry2 = sttsEntry2;
                        factor = factor;
                    }
                    getSampleNumbersCache.put(key, syncSamples);
                    return syncSamples;
                }
                throw new RuntimeException("Sample rates must be a multiple of the lowest sample rate to create a correct file!");
            }
            throw new RuntimeException("There was absolutely no Track with sync samples. I can't work with that!");
        } else {
            for (Track candidate2 : movie.getTracks()) {
                if (candidate2.getSyncSamples() != null && candidate2.getSyncSamples().length > 0) {
                    long[] refSyncSamples2 = sampleNumbers(candidate2, movie);
                    int refSampleCount2 = candidate2.getSamples().size();
                    long[] syncSamples2 = new long[refSyncSamples2.length];
                    double stretch2 = ((double) ((long) track.getSamples().size())) / ((double) refSampleCount2);
                    for (int i3 = 0; i3 < syncSamples2.length; i3++) {
                        syncSamples2[i3] = ((long) Math.ceil(((double) (refSyncSamples2[i3] - 1)) * stretch2)) + 1;
                    }
                    getSampleNumbersCache.put(key, syncSamples2);
                    return syncSamples2;
                }
            }
            throw new RuntimeException("There was absolutely no Track with sync samples. I can't work with that!");
        }
    }

    public static List<long[]> getSyncSamplesTimestamps(Movie movie, Track track) {
        long[] currentTrackSyncSamples;
        List<long[]> times = new LinkedList<>();
        for (Track currentTrack : movie.getTracks()) {
            if (currentTrack.getHandler().equals(track.getHandler()) && (currentTrackSyncSamples = currentTrack.getSyncSamples()) != null && currentTrackSyncSamples.length > 0) {
                times.add(getTimes(currentTrack, movie));
            }
        }
        return times;
    }

    public long[] getCommonIndices(long[] syncSamples, long[] syncSampleTimes, long timeScale, long[]... otherTracksTimes) {
        SyncSampleIntersectFinderImpl syncSampleIntersectFinderImpl = this;
        List<Long> nuSyncSamples = new LinkedList<>();
        List<Long> nuSyncSampleTimes = new LinkedList<>();
        for (int i = 0; i < syncSampleTimes.length; i++) {
            boolean foundInEveryRef = true;
            int length = otherTracksTimes.length;
            for (int i2 = 0; i2 < length; i2++) {
                foundInEveryRef &= Arrays.binarySearch(otherTracksTimes[i2], syncSampleTimes[i]) >= 0;
            }
            if (foundInEveryRef) {
                nuSyncSamples.add(Long.valueOf(syncSamples[i]));
                nuSyncSampleTimes.add(Long.valueOf(syncSampleTimes[i]));
            }
        }
        if (((double) nuSyncSamples.size()) < ((double) syncSamples.length) * 0.25d) {
            String log = "" + String.format("%5d - Common:  [", Integer.valueOf(nuSyncSamples.size()));
            for (Long l : nuSyncSamples) {
                long l2 = l.longValue();
                log = log + String.format("%10d,", Long.valueOf(l2));
            }
            LOG.warning(log + Operators.ARRAY_END_STR);
            String log2 = "" + String.format("%5d - In    :  [", Integer.valueOf(syncSamples.length));
            for (long l3 : syncSamples) {
                log2 = log2 + String.format("%10d,", Long.valueOf(l3));
            }
            LOG.warning(log2 + Operators.ARRAY_END_STR);
            LOG.warning("There are less than 25% of common sync samples in the given track.");
            throw new RuntimeException("There are less than 25% of common sync samples in the given track.");
        }
        if (((double) nuSyncSamples.size()) < ((double) syncSamples.length) * 0.5d) {
            LOG.fine("There are less than 50% of common sync samples in the given track. This is implausible but I'm ok to continue.");
        } else if (nuSyncSamples.size() < syncSamples.length) {
            LOG.finest("Common SyncSample positions vs. this tracks SyncSample positions: " + nuSyncSamples.size() + " vs. " + syncSamples.length);
        }
        List<Long> finalSampleList = new LinkedList<>();
        if (syncSampleIntersectFinderImpl.minFragmentDurationSeconds > 0) {
            long lastSyncSampleTime = -1;
            Iterator<Long> nuSyncSamplesIterator = nuSyncSamples.iterator();
            Iterator<Long> nuSyncSampleTimesIterator = nuSyncSampleTimes.iterator();
            while (nuSyncSamplesIterator.hasNext() && nuSyncSampleTimesIterator.hasNext()) {
                long curSyncSample = nuSyncSamplesIterator.next().longValue();
                long curSyncSampleTime = nuSyncSampleTimesIterator.next().longValue();
                if (lastSyncSampleTime == -1 || (curSyncSampleTime - lastSyncSampleTime) / timeScale >= ((long) syncSampleIntersectFinderImpl.minFragmentDurationSeconds)) {
                    finalSampleList.add(Long.valueOf(curSyncSample));
                    lastSyncSampleTime = curSyncSampleTime;
                }
                syncSampleIntersectFinderImpl = this;
            }
        } else {
            finalSampleList = nuSyncSamples;
        }
        long[] finalSampleArray = new long[finalSampleList.size()];
        for (int i3 = 0; i3 < finalSampleArray.length; i3++) {
            finalSampleArray[i3] = finalSampleList.get(i3).longValue();
        }
        return finalSampleArray;
    }

    private static long[] getTimes(Track track, Movie m) {
        CacheTuple key = new CacheTuple(track, m);
        long[] result = getTimesCache.get(key);
        if (result != null) {
            return result;
        }
        long[] syncSamples = track.getSyncSamples();
        long[] syncSampleTimes = new long[syncSamples.length];
        Queue<TimeToSampleBox.Entry> timeQueue = new LinkedList<>(track.getDecodingTimeEntries());
        int currentSample = 1;
        long currentDuration = 0;
        long currentDelta = 0;
        int currentSyncSampleIndex = 0;
        long left = 0;
        long scalingFactor = calculateTracktimesScalingFactor(m, track);
        while (((long) currentSample) <= syncSamples[syncSamples.length - 1]) {
            int currentSample2 = currentSample + 1;
            if (((long) currentSample) == syncSamples[currentSyncSampleIndex]) {
                syncSampleTimes[currentSyncSampleIndex] = currentDuration * scalingFactor;
                currentSyncSampleIndex++;
            }
            long left2 = left - 1;
            if (left == 0) {
                TimeToSampleBox.Entry entry = timeQueue.poll();
                left = entry.getCount() - 1;
                currentDelta = entry.getDelta();
            } else {
                left = left2;
            }
            currentDuration += currentDelta;
            currentSample = currentSample2;
            result = result;
        }
        getTimesCache.put(key, syncSampleTimes);
        return syncSampleTimes;
    }

    private static long calculateTracktimesScalingFactor(Movie m, Track track) {
        long timeScale = 1;
        for (Track track1 : m.getTracks()) {
            if (track1.getHandler().equals(track.getHandler()) && track1.getTrackMetaData().getTimescale() != track.getTrackMetaData().getTimescale()) {
                timeScale = Math.lcm(timeScale, track1.getTrackMetaData().getTimescale());
            }
        }
        return timeScale;
    }

    public static class CacheTuple {
        Movie movie;
        Track track;

        public CacheTuple(Track track2, Movie movie2) {
            this.track = track2;
            this.movie = movie2;
        }

        public boolean equals(Object o) {
            if (this == o) {
                return true;
            }
            if (o == null || getClass() != o.getClass()) {
                return false;
            }
            CacheTuple that = (CacheTuple) o;
            Movie movie2 = this.movie;
            if (movie2 == null ? that.movie != null : !movie2.equals(that.movie)) {
                return false;
            }
            Track track2 = this.track;
            if (track2 == null ? that.track == null : track2.equals(that.track)) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            Track track2 = this.track;
            int i = 0;
            int hashCode = (track2 != null ? track2.hashCode() : 0) * 31;
            Movie movie2 = this.movie;
            if (movie2 != null) {
                i = movie2.hashCode();
            }
            return hashCode + i;
        }
    }
}
