package com.googlecode.mp4parser.authoring.builder;

import com.coremedia.iso.boxes.TimeToSampleBox;
import com.googlecode.mp4parser.authoring.Movie;
import com.googlecode.mp4parser.authoring.Track;
import java.util.Arrays;
import java.util.List;

public class TwoSecondIntersectionFinder implements FragmentIntersectionFinder {
    /* access modifiers changed from: protected */
    public long getDuration(Track track) {
        long duration = 0;
        for (TimeToSampleBox.Entry entry : track.getDecodingTimeEntries()) {
            duration += entry.getCount() * entry.getDelta();
        }
        return duration;
    }

    @Override // com.googlecode.mp4parser.authoring.builder.FragmentIntersectionFinder
    public long[] sampleNumbers(Track track, Movie movie) {
        int currentFragment;
        List<TimeToSampleBox.Entry> entries = track.getDecodingTimeEntries();
        double trackLength = 0.0d;
        for (Track thisTrack : movie.getTracks()) {
            double thisTracksLength = (double) (getDuration(thisTrack) / thisTrack.getTrackMetaData().getTimescale());
            if (trackLength < thisTracksLength) {
                trackLength = thisTracksLength;
            }
        }
        int i = 1;
        int fragmentCount = ((int) Math.ceil(trackLength / 2.0d)) - 1;
        if (fragmentCount < 1) {
            fragmentCount = 1;
        }
        long[] fragments = new long[fragmentCount];
        Arrays.fill(fragments, -1L);
        fragments[0] = 1;
        long time = 0;
        int samples = 0;
        for (TimeToSampleBox.Entry entry : entries) {
            int i2 = 0;
            while (((long) i2) < entry.getCount() && (currentFragment = ((int) ((time / track.getTrackMetaData().getTimescale()) / 2)) + i) < fragments.length) {
                fragments[currentFragment] = (long) (samples + 1);
                time += entry.getDelta();
                i2++;
                samples++;
                i = 1;
            }
            i = 1;
        }
        long last = (long) (samples + 1);
        for (int i3 = fragments.length - 1; i3 >= 0; i3--) {
            if (fragments[i3] == -1) {
                fragments[i3] = last;
            }
            last = fragments[i3];
        }
        return fragments;
    }
}
