package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SoundMediaHeaderBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.googlecode.mp4parser.authoring.AbstractTrack;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import com.googlecode.mp4parser.boxes.mp4.ESDescriptorBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.AudioSpecificConfig;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.BitReaderBuffer;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.DecoderConfigDescriptor;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.ESDescriptor;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.SLConfigDescriptor;
import com.taobao.weex.el.parse.Operators;
import com.tencent.ugc.TXRecordCommon;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.util.Date;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import net.ossrs.yasea.SrsFlvMuxer;

public class AACTrackImpl extends AbstractTrack {
    public static Map<Integer, Integer> samplingFrequencyIndexMap;
    long avgBitRate;
    int bitrate;
    int bufferSizeDB;
    int channelCount;
    int channelconfig;
    private BufferedInputStream inputStream;
    private String lang = "und";
    long maxBitRate;
    boolean readSamples = false;
    SampleDescriptionBox sampleDescriptionBox;
    int samplerate;
    private List<ByteBuffer> samples;
    List<TimeToSampleBox.Entry> stts;
    TrackMetaData trackMetaData = new TrackMetaData();

    static {
        HashMap hashMap = new HashMap();
        samplingFrequencyIndexMap = hashMap;
        hashMap.put(96000, 0);
        samplingFrequencyIndexMap.put(88200, 1);
        samplingFrequencyIndexMap.put(64000, 2);
        samplingFrequencyIndexMap.put(48000, 3);
        samplingFrequencyIndexMap.put(44100, 4);
        samplingFrequencyIndexMap.put(32000, 5);
        samplingFrequencyIndexMap.put(24000, 6);
        Map<Integer, Integer> map = samplingFrequencyIndexMap;
        Integer valueOf = Integer.valueOf((int) SrsFlvMuxer.SrsCodecAudioSampleRate.R22050);
        map.put(valueOf, 7);
        samplingFrequencyIndexMap.put(16000, 8);
        samplingFrequencyIndexMap.put(12000, 9);
        samplingFrequencyIndexMap.put(Integer.valueOf((int) SrsFlvMuxer.SrsCodecAudioSampleRate.R11025), 10);
        samplingFrequencyIndexMap.put(Integer.valueOf((int) TXRecordCommon.AUDIO_SAMPLERATE_8000), 11);
        samplingFrequencyIndexMap.put(0, 96000);
        samplingFrequencyIndexMap.put(1, 88200);
        samplingFrequencyIndexMap.put(2, 64000);
        samplingFrequencyIndexMap.put(3, 48000);
        samplingFrequencyIndexMap.put(4, 44100);
        samplingFrequencyIndexMap.put(5, 32000);
        samplingFrequencyIndexMap.put(6, 24000);
        samplingFrequencyIndexMap.put(7, valueOf);
        samplingFrequencyIndexMap.put(8, 16000);
        samplingFrequencyIndexMap.put(9, 12000);
        samplingFrequencyIndexMap.put(10, Integer.valueOf((int) SrsFlvMuxer.SrsCodecAudioSampleRate.R11025));
        samplingFrequencyIndexMap.put(11, Integer.valueOf((int) TXRecordCommon.AUDIO_SAMPLERATE_8000));
    }

    public AACTrackImpl(InputStream inputStream2, String lang2) throws IOException {
        this.lang = lang2;
        parse(inputStream2);
    }

    public AACTrackImpl(InputStream inputStream2) throws IOException {
        parse(inputStream2);
    }

    private void parse(InputStream inputStream2) throws IOException {
        this.inputStream = new BufferedInputStream(inputStream2);
        this.stts = new LinkedList();
        if (readVariables()) {
            this.samples = new LinkedList();
            if (readSamples()) {
                double packetsPerSecond = ((double) this.samplerate) / 1024.0d;
                double duration = ((double) this.samples.size()) / packetsPerSecond;
                long dataSize = 0;
                LinkedList<Integer> queue = new LinkedList<>();
                for (int i = 0; i < this.samples.size(); i++) {
                    int size = this.samples.get(i).capacity();
                    dataSize += (long) size;
                    queue.add(Integer.valueOf(size));
                    while (((double) queue.size()) > packetsPerSecond) {
                        queue.pop();
                    }
                    if (queue.size() == ((int) packetsPerSecond)) {
                        int currSize = 0;
                        for (int j = 0; j < queue.size(); j++) {
                            currSize += queue.get(j).intValue();
                        }
                        double currBitrate = ((((double) currSize) * 8.0d) / ((double) queue.size())) * packetsPerSecond;
                        if (currBitrate > ((double) this.maxBitRate)) {
                            this.maxBitRate = (long) ((int) currBitrate);
                        }
                    }
                }
                this.avgBitRate = (long) ((int) (((double) (8 * dataSize)) / duration));
                this.bufferSizeDB = 1536;
                this.sampleDescriptionBox = new SampleDescriptionBox();
                AudioSampleEntry audioSampleEntry = new AudioSampleEntry(AudioSampleEntry.TYPE3);
                audioSampleEntry.setChannelCount(2);
                audioSampleEntry.setSampleRate((long) this.samplerate);
                audioSampleEntry.setDataReferenceIndex(1);
                audioSampleEntry.setSampleSize(16);
                ESDescriptorBox esds = new ESDescriptorBox();
                ESDescriptor descriptor = new ESDescriptor();
                descriptor.setEsId(0);
                SLConfigDescriptor slConfigDescriptor = new SLConfigDescriptor();
                slConfigDescriptor.setPredefined(2);
                descriptor.setSlConfigDescriptor(slConfigDescriptor);
                DecoderConfigDescriptor decoderConfigDescriptor = new DecoderConfigDescriptor();
                decoderConfigDescriptor.setObjectTypeIndication(64);
                decoderConfigDescriptor.setStreamType(5);
                decoderConfigDescriptor.setBufferSizeDB(this.bufferSizeDB);
                decoderConfigDescriptor.setMaxBitRate(this.maxBitRate);
                decoderConfigDescriptor.setAvgBitRate(this.avgBitRate);
                AudioSpecificConfig audioSpecificConfig = new AudioSpecificConfig();
                audioSpecificConfig.setAudioObjectType(2);
                audioSpecificConfig.setSamplingFrequencyIndex(samplingFrequencyIndexMap.get(Integer.valueOf(this.samplerate)).intValue());
                audioSpecificConfig.setChannelConfiguration(this.channelconfig);
                decoderConfigDescriptor.setAudioSpecificInfo(audioSpecificConfig);
                descriptor.setDecoderConfigDescriptor(decoderConfigDescriptor);
                esds.setData(descriptor.serialize());
                audioSampleEntry.addBox(esds);
                this.sampleDescriptionBox.addBox(audioSampleEntry);
                this.trackMetaData.setCreationTime(new Date());
                this.trackMetaData.setModificationTime(new Date());
                this.trackMetaData.setLanguage(this.lang);
                this.trackMetaData.setTimescale((long) this.samplerate);
                return;
            }
            throw new IOException();
        }
        throw new IOException();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.sampleDescriptionBox;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        return this.stts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public long[] getSyncSamples() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        return this.trackMetaData;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return "soun";
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        return this.samples;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public Box getMediaHeaderBox() {
        return new SoundMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return null;
    }

    private boolean readVariables() throws IOException {
        byte[] data = new byte[100];
        this.inputStream.mark(100);
        if (100 != this.inputStream.read(data, 0, 100)) {
            return false;
        }
        this.inputStream.reset();
        BitReaderBuffer brb = new BitReaderBuffer(ByteBuffer.wrap(data));
        if (brb.readBits(12) != 4095) {
            return false;
        }
        brb.readBits(1);
        brb.readBits(2);
        brb.readBits(1);
        brb.readBits(2);
        this.samplerate = samplingFrequencyIndexMap.get(Integer.valueOf(brb.readBits(4))).intValue();
        brb.readBits(1);
        this.channelconfig = brb.readBits(3);
        brb.readBits(1);
        brb.readBits(1);
        brb.readBits(2);
        return true;
    }

    private boolean readSamples() throws IOException {
        int i = 1;
        if (this.readSamples) {
            return true;
        }
        this.readSamples = true;
        byte[] header = new byte[15];
        boolean ret = false;
        this.inputStream.mark(15);
        while (-1 != this.inputStream.read(header)) {
            ByteBuffer bb = ByteBuffer.wrap(header);
            this.inputStream.reset();
            BitReaderBuffer brb = new BitReaderBuffer(bb);
            if (brb.readBits(12) != 4095) {
                return false;
            }
            brb.readBits(3);
            int protectionAbsent = brb.readBits(i);
            brb.readBits(14);
            int frameSize = brb.readBits(13);
            brb.readBits(11);
            brb.readBits(2);
            int used = (int) Math.ceil(((double) brb.getPosition()) / 8.0d);
            if (protectionAbsent == 0) {
                used += 2;
            }
            this.inputStream.skip((long) used);
            byte[] data = new byte[(frameSize - used)];
            this.inputStream.read(data);
            this.samples.add(ByteBuffer.wrap(data));
            this.stts.add(new TimeToSampleBox.Entry(1, 1024));
            this.inputStream.mark(15);
            header = header;
            ret = true;
            i = 1;
        }
        return ret;
    }

    public String toString() {
        return "AACTrackImpl{samplerate=" + this.samplerate + ", bitrate=" + this.bitrate + ", channelCount=" + this.channelCount + ", channelconfig=" + this.channelconfig + Operators.BLOCK_END;
    }
}
