package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.googlecode.mp4parser.authoring.AbstractTrack;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import java.nio.ByteBuffer;
import java.util.LinkedList;
import java.util.List;

public class CroppedTrack extends AbstractTrack {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private int fromSample;
    Track origTrack;
    private long[] syncSampleArray;
    private int toSample;

    public CroppedTrack(Track origTrack2, long fromSample2, long toSample2) {
        this.origTrack = origTrack2;
        this.fromSample = (int) fromSample2;
        this.toSample = (int) toSample2;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        return this.origTrack.getSamples().subList(this.fromSample, this.toSample);
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.origTrack.getSampleDescriptionBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        if (this.origTrack.getDecodingTimeEntries() == null || this.origTrack.getDecodingTimeEntries().isEmpty()) {
            return null;
        }
        long[] decodingTimes = TimeToSampleBox.blowupTimeToSamples(this.origTrack.getDecodingTimeEntries());
        int i = this.toSample;
        int i2 = this.fromSample;
        long[] nuDecodingTimes = new long[(i - i2)];
        System.arraycopy(decodingTimes, i2, nuDecodingTimes, 0, i - i2);
        LinkedList<TimeToSampleBox.Entry> returnDecodingEntries = new LinkedList<>();
        for (long nuDecodingTime : nuDecodingTimes) {
            if (returnDecodingEntries.isEmpty() || returnDecodingEntries.getLast().getDelta() != nuDecodingTime) {
                returnDecodingEntries.add(new TimeToSampleBox.Entry(1, nuDecodingTime));
            } else {
                TimeToSampleBox.Entry e = returnDecodingEntries.getLast();
                e.setCount(e.getCount() + 1);
            }
        }
        return returnDecodingEntries;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        if (this.origTrack.getCompositionTimeEntries() == null || this.origTrack.getCompositionTimeEntries().isEmpty()) {
            return null;
        }
        int[] compositionTime = CompositionTimeToSample.blowupCompositionTimes(this.origTrack.getCompositionTimeEntries());
        int i = this.toSample;
        int i2 = this.fromSample;
        int[] nuCompositionTimes = new int[(i - i2)];
        System.arraycopy(compositionTime, i2, nuCompositionTimes, 0, i - i2);
        LinkedList<CompositionTimeToSample.Entry> returnDecodingEntries = new LinkedList<>();
        for (int nuDecodingTime : nuCompositionTimes) {
            if (returnDecodingEntries.isEmpty() || returnDecodingEntries.getLast().getOffset() != nuDecodingTime) {
                returnDecodingEntries.add(new CompositionTimeToSample.Entry(1, nuDecodingTime));
            } else {
                CompositionTimeToSample.Entry e = returnDecodingEntries.getLast();
                e.setCount(e.getCount() + 1);
            }
        }
        return returnDecodingEntries;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public synchronized long[] getSyncSamples() {
        if (this.syncSampleArray != null) {
            return this.syncSampleArray;
        } else if (this.origTrack.getSyncSamples() == null || this.origTrack.getSyncSamples().length <= 0) {
            return null;
        } else {
            List<Long> syncSamples = new LinkedList<>();
            long[] syncSamples2 = this.origTrack.getSyncSamples();
            for (long l : syncSamples2) {
                if (l >= ((long) this.fromSample) && l < ((long) this.toSample)) {
                    syncSamples.add(Long.valueOf(l - ((long) this.fromSample)));
                }
            }
            this.syncSampleArray = new long[syncSamples.size()];
            for (int i = 0; i < this.syncSampleArray.length; i++) {
                this.syncSampleArray[i] = syncSamples.get(i).longValue();
            }
            return this.syncSampleArray;
        }
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        if (this.origTrack.getSampleDependencies() == null || this.origTrack.getSampleDependencies().isEmpty()) {
            return null;
        }
        return this.origTrack.getSampleDependencies().subList(this.fromSample, this.toSample);
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        return this.origTrack.getTrackMetaData();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return this.origTrack.getHandler();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public Box getMediaHeaderBox() {
        return this.origTrack.getMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return this.origTrack.getSubsampleInformationBox();
    }
}
