package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.AbstractMediaHeaderBox;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SoundMediaHeaderBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.googlecode.mp4parser.authoring.AbstractTrack;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import com.googlecode.mp4parser.boxes.EC3SpecificBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.BitReaderBuffer;
import com.taobao.weex.el.parse.Operators;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import net.ossrs.yasea.SrsFlvMuxer;

public class EC3TrackImpl extends AbstractTrack {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    int bitrate;
    List<BitStreamInfo> entries = new LinkedList();
    int frameSize;
    private BufferedInputStream inputStream;
    private String lang = "und";
    SampleDescriptionBox sampleDescriptionBox;
    int samplerate;
    private List<ByteBuffer> samples;
    List<TimeToSampleBox.Entry> stts = new LinkedList();
    TrackMetaData trackMetaData = new TrackMetaData();

    public EC3TrackImpl(InputStream fin, String lang2) throws IOException {
        this.lang = lang2;
        parse(fin);
    }

    public EC3TrackImpl(InputStream fin) throws IOException {
        parse(fin);
    }

    private void parse(InputStream fin) throws IOException {
        BufferedInputStream bufferedInputStream = new BufferedInputStream(fin);
        this.inputStream = bufferedInputStream;
        boolean done = false;
        bufferedInputStream.mark(10000);
        while (!done) {
            BitStreamInfo bsi = readVariables();
            if (bsi != null) {
                for (BitStreamInfo entry : this.entries) {
                    if (bsi.strmtyp != 1 && entry.substreamid == bsi.substreamid) {
                        done = true;
                    }
                }
                if (!done) {
                    this.entries.add(bsi);
                    this.inputStream.skip((long) bsi.frameSize);
                }
            } else {
                throw new IOException();
            }
        }
        this.inputStream.reset();
        if (this.entries.size() != 0) {
            this.samplerate = this.entries.get(0).samplerate;
            this.sampleDescriptionBox = new SampleDescriptionBox();
            AudioSampleEntry audioSampleEntry = new AudioSampleEntry(AudioSampleEntry.TYPE9);
            audioSampleEntry.setChannelCount(2);
            audioSampleEntry.setSampleRate((long) this.samplerate);
            audioSampleEntry.setDataReferenceIndex(1);
            audioSampleEntry.setSampleSize(16);
            EC3SpecificBox ec3 = new EC3SpecificBox();
            int[] deps = new int[this.entries.size()];
            int[] chan_locs = new int[this.entries.size()];
            for (BitStreamInfo bsi2 : this.entries) {
                if (bsi2.strmtyp == 1) {
                    int i = bsi2.substreamid;
                    deps[i] = deps[i] + 1;
                    chan_locs[bsi2.substreamid] = ((bsi2.chanmap >> 6) & 256) | ((bsi2.chanmap >> 5) & 255);
                }
            }
            for (BitStreamInfo bsi3 : this.entries) {
                if (bsi3.strmtyp != 1) {
                    EC3SpecificBox.Entry e = new EC3SpecificBox.Entry();
                    e.fscod = bsi3.fscod;
                    e.bsid = bsi3.bsid;
                    e.bsmod = bsi3.bsmod;
                    e.acmod = bsi3.acmod;
                    e.lfeon = bsi3.lfeon;
                    e.reserved = 0;
                    e.num_dep_sub = deps[bsi3.substreamid];
                    e.chan_loc = chan_locs[bsi3.substreamid];
                    e.reserved2 = 0;
                    ec3.addEntry(e);
                }
                this.bitrate += bsi3.bitrate;
                this.frameSize += bsi3.frameSize;
            }
            ec3.setDataRate(this.bitrate / 1000);
            audioSampleEntry.addBox(ec3);
            this.sampleDescriptionBox.addBox(audioSampleEntry);
            this.trackMetaData.setCreationTime(new Date());
            this.trackMetaData.setModificationTime(new Date());
            this.trackMetaData.setLanguage(this.lang);
            this.trackMetaData.setTimescale((long) this.samplerate);
            this.samples = new LinkedList();
            if (!readSamples()) {
                throw new IOException();
            }
            return;
        }
        throw new IOException();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        return this.samples;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.sampleDescriptionBox;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        return this.stts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public long[] getSyncSamples() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        return null;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        return this.trackMetaData;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return "soun";
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public AbstractMediaHeaderBox getMediaHeaderBox() {
        return new SoundMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return null;
    }

    private BitStreamInfo readVariables() throws IOException {
        int numblkscod;
        int i;
        int i2;
        byte[] data = new byte[200];
        this.inputStream.mark(200);
        if (200 != this.inputStream.read(data, 0, 200)) {
            return null;
        }
        this.inputStream.reset();
        BitReaderBuffer brb = new BitReaderBuffer(ByteBuffer.wrap(data));
        if (brb.readBits(16) != 2935) {
            return null;
        }
        BitStreamInfo entry = new BitStreamInfo();
        entry.strmtyp = brb.readBits(2);
        entry.substreamid = brb.readBits(3);
        entry.frameSize = (brb.readBits(11) + 1) * 2;
        entry.fscod = brb.readBits(2);
        int fscod2 = -1;
        if (entry.fscod == 3) {
            fscod2 = brb.readBits(2);
            numblkscod = 3;
        } else {
            numblkscod = brb.readBits(2);
        }
        int numberOfBlocksPerSyncFrame = 0;
        if (numblkscod == 0) {
            numberOfBlocksPerSyncFrame = 1;
        } else if (numblkscod == 1) {
            numberOfBlocksPerSyncFrame = 2;
        } else if (numblkscod == 2) {
            numberOfBlocksPerSyncFrame = 3;
        } else if (numblkscod == 3) {
            numberOfBlocksPerSyncFrame = 6;
        }
        entry.frameSize *= 6 / numberOfBlocksPerSyncFrame;
        entry.acmod = brb.readBits(3);
        entry.lfeon = brb.readBits(1);
        entry.bsid = brb.readBits(5);
        brb.readBits(5);
        if (1 == brb.readBits(1)) {
            brb.readBits(8);
        }
        if (entry.acmod == 0) {
            brb.readBits(5);
            if (1 == brb.readBits(1)) {
                brb.readBits(8);
            }
        }
        if (1 == entry.strmtyp && 1 == brb.readBits(1)) {
            entry.chanmap = brb.readBits(16);
        }
        if (1 == brb.readBits(1)) {
            if (entry.acmod > 2) {
                brb.readBits(2);
            }
            if (1 == (entry.acmod & 1) && entry.acmod > 2) {
                brb.readBits(3);
                brb.readBits(3);
            }
            if ((entry.acmod & 4) > 0) {
                brb.readBits(3);
                brb.readBits(3);
            }
            if (1 == entry.lfeon && 1 == brb.readBits(1)) {
                brb.readBits(5);
            }
            if (entry.strmtyp == 0) {
                if (1 == brb.readBits(1)) {
                    i2 = 6;
                    brb.readBits(6);
                } else {
                    i2 = 6;
                }
                if (entry.acmod == 0 && 1 == brb.readBits(1)) {
                    brb.readBits(i2);
                }
                if (1 == brb.readBits(1)) {
                    brb.readBits(i2);
                }
                int mixdef = brb.readBits(2);
                if (1 == mixdef) {
                    brb.readBits(5);
                } else if (2 == mixdef) {
                    brb.readBits(12);
                } else if (3 == mixdef) {
                    int mixdeflen = brb.readBits(5);
                    if (1 == brb.readBits(1)) {
                        brb.readBits(5);
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            brb.readBits(4);
                        }
                        if (1 == brb.readBits(1)) {
                            if (1 == brb.readBits(1)) {
                                brb.readBits(4);
                            }
                            if (1 == brb.readBits(1)) {
                                brb.readBits(4);
                            }
                        }
                    }
                    if (1 == brb.readBits(1)) {
                        brb.readBits(5);
                        if (1 == brb.readBits(1)) {
                            brb.readBits(7);
                            if (1 == brb.readBits(1)) {
                                brb.readBits(8);
                            }
                        }
                    }
                    for (int i3 = 0; i3 < mixdeflen + 2; i3++) {
                        brb.readBits(8);
                    }
                    brb.byteSync();
                }
                if (entry.acmod < 2) {
                    if (1 == brb.readBits(1)) {
                        brb.readBits(14);
                    }
                    if (entry.acmod == 0 && 1 == brb.readBits(1)) {
                        brb.readBits(14);
                    }
                    if (1 == brb.readBits(1)) {
                        if (numblkscod == 0) {
                            brb.readBits(5);
                        } else {
                            for (int i4 = 0; i4 < numberOfBlocksPerSyncFrame; i4++) {
                                if (1 == brb.readBits(1)) {
                                    brb.readBits(5);
                                }
                            }
                        }
                    }
                }
            }
        }
        if (1 == brb.readBits(1)) {
            i = 3;
            entry.bsmod = brb.readBits(3);
        } else {
            i = 3;
        }
        int i5 = entry.fscod;
        if (i5 == 0) {
            entry.samplerate = 48000;
        } else if (i5 == 1) {
            entry.samplerate = 44100;
        } else if (i5 == 2) {
            entry.samplerate = 32000;
        } else if (i5 == i) {
            if (fscod2 == 0) {
                entry.samplerate = 24000;
            } else if (fscod2 == 1) {
                entry.samplerate = SrsFlvMuxer.SrsCodecAudioSampleRate.R22050;
            } else if (fscod2 == 2) {
                entry.samplerate = 16000;
            } else if (fscod2 == i) {
                entry.samplerate = 0;
            }
        }
        if (entry.samplerate == 0) {
            return null;
        }
        entry.bitrate = (int) ((((double) entry.samplerate) / 1536.0d) * ((double) entry.frameSize) * 8.0d);
        return entry;
    }

    private boolean readSamples() throws IOException {
        int read = this.frameSize;
        boolean ret = false;
        while (true) {
            int i = this.frameSize;
            if (i != read) {
                return ret;
            }
            ret = true;
            byte[] data = new byte[i];
            read = this.inputStream.read(data);
            if (read == this.frameSize) {
                this.samples.add(ByteBuffer.wrap(data));
                this.stts.add(new TimeToSampleBox.Entry(1, 1536));
            }
        }
    }

    public static class BitStreamInfo extends EC3SpecificBox.Entry {
        public int bitrate;
        public int chanmap;
        public int frameSize;
        public int samplerate;
        public int strmtyp;
        public int substreamid;

        @Override // com.googlecode.mp4parser.boxes.EC3SpecificBox.Entry
        public String toString() {
            return "BitStreamInfo{frameSize=" + this.frameSize + ", substreamid=" + this.substreamid + ", bitrate=" + this.bitrate + ", samplerate=" + this.samplerate + ", strmtyp=" + this.strmtyp + ", chanmap=" + this.chanmap + Operators.BLOCK_END;
        }
    }

    public String toString() {
        return "EC3TrackImpl{bitrate=" + this.bitrate + ", samplerate=" + this.samplerate + ", entries=" + this.entries + Operators.BLOCK_END;
    }
}
