package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.AbstractMediaHeaderBox;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.VideoMediaHeaderBox;
import com.coremedia.iso.boxes.h264.AvcConfigurationBox;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.authoring.AbstractTrack;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import com.googlecode.mp4parser.h264.model.PictureParameterSet;
import com.googlecode.mp4parser.h264.model.SeqParameterSet;
import com.googlecode.mp4parser.h264.read.CAVLCReader;
import com.taobao.weex.el.parse.Operators;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import java.util.logging.Logger;

public class H264TrackImpl extends AbstractTrack {
    private static final Logger LOG = Logger.getLogger(H264TrackImpl.class.getName());
    List<CompositionTimeToSample.Entry> ctts;
    private int currentScSize;
    private boolean determineFrameRate = true;
    int frameNrInGop = 0;
    private int frametick;
    private int height;
    private String lang = "und";
    PictureParameterSet pictureParameterSet = null;
    LinkedList<byte[]> pictureParameterSetList = new LinkedList<>();
    private int prevScSize;
    boolean readSamples = false;
    private ReaderWrapper reader;
    SampleDescriptionBox sampleDescriptionBox;
    private List<ByteBuffer> samples;
    List<SampleDependencyTypeBox.Entry> sdtp;
    private SEIMessage seiMessage;
    SeqParameterSet seqParameterSet = null;
    LinkedList<byte[]> seqParameterSetList = new LinkedList<>();
    List<Integer> stss;
    List<TimeToSampleBox.Entry> stts;
    private int timescale;
    TrackMetaData trackMetaData = new TrackMetaData();
    private int width;

    /* access modifiers changed from: private */
    public enum NALActions {
        IGNORE,
        BUFFER,
        STORE,
        END
    }

    public H264TrackImpl(InputStream inputStream, String lang2, int timescale2) throws IOException {
        this.lang = lang2;
        if (timescale2 > 1000) {
            this.timescale = timescale2;
            this.frametick = 1000;
            this.determineFrameRate = false;
            parse(inputStream);
            return;
        }
        throw new IllegalArgumentException("Timescale must be specified in milliseconds!");
    }

    public H264TrackImpl(InputStream inputStream, String lang2) throws IOException {
        this.lang = lang2;
        parse(inputStream);
    }

    public H264TrackImpl(InputStream inputStream) throws IOException {
        parse(inputStream);
    }

    private void parse(InputStream inputStream) throws IOException {
        this.reader = new ReaderWrapper(this, inputStream, null);
        this.stts = new LinkedList();
        this.ctts = new LinkedList();
        this.sdtp = new LinkedList();
        this.stss = new LinkedList();
        this.samples = new LinkedList();
        if (!readSamples()) {
            throw new IOException();
        } else if (readVariables()) {
            this.sampleDescriptionBox = new SampleDescriptionBox();
            VisualSampleEntry visualSampleEntry = new VisualSampleEntry(VisualSampleEntry.TYPE3);
            visualSampleEntry.setDataReferenceIndex(1);
            visualSampleEntry.setDepth(24);
            visualSampleEntry.setFrameCount(1);
            visualSampleEntry.setHorizresolution(72.0d);
            visualSampleEntry.setVertresolution(72.0d);
            visualSampleEntry.setWidth(this.width);
            visualSampleEntry.setHeight(this.height);
            visualSampleEntry.setCompressorname("AVC Coding");
            AvcConfigurationBox avcConfigurationBox = new AvcConfigurationBox();
            avcConfigurationBox.setSequenceParameterSets(this.seqParameterSetList);
            avcConfigurationBox.setPictureParameterSets(this.pictureParameterSetList);
            avcConfigurationBox.setAvcLevelIndication(this.seqParameterSet.level_idc);
            avcConfigurationBox.setAvcProfileIndication(this.seqParameterSet.profile_idc);
            avcConfigurationBox.setBitDepthLumaMinus8(this.seqParameterSet.bit_depth_luma_minus8);
            avcConfigurationBox.setBitDepthChromaMinus8(this.seqParameterSet.bit_depth_chroma_minus8);
            avcConfigurationBox.setChromaFormat(this.seqParameterSet.chroma_format_idc.getId());
            avcConfigurationBox.setConfigurationVersion(1);
            avcConfigurationBox.setLengthSizeMinusOne(3);
            avcConfigurationBox.setProfileCompatibility(this.seqParameterSetList.get(0)[1]);
            visualSampleEntry.addBox(avcConfigurationBox);
            this.sampleDescriptionBox.addBox(visualSampleEntry);
            this.trackMetaData.setCreationTime(new Date());
            this.trackMetaData.setModificationTime(new Date());
            this.trackMetaData.setLanguage(this.lang);
            this.trackMetaData.setTimescale((long) this.timescale);
            this.trackMetaData.setWidth((double) this.width);
            this.trackMetaData.setHeight((double) this.height);
        } else {
            throw new IOException();
        }
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.sampleDescriptionBox;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        return this.stts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        return this.ctts;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public long[] getSyncSamples() {
        long[] returns = new long[this.stss.size()];
        for (int i = 0; i < this.stss.size(); i++) {
            returns[i] = (long) this.stss.get(i).intValue();
        }
        return returns;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        return this.sdtp;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        return this.trackMetaData;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return "vide";
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        return this.samples;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public AbstractMediaHeaderBox getMediaHeaderBox() {
        return new VideoMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return null;
    }

    private boolean readVariables() {
        this.width = (this.seqParameterSet.pic_width_in_mbs_minus1 + 1) * 16;
        int mult = 2;
        if (this.seqParameterSet.frame_mbs_only_flag) {
            mult = 1;
        }
        this.height = (this.seqParameterSet.pic_height_in_map_units_minus1 + 1) * 16 * mult;
        if (this.seqParameterSet.frame_cropping_flag) {
            int chromaArrayType = 0;
            if (!this.seqParameterSet.residual_color_transform_flag) {
                chromaArrayType = this.seqParameterSet.chroma_format_idc.getId();
            }
            int cropUnitX = 1;
            int cropUnitY = mult;
            if (chromaArrayType != 0) {
                cropUnitX = this.seqParameterSet.chroma_format_idc.getSubWidth();
                cropUnitY = this.seqParameterSet.chroma_format_idc.getSubHeight() * mult;
            }
            this.width -= (this.seqParameterSet.frame_crop_left_offset + this.seqParameterSet.frame_crop_right_offset) * cropUnitX;
            this.height -= (this.seqParameterSet.frame_crop_top_offset + this.seqParameterSet.frame_crop_bottom_offset) * cropUnitY;
        }
        return true;
    }

    private boolean findNextStartcode() throws IOException {
        byte[] test = {-1, -1, -1, -1};
        while (true) {
            int c = this.reader.read();
            if (c == -1) {
                return false;
            }
            test[0] = test[1];
            test[1] = test[2];
            test[2] = test[3];
            test[3] = (byte) c;
            if (test[0] == 0 && test[1] == 0 && test[2] == 0 && test[3] == 1) {
                this.prevScSize = this.currentScSize;
                this.currentScSize = 4;
                return true;
            } else if (test[0] == 0 && test[1] == 0 && test[2] == 1) {
                this.prevScSize = this.currentScSize;
                this.currentScSize = 3;
                return true;
            }
        }
    }

    private boolean readSamples() throws IOException {
        boolean IdrPicFlag;
        if (this.readSamples) {
            return true;
        }
        this.readSamples = true;
        findNextStartcode();
        this.reader.mark();
        long pos = this.reader.getPos();
        ArrayList<byte[]> buffered = new ArrayList<>();
        int frameNr = 0;
        while (findNextStartcode()) {
            long newpos = this.reader.getPos();
            int size = (int) ((newpos - pos) - ((long) this.prevScSize));
            this.reader.reset();
            byte[] data = new byte[size];
            this.reader.read(data);
            byte b = data[0];
            int nal_ref_idc = (b >> 5) & 3;
            int nal_unit_type = b & 31;
            LOG.fine("Found startcode at " + (pos - 4) + " Type: " + nal_unit_type + " ref idc: " + nal_ref_idc + " (size " + size + Operators.BRACKET_END_STR);
            int i = AnonymousClass1.$SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions[handleNALUnit(nal_ref_idc, nal_unit_type, data).ordinal()];
            if (i == 2) {
                buffered.add(data);
            } else if (i == 3) {
                int stdpValue = 22;
                frameNr++;
                buffered.add(data);
                ByteBuffer bb = createSample(buffered);
                if (nal_unit_type == 5) {
                    stdpValue = 22 + 16;
                    IdrPicFlag = true;
                } else {
                    IdrPicFlag = false;
                }
                SliceHeader sh = new SliceHeader(cleanBuffer(buffered.get(buffered.size() - 1)), this.seqParameterSet, this.pictureParameterSet, IdrPicFlag);
                if (sh.slice_type == SliceHeader.SliceType.B) {
                    stdpValue += 4;
                }
                LOG.fine("Adding sample with size " + bb.capacity() + " and header " + sh);
                buffered.clear();
                this.samples.add(bb);
                this.stts.add(new TimeToSampleBox.Entry(1, (long) this.frametick));
                if (nal_unit_type == 5) {
                    this.stss.add(Integer.valueOf(frameNr));
                }
                if (this.seiMessage.n_frames == 0) {
                    this.frameNrInGop = 0;
                }
                int offset = 0;
                if (this.seiMessage.clock_timestamp_flag) {
                    offset = this.seiMessage.n_frames - this.frameNrInGop;
                } else if (this.seiMessage.removal_delay_flag) {
                    offset = this.seiMessage.dpb_removal_delay / 2;
                }
                this.ctts.add(new CompositionTimeToSample.Entry(1, this.frametick * offset));
                this.sdtp.add(new SampleDependencyTypeBox.Entry(stdpValue));
                this.frameNrInGop++;
            } else if (i == 4) {
                return true;
            }
            pos = newpos;
            this.reader.seek(this.currentScSize);
            this.reader.mark();
        }
        return true;
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.googlecode.mp4parser.authoring.tracks.H264TrackImpl$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions;

        static {
            int[] iArr = new int[NALActions.values().length];
            $SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions = iArr;
            try {
                iArr[NALActions.IGNORE.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions[NALActions.BUFFER.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions[NALActions.STORE.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$googlecode$mp4parser$authoring$tracks$H264TrackImpl$NALActions[NALActions.END.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    /* JADX INFO: Multiple debug info for r1v2 byte[]: [D('i' int), D('output' byte[])] */
    private ByteBuffer createSample(List<byte[]> buffers) {
        int outsize = 0;
        for (int i = 0; i < buffers.size(); i++) {
            outsize += buffers.get(i).length + 4;
        }
        ByteBuffer bb = ByteBuffer.wrap(new byte[outsize]);
        for (int i2 = 0; i2 < buffers.size(); i2++) {
            bb.putInt(buffers.get(i2).length);
            bb.put(buffers.get(i2));
        }
        bb.rewind();
        return bb;
    }

    private ByteArrayInputStream cleanBuffer(byte[] data) {
        byte[] output = new byte[data.length];
        int inPos = 0;
        int outPos = 0;
        while (inPos < data.length) {
            if (data[inPos] == 0 && data[inPos + 1] == 0 && data[inPos + 2] == 3) {
                output[outPos] = 0;
                output[outPos + 1] = 0;
                inPos += 3;
                outPos += 2;
            } else {
                output[outPos] = data[inPos];
                inPos++;
                outPos++;
            }
        }
        return new ByteArrayInputStream(output, 0, outPos);
    }

    /* JADX INFO: Multiple debug info for r0v4 com.googlecode.mp4parser.authoring.tracks.H264TrackImpl$NALActions: [D('is' java.io.ByteArrayInputStream), D('action' com.googlecode.mp4parser.authoring.tracks.H264TrackImpl$NALActions)] */
    /* JADX INFO: Multiple debug info for r0v7 com.googlecode.mp4parser.authoring.tracks.H264TrackImpl$NALActions: [D('is' java.io.ByteArrayInputStream), D('action' com.googlecode.mp4parser.authoring.tracks.H264TrackImpl$NALActions)] */
    private NALActions handleNALUnit(int nal_ref_idc, int nal_unit_type, byte[] data) throws IOException {
        switch (nal_unit_type) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
                return NALActions.STORE;
            case 6:
                this.seiMessage = new SEIMessage(cleanBuffer(data), this.seqParameterSet);
                return NALActions.BUFFER;
            case 7:
                if (this.seqParameterSet == null) {
                    ByteArrayInputStream is = cleanBuffer(data);
                    is.read();
                    this.seqParameterSet = SeqParameterSet.read(is);
                    this.seqParameterSetList.add(data);
                    configureFramerate();
                }
                return NALActions.IGNORE;
            case 8:
                if (this.pictureParameterSet == null) {
                    ByteArrayInputStream is2 = new ByteArrayInputStream(data);
                    is2.read();
                    this.pictureParameterSet = PictureParameterSet.read(is2);
                    this.pictureParameterSetList.add(data);
                }
                return NALActions.IGNORE;
            case 9:
                Logger logger = LOG;
                logger.fine("Access unit delimiter type: " + (data[1] >> 5));
                return NALActions.BUFFER;
            case 10:
            case 11:
                return NALActions.END;
            default:
                PrintStream printStream = System.err;
                printStream.println("Unknown NAL unit type: " + nal_unit_type);
                return NALActions.IGNORE;
        }
    }

    private void configureFramerate() {
        if (!this.determineFrameRate) {
            return;
        }
        if (this.seqParameterSet.vuiParams != null) {
            this.timescale = this.seqParameterSet.vuiParams.time_scale >> 1;
            int i = this.seqParameterSet.vuiParams.num_units_in_tick;
            this.frametick = i;
            if (this.timescale == 0 || i == 0) {
                PrintStream printStream = System.err;
                printStream.println("Warning: vuiParams contain invalid values: time_scale: " + this.timescale + " and frame_tick: " + this.frametick + ". Setting frame rate to 25fps");
                this.timescale = 90000;
                this.frametick = 3600;
                return;
            }
            return;
        }
        System.err.println("Warning: Can't determine frame rate. Guessing 25 fps");
        this.timescale = 90000;
        this.frametick = 3600;
    }

    public void printAccessUnitDelimiter(byte[] data) {
        Logger logger = LOG;
        logger.fine("Access unit delimiter: " + (data[1] >> 5));
    }

    public static class SliceHeader {
        public boolean bottom_field_flag = false;
        public int colour_plane_id;
        public int delta_pic_order_cnt_bottom;
        public boolean field_pic_flag = false;
        public int first_mb_in_slice;
        public int frame_num;
        public int idr_pic_id;
        public int pic_order_cnt_lsb;
        public int pic_parameter_set_id;
        public SliceType slice_type;

        public enum SliceType {
            P,
            B,
            I,
            SP,
            SI
        }

        public SliceHeader(InputStream is, SeqParameterSet sps, PictureParameterSet pps, boolean IdrPicFlag) throws IOException {
            is.read();
            CAVLCReader reader = new CAVLCReader(is);
            this.first_mb_in_slice = reader.readUE("SliceHeader: first_mb_in_slice");
            switch (reader.readUE("SliceHeader: slice_type")) {
                case 0:
                case 5:
                    this.slice_type = SliceType.P;
                    break;
                case 1:
                case 6:
                    this.slice_type = SliceType.B;
                    break;
                case 2:
                case 7:
                    this.slice_type = SliceType.I;
                    break;
                case 3:
                case 8:
                    this.slice_type = SliceType.SP;
                    break;
                case 4:
                case 9:
                    this.slice_type = SliceType.SI;
                    break;
            }
            this.pic_parameter_set_id = reader.readUE("SliceHeader: pic_parameter_set_id");
            if (sps.residual_color_transform_flag) {
                this.colour_plane_id = reader.readU(2, "SliceHeader: colour_plane_id");
            }
            this.frame_num = reader.readU(sps.log2_max_frame_num_minus4 + 4, "SliceHeader: frame_num");
            if (!sps.frame_mbs_only_flag) {
                boolean readBool = reader.readBool("SliceHeader: field_pic_flag");
                this.field_pic_flag = readBool;
                if (readBool) {
                    this.bottom_field_flag = reader.readBool("SliceHeader: bottom_field_flag");
                }
            }
            if (IdrPicFlag) {
                this.idr_pic_id = reader.readUE("SliceHeader: idr_pic_id");
                if (sps.pic_order_cnt_type == 0) {
                    this.pic_order_cnt_lsb = reader.readU(sps.log2_max_pic_order_cnt_lsb_minus4 + 4, "SliceHeader: pic_order_cnt_lsb");
                    if (pps.pic_order_present_flag && !this.field_pic_flag) {
                        this.delta_pic_order_cnt_bottom = reader.readSE("SliceHeader: delta_pic_order_cnt_bottom");
                    }
                }
            }
        }

        public String toString() {
            return "SliceHeader{first_mb_in_slice=" + this.first_mb_in_slice + ", slice_type=" + this.slice_type + ", pic_parameter_set_id=" + this.pic_parameter_set_id + ", colour_plane_id=" + this.colour_plane_id + ", frame_num=" + this.frame_num + ", field_pic_flag=" + this.field_pic_flag + ", bottom_field_flag=" + this.bottom_field_flag + ", idr_pic_id=" + this.idr_pic_id + ", pic_order_cnt_lsb=" + this.pic_order_cnt_lsb + ", delta_pic_order_cnt_bottom=" + this.delta_pic_order_cnt_bottom + Operators.BLOCK_END;
        }
    }

    /* access modifiers changed from: private */
    public class ReaderWrapper {
        private InputStream inputStream;
        private long markPos;
        private long pos;

        /* synthetic */ ReaderWrapper(H264TrackImpl x0, InputStream x1, AnonymousClass1 x2) {
            this(x1);
        }

        private ReaderWrapper(InputStream inputStream2) {
            this.pos = 0;
            this.markPos = 0;
            this.inputStream = inputStream2;
        }

        /* access modifiers changed from: package-private */
        public int read() throws IOException {
            this.pos++;
            return this.inputStream.read();
        }

        /* access modifiers changed from: package-private */
        public long read(byte[] data) throws IOException {
            long read = (long) this.inputStream.read(data);
            this.pos += read;
            return read;
        }

        /* access modifiers changed from: package-private */
        public long seek(int dist) throws IOException {
            long seeked = this.inputStream.skip((long) dist);
            this.pos += seeked;
            return seeked;
        }

        public long getPos() {
            return this.pos;
        }

        public void mark() {
            Logger logger = H264TrackImpl.LOG;
            logger.fine("Marking with " + 1048576 + " at " + this.pos);
            this.inputStream.mark(1048576);
            this.markPos = this.pos;
        }

        public void reset() throws IOException {
            long diff = this.pos - this.markPos;
            Logger logger = H264TrackImpl.LOG;
            logger.fine("Resetting to " + this.markPos + " (pos is " + this.pos + ") which makes the buffersize " + diff);
            this.inputStream.reset();
            this.pos = this.markPos;
        }
    }

    public class SEIMessage {
        boolean clock_timestamp_flag;
        int cnt_dropped_flag;
        int counting_type;
        int cpb_removal_delay;
        int ct_type;
        int discontinuity_flag;
        int dpb_removal_delay;
        int full_timestamp_flag;
        int hours_value;
        int minutes_value;
        int n_frames;
        int nuit_field_based_flag;
        int payloadSize = 0;
        int payloadType = 0;
        int pic_struct;
        boolean removal_delay_flag;
        int seconds_value;
        SeqParameterSet sps;
        int time_offset;
        int time_offset_length;

        /* JADX WARN: Type inference failed for: r3v0 */
        /* JADX WARN: Type inference failed for: r3v1, types: [boolean, int] */
        /* JADX WARN: Type inference failed for: r3v3 */
        /* JADX WARNING: Unknown variable types count: 1 */
        public SEIMessage(InputStream is, SeqParameterSet sps2) throws IOException {
            int read;
            int numClockTS;
            int read2;
            ?? r3 = 0;
            this.sps = sps2;
            is.read();
            int datasize = is.available();
            int read3 = 0;
            while (read3 < datasize) {
                int i = r3 == true ? 1 : 0;
                int i2 = r3 == true ? 1 : 0;
                int i3 = r3 == true ? 1 : 0;
                this.payloadType = i;
                this.payloadSize = r3;
                int last_payload_type_bytes = is.read();
                while (true) {
                    read3++;
                    if (last_payload_type_bytes == 255) {
                        this.payloadType += last_payload_type_bytes;
                        last_payload_type_bytes = is.read();
                    } else {
                        this.payloadType += last_payload_type_bytes;
                        int last_payload_size_bytes = is.read();
                        read3++;
                        while (last_payload_size_bytes == 255) {
                            this.payloadSize += last_payload_size_bytes;
                            last_payload_size_bytes = is.read();
                            read3++;
                        }
                        int i4 = this.payloadSize + last_payload_size_bytes;
                        this.payloadSize = i4;
                        if (datasize - read3 < i4) {
                            read3 = datasize;
                        } else if (this.payloadType == 1) {
                            if (sps2.vuiParams != null) {
                                if (sps2.vuiParams.nalHRDParams != null || sps2.vuiParams.vclHRDParams != null || sps2.vuiParams.pic_struct_present_flag) {
                                    byte[] data = new byte[this.payloadSize];
                                    is.read(data);
                                    int read4 = read3 + this.payloadSize;
                                    CAVLCReader reader = new CAVLCReader(new ByteArrayInputStream(data));
                                    if (sps2.vuiParams.nalHRDParams == null && sps2.vuiParams.vclHRDParams == null) {
                                        this.removal_delay_flag = r3;
                                    } else {
                                        this.removal_delay_flag = true;
                                        this.cpb_removal_delay = reader.readU(sps2.vuiParams.nalHRDParams.cpb_removal_delay_length_minus1 + 1, "SEI: cpb_removal_delay");
                                        this.dpb_removal_delay = reader.readU(sps2.vuiParams.nalHRDParams.dpb_output_delay_length_minus1 + 1, "SEI: dpb_removal_delay");
                                    }
                                    if (sps2.vuiParams.pic_struct_present_flag) {
                                        int readU = reader.readU(4, "SEI: pic_struct");
                                        this.pic_struct = readU;
                                        switch (readU) {
                                            case 3:
                                            case 4:
                                            case 7:
                                                numClockTS = 2;
                                                break;
                                            case 5:
                                            case 6:
                                            case 8:
                                                numClockTS = 3;
                                                break;
                                            default:
                                                numClockTS = 1;
                                                break;
                                        }
                                        int i5 = 0;
                                        while (i5 < numClockTS) {
                                            boolean readBool = reader.readBool("pic_timing SEI: clock_timestamp_flag[" + i5 + Operators.ARRAY_END_STR);
                                            this.clock_timestamp_flag = readBool;
                                            if (readBool) {
                                                this.ct_type = reader.readU(2, "pic_timing SEI: ct_type");
                                                this.nuit_field_based_flag = reader.readU(1, "pic_timing SEI: nuit_field_based_flag");
                                                this.counting_type = reader.readU(5, "pic_timing SEI: counting_type");
                                                this.full_timestamp_flag = reader.readU(1, "pic_timing SEI: full_timestamp_flag");
                                                this.discontinuity_flag = reader.readU(1, "pic_timing SEI: discontinuity_flag");
                                                this.cnt_dropped_flag = reader.readU(1, "pic_timing SEI: cnt_dropped_flag");
                                                this.n_frames = reader.readU(8, "pic_timing SEI: n_frames");
                                                read2 = read4;
                                                if (this.full_timestamp_flag == 1) {
                                                    this.seconds_value = reader.readU(6, "pic_timing SEI: seconds_value");
                                                    this.minutes_value = reader.readU(6, "pic_timing SEI: minutes_value");
                                                    this.hours_value = reader.readU(5, "pic_timing SEI: hours_value");
                                                } else if (reader.readBool("pic_timing SEI: seconds_flag")) {
                                                    this.seconds_value = reader.readU(6, "pic_timing SEI: seconds_value");
                                                    if (reader.readBool("pic_timing SEI: minutes_flag")) {
                                                        this.minutes_value = reader.readU(6, "pic_timing SEI: minutes_value");
                                                        if (reader.readBool("pic_timing SEI: hours_flag")) {
                                                            this.hours_value = reader.readU(5, "pic_timing SEI: hours_value");
                                                        }
                                                    }
                                                }
                                                if (sps2.vuiParams.nalHRDParams != null) {
                                                    this.time_offset_length = sps2.vuiParams.nalHRDParams.time_offset_length;
                                                } else if (sps2.vuiParams.vclHRDParams != null) {
                                                    this.time_offset_length = sps2.vuiParams.vclHRDParams.time_offset_length;
                                                } else {
                                                    this.time_offset_length = 24;
                                                }
                                                this.time_offset = reader.readU(24, "pic_timing SEI: time_offset");
                                            } else {
                                                read2 = read4;
                                            }
                                            i5++;
                                            read4 = read2;
                                        }
                                        read = read4;
                                    } else {
                                        read = read4;
                                    }
                                    read3 = read;
                                }
                            }
                            for (int i6 = 0; i6 < this.payloadSize; i6++) {
                                is.read();
                                read3++;
                            }
                        } else {
                            for (int i7 = 0; i7 < this.payloadSize; i7++) {
                                is.read();
                                read3++;
                            }
                        }
                        H264TrackImpl.LOG.fine(toString());
                        r3 = 0;
                    }
                }
            }
        }

        public String toString() {
            String out = "SEIMessage{payloadType=" + this.payloadType + ", payloadSize=" + this.payloadSize;
            if (this.payloadType == 1) {
                if (!(this.sps.vuiParams.nalHRDParams == null && this.sps.vuiParams.vclHRDParams == null)) {
                    out = out + ", cpb_removal_delay=" + this.cpb_removal_delay + ", dpb_removal_delay=" + this.dpb_removal_delay;
                }
                if (this.sps.vuiParams.pic_struct_present_flag) {
                    out = out + ", pic_struct=" + this.pic_struct;
                    if (this.clock_timestamp_flag) {
                        out = out + ", ct_type=" + this.ct_type + ", nuit_field_based_flag=" + this.nuit_field_based_flag + ", counting_type=" + this.counting_type + ", full_timestamp_flag=" + this.full_timestamp_flag + ", discontinuity_flag=" + this.discontinuity_flag + ", cnt_dropped_flag=" + this.cnt_dropped_flag + ", n_frames=" + this.n_frames + ", seconds_value=" + this.seconds_value + ", minutes_value=" + this.minutes_value + ", hours_value=" + this.hours_value + ", time_offset_length=" + this.time_offset_length + ", time_offset=" + this.time_offset;
                    }
                }
            }
            return out + Operators.BLOCK_END;
        }
    }
}
