package com.googlecode.mp4parser.boxes;

import com.coremedia.iso.Hex;
import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.TrackHeaderBox;
import com.coremedia.iso.boxes.fragment.TrackFragmentHeaderBox;
import com.googlecode.mp4parser.AbstractFullBox;
import com.googlecode.mp4parser.util.Path;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.math.BigInteger;
import java.nio.ByteBuffer;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.LinkedList;
import java.util.List;

public abstract class AbstractSampleEncryptionBox extends AbstractFullBox {
    int algorithmId = -1;
    List<Entry> entries = new LinkedList();
    int ivSize = -1;
    byte[] kid = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};

    protected AbstractSampleEncryptionBox(String type) {
        super(type);
    }

    public int getOffsetToFirstIV() {
        return (getSize() > 4294967296L ? 16 : 8) + (isOverrideTrackEncryptionBoxParameters() ? 20 : 0) + 4;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        int useThisIvSize = -1;
        if ((getFlags() & 1) > 0) {
            this.algorithmId = IsoTypeReader.readUInt24(content);
            this.ivSize = IsoTypeReader.readUInt8(content);
            useThisIvSize = this.ivSize;
            byte[] bArr = new byte[16];
            this.kid = bArr;
            content.get(bArr);
        } else {
            for (Box tkhd : Path.getPaths(this, "/moov[0]/trak/tkhd")) {
                if (((TrackHeaderBox) tkhd).getTrackId() == ((TrackFragmentHeaderBox) getParent().getBoxes(TrackFragmentHeaderBox.class).get(0)).getTrackId()) {
                    AbstractTrackEncryptionBox tenc = (AbstractTrackEncryptionBox) Path.getPath(tkhd, "../mdia[0]/minf[0]/stbl[0]/stsd[0]/enc.[0]/sinf[0]/schi[0]/tenc[0]");
                    if (tenc == null) {
                        tenc = (AbstractTrackEncryptionBox) Path.getPath(tkhd, "../mdia[0]/minf[0]/stbl[0]/stsd[0]/enc.[0]/sinf[0]/schi[0]/uuid[0]");
                    }
                    useThisIvSize = tenc.getDefaultIvSize();
                }
            }
        }
        long numOfEntries = IsoTypeReader.readUInt32(content);
        while (true) {
            long numOfEntries2 = numOfEntries - 1;
            if (numOfEntries > 0) {
                Entry e = new Entry();
                e.iv = new byte[(useThisIvSize < 0 ? 8 : useThisIvSize)];
                content.get(e.iv);
                if ((getFlags() & 2) > 0) {
                    int numOfPairs = IsoTypeReader.readUInt16(content);
                    e.pairs = new LinkedList();
                    while (true) {
                        int numOfPairs2 = numOfPairs - 1;
                        if (numOfPairs <= 0) {
                            break;
                        }
                        e.pairs.add(e.createPair(IsoTypeReader.readUInt16(content), IsoTypeReader.readUInt32(content)));
                        numOfPairs = numOfPairs2;
                    }
                }
                this.entries.add(e);
                numOfEntries = numOfEntries2;
            } else {
                return;
            }
        }
    }

    public int getSampleCount() {
        return this.entries.size();
    }

    public List<Entry> getEntries() {
        return this.entries;
    }

    public void setEntries(List<Entry> entries2) {
        this.entries = entries2;
    }

    public int getAlgorithmId() {
        return this.algorithmId;
    }

    public void setAlgorithmId(int algorithmId2) {
        this.algorithmId = algorithmId2;
    }

    public int getIvSize() {
        return this.ivSize;
    }

    public void setIvSize(int ivSize2) {
        this.ivSize = ivSize2;
    }

    public byte[] getKid() {
        return this.kid;
    }

    public void setKid(byte[] kid2) {
        this.kid = kid2;
    }

    public boolean isSubSampleEncryption() {
        return (getFlags() & 2) > 0;
    }

    public boolean isOverrideTrackEncryptionBoxParameters() {
        return (getFlags() & 1) > 0;
    }

    public void setSubSampleEncryption(boolean b) {
        if (b) {
            setFlags(getFlags() | 2);
        } else {
            setFlags(getFlags() & 16777213);
        }
    }

    public void setOverrideTrackEncryptionBoxParameters(boolean b) {
        if (b) {
            setFlags(getFlags() | 1);
        } else {
            setFlags(getFlags() & 16777214);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        if (isOverrideTrackEncryptionBoxParameters()) {
            IsoTypeWriter.writeUInt24(byteBuffer, this.algorithmId);
            IsoTypeWriter.writeUInt8(byteBuffer, this.ivSize);
            byteBuffer.put(this.kid);
        }
        IsoTypeWriter.writeUInt32(byteBuffer, (long) this.entries.size());
        for (Entry entry : this.entries) {
            if (isOverrideTrackEncryptionBoxParameters()) {
                byte[] ivFull = new byte[this.ivSize];
                System.arraycopy(entry.iv, 0, ivFull, this.ivSize - entry.iv.length, entry.iv.length);
                byteBuffer.put(ivFull);
            } else {
                byteBuffer.put(entry.iv);
            }
            if (isSubSampleEncryption()) {
                IsoTypeWriter.writeUInt16(byteBuffer, entry.pairs.size());
                for (Entry.Pair pair : entry.pairs) {
                    IsoTypeWriter.writeUInt16(byteBuffer, pair.clear);
                    IsoTypeWriter.writeUInt32(byteBuffer, pair.encrypted);
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long contentSize = 4;
        if (isOverrideTrackEncryptionBoxParameters()) {
            contentSize = 4 + 4 + ((long) this.kid.length);
        }
        long contentSize2 = contentSize + 4;
        for (Entry entry : this.entries) {
            contentSize2 += (long) entry.getSize();
        }
        return contentSize2;
    }

    @Override // com.coremedia.iso.boxes.Box, com.googlecode.mp4parser.AbstractBox
    public void getBox(WritableByteChannel os) throws IOException {
        super.getBox(os);
    }

    public Entry createEntry() {
        return new Entry();
    }

    public class Entry {
        public byte[] iv;
        public List<Pair> pairs = new LinkedList();

        public Entry() {
        }

        public int getSize() {
            int size;
            if (AbstractSampleEncryptionBox.this.isOverrideTrackEncryptionBoxParameters()) {
                size = AbstractSampleEncryptionBox.this.ivSize;
            } else {
                size = this.iv.length;
            }
            if (AbstractSampleEncryptionBox.this.isSubSampleEncryption()) {
                size += 2;
                for (Pair pair : this.pairs) {
                    size += 6;
                }
            }
            return size;
        }

        public Pair createPair(int clear, long encrypted) {
            return new Pair(clear, encrypted);
        }

        public class Pair {
            public int clear;
            public long encrypted;

            public Pair(int clear2, long encrypted2) {
                this.clear = clear2;
                this.encrypted = encrypted2;
            }

            public boolean equals(Object o) {
                if (this == o) {
                    return true;
                }
                if (o == null || getClass() != o.getClass()) {
                    return false;
                }
                Pair pair = (Pair) o;
                if (this.clear == pair.clear && this.encrypted == pair.encrypted) {
                    return true;
                }
                return false;
            }

            public int hashCode() {
                long j = this.encrypted;
                return (this.clear * 31) + ((int) (j ^ (j >>> 32)));
            }

            public String toString() {
                return "clr:" + this.clear + " enc:" + this.encrypted;
            }
        }

        public boolean equals(Object o) {
            if (this == o) {
                return true;
            }
            if (o == null || getClass() != o.getClass()) {
                return false;
            }
            Entry entry = (Entry) o;
            if (!new BigInteger(this.iv).equals(new BigInteger(entry.iv))) {
                return false;
            }
            List<Pair> list = this.pairs;
            if (list == null ? entry.pairs == null : list.equals(entry.pairs)) {
                return true;
            }
            return false;
        }

        public int hashCode() {
            byte[] bArr = this.iv;
            int i = 0;
            int hashCode = (bArr != null ? Arrays.hashCode(bArr) : 0) * 31;
            List<Pair> list = this.pairs;
            if (list != null) {
                i = list.hashCode();
            }
            return hashCode + i;
        }

        public String toString() {
            return "Entry{iv=" + Hex.encodeHex(this.iv) + ", pairs=" + this.pairs + Operators.BLOCK_END;
        }
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AbstractSampleEncryptionBox that = (AbstractSampleEncryptionBox) o;
        if (this.algorithmId != that.algorithmId || this.ivSize != that.ivSize) {
            return false;
        }
        List<Entry> list = this.entries;
        if (list == null ? that.entries != null : !list.equals(that.entries)) {
            return false;
        }
        if (!Arrays.equals(this.kid, that.kid)) {
            return false;
        }
        return true;
    }

    public int hashCode() {
        int result = ((this.algorithmId * 31) + this.ivSize) * 31;
        byte[] bArr = this.kid;
        int i = 0;
        int result2 = (result + (bArr != null ? Arrays.hashCode(bArr) : 0)) * 31;
        List<Entry> list = this.entries;
        if (list != null) {
            i = list.hashCode();
        }
        return result2 + i;
    }

    public List<Short> getEntrySizes() {
        List<Short> entrySizes = new ArrayList<>(this.entries.size());
        for (Entry entry : this.entries) {
            short size = (short) entry.iv.length;
            if (isSubSampleEncryption()) {
                size = (short) ((entry.pairs.size() * 6) + ((short) (size + 2)));
            }
            entrySizes.add(Short.valueOf(size));
        }
        return entrySizes;
    }
}
