package com.googlecode.mp4parser.boxes;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.BitReaderBuffer;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.BitWriterBuffer;
import java.nio.ByteBuffer;

public class DTSSpecificBox extends AbstractBox {
    long DTSSamplingFrequency;
    int LBRDurationMod;
    long avgBitRate;
    int channelLayout;
    int coreLFEPresent;
    int coreLayout;
    int coreSize;
    int frameDuration;
    long maxBitRate;
    int multiAssetFlag;
    int pcmSampleDepth;
    int representationType;
    int reserved;
    int reservedBoxPresent;
    int stereoDownmix;
    int streamConstruction;

    public DTSSpecificBox() {
        super("ddts");
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        return 20;
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        this.DTSSamplingFrequency = IsoTypeReader.readUInt32(content);
        this.maxBitRate = IsoTypeReader.readUInt32(content);
        this.avgBitRate = IsoTypeReader.readUInt32(content);
        this.pcmSampleDepth = IsoTypeReader.readUInt8(content);
        BitReaderBuffer brb = new BitReaderBuffer(content);
        this.frameDuration = brb.readBits(2);
        this.streamConstruction = brb.readBits(5);
        this.coreLFEPresent = brb.readBits(1);
        this.coreLayout = brb.readBits(6);
        this.coreSize = brb.readBits(14);
        this.stereoDownmix = brb.readBits(1);
        this.representationType = brb.readBits(3);
        this.channelLayout = brb.readBits(16);
        this.multiAssetFlag = brb.readBits(1);
        this.LBRDurationMod = brb.readBits(1);
        this.reservedBoxPresent = brb.readBits(1);
        this.reserved = brb.readBits(5);
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        IsoTypeWriter.writeUInt32(byteBuffer, this.DTSSamplingFrequency);
        IsoTypeWriter.writeUInt32(byteBuffer, this.maxBitRate);
        IsoTypeWriter.writeUInt32(byteBuffer, this.avgBitRate);
        IsoTypeWriter.writeUInt8(byteBuffer, this.pcmSampleDepth);
        BitWriterBuffer bwb = new BitWriterBuffer(byteBuffer);
        bwb.writeBits(this.frameDuration, 2);
        bwb.writeBits(this.streamConstruction, 5);
        bwb.writeBits(this.coreLFEPresent, 1);
        bwb.writeBits(this.coreLayout, 6);
        bwb.writeBits(this.coreSize, 14);
        bwb.writeBits(this.stereoDownmix, 1);
        bwb.writeBits(this.representationType, 3);
        bwb.writeBits(this.channelLayout, 16);
        bwb.writeBits(this.multiAssetFlag, 1);
        bwb.writeBits(this.LBRDurationMod, 1);
        bwb.writeBits(this.reservedBoxPresent, 1);
        bwb.writeBits(this.reserved, 5);
    }

    public long getAvgBitRate() {
        return this.avgBitRate;
    }

    public void setAvgBitRate(long avgBitRate2) {
        this.avgBitRate = avgBitRate2;
    }

    public long getDTSSamplingFrequency() {
        return this.DTSSamplingFrequency;
    }

    public void setDTSSamplingFrequency(long DTSSamplingFrequency2) {
        this.DTSSamplingFrequency = DTSSamplingFrequency2;
    }

    public long getMaxBitRate() {
        return this.maxBitRate;
    }

    public void setMaxBitRate(long maxBitRate2) {
        this.maxBitRate = maxBitRate2;
    }

    public int getPcmSampleDepth() {
        return this.pcmSampleDepth;
    }

    public void setPcmSampleDepth(int pcmSampleDepth2) {
        this.pcmSampleDepth = pcmSampleDepth2;
    }

    public int getFrameDuration() {
        return this.frameDuration;
    }

    public void setFrameDuration(int frameDuration2) {
        this.frameDuration = frameDuration2;
    }

    public int getStreamConstruction() {
        return this.streamConstruction;
    }

    public void setStreamConstruction(int streamConstruction2) {
        this.streamConstruction = streamConstruction2;
    }

    public int getCoreLFEPresent() {
        return this.coreLFEPresent;
    }

    public void setCoreLFEPresent(int coreLFEPresent2) {
        this.coreLFEPresent = coreLFEPresent2;
    }

    public int getCoreLayout() {
        return this.coreLayout;
    }

    public void setCoreLayout(int coreLayout2) {
        this.coreLayout = coreLayout2;
    }

    public int getCoreSize() {
        return this.coreSize;
    }

    public void setCoreSize(int coreSize2) {
        this.coreSize = coreSize2;
    }

    public int getStereoDownmix() {
        return this.stereoDownmix;
    }

    public void setStereoDownmix(int stereoDownmix2) {
        this.stereoDownmix = stereoDownmix2;
    }

    public int getRepresentationType() {
        return this.representationType;
    }

    public void setRepresentationType(int representationType2) {
        this.representationType = representationType2;
    }

    public int getChannelLayout() {
        return this.channelLayout;
    }

    public void setChannelLayout(int channelLayout2) {
        this.channelLayout = channelLayout2;
    }

    public int getMultiAssetFlag() {
        return this.multiAssetFlag;
    }

    public void setMultiAssetFlag(int multiAssetFlag2) {
        this.multiAssetFlag = multiAssetFlag2;
    }

    public int getLBRDurationMod() {
        return this.LBRDurationMod;
    }

    public void setLBRDurationMod(int LBRDurationMod2) {
        this.LBRDurationMod = LBRDurationMod2;
    }

    public int getReserved() {
        return this.reserved;
    }

    public void setReserved(int reserved2) {
        this.reserved = reserved2;
    }

    public int getReservedBoxPresent() {
        return this.reservedBoxPresent;
    }

    public void setReservedBoxPresent(int reservedBoxPresent2) {
        this.reservedBoxPresent = reservedBoxPresent2;
    }
}
