package com.googlecode.mp4parser.boxes.apple;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.sampleentry.SampleEntry;
import java.nio.ByteBuffer;

public class QuicktimeTextSampleEntry extends SampleEntry {
    public static final String TYPE = "text";
    int backgroundB;
    int backgroundG;
    int backgroundR;
    long defaultTextBox;
    int displayFlags;
    short fontFace;
    String fontName = "";
    short fontNumber;
    int foregroundB = 65535;
    int foregroundG = 65535;
    int foregroundR = 65535;
    long reserved1;
    byte reserved2;
    short reserved3;
    int textJustification;

    public QuicktimeTextSampleEntry() {
        super("text");
    }

    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        _parseReservedAndDataReferenceIndex(content);
        this.displayFlags = content.getInt();
        this.textJustification = content.getInt();
        this.backgroundR = IsoTypeReader.readUInt16(content);
        this.backgroundG = IsoTypeReader.readUInt16(content);
        this.backgroundB = IsoTypeReader.readUInt16(content);
        this.defaultTextBox = IsoTypeReader.readUInt64(content);
        this.reserved1 = IsoTypeReader.readUInt64(content);
        this.fontNumber = content.getShort();
        this.fontFace = content.getShort();
        this.reserved2 = content.get();
        this.reserved3 = content.getShort();
        this.foregroundR = IsoTypeReader.readUInt16(content);
        this.foregroundG = IsoTypeReader.readUInt16(content);
        this.foregroundB = IsoTypeReader.readUInt16(content);
        if (content.remaining() > 0) {
            byte[] myFontName = new byte[IsoTypeReader.readUInt8(content)];
            content.get(myFontName);
            this.fontName = new String(myFontName);
            return;
        }
        this.fontName = null;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        String str = this.fontName;
        return (long) ((str != null ? str.length() : 0) + 52);
    }

    public int getDisplayFlags() {
        return this.displayFlags;
    }

    public void setDisplayFlags(int displayFlags2) {
        this.displayFlags = displayFlags2;
    }

    public int getTextJustification() {
        return this.textJustification;
    }

    public void setTextJustification(int textJustification2) {
        this.textJustification = textJustification2;
    }

    public int getBackgroundR() {
        return this.backgroundR;
    }

    public void setBackgroundR(int backgroundR2) {
        this.backgroundR = backgroundR2;
    }

    public int getBackgroundG() {
        return this.backgroundG;
    }

    public void setBackgroundG(int backgroundG2) {
        this.backgroundG = backgroundG2;
    }

    public int getBackgroundB() {
        return this.backgroundB;
    }

    public void setBackgroundB(int backgroundB2) {
        this.backgroundB = backgroundB2;
    }

    public long getDefaultTextBox() {
        return this.defaultTextBox;
    }

    public void setDefaultTextBox(long defaultTextBox2) {
        this.defaultTextBox = defaultTextBox2;
    }

    public long getReserved1() {
        return this.reserved1;
    }

    public void setReserved1(long reserved12) {
        this.reserved1 = reserved12;
    }

    public short getFontNumber() {
        return this.fontNumber;
    }

    public void setFontNumber(short fontNumber2) {
        this.fontNumber = fontNumber2;
    }

    public short getFontFace() {
        return this.fontFace;
    }

    public void setFontFace(short fontFace2) {
        this.fontFace = fontFace2;
    }

    public byte getReserved2() {
        return this.reserved2;
    }

    public void setReserved2(byte reserved22) {
        this.reserved2 = reserved22;
    }

    public short getReserved3() {
        return this.reserved3;
    }

    public void setReserved3(short reserved32) {
        this.reserved3 = reserved32;
    }

    public int getForegroundR() {
        return this.foregroundR;
    }

    public void setForegroundR(int foregroundR2) {
        this.foregroundR = foregroundR2;
    }

    public int getForegroundG() {
        return this.foregroundG;
    }

    public void setForegroundG(int foregroundG2) {
        this.foregroundG = foregroundG2;
    }

    public int getForegroundB() {
        return this.foregroundB;
    }

    public void setForegroundB(int foregroundB2) {
        this.foregroundB = foregroundB2;
    }

    public String getFontName() {
        return this.fontName;
    }

    public void setFontName(String fontName2) {
        this.fontName = fontName2;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        _writeReservedAndDataReferenceIndex(byteBuffer);
        byteBuffer.putInt(this.displayFlags);
        byteBuffer.putInt(this.textJustification);
        IsoTypeWriter.writeUInt16(byteBuffer, this.backgroundR);
        IsoTypeWriter.writeUInt16(byteBuffer, this.backgroundG);
        IsoTypeWriter.writeUInt16(byteBuffer, this.backgroundB);
        IsoTypeWriter.writeUInt64(byteBuffer, this.defaultTextBox);
        IsoTypeWriter.writeUInt64(byteBuffer, this.reserved1);
        byteBuffer.putShort(this.fontNumber);
        byteBuffer.putShort(this.fontFace);
        byteBuffer.put(this.reserved2);
        byteBuffer.putShort(this.reserved3);
        IsoTypeWriter.writeUInt16(byteBuffer, this.foregroundR);
        IsoTypeWriter.writeUInt16(byteBuffer, this.foregroundG);
        IsoTypeWriter.writeUInt16(byteBuffer, this.foregroundB);
        String str = this.fontName;
        if (str != null) {
            IsoTypeWriter.writeUInt8(byteBuffer, str.length());
            byteBuffer.put(this.fontName.getBytes());
        }
    }
}
