package com.googlecode.mp4parser.boxes.mp4.samplegrouping;

import com.coremedia.iso.IsoTypeReader;
import com.coremedia.iso.IsoTypeWriter;
import com.googlecode.mp4parser.AbstractFullBox;
import com.googlecode.mp4parser.util.CastUtils;
import com.taobao.weex.el.parse.Operators;
import java.nio.ByteBuffer;
import java.util.LinkedList;
import java.util.List;

public class SampleGroupDescriptionBox extends AbstractFullBox {
    public static final String TYPE = "sgpd";
    private int defaultLength;
    private int descriptionLength;
    private List<GroupEntry> groupEntries = new LinkedList();
    private String groupingType;

    public SampleGroupDescriptionBox() {
        super(TYPE);
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public long getContentSize() {
        long size = 8;
        if (getVersion() == 1) {
            size = 8 + 4;
        }
        long size2 = size + 4;
        for (GroupEntry groupEntry : this.groupEntries) {
            if (getVersion() == 1 && this.defaultLength == 0) {
                size2 += 4;
            }
            size2 += (long) groupEntry.size();
        }
        return size2;
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void getContent(ByteBuffer byteBuffer) {
        writeVersionAndFlags(byteBuffer);
        byteBuffer.put(this.groupingType.getBytes());
        if (getVersion() == 1) {
            IsoTypeWriter.writeUInt32(byteBuffer, (long) this.defaultLength);
        }
        IsoTypeWriter.writeUInt32(byteBuffer, (long) this.groupEntries.size());
        for (GroupEntry entry : this.groupEntries) {
            if (getVersion() == 1 && this.defaultLength == 0) {
                IsoTypeWriter.writeUInt32(byteBuffer, (long) entry.get().limit());
            }
            byteBuffer.put(entry.get());
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.googlecode.mp4parser.AbstractBox
    public void _parseDetails(ByteBuffer content) {
        parseVersionAndFlags(content);
        if (getVersion() == 1) {
            this.groupingType = IsoTypeReader.read4cc(content);
            if (getVersion() == 1) {
                this.defaultLength = CastUtils.l2i(IsoTypeReader.readUInt32(content));
            }
            long entryCount = IsoTypeReader.readUInt32(content);
            while (true) {
                long entryCount2 = entryCount - 1;
                if (entryCount > 0) {
                    int length = this.defaultLength;
                    if (getVersion() == 1) {
                        if (this.defaultLength == 0) {
                            this.descriptionLength = CastUtils.l2i(IsoTypeReader.readUInt32(content));
                            length = this.descriptionLength;
                        }
                        ByteBuffer parseMe = content.slice();
                        parseMe.limit(length);
                        this.groupEntries.add(parseGroupEntry(parseMe, this.groupingType));
                        content.position(content.position() + length);
                        entryCount = entryCount2;
                    } else {
                        throw new RuntimeException("This should be implemented");
                    }
                } else {
                    return;
                }
            }
        } else {
            throw new RuntimeException("SampleGroupDescriptionBox are only supported in version 1");
        }
    }

    private GroupEntry parseGroupEntry(ByteBuffer content, String groupingType2) {
        GroupEntry groupEntry;
        if (RollRecoveryEntry.TYPE.equals(groupingType2)) {
            groupEntry = new RollRecoveryEntry();
        } else if (RateShareEntry.TYPE.equals(groupingType2)) {
            groupEntry = new RateShareEntry();
        } else if (CencSampleEncryptionInformationGroupEntry.TYPE.equals(groupingType2)) {
            groupEntry = new CencSampleEncryptionInformationGroupEntry();
        } else if (VisualRandomAccessEntry.TYPE.equals(groupingType2)) {
            groupEntry = new VisualRandomAccessEntry();
        } else if (TemporalLevelEntry.TYPE.equals(groupingType2)) {
            groupEntry = new TemporalLevelEntry();
        } else {
            groupEntry = new UnknownEntry();
        }
        groupEntry.parse(content);
        return groupEntry;
    }

    public String getGroupingType() {
        return this.groupingType;
    }

    public void setGroupingType(String groupingType2) {
        this.groupingType = groupingType2;
    }

    public int getDefaultLength() {
        return this.defaultLength;
    }

    public void setDefaultLength(int defaultLength2) {
        this.defaultLength = defaultLength2;
    }

    public List<GroupEntry> getGroupEntries() {
        return this.groupEntries;
    }

    public void setGroupEntries(List<GroupEntry> groupEntries2) {
        this.groupEntries = groupEntries2;
    }

    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SampleGroupDescriptionBox that = (SampleGroupDescriptionBox) o;
        if (this.defaultLength != that.defaultLength) {
            return false;
        }
        List<GroupEntry> list = this.groupEntries;
        if (list == null ? that.groupEntries != null : !list.equals(that.groupEntries)) {
            return false;
        }
        String str = this.groupingType;
        if (str == null ? that.groupingType == null : str.equals(that.groupingType)) {
            return true;
        }
        return false;
    }

    public int hashCode() {
        String str = this.groupingType;
        int i = 0;
        int result = (((str != null ? str.hashCode() : 0) * 31) + this.defaultLength) * 31;
        List<GroupEntry> list = this.groupEntries;
        if (list != null) {
            i = list.hashCode();
        }
        return result + i;
    }

    public String toString() {
        return "SampleGroupDescriptionBox{groupingType='" + this.groupingType + Operators.SINGLE_QUOTE + ", defaultLength=" + this.defaultLength + ", groupEntries=" + this.groupEntries + Operators.BLOCK_END;
    }
}
