package com.heytap.mcssdk;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.ServiceConnection;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.os.Build;
import android.os.Bundle;
import android.os.IBinder;
import android.text.TextUtils;
import com.heytap.mcssdk.base.Base64;
import com.heytap.mcssdk.constant.IntentConstant;
import com.heytap.mcssdk.constant.MessageConstant;
import com.heytap.mcssdk.manage.NotificatonChannelManager;
import com.heytap.mcssdk.mode.AppLimitBean;
import com.heytap.mcssdk.mode.CallBackResult;
import com.heytap.mcssdk.parser.CallBackResultParser;
import com.heytap.mcssdk.parser.DataMessageParser;
import com.heytap.mcssdk.parser.Parser;
import com.heytap.mcssdk.processor.CallBackResultProcessor;
import com.heytap.mcssdk.processor.DataMessageProcessor;
import com.heytap.mcssdk.processor.Processor;
import com.heytap.mcssdk.utils.LogUtil;
import com.heytap.mcssdk.utils.StatUtil;
import com.heytap.mcssdk.utils.Utils;
import com.heytap.msp.push.callback.ICallBackResultService;
import com.heytap.msp.push.callback.IGetAppNotificationCallBackService;
import com.heytap.msp.push.callback.ISetAppNotificationCallBackService;
import com.heytap.msp.push.mode.MessageStat;
import com.mcs.aidl.IMcsSdkService;
import com.taobao.weex.WXEnvironment;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import org.json.JSONException;
import org.json.JSONObject;

public class PushService implements IPushService {
    private static final String APP_PACKAGE = "appPackage";
    private static final String APP_VERSION_CODE = "versionCode";
    private static final String APP_VERSION_NAME = "versionName";
    private static final int DEFAULT_API_MAX_COUNT = 2;
    private static final String EVENT_ID = "eventID";
    private static final String EXTRA = "extra";
    private static final String GLOBAL_ID = "globalID";
    private static final int MAX_HOUR_IN_DAY = 23;
    private static final int MAX_MIN_IN_HOUR = 59;
    private static final int MCS_SUPPORT_VERSION = 1019;
    private static final String MESSAGE_ID = "messageID";
    private static final String MESSAGE_TYPE = "messageType";
    private static String NEW_MCS_RECEIVE_SDK_ACTION = "";
    private static final String NEW_MCS_RECEIVE_SDK_ACTION_Base64 = "Y29tLm1jcy5hY3Rpb24uUkVDRUlWRV9TREtfTUVTU0FHRQ==";
    private static final int[] OLD_MCS_PACKAGE = {99, 111, 109, 46, 99, 111, 108, 111, 114, 111, 115, 46, 109, 99, 115};
    private static final int[] OLD_MCS_RECEIVE_SDK_ACTION = {99, 111, 109, 46, 99, 111, 108, 111, 114, 111, 115, 46, 109, 99, 115, 115, 100, 107, 46, 97, 99, 116, 105, 111, 110, 46, 82, 69, 67, 69, 73, 86, 69, 95, 83, 68, 75, 95, 77, 69, 83, 83, 65, 71, 69};
    private static final String PUSH_SDK_VERSION = "pushSdkVersion";
    private static final int SDK_INT_24 = 24;
    private static final String SUPPORT_OPEN_PUSH = "supportOpenPush";
    private static final int SYSTEM_UID = 1000;
    private static final String TASK_ID = "taskID";
    private static final String TYPE = "type";
    private static int sCount = 0;
    private static boolean sIsNewMcsPkg;
    private static String sMcsPkgName;
    private ConcurrentHashMap<Integer, AppLimitBean> mAppLimitMap;
    private String mAuthCode;
    private Context mContext;
    private ICallBackResultService mICallBackResultService;
    private IGetAppNotificationCallBackService mIGetAppNotificationCallBackService;
    private ISetAppNotificationCallBackService mISetAppNotificationCallBackService;
    private List<Parser> mParsers;
    private List<Processor> mProcessors;
    private String mRegisterID;
    private String mVerifyCode;

    public PushService init(Context context, boolean needLog) {
        if (context != null) {
            innerInit(context);
            new NotificatonChannelManager().createDefaultChannel(this.mContext);
            LogUtil.setDebugs(needLog);
            return this;
        }
        throw new IllegalArgumentException("context can't be null");
    }

    public void innerInit(Context context) {
        Context applicationContext = context.getApplicationContext();
        this.mContext = applicationContext;
        if (sMcsPkgName == null) {
            String newMcsPkg = getNewMcsPackageName(applicationContext);
            if (newMcsPkg == null) {
                sMcsPkgName = Utils.getString(OLD_MCS_PACKAGE);
                sIsNewMcsPkg = false;
                return;
            }
            sMcsPkgName = newMcsPkg;
            sIsNewMcsPkg = true;
        }
    }

    private PushService() {
        this.mProcessors = new ArrayList();
        this.mParsers = new ArrayList();
        this.mRegisterID = null;
        synchronized (PushService.class) {
            if (sCount <= 0) {
                sCount++;
            } else {
                throw new RuntimeException("PushService can't create again!");
            }
        }
        addParser(new DataMessageParser());
        addParser(new CallBackResultParser());
        addProcessor(new DataMessageProcessor());
        addProcessor(new CallBackResultProcessor());
        this.mAppLimitMap = new ConcurrentHashMap<>();
    }

    public static PushService getInstance() {
        return SingletonHolder.INSTANCE;
    }

    private String getNewMcsPackageName(Context context) {
        if (TextUtils.isEmpty(NEW_MCS_RECEIVE_SDK_ACTION)) {
            NEW_MCS_RECEIVE_SDK_ACTION = new String(Base64.decodeBase64(NEW_MCS_RECEIVE_SDK_ACTION_Base64));
        }
        List<ResolveInfo> resolveInfoList = context.getPackageManager().queryIntentServices(new Intent(NEW_MCS_RECEIVE_SDK_ACTION), 8192);
        if (Build.VERSION.SDK_INT < 24) {
            return null;
        }
        for (ResolveInfo resolveInfo : resolveInfoList) {
            String pkg = resolveInfo.serviceInfo.packageName;
            try {
                boolean isSystemUid = false;
                boolean hasSystemFlag = (context.getPackageManager().getApplicationInfo(pkg, 0).flags & 1) == 1;
                if (context.getPackageManager().getPackageUid(pkg, 0) == context.getPackageManager().getPackageUid(WXEnvironment.OS, 0)) {
                    isSystemUid = true;
                }
                if (hasSystemFlag || isSystemUid) {
                    return pkg;
                }
            } catch (PackageManager.NameNotFoundException e) {
            }
        }
        return null;
    }

    public String getMcsPackageName(Context context) {
        if (sMcsPkgName == null) {
            String newMcsPkg = getNewMcsPackageName(context);
            if (newMcsPkg == null) {
                sMcsPkgName = Utils.getString(OLD_MCS_PACKAGE);
                sIsNewMcsPkg = false;
            } else {
                sMcsPkgName = newMcsPkg;
                sIsNewMcsPkg = true;
            }
        }
        return sMcsPkgName;
    }

    public String getReceiveSdkAction(Context context) {
        if (sMcsPkgName == null) {
            getNewMcsPackageName(context);
        }
        if (!sIsNewMcsPkg) {
            return Utils.getString(OLD_MCS_RECEIVE_SDK_ACTION);
        }
        if (TextUtils.isEmpty(NEW_MCS_RECEIVE_SDK_ACTION)) {
            NEW_MCS_RECEIVE_SDK_ACTION = new String(Base64.decodeBase64(NEW_MCS_RECEIVE_SDK_ACTION_Base64));
        }
        return NEW_MCS_RECEIVE_SDK_ACTION;
    }

    public boolean isSupportPushByClient(Context context) {
        return isSupportPushInner(context);
    }

    private boolean isSupportPushInner(Context context) {
        if (this.mContext == null) {
            this.mContext = context.getApplicationContext();
        }
        String pkg = getMcsPackageName(this.mContext);
        return Utils.isExistPackage(this.mContext, pkg) && Utils.getVersionCode(this.mContext, pkg) >= 1019 && Utils.isSupportPush(this.mContext, pkg, SUPPORT_OPEN_PUSH);
    }

    @Deprecated
    private static void onAppStart(Context context) {
        StatUtil.statisticMessage(context, new MessageStat(context.getPackageName(), "app_start", null));
    }

    private synchronized void addProcessor(Processor processor) {
        if (processor != null) {
            this.mProcessors.add(processor);
        }
    }

    private synchronized void addParser(Parser parser) {
        if (parser != null) {
            this.mParsers.add(parser);
        }
    }

    public List<Parser> getParsers() {
        return this.mParsers;
    }

    public List<Processor> getProcessors() {
        return this.mProcessors;
    }

    private boolean checkContext() {
        return this.mContext != null;
    }

    private boolean checkRegisterID() {
        return this.mRegisterID != null;
    }

    private boolean checkAll() throws IllegalArgumentException {
        return checkContext() && checkRegisterID();
    }

    public void setAppKeySecret(String appKey, String appSecret) {
        this.mAuthCode = appKey;
        this.mVerifyCode = appSecret;
    }

    @Override // com.heytap.mcssdk.IPushService
    public String getRegisterID() {
        return this.mRegisterID;
    }

    @Override // com.heytap.mcssdk.IPushService
    public void setRegisterID(String mRegisterID2) {
        this.mRegisterID = mRegisterID2;
    }

    private void startMcsService(int commandType, JSONObject extra) {
        startMcsService(commandType, "", extra);
    }

    private void startMcsService(int commandType, String params, JSONObject extra) {
        if (checkCommandLimit(commandType)) {
            ICallBackResultService iCallBackResultService = this.mICallBackResultService;
            if (iCallBackResultService != null) {
                iCallBackResultService.onError(getErrorCode(commandType), "api_call_too_frequently");
                return;
            }
            return;
        }
        try {
            this.mContext.startService(getIntent(commandType, params, extra));
        } catch (Exception e) {
            LogUtil.e("startMcsService--Exception" + e.getMessage());
        }
    }

    public void bindMcsService(int commandType) {
        if (checkCommandLimit(commandType)) {
            ICallBackResultService iCallBackResultService = this.mICallBackResultService;
            if (iCallBackResultService != null) {
                iCallBackResultService.onError(getErrorCode(commandType), "api_call_too_frequently");
                return;
            }
            return;
        }
        final Intent intent = getIntent(commandType, "", null);
        this.mContext.bindService(intent, new ServiceConnection() {
            /* class com.heytap.mcssdk.PushService.AnonymousClass1 */

            public void onServiceConnected(ComponentName componentName, IBinder iBinder) {
                Bundle bundle = new Bundle();
                bundle.putAll(intent.getExtras());
                try {
                    IMcsSdkService.Stub.asInterface(iBinder).process(bundle);
                } catch (Exception e) {
                    LogUtil.d("bindMcsService exception:" + e);
                }
                PushService.this.mContext.unbindService(this);
            }

            public void onServiceDisconnected(ComponentName componentName) {
            }
        }, 1);
    }

    private Intent getIntent(int commandType, String params, JSONObject extra) {
        Intent intent = new Intent();
        intent.setAction(getReceiveSdkAction(this.mContext));
        intent.setPackage(getMcsPackageName(this.mContext));
        intent.putExtra("type", commandType);
        JSONObject extraJson = new JSONObject();
        try {
            extraJson.putOpt(APP_VERSION_NAME, Utils.getVersionName(this.mContext, this.mContext.getPackageName()));
            extraJson.putOpt(APP_VERSION_CODE, Integer.valueOf(Utils.getVersionCode(this.mContext, this.mContext.getPackageName())));
            if (extra != null) {
                Iterator<String> tmp = extra.keys();
                while (tmp.hasNext()) {
                    String key = tmp.next();
                    extraJson.putOpt(key, extra.get(key));
                }
            }
        } catch (Exception e) {
        } catch (Throwable th) {
            intent.putExtra("extra", extraJson.toString());
            throw th;
        }
        intent.putExtra("extra", extraJson.toString());
        intent.putExtra("params", params);
        intent.putExtra("appPackage", this.mContext.getPackageName());
        intent.putExtra(IntentConstant.APP_KEY, this.mAuthCode);
        intent.putExtra(IntentConstant.APP_SECRET, this.mVerifyCode);
        intent.putExtra(IntentConstant.REGISTER_ID, this.mRegisterID);
        intent.putExtra(IntentConstant.SDK_VERSION, getSDKVersionName());
        return intent;
    }

    public ICallBackResultService getPushCallback() {
        return this.mICallBackResultService;
    }

    public void setPushCallback(ICallBackResultService ICallBackResultService) {
        this.mICallBackResultService = ICallBackResultService;
    }

    public IGetAppNotificationCallBackService getPushGetAppNotificationCallBack() {
        return this.mIGetAppNotificationCallBackService;
    }

    public ISetAppNotificationCallBackService getPushSetAppNotificationCallBack() {
        return this.mISetAppNotificationCallBackService;
    }

    @Override // com.heytap.mcssdk.IPushService
    public void register(Context applicationContext, String appKey, String appSecret, JSONObject extra, ICallBackResultService ICallBackResultService) {
        if (applicationContext != null) {
            if (this.mContext == null) {
                this.mContext = applicationContext.getApplicationContext();
            }
            if (Utils.isSupportPushByClient(this.mContext)) {
                this.mAuthCode = appKey;
                this.mVerifyCode = appSecret;
                this.mICallBackResultService = ICallBackResultService;
                if (extra == null) {
                    extra = new JSONObject();
                }
                try {
                    extra.putOpt("appVersionCode", Integer.valueOf(Utils.getVersionCode(applicationContext)));
                    extra.putOpt("appVersionName", Utils.getVersionName(applicationContext));
                } catch (JSONException e) {
                    LogUtil.e("register-Exception:" + e.getMessage());
                }
                startMcsService(MessageConstant.CommandId.COMMAND_REGISTER, extra);
            } else if (ICallBackResultService != null) {
                ICallBackResultService.onRegister(-2, null);
            }
        } else if (ICallBackResultService != null) {
            ICallBackResultService.onRegister(-2, null);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void register(Context applicationContext, String appKey, String appSecret, ICallBackResultService ICallBackResultService) {
        register(applicationContext, appKey, appSecret, null, ICallBackResultService);
    }

    public void unRegister(Context applicationContext, String appKey, String appSecret, JSONObject extra, ICallBackResultService ICallBackResultService) {
        this.mAuthCode = appKey;
        this.mVerifyCode = appSecret;
        this.mContext = applicationContext.getApplicationContext();
        this.mICallBackResultService = ICallBackResultService;
        unRegister(extra);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void unRegister(JSONObject extra) {
        if (checkContext()) {
            startMcsService(MessageConstant.CommandId.COMMAND_UNREGISTER, extra);
        } else if (getPushCallback() != null) {
            getPushCallback().onUnRegister(-2);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void unRegister() {
        unRegister(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void getRegister(JSONObject extra) {
        if (checkContext()) {
            startMcsService(MessageConstant.CommandId.COMMAND_REGISTER, extra);
        } else if (getPushCallback() != null) {
            getPushCallback().onRegister(-2, null);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void getRegister() {
        getRegister(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void pausePush(JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_PAUSE_PUSH, extra);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void pausePush() {
        pausePush(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void resumePush(JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_RESUME_PUSH, extra);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void resumePush() {
        resumePush(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void getNotificationStatus(JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_GET_NOTIFICATION_STATUS, extra);
        } else if (getPushCallback() != null) {
            getPushCallback().onGetNotificationStatus(-2, 0);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void getNotificationStatus() {
        getNotificationStatus(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void setNotificationType(int notificationType, JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_SET_NOTIFICATION_TYPE, notificationType + "", extra);
            return;
        }
        LogUtil.e(LogUtil.TAG, "please call the register first!");
    }

    @Override // com.heytap.mcssdk.IPushService
    public void setNotificationType(int notificationType) {
        setNotificationType(notificationType, null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void clearNotificationType(JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_CLEAR_NOTIFICATION_TYPE, extra);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void clearNotificationType() {
        clearNotificationType(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void openNotificationSettings(JSONObject extra) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_SET_NOTIFICATION_SETTINGS, extra);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void openNotificationSettings() {
        openNotificationSettings(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void clearNotifications() {
        clearNotifications(null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void clearNotifications(JSONObject extra) {
        if (checkContext()) {
            startMcsService(MessageConstant.CommandId.COMMAND_CLEAR_PKG_NOTIFICATION, extra);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    public void getPushStatus() {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_GET_PUSH_STATUS, null);
        } else if (getPushCallback() != null) {
            getPushCallback().onGetPushStatus(-2, 0);
        }
    }

    public static String getSDKVersionName() {
        return "3.1.0";
    }

    public static int getSDKVersionCode() {
        return 3100;
    }

    public String getPushVersionName() {
        if (!checkContext()) {
            return "";
        }
        Context context = this.mContext;
        return Utils.getVersionName(context, getMcsPackageName(context));
    }

    public int getPushVersionCode() {
        if (!checkContext()) {
            return 0;
        }
        Context context = this.mContext;
        return Utils.getVersionCode(context, getMcsPackageName(context));
    }

    @Override // com.heytap.mcssdk.IPushService
    public void setPushTime(List<Integer> weekDays, int startHour, int startMin, int endHour, int endMin, JSONObject extra) throws IllegalArgumentException {
        if (checkAll()) {
            if (weekDays == null || weekDays.size() <= 0 || startHour < 0 || startMin < 0 || endHour < startHour || endHour > 23 || endMin < startMin || endMin > 59) {
                throw new IllegalArgumentException("params are not all right,please check params");
            }
            try {
                JSONObject jsonObject = new JSONObject();
                jsonObject.put("weekDays", CallBackResult.parseToString(weekDays));
                jsonObject.put("startHour", startHour);
                jsonObject.put("startMin", startMin);
                jsonObject.put("endHour", endHour);
                jsonObject.put("endMin", endMin);
                startMcsService(MessageConstant.CommandId.COMMAND_SET_PUSH_TIME, jsonObject.toString(), extra);
            } catch (JSONException e) {
                LogUtil.e(LogUtil.TAG, e.getLocalizedMessage());
            }
        } else if (getPushCallback() != null) {
            getPushCallback().onSetPushTime(-2, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void setPushTime(List<Integer> weekDays, int startHour, int startMin, int endHour, int endMin) {
        setPushTime(weekDays, startHour, startMin, endHour, endMin, null);
    }

    @Override // com.heytap.mcssdk.IPushService
    public void requestNotificationPermission() {
        if (checkContext()) {
            bindMcsService(MessageConstant.CommandId.COMMAND_NOTIFICATION_ALLOWANCE);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void enableAppNotificationSwitch(ISetAppNotificationCallBackService callBackService) {
        if (checkContext()) {
            this.mISetAppNotificationCallBackService = callBackService;
            startMcsService(MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_OPEN, null);
            return;
        }
        ISetAppNotificationCallBackService iSetAppNotificationCallBackService = this.mISetAppNotificationCallBackService;
        if (iSetAppNotificationCallBackService != null) {
            iSetAppNotificationCallBackService.onSetAppNotificationSwitch(-2);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void disableAppNotificationSwitch(ISetAppNotificationCallBackService callBackService) {
        if (checkContext()) {
            this.mISetAppNotificationCallBackService = callBackService;
            startMcsService(MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_CLOSE, null);
        } else if (getPushCallback() != null) {
            this.mISetAppNotificationCallBackService.onSetAppNotificationSwitch(-2);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void getAppNotificationSwitch(IGetAppNotificationCallBackService callBackService) {
        if (checkContext()) {
            this.mIGetAppNotificationCallBackService = callBackService;
            startMcsService(MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_GET, null);
            return;
        }
        IGetAppNotificationCallBackService iGetAppNotificationCallBackService = this.mIGetAppNotificationCallBackService;
        if (iGetAppNotificationCallBackService != null) {
            iGetAppNotificationCallBackService.onGetAppNotificationSwitch(-2, 0);
        }
    }

    @Override // com.heytap.mcssdk.IPushService
    public void cancelNotification(JSONObject jsonObject) {
        if (checkAll()) {
            startMcsService(MessageConstant.CommandId.COMMAND_CANCEL_NOTIFICATION, jsonObject);
        } else {
            LogUtil.e(LogUtil.TAG, "please call the register first!");
        }
    }

    public Context getContext() {
        return this.mContext;
    }

    public Map<Integer, AppLimitBean> getAppLimitMap() {
        return this.mAppLimitMap;
    }

    public boolean checkCommandLimit(int type) {
        AppLimitBean appLimitBean = addCommandToMap(type);
        if (type == 12291 || type == 12312 || appLimitBean.getCount() <= 2) {
            return false;
        }
        return true;
    }

    private AppLimitBean addCommandToMap(int type) {
        if (this.mAppLimitMap.containsKey(Integer.valueOf(type))) {
            AppLimitBean appLimitBean = this.mAppLimitMap.get(Integer.valueOf(type));
            if (checkTimeNeedUpdate(appLimitBean)) {
                appLimitBean.setCount(1);
                appLimitBean.setLastedTime(System.currentTimeMillis());
                LogUtil.d("addCommandToMap : appLimitBean.setCount(1)");
                return appLimitBean;
            }
            appLimitBean.setCount(appLimitBean.getCount() + 1);
            LogUtil.d("addCommandToMap :appLimitBean.getCount() + 1");
            return appLimitBean;
        }
        AppLimitBean appLimitBean2 = new AppLimitBean(System.currentTimeMillis(), 1);
        this.mAppLimitMap.put(Integer.valueOf(type), appLimitBean2);
        LogUtil.d("addCommandToMap :appBean is null");
        return appLimitBean2;
    }

    private boolean checkTimeNeedUpdate(AppLimitBean appLimitBean) {
        long lastedTime = appLimitBean.getLastedTime();
        long currentTime = System.currentTimeMillis();
        LogUtil.d("checkTimeNeedUpdate : lastedTime " + lastedTime + " currentTime:" + currentTime);
        return currentTime - lastedTime > 1000;
    }

    public int getErrorCode(int type) {
        switch (type) {
            case MessageConstant.CommandId.COMMAND_REGISTER:
                return -1;
            case MessageConstant.CommandId.COMMAND_UNREGISTER:
                return -2;
            case MessageConstant.CommandId.COMMAND_STATISTIC:
                return -14;
            default:
                switch (type) {
                    case MessageConstant.CommandId.COMMAND_SET_PUSH_TIME:
                        return -11;
                    case MessageConstant.CommandId.COMMAND_PAUSE_PUSH:
                        return -3;
                    case MessageConstant.CommandId.COMMAND_RESUME_PUSH:
                        return -4;
                    default:
                        switch (type) {
                            case MessageConstant.CommandId.COMMAND_GET_PUSH_STATUS:
                                return -10;
                            case MessageConstant.CommandId.COMMAND_SET_NOTIFICATION_TYPE:
                                return -6;
                            case MessageConstant.CommandId.COMMAND_CLEAR_NOTIFICATION_TYPE:
                                return -7;
                            case MessageConstant.CommandId.COMMAND_GET_NOTIFICATION_STATUS:
                                return -5;
                            case MessageConstant.CommandId.COMMAND_SET_NOTIFICATION_SETTINGS:
                                return -8;
                            case MessageConstant.CommandId.COMMAND_CLEAR_PKG_NOTIFICATION:
                                return -9;
                            case MessageConstant.CommandId.COMMAND_SEND_INSTANT_ACK:
                                return -13;
                            case MessageConstant.CommandId.COMMAND_NOTIFICATION_ALLOWANCE:
                                return -12;
                            default:
                                switch (type) {
                                    case MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_OPEN:
                                        return -15;
                                    case MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_CLOSE:
                                        return -16;
                                    case MessageConstant.CommandId.COMMAND_APP_NOTIFICATION_GET:
                                        return -17;
                                    default:
                                        return 0;
                                }
                        }
                }
        }
    }

    /* access modifiers changed from: private */
    public static class SingletonHolder {
        private static final PushService INSTANCE = new PushService();

        private SingletonHolder() {
        }
    }
}
