package com.heytap.mcssdk.notification;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Context;
import android.graphics.drawable.Icon;
import android.os.Build;
import android.service.notification.StatusBarNotification;
import com.heytap.mcssdk.manage.NotificatonChannelManager;
import com.heytap.msp.push.notification.PushNotification;
import com.igexin.push.core.b;

public class NotificationHelper {
    public static StatusBarNotification[] getActiveNotifications(NotificationManager nm, String packageName) {
        if (Build.VERSION.SDK_INT >= 23) {
            return nm.getActiveNotifications();
        }
        return null;
    }

    public static boolean isExistNotificationsByPkgAndId(NotificationManager nm, String packageName, int notifyId) {
        StatusBarNotification[] array = getActiveNotifications(nm, packageName);
        if (array == null || array.length == 0) {
            return false;
        }
        for (StatusBarNotification notification : array) {
            if (notification.getId() == notifyId) {
                return true;
            }
        }
        return false;
    }

    public static NotificationManager getNotificationManager(Context context) {
        if (context == null) {
            return null;
        }
        try {
            return (NotificationManager) context.getSystemService(b.n);
        } catch (Throwable th) {
            return null;
        }
    }

    public static Notification createDefaultGroupNotification(Context context, String group, PushNotification.Builder childBuild) {
        Notification.Builder groupBuild = new Notification.Builder(context);
        if (Build.VERSION.SDK_INT >= 26) {
            groupBuild.setChannelId(NotificatonChannelManager.DEFAULT_NOTIFICATION_CHANNEL_ID);
        }
        if (Build.VERSION.SDK_INT >= 20) {
            groupBuild.setGroup(group);
            groupBuild.setGroupSummary(true);
        }
        if (setGroupIcon(groupBuild, childBuild)) {
            return groupBuild.build();
        }
        return null;
    }

    private static boolean setGroupIcon(Notification.Builder groupBuild, PushNotification.Builder childBuild) {
        int iconRes = childBuild.getIconRes();
        int iconLevel = childBuild.getIconLevel();
        Icon icon = childBuild.getIcon();
        if (icon != null && Build.VERSION.SDK_INT >= 23) {
            groupBuild.setSmallIcon(icon);
            return true;
        } else if (iconRes != 0 && iconLevel != 0) {
            groupBuild.setSmallIcon(iconRes, iconLevel);
            return true;
        } else if (iconRes == 0) {
            return false;
        } else {
            groupBuild.setSmallIcon(iconRes);
            return true;
        }
    }
}
