package com.heytap.mcssdk.notification;

import android.app.Notification;
import android.app.NotificationManager;
import android.content.Context;
import android.os.Build;
import android.os.Bundle;
import android.service.notification.StatusBarNotification;
import android.text.TextUtils;
import com.heytap.mcssdk.PushService;
import com.heytap.mcssdk.constant.McsEventConstant;
import com.heytap.mcssdk.constant.PushConstant;
import com.heytap.mcssdk.statis.McsStatisticUtils;
import com.heytap.msp.push.HeytapPushManager;
import com.heytap.msp.push.constant.ConfigConstant;
import com.heytap.msp.push.mode.DataMessage;
import com.heytap.msp.push.mode.NotificationSortMessage;
import com.heytap.msp.push.notification.ISortListener;
import com.heytap.msp.push.notification.PushNotification;
import com.heytap.msp.push.statis.StatisticUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class PushNotificationSortManager {
    private int canDelete;
    private List<NotificationSortMessage> canDeleteList = new ArrayList();
    private List<String> deleteList = new ArrayList();
    private int highSize;
    private int keepNumber = 3;
    private int normalSize;
    private int notDelete;

    public void startBuild(PushNotification.Builder builder, ISortListener listener) {
        if (builder != null) {
            callbackListener(listener, doTask(builder, builder.getAutoDelete(), builder.getImportantLevel(), builder.getMessageId(), builder.getStatisticData()), builder);
        }
    }

    private boolean doTask(PushNotification.Builder builder, int autoDelete, int importantLevel, String messageId, String statisticData) {
        Context context = PushService.getInstance().getContext();
        if (builder == null || context == null) {
            return false;
        }
        NotificationManager nm = NotificationHelper.getNotificationManager(context);
        NotificationSortMessage currentMessage = new NotificationSortMessage(messageId, importantLevel, autoDelete, false, System.currentTimeMillis(), statisticData);
        if (!judgeMessageNeedDoAntiDeleteAndAntiFolderLogic(context, nm, currentMessage, builder)) {
            return true;
        }
        dealShowedNotificationList(nm, context);
        return dealCurrentMessage(nm, context, builder, currentMessage);
    }

    private void callbackListener(ISortListener listener, boolean needPost, PushNotification.Builder builder) {
        if (listener != null) {
            listener.buildCompleted(needPost, builder, this.deleteList);
        }
    }

    private boolean dealCurrentMessage(NotificationManager nm, Context context, PushNotification.Builder builder, NotificationSortMessage currentMessage) {
        boolean needPost;
        if (this.canDelete + this.notDelete < this.keepNumber) {
            if (currentMessage.getAutoDelete() == -1) {
                currentMessage.setGroup(PushConstant.Notification.DEFAULT_NOTIFICATION_NOT_DELETE_GROUP_KEY + context.getPackageName());
            } else {
                currentMessage.setGroup(PushConstant.Notification.DEFAULT_NOTIFICATION_CAN_DELETE_GROUP_KEY + context.getPackageName());
            }
            needPost = true;
        } else if (currentMessage.getAutoDelete() == -1) {
            currentMessage.setGroup(PushConstant.Notification.DEFAULT_NOTIFICATION_NOT_DELETE_GROUP_KEY + context.getPackageName());
            int allowDelete = this.keepNumber - this.notDelete;
            if (allowDelete > 0) {
                deleteLowestMessage(context, nm, allowDelete - 1);
            } else {
                Notification group = NotificationHelper.createDefaultGroupNotification(context, currentMessage.getGroup(), builder);
                if (group != null) {
                    nm.notify(4096, group);
                }
            }
            needPost = true;
        } else {
            needPost = judgeShowCurrentMessage(context, nm, currentMessage);
        }
        if (needPost) {
            doMessageConfig(builder, currentMessage);
        } else {
            McsStatisticUtils.statisticEvent(context, McsEventConstant.EventId.EVENT_ID_PUSH_NO_SHOW_BY_FOLD, createDataMessage(context, currentMessage));
        }
        return needPost;
    }

    private boolean judgeShowCurrentMessage(Context context, NotificationManager nm, NotificationSortMessage currentMessage) {
        boolean needPosted;
        int i = this.notDelete;
        int i2 = this.keepNumber;
        boolean z = false;
        if (i >= i2) {
            return false;
        }
        int allowDelete = i2 - i;
        if (currentMessage.getImportantLevel() == 7) {
            needPosted = true;
        } else if (currentMessage.getImportantLevel() == 5) {
            if (this.highSize < allowDelete) {
                z = true;
            }
            needPosted = z;
        } else {
            if (this.highSize + this.normalSize < allowDelete) {
                z = true;
            }
            needPosted = z;
        }
        if (needPosted) {
            deleteLowestMessage(context, nm, allowDelete - 1);
        }
        return needPosted;
    }

    private void deleteLowestMessage(Context context, NotificationManager nm, int allowDelete) {
        keepMessage(this.canDeleteList, allowDelete);
        sendCommandOrStatic(context, nm, this.canDeleteList);
    }

    private void sendCommandOrStatic(Context context, NotificationManager nm, List<NotificationSortMessage> list) {
        if (list != null && list.size() != 0) {
            JSONObject root = new JSONObject();
            JSONArray array = new JSONArray();
            List<DataMessage> arrayList = new ArrayList<>();
            deleteNotification(context, nm, array, list, arrayList);
            if (array.length() != 0) {
                try {
                    root.put(PushConstant.NotificationSort.SORT_ARRAY, array);
                    HeytapPushManager.cancelNotification(root);
                } catch (JSONException e) {
                }
            }
            if (arrayList.size() != 0) {
                HashMap<String, List<DataMessage>> map = new HashMap<>();
                map.put(McsEventConstant.EventId.EVENT_ID_PUSH_DELETE_BY_FOLD, arrayList);
                StatisticUtils.statisticEvent(context, map);
            }
        }
    }

    private void deleteNotification(Context context, NotificationManager nm, JSONArray array, List<NotificationSortMessage> dataList, List<DataMessage> staticList) {
        for (NotificationSortMessage message : dataList) {
            if (message.isMcs()) {
                try {
                    JSONObject object = new JSONObject();
                    object.put(ConfigConstant.NotificationSort.EXTRA_MESSAGE_ID, message.getMessageId());
                    object.put(ConfigConstant.NotificationSort.EXTRA_NOTIFY_ID, message.getNotifyId());
                    array.put(object);
                } catch (JSONException e) {
                }
            } else {
                staticList.add(createDataMessage(context, message));
                this.deleteList.add(message.getMessageId());
            }
            nm.cancel(message.getNotifyId());
        }
    }

    private DataMessage createDataMessage(Context context, NotificationSortMessage message) {
        DataMessage dataMessage = new DataMessage(context.getPackageName(), message.getMessageId());
        try {
            JSONObject root = new JSONObject();
            root.put(PushConstant.NotificationSort.IS_MCS, AbsoluteConst.FALSE);
            String statisticData = message.getStatisticData();
            if (!TextUtils.isEmpty(statisticData)) {
                root.put(PushConstant.NotificationSort.CLIENT_STATISTIC_DATA, statisticData);
            }
            dataMessage.setStatisticsExtra(root.toString());
        } catch (JSONException e) {
        }
        return dataMessage;
    }

    private int keepMessage(List<NotificationSortMessage> list, int keepNumber2) {
        int listSize = list == null ? 0 : list.size();
        if (keepNumber2 <= 0 || listSize == 0) {
            return keepNumber2;
        }
        if (listSize < keepNumber2) {
            int keepNumber3 = keepNumber2 - listSize;
            list.clear();
            return keepNumber3;
        }
        for (int i = 0; i < keepNumber2; i++) {
            list.remove((listSize - 1) - i);
        }
        return 0;
    }

    private void dealShowedNotificationList(NotificationManager nm, Context context) {
        initParams(NotificationHelper.getActiveNotifications(nm, context.getPackageName()));
    }

    private void initParams(StatusBarNotification[] statusBarNotifications) {
        StatusBarNotification[] statusBarNotificationArr = statusBarNotifications;
        resetParams();
        if (statusBarNotificationArr != null && statusBarNotificationArr.length != 0) {
            int length = statusBarNotificationArr.length;
            int i = 0;
            while (i < length) {
                StatusBarNotification statusBarNotification = statusBarNotificationArr[i];
                Bundle extras = statusBarNotification.getNotification().extras;
                boolean isMcs = extras.getBoolean(ConfigConstant.NotificationSort.EXTRA_IS_MCS, true);
                long postTime = extras.getLong(ConfigConstant.NotificationSort.EXTRA_POST_TIME, statusBarNotification.getPostTime());
                String messageId = extras.getString(ConfigConstant.NotificationSort.EXTRA_MESSAGE_ID, "");
                int autoDelete = extras.getInt(ConfigConstant.NotificationSort.EXTRA_AUTO_DELETE, 1);
                int importantLevel = extras.getInt(ConfigConstant.NotificationSort.EXTRA_IMPORTANT_LEVEL, 7);
                NotificationSortMessage message = new NotificationSortMessage(messageId, importantLevel, autoDelete, isMcs, postTime, statusBarNotification.getId(), extras.getString(ConfigConstant.NotificationSort.EXTRA_STATISTIC_DATA));
                initCanDeleteAndNotDelete(autoDelete);
                initHighAndNormalSize(importantLevel);
                initList(message);
                i++;
                statusBarNotificationArr = statusBarNotifications;
            }
        }
    }

    private void initHighAndNormalSize(int importantLevel) {
        if (importantLevel == 7) {
            this.highSize++;
        } else if (importantLevel == 5) {
            this.normalSize++;
        }
    }

    private void initList(NotificationSortMessage message) {
        if (message.getAutoDelete() == 1) {
            if (this.canDeleteList.size() != 0) {
                for (int i = this.canDeleteList.size() - 1; i >= 0; i--) {
                    NotificationSortMessage sortMessage = this.canDeleteList.get(i);
                    if (message.getImportantLevel() >= sortMessage.getImportantLevel() && message.getPostTime() >= sortMessage.getPostTime()) {
                        this.canDeleteList.add(i + 1, sortMessage);
                        return;
                    }
                }
            }
            this.canDeleteList.add(0, message);
        }
    }

    private void resetParams() {
        this.canDelete = 0;
        this.notDelete = 0;
        this.highSize = 0;
        this.normalSize = 0;
        this.canDeleteList.clear();
        this.deleteList.clear();
    }

    private void initCanDeleteAndNotDelete(int autoDelete) {
        if (autoDelete == -1) {
            this.notDelete++;
        } else if (autoDelete == 1) {
            this.canDelete++;
        }
    }

    public boolean judgeMessageNeedDoAntiDeleteAndAntiFolderLogic(Context context, NotificationManager nm, NotificationSortMessage currentMessage, PushNotification.Builder builder) {
        if (currentMessage.getAutoDelete() == 0 || Build.VERSION.SDK_INT < 24 || Build.VERSION.SDK_INT >= 30) {
            return false;
        }
        if (!NotificationHelper.isExistNotificationsByPkgAndId(nm, context.getPackageName(), 4096)) {
            return true;
        }
        currentMessage.setGroup(PushConstant.Notification.DEFAULT_NOTIFICATION_NOT_DELETE_GROUP_KEY + context.getPackageName());
        doMessageConfig(builder, currentMessage);
        return false;
    }

    private void doMessageConfig(PushNotification.Builder builder, NotificationSortMessage currentMessage) {
        Bundle extras = new Bundle();
        extras.putInt(ConfigConstant.NotificationSort.EXTRA_AUTO_DELETE, currentMessage.getAutoDelete());
        extras.putInt(ConfigConstant.NotificationSort.EXTRA_IMPORTANT_LEVEL, currentMessage.getImportantLevel());
        extras.putString(ConfigConstant.NotificationSort.EXTRA_MESSAGE_ID, currentMessage.getMessageId());
        extras.putLong(ConfigConstant.NotificationSort.EXTRA_POST_TIME, System.currentTimeMillis());
        extras.putBoolean(ConfigConstant.NotificationSort.EXTRA_IS_MCS, false);
        extras.putString(ConfigConstant.NotificationSort.EXTRA_STATISTIC_DATA, currentMessage.getStatisticData());
        if (Build.VERSION.SDK_INT >= 20) {
            builder.addExtras(extras);
            builder.setGroup(currentMessage.getGroup());
        }
    }

    public static PushNotificationSortManager getInstance() {
        return SingletonHolder.INSTANCE;
    }

    /* access modifiers changed from: private */
    public static class SingletonHolder {
        private static final PushNotificationSortManager INSTANCE = new PushNotificationSortManager();

        private SingletonHolder() {
        }
    }
}
