package com.heytap.mcssdk.parser;

import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import com.heytap.mcssdk.constant.IntentConstant;
import com.heytap.mcssdk.constant.McsEventConstant;
import com.heytap.mcssdk.statis.McsStatisticUtils;
import com.heytap.mcssdk.utils.CryptoUtil;
import com.heytap.mcssdk.utils.LogUtil;
import com.heytap.msp.push.mode.BaseMode;
import com.heytap.msp.push.mode.DataMessage;
import org.json.JSONException;
import org.json.JSONObject;

public class DataMessageParser extends MessageParser {
    @Override // com.heytap.mcssdk.parser.Parser
    public BaseMode parse(Context context, int type, Intent intent) {
        if (4103 != type && 4098 != type && 4108 != type) {
            return null;
        }
        BaseMode baseMode = parseMessageByIntent(intent, type);
        McsStatisticUtils.statisticEvent(context, McsEventConstant.EventId.EVENT_ID_PUSH_TRANSMIT, (DataMessage) baseMode);
        return baseMode;
    }

    @Override // com.heytap.mcssdk.parser.MessageParser
    public BaseMode parseMessageByIntent(Intent intent, int type) {
        try {
            DataMessage message = new DataMessage();
            message.setMessageID(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.MESSAGE_ID)));
            message.setTaskID(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.TASK_ID)));
            message.setGlobalId(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.GLOBAL_ID)));
            message.setAppPackage(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.APP_PACKAGE)));
            message.setTitle(CryptoUtil.sdkDecrypt(intent.getStringExtra("title")));
            message.setContent(CryptoUtil.sdkDecrypt(intent.getStringExtra("content")));
            message.setDescription(CryptoUtil.sdkDecrypt(intent.getStringExtra("description")));
            String notifyId = CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.NOTIFY_ID));
            int i = 0;
            message.setNotifyID(TextUtils.isEmpty(notifyId) ? 0 : Integer.parseInt(notifyId));
            message.setMiniProgramPkg(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.MINI_PROGRAM_PKG)));
            message.setMessageType(type);
            message.setEventId(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.EVENT_ID)));
            message.setStatisticsExtra(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.STATISTICS_EXTRA)));
            String dataExtra = CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.DATA_EXTRA));
            message.setDataExtra(dataExtra);
            String msgCommand = getMsgCommand(dataExtra);
            if (!TextUtils.isEmpty(msgCommand)) {
                i = Integer.parseInt(msgCommand);
            }
            message.setMsgCommand(i);
            message.setBalanceTime(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.BALANCE_TIME)));
            message.setStartDate(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.START_DATE)));
            message.setEndDate(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.END_DATE)));
            message.setTimeRanges(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.TIME_RANGES)));
            message.setRule(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.RULE)));
            message.setForcedDelivery(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.FORCED_DELIVERY)));
            message.setDistinctContent(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.DISTINCT_CONTENT)));
            message.setAppId(CryptoUtil.sdkDecrypt(intent.getStringExtra(IntentConstant.APP_ID)));
            return message;
        } catch (Exception e) {
            LogUtil.d("OnHandleIntent--" + e.getMessage());
            return null;
        }
    }

    public String getMsgCommand(String extra) {
        if (TextUtils.isEmpty(extra)) {
            return "";
        }
        try {
            return new JSONObject(extra).optString(IntentConstant.MSG_COMMAND);
        } catch (JSONException e) {
            LogUtil.d(e.getMessage());
            return "";
        }
    }
}
