package com.heytap.mcssdk.utils;

import android.content.Context;
import android.content.SharedPreferences;
import android.os.Build;
import com.heytap.mcssdk.PushService;
import com.heytap.mcssdk.constant.Constants;

public class SharedPreferenceManager {
    private static final String DECRYPT_TAG = "decryptTag";
    private static final String HAS_DEFAULT_CHANNEL_CREATED = "hasDefaultChannelCreated";
    private static final String SHARED_PREFS_NAME = "shared_msg_sdk";
    private static final String STATIC_INFOMATION_SDK_VERSION = "lastUpLoadInfoSDKVersionName";
    private static final String STATIC_INFOMATION_UNIQUE_ID = "lastUploadInfoUniqueID";
    private Context mContext;
    private SharedPreferences mSharedPrefs;
    private Object prefsLock;

    public boolean hasDefaultChannelCreated() {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getBoolean(HAS_DEFAULT_CHANNEL_CREATED, false);
        }
        return false;
    }

    public void setHasDefaultChannelCreated(boolean hasCreated) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            sharedPreferences.edit().putBoolean(HAS_DEFAULT_CHANNEL_CREATED, hasCreated).commit();
        }
    }

    public void saveSDKVersionName() {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            sharedPreferences.edit().putString(STATIC_INFOMATION_SDK_VERSION, "3.1.0").commit();
        }
    }

    public void saveLastUploadUniqueID(String uniqueID) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            sharedPreferences.edit().putString(STATIC_INFOMATION_UNIQUE_ID, uniqueID).commit();
        }
    }

    public String getLastUpdataUniqueID() {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getString(STATIC_INFOMATION_UNIQUE_ID, "");
        }
        return "";
    }

    public String getLastUploadInfoSDKVersion() {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getString(STATIC_INFOMATION_SDK_VERSION, "");
        }
        return "";
    }

    public void saveDecryptTag(String tag) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            sharedPreferences.edit().putString(DECRYPT_TAG, tag).commit();
        }
    }

    public String getDecryptTag() {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getString(DECRYPT_TAG, "DES");
        }
        return "DES";
    }

    public int getIntData(String key) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getInt(key, 0);
        }
        return 0;
    }

    public int getIntData(String key, int value) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getInt(key, value);
        }
        return value;
    }

    public long getLongData(String key) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getLong(key, Constants.UNKNOWN_LONG.longValue());
        }
        return Constants.UNKNOWN_LONG.longValue();
    }

    public long getLongData(String key, long value) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            return sharedPreferences.getLong(key, value);
        }
        return value;
    }

    public void setIntData(String key, int value) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            SharedPreferences.Editor editor = sharedPreferences.edit();
            editor.putInt(key, value);
            editor.apply();
        }
    }

    public void setLongData(String key, long value) {
        SharedPreferences sharedPreferences = getSharedPrefs();
        if (sharedPreferences != null) {
            SharedPreferences.Editor editor = sharedPreferences.edit();
            editor.putLong(key, value);
            editor.apply();
        }
    }

    private SharedPreferenceManager() {
        this.prefsLock = new Object();
        Context context = PushService.getInstance().getContext();
        if (context != null) {
            this.mContext = getStorageContext(context);
        }
        Context context2 = this.mContext;
        if (context2 != null) {
            this.mSharedPrefs = context2.getSharedPreferences(SHARED_PREFS_NAME, 0);
        }
    }

    private Context getStorageContext(Context context) {
        boolean fbeVersion = ApkInfoUtil.isFBEVersion();
        LogUtil.d("fbeVersion is " + fbeVersion);
        if (!fbeVersion || Build.VERSION.SDK_INT < 24) {
            return context.getApplicationContext();
        }
        return context.createDeviceProtectedStorageContext();
    }

    private SharedPreferences getSharedPrefs() {
        SharedPreferences sharedPreferences = this.mSharedPrefs;
        if (sharedPreferences != null) {
            return sharedPreferences;
        }
        synchronized (this.prefsLock) {
            if (this.mSharedPrefs != null || this.mContext == null) {
                return this.mSharedPrefs;
            }
            SharedPreferences sharedPreferences2 = this.mContext.getSharedPreferences(SHARED_PREFS_NAME, 0);
            this.mSharedPrefs = sharedPreferences2;
            return sharedPreferences2;
        }
    }

    public static SharedPreferenceManager getInstance() {
        return SharedPreferenceManagerInstanceHolder.INSTANCE;
    }

    private static class SharedPreferenceManagerInstanceHolder {
        static SharedPreferenceManager INSTANCE = new SharedPreferenceManager();

        private SharedPreferenceManagerInstanceHolder() {
        }
    }
}
