package com.heytap.mcssdk.utils;

import android.content.Context;
import android.content.Intent;
import com.heytap.mcssdk.PushService;
import com.heytap.mcssdk.constant.IntentConstant;
import com.heytap.mcssdk.constant.MessageConstant;
import com.heytap.msp.push.mode.MessageStat;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

public class StatUtil {
    private static final String COUNT = "count";
    private static final int MCS_SUPPORT_VERSION = 1017;
    private static final String STAT_LIST = "list";
    private static final String TYPE = "type";

    public static void statisticMessage(Context context, MessageStat message) {
        LinkedList<MessageStat> list = new LinkedList<>();
        list.add(message);
        statisticMessage(context, list);
    }

    public static boolean statisticMessage(Context context, List<MessageStat> messages) {
        LinkedList<MessageStat> list = new LinkedList<>();
        list.addAll(messages);
        LogUtil.d("isSupportStatisticByMcs:" + isSupportStatisticByMcs(context) + ",list size:" + list.size());
        if (list.size() <= 0 || !isSupportStatisticByMcs(context)) {
            return false;
        }
        return statisticMessageByMcs(context, list);
    }

    private static boolean isSupportStatisticByMcs(Context context) {
        String pkg = PushService.getInstance().getMcsPackageName(context);
        return Utils.isExistPackage(context, pkg) && Utils.getVersionCode(context, pkg) >= 1017;
    }

    private static boolean statisticMessageByMcs(Context context, List<MessageStat> messages) {
        try {
            Intent intent = new Intent();
            intent.setAction(PushService.getInstance().getReceiveSdkAction(context));
            intent.setPackage(PushService.getInstance().getMcsPackageName(context));
            intent.putExtra(IntentConstant.APP_PACKAGE, context.getPackageName());
            intent.putExtra("type", MessageConstant.CommandId.COMMAND_STATISTIC);
            intent.putExtra(COUNT, messages.size());
            ArrayList<String> list = new ArrayList<>();
            for (MessageStat message : messages) {
                list.add(message.toJsonObject());
            }
            intent.putStringArrayListExtra("list", list);
            context.startService(intent);
            return true;
        } catch (Exception e) {
            LogUtil.e("statisticMessage--Exception" + e.getMessage());
            return false;
        }
    }
}
