package com.igexin.assist.control.huawei;

import android.content.Context;
import android.content.pm.PackageInfo;
import android.text.TextUtils;
import android.util.Log;
import com.huawei.agconnect.config.AGConnectServicesConfig;
import com.huawei.hmf.tasks.OnCompleteListener;
import com.huawei.hmf.tasks.Task;
import com.huawei.hms.aaid.HmsInstanceId;
import com.huawei.hms.push.HmsMessaging;
import com.igexin.assist.MessageBean;
import com.igexin.assist.action.MessageManger;
import com.igexin.assist.control.AbstractPushManager;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.assist.util.AssistUtils;
import com.xiaomi.mipush.sdk.Constants;

public class ManufacturePushManager implements AbstractPushManager {
    public static final String HONOR = AssistUtils.BRAND_HON.toLowerCase();
    public static final String HUAWEI = "Huawei".toLowerCase();
    private static final String PACKAGE_HUAWEI = "com.huawei.hwid";
    public static final String PLUGIN_VERSION = "3.1.1";
    public static final String TAG = "Assist_HW";
    private String appId;
    private Context context;
    private final Object object = new Object();
    private String token = "";

    public ManufacturePushManager(Context context2) {
        try {
            this.context = context2;
            Log.d("Assist_HW", "huawei plugin version = 3.1.1, huawei sdk version = " + ((String) context2.getPackageManager().getApplicationInfo(context2.getPackageName(), 128).metaData.get("com.huawei.hms.client.service.name:push")).split(Constants.COLON_SEPARATOR)[1]);
        } catch (Throwable th) {
            Log.d("Assist_HW", th.getMessage());
            Log.d("Assist_HW", "huawei plugin version = 3.1.1, not meta-data");
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void register(final Context context2) {
        Log.d("Assist_HW", "Register hmspush, pkg = " + context2.getPackageName());
        if (!isSupport()) {
            Log.d("Assist_HW", "hmspush not support.");
        } else {
            new Thread() {
                /* class com.igexin.assist.control.huawei.ManufacturePushManager.AnonymousClass1 */

                public void run() {
                    try {
                        synchronized (ManufacturePushManager.this.object) {
                            if (TextUtils.isEmpty(ManufacturePushManager.this.appId)) {
                                ManufacturePushManager.this.appId = AGConnectServicesConfig.fromContext(context2).getString("client/app_id");
                            }
                        }
                        ManufacturePushManager.this.token = HmsInstanceId.getInstance(context2).getToken(ManufacturePushManager.this.appId, "HCM");
                        Log.i("Assist_HW", "get hms token:" + ManufacturePushManager.this.token);
                        if (!TextUtils.isEmpty(ManufacturePushManager.this.token)) {
                            Context context = context2;
                            MessageManger.getInstance().addMessage(new MessageBean(context, "token", AssistPushConsts.HW_PREFIX + ManufacturePushManager.this.token));
                        }
                    } catch (Throwable th) {
                        Log.e("Assist_HW", "get hms token failed:" + th.getMessage());
                    }
                }
            }.start();
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void unregister(final Context context2) {
        new Thread() {
            /* class com.igexin.assist.control.huawei.ManufacturePushManager.AnonymousClass2 */

            public void run() {
                try {
                    HmsInstanceId.getInstance(context2).deleteToken(AGConnectServicesConfig.fromContext(context2).getString("client/app_id"), "HCM");
                    Log.i("Assist_HW", "deleteToken success.");
                } catch (Throwable th) {
                    Log.e("Assist_HW", "deleteToken failed." + th);
                }
            }
        }.start();
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOnPush(Context context2) {
        Log.d("Assist_HW", "turnOnPush");
        HmsMessaging.getInstance(context2).turnOnPush().addOnCompleteListener(new OnCompleteListener<Void>() {
            /* class com.igexin.assist.control.huawei.ManufacturePushManager.AnonymousClass3 */

            public void onComplete(Task<Void> task) {
                if (task.isSuccessful()) {
                    Log.i("Assist_HW", "turnOnPush Complete");
                    return;
                }
                Log.e("Assist_HW", "turnOnPush failed: ret=" + task.getException().getMessage());
            }
        });
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOffPush(Context context2) {
        Log.d("Assist_HW", "turnOffPush");
        HmsMessaging.getInstance(context2).turnOffPush().addOnCompleteListener(new OnCompleteListener<Void>() {
            /* class com.igexin.assist.control.huawei.ManufacturePushManager.AnonymousClass4 */

            public void onComplete(Task<Void> task) {
                if (task.isSuccessful()) {
                    Log.i("Assist_HW", "turnOffPush Complete");
                    return;
                }
                Log.e("Assist_HW", "turnOffPush failed: ret=" + task.getException().getMessage());
            }
        });
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getToken(Context context2) {
        return this.token;
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void setSilentTime(Context context2, int i, int i2) {
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public boolean isSupport() {
        try {
            PackageInfo packageInfo = this.context.getPackageManager().getPackageInfo(PACKAGE_HUAWEI, 0);
            Class<?> cls = Class.forName("android.os.SystemProperties");
            int parseInt = Integer.parseInt((String) cls.getDeclaredMethod("get", String.class).invoke(cls, "ro.build.hw_emui_api_level"));
            Log.d("Assist_HW", "pkgInfo.versionCode " + packageInfo.versionCode + " apiVersionCode = " + parseInt);
            if (packageInfo.versionCode < 30000000 || parseInt <= 9) {
                return false;
            }
            return true;
        } catch (Throwable th) {
            Log.d("Assist_HW", "check hw device error = " + th);
            return false;
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getBrandCode() {
        return "2";
    }
}
