package com.igexin.assist.control.meizu;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.os.Build;
import android.text.TextUtils;
import android.util.Log;
import com.igexin.assist.control.AbstractPushManager;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.assist.util.AssistUtils;
import com.meizu.cloud.pushsdk.PushManager;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;

public class ManufacturePushManager implements AbstractPushManager {
    public static final String PLUGIN_VERSION = "3.2.2";
    public static final String TAG = "Assist_MZ";
    private String appId = "";
    private String appKey = "";
    private Context context;

    public ManufacturePushManager(Context context2) {
        String str = PushManager.TAG;
        try {
            Field[] declaredFields = Class.forName("com.meizu.cloud.pushsdk.PushManager").getDeclaredFields();
            for (Field field : declaredFields) {
                if (Modifier.isFinal(field.getModifiers()) && "TAG".equals(field.getName())) {
                    str = (String) field.get(null);
                }
            }
        } catch (Exception e) {
        }
        Log.d("Assist_MZ", "meizu plugin version = 3.2.2, meizu sdk version = ".concat(String.valueOf(str)));
        this.context = context2;
        ApplicationInfo applicationInfo = context2.getPackageManager().getApplicationInfo(context2.getPackageName(), 128);
        String appIdByBuildConfig = Utils.getAppIdByBuildConfig(applicationInfo);
        this.appId = appIdByBuildConfig;
        if (TextUtils.isEmpty(appIdByBuildConfig)) {
            String str2 = (String) applicationInfo.metaData.get(AssistPushConsts.MEIZUPUSH_APPID);
            this.appId = str2;
            this.appId = str2.replace(AssistPushConsts.MZ_PREFIX, "");
        }
        String appKeyByBuildConfig = Utils.getAppKeyByBuildConfig(applicationInfo);
        this.appKey = appKeyByBuildConfig;
        if (TextUtils.isEmpty(appKeyByBuildConfig)) {
            String str3 = (String) applicationInfo.metaData.get(AssistPushConsts.MEIZUPUSH_APPKEY);
            this.appKey = str3;
            this.appKey = str3.replace(AssistPushConsts.MZ_PREFIX, "");
        }
    }

    private static boolean isBrandMeizu() {
        boolean z;
        try {
            String a = i.a("ro.meizu.product.model");
            Log.d("Assist_MZ", "brand = ".concat(String.valueOf(a)));
            if (TextUtils.isEmpty(a) && !AssistUtils.BRAND_MZ.equalsIgnoreCase(Build.BRAND)) {
                if (!"22c4185e".equalsIgnoreCase(Build.BRAND)) {
                    z = false;
                    Log.d("Assist_MZ", "is mz:".concat(String.valueOf(z)));
                    return z;
                }
            }
            z = true;
            Log.d("Assist_MZ", "is mz:".concat(String.valueOf(z)));
            return z;
        } catch (Throwable th) {
            return false;
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getBrandCode() {
        return "4";
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getToken(Context context2) {
        if (context2 == null) {
            return null;
        }
        return PushManager.getPushId(context2);
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public boolean isSupport() {
        try {
            return isBrandMeizu();
        } catch (Throwable th) {
            return false;
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void register(Context context2) {
        try {
            if (!TextUtils.isEmpty(this.appId) && !TextUtils.isEmpty(this.appKey)) {
                if (context2 != null) {
                    Log.d("Assist_MZ", "Register meizupush, pkg = " + context2.getPackageName());
                    if (isSupport()) {
                        PushManager.register(context2, this.appId, this.appKey);
                        return;
                    } else {
                        Log.d("Assist_MZ", "mzpush not support.");
                        return;
                    }
                }
            }
            Log.d("Assist_MZ", "Register mzpush appId not find, or context null.");
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void setSilentTime(Context context2, int i, int i2) {
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOffPush(Context context2) {
        if (context2 != null) {
            String pushId = PushManager.getPushId(context2);
            if (!TextUtils.isEmpty(this.appId) && !TextUtils.isEmpty(this.appKey) && !TextUtils.isEmpty(pushId)) {
                PushManager.switchPush(context2, this.appId, this.appKey, pushId, false);
            }
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOnPush(Context context2) {
        if (context2 != null) {
            String pushId = PushManager.getPushId(context2);
            if (!TextUtils.isEmpty(this.appId) && !TextUtils.isEmpty(this.appKey) && !TextUtils.isEmpty(pushId)) {
                PushManager.switchPush(context2, this.appId, this.appKey, pushId, true);
            }
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void unregister(Context context2) {
        try {
            if (!TextUtils.isEmpty(this.appId)) {
                if (!TextUtils.isEmpty(this.appKey)) {
                    Log.d("Assist_MZ", "|Unregister meizupush");
                    PushManager.unRegister(context2, this.appId, this.appKey);
                    return;
                }
            }
            Log.d("Assist_MZ", "|Unregister meizupush appId not find");
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }
}
