package com.igexin.assist.control.oppo;

import android.app.NotificationManager;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.os.Build;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Log;
import com.heytap.msp.push.HeytapPushManager;
import com.heytap.msp.push.callback.ICallBackResultService;
import com.igexin.assist.MessageBean;
import com.igexin.assist.action.MessageManger;
import com.igexin.assist.control.AbstractPushManager;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.push.core.b;
import com.xiaomi.mipush.sdk.Constants;
import java.lang.reflect.Constructor;
import java.util.ArrayList;

public class OppoPushManager implements ICallBackResultService, AbstractPushManager {
    public static final String PLUGIN_VERSION = "3.1.2";
    public static final String TAG = "Assist_OP";
    private String appKey = "";
    private String appSecret = "";
    private Context context;

    public OppoPushManager(Context context2) {
        try {
            Log.d("Assist_OP", "oppo plugin version = 3.1.2, oppo sdk version = " + HeytapPushManager.getSDKVersionName());
            ApplicationInfo applicationInfo = context2.getPackageManager().getApplicationInfo(context2.getPackageName(), 128);
            String appKeyByBuildConfig = Utils.getAppKeyByBuildConfig(applicationInfo);
            this.appKey = appKeyByBuildConfig;
            if (TextUtils.isEmpty(appKeyByBuildConfig)) {
                String str = (String) applicationInfo.metaData.get(AssistPushConsts.OPPOPUSH_APPKEY);
                this.appKey = str;
                this.appKey = str.replace(AssistPushConsts.OPPO_PREFIX, "");
            }
            String appSecretByBuildConfig = Utils.getAppSecretByBuildConfig(applicationInfo);
            this.appSecret = appSecretByBuildConfig;
            if (TextUtils.isEmpty(appSecretByBuildConfig)) {
                String str2 = (String) applicationInfo.metaData.get(AssistPushConsts.OPPOPUSH_APPSECRET);
                this.appSecret = str2;
                this.appSecret = str2.replace(AssistPushConsts.OPPO_PREFIX, "");
            }
            createNotificationChannel(context2);
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }

    public static boolean checkOppoDevice(Context context2) {
        try {
            HeytapPushManager.init(context2, false);
            return HeytapPushManager.isSupportPush(context2);
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
            return false;
        }
    }

    private void createNotificationChannel(Context context2) {
        if (Build.VERSION.SDK_INT >= 26) {
            NotificationManager notificationManager = (NotificationManager) context2.getSystemService(b.n);
            Class<?> cls = Class.forName("android.app.NotificationChannel");
            Constructor<?> constructor = cls.getConstructor(String.class, CharSequence.class, Integer.TYPE);
            if (constructor != null) {
                if (((Parcelable) NotificationManager.class.getMethod("getNotificationChannel", String.class).invoke(notificationManager, "Default")) == null) {
                    NotificationManager.class.getMethod("createNotificationChannel", cls).invoke(notificationManager, (Parcelable) constructor.newInstance("Default", "Default", 3));
                }
            }
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getBrandCode() {
        return null;
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getToken(Context context2) {
        return HeytapPushManager.getRegisterID();
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public boolean isSupport() {
        Context context2 = this.context;
        if (context2 == null) {
            return false;
        }
        try {
            HeytapPushManager.init(context2, false);
            boolean isSupportPush = HeytapPushManager.isSupportPush(this.context);
            Log.d("Assist_OP", "is oppo:".concat(String.valueOf(isSupportPush)));
            return isSupportPush;
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
            return false;
        }
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onError(int i, String str) {
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onGetNotificationStatus(int i, int i2) {
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onGetPushStatus(int i, int i2) {
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onRegister(int i, String str) {
        try {
            Log.d("Assist_OP", "onToken :" + str + ", code = " + i);
            if (this.context != null && i == 0 && !TextUtils.isEmpty(str) && !str.equalsIgnoreCase("InvalidAppKey")) {
                MessageManger.getInstance().addMessage(new MessageBean(this.context, "token", AssistPushConsts.OPPO_PREFIX.concat(String.valueOf(str))));
            }
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onSetPushTime(int i, String str) {
    }

    @Override // com.heytap.msp.push.callback.ICallBackResultService
    public void onUnRegister(int i) {
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void register(Context context2) {
        try {
            this.context = context2;
            if (!TextUtils.isEmpty(this.appKey)) {
                if (!TextUtils.isEmpty(this.appSecret)) {
                    Log.d("Assist_OP", "Register oppo push, pkg = " + context2.getPackageName() + ", appKey = " + this.appKey + ", appSecret = " + this.appSecret);
                    if (isSupport()) {
                        HeytapPushManager.register(context2, this.appKey, this.appSecret, this);
                        return;
                    } else {
                        Log.d("Assist_OP", "not support oppo push.");
                        return;
                    }
                }
            }
            Log.d("Assist_OP", "Register oppo push appKey or appSecret is null or empty");
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void setSilentTime(Context context2, int i, int i2) {
        if (i2 == 0) {
            turnOnPush(context2);
            return;
        }
        int i3 = (i + i2) % 24;
        Log.d("Assist_OP", "getui setSilentTime" + i + Constants.COLON_SEPARATOR + i2);
        Log.d("Assist_OP", "oppo push setAcceptTime" + i3 + Constants.COLON_SEPARATOR + i);
        ArrayList arrayList = new ArrayList();
        for (int i4 = 0; i4 < 7; i4++) {
            arrayList.add(Integer.valueOf(i4));
        }
        HeytapPushManager.setPushTime(arrayList, i3, 0, i, 0);
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOffPush(Context context2) {
        try {
            HeytapPushManager.pausePush();
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOnPush(Context context2) {
        try {
            HeytapPushManager.resumePush();
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void unregister(Context context2) {
        try {
            HeytapPushManager.unRegister();
        } catch (Throwable th) {
            Log.d("Assist_OP", th.getMessage());
        }
    }
}
