package com.igexin.assist.control.vivo;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import com.igexin.assist.MessageBean;
import com.igexin.assist.action.MessageManger;
import com.igexin.assist.control.AbstractPushManager;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.sdk.PushManager;
import com.meizu.cloud.pushsdk.constants.PushConstants;
import com.tencent.connect.common.Constants;
import com.vivo.push.IPushActionListener;
import com.vivo.push.PushClient;
import java.io.File;
import java.lang.reflect.Field;

public class ManufacturePushManager implements AbstractPushManager {
    public static final String PLUGIN_VERSION = "3.1.0";
    public static final String TAG = "Assist_VV";
    public static final String VIVO = "Vivo".toLowerCase();
    private static final String VIVO_VERSION = "sdk_version_vivo";
    private static final String phoneBrand = Build.BRAND;
    private Context context;
    private String mSdkSwitchPath;

    public ManufacturePushManager(Context context2) {
        try {
            this.context = context2;
            ApplicationInfo applicationInfo = context2.getPackageManager().getApplicationInfo(context2.getPackageName(), 128);
            Log.d("Assist_VV", "vivo plugin version = 3.1.0, vivo sdk version = " + applicationInfo.metaData.get(VIVO_VERSION));
            this.mSdkSwitchPath = context2.getFilesDir().getPath() + "/init.pid";
            PushClient.getInstance(context2).initialize();
            PushClient.getInstance(context2).checkManifest();
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addVivoMessageBeanExtra(MessageBean messageBean) {
        try {
            Field declaredField = MessageBean.class.getDeclaredField(PushConstants.EXTRA);
            declaredField.setAccessible(true);
            ((Bundle) declaredField.get(messageBean)).putBoolean("isForce", true);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private boolean isSdkInit() {
        if (this.mSdkSwitchPath != null) {
            return new File(this.mSdkSwitchPath).exists();
        }
        return false;
    }

    private void turnOnPush(final Context context2, final boolean z) {
        try {
            PushClient.getInstance(context2).turnOnPush(new IPushActionListener() {
                /* class com.igexin.assist.control.vivo.ManufacturePushManager.AnonymousClass1 */

                @Override // com.vivo.push.IPushActionListener
                public void onStateChanged(int i) {
                    Log.d("Assist_VV", "turnOnPush finish, state = ".concat(String.valueOf(i)));
                    if (i == 0) {
                        String regId = PushClient.getInstance(context2).getRegId();
                        Log.d("Assist_VV", "turnOnPush token = ".concat(String.valueOf(regId)));
                        if (context2 != null && !TextUtils.isEmpty(regId)) {
                            MessageBean messageBean = new MessageBean(context2, "token", AssistPushConsts.VIVO_PREFIX.concat(String.valueOf(regId)));
                            if (z) {
                                ManufacturePushManager.this.addVivoMessageBeanExtra(messageBean);
                            }
                            MessageManger.getInstance().addMessage(messageBean);
                        }
                    } else if (i == 101) {
                        Log.d("Assist_VV", "the vivo rom not support system push");
                    }
                }
            });
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getBrandCode() {
        return Constants.VIA_SHARE_TYPE_INFO;
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public String getToken(Context context2) {
        return PushClient.getInstance(context2).getRegId();
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public boolean isSupport() {
        try {
            if (!TextUtils.equals(VIVO, phoneBrand.toLowerCase())) {
                return false;
            }
            boolean isSupport = PushClient.getInstance(this.context).isSupport();
            Log.d("Assist_VV", "the vivo system push support = ".concat(String.valueOf(isSupport)));
            return isSupport;
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
            return false;
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void register(Context context2) {
        try {
            Log.d("Assist_VV", "Register vivo push, pkg = " + context2.getPackageName());
            if (!PushManager.getInstance().isPushTurnedOn(context2)) {
                if (isSdkInit()) {
                    Log.d("Assist_VV", "gt push off.");
                    return;
                }
            }
            if (isSupport()) {
                turnOnPush(context2, false);
            } else {
                Log.d("Assist_VV", "vivopush not support.");
            }
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void setSilentTime(Context context2, int i, int i2) {
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOffPush(Context context2) {
        try {
            PushClient.getInstance(context2).turnOffPush(new IPushActionListener() {
                /* class com.igexin.assist.control.vivo.ManufacturePushManager.AnonymousClass2 */

                @Override // com.vivo.push.IPushActionListener
                public void onStateChanged(int i) {
                    Log.d("Assist_VV", "turnOffPush finish, state = ".concat(String.valueOf(i)));
                }
            });
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
        }
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void turnOnPush(Context context2) {
        turnOnPush(context2, true);
    }

    @Override // com.igexin.assist.control.AbstractPushManager
    public void unregister(Context context2) {
        try {
            turnOffPush(context2);
        } catch (Throwable th) {
            Log.d("Assist_VV", th.getMessage());
        }
    }
}
