package com.igexin.sdk;

import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import android.util.Log;
import com.igexin.assist.MessageBean;
import com.igexin.assist.action.MessageManger;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.assist.util.AssistUtils;
import com.meizu.cloud.pushsdk.MzPushMessageReceiver;
import com.meizu.cloud.pushsdk.handler.MzPushMessage;
import com.meizu.cloud.pushsdk.notification.PushNotificationBuilder;
import com.meizu.cloud.pushsdk.platform.message.PushSwitchStatus;
import com.meizu.cloud.pushsdk.platform.message.RegisterStatus;
import com.meizu.cloud.pushsdk.platform.message.SubAliasStatus;
import com.meizu.cloud.pushsdk.platform.message.SubTagsStatus;
import com.meizu.cloud.pushsdk.platform.message.UnRegisterStatus;
import com.xiaomi.mipush.sdk.Constants;
import org.json.JSONObject;

public class FlymePushReceiver extends MzPushMessageReceiver {
    public static final String CONTENT = "content";
    public static final String MSG_KEY_PAYLOAD = "gt_payload";
    public static final String MZ_STATUS_BAR_SMALL_ICON = "mz_push_notification_small_icon";
    public static final String TAG = "Assist_MZ";
    private Context context;
    private int statusBarIconId;

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onMessage(Context context2, Intent intent) {
        if (context2 != null && intent != null) {
            try {
                Log.d("Assist_MZ", "onMessage intent msg...");
                Log.d("Assist_MZ", "onMessage intent msg :" + intent.toUri(0));
                String stringExtra = intent.getStringExtra("content");
                if (!TextUtils.isEmpty(stringExtra)) {
                    MessageBean messageBean = new MessageBean(context2, AssistPushConsts.MSG_TYPE_PAYLOAD, stringExtra);
                    messageBean.setMessageSource(AssistPushConsts.MZ_PREFIX);
                    MessageManger.getInstance().addMessage(messageBean);
                }
            } catch (Throwable th) {
                Log.d("Assist_MZ", th.getMessage());
            }
        }
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onMessage(Context context2, String str) {
        try {
            Log.d("Assist_MZ", "onMessage receive msg ...");
            Log.d("Assist_MZ", "onMessage receive msg:".concat(String.valueOf(str)));
            if (context2 != null && !TextUtils.isEmpty(str)) {
                MessageBean messageBean = new MessageBean(context2, AssistPushConsts.MSG_TYPE_PAYLOAD, str);
                messageBean.setMessageSource(AssistPushConsts.MZ_PREFIX);
                MessageManger.getInstance().addMessage(messageBean);
            }
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onNotificationArrived(Context context2, MzPushMessage mzPushMessage) {
        Log.d("Assist_MZ", "onNotificationArrived receive msg ...");
        Log.d("Assist_MZ", "onNotificationArrived receive msg:".concat(String.valueOf(mzPushMessage)));
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onNotificationClicked(Context context2, MzPushMessage mzPushMessage) {
        try {
            Log.d("Assist_MZ", "onNotificationClicked receive msg ...");
            Log.d("Assist_MZ", "onNotificationClicked receive msg:" + mzPushMessage.getTitle() + Constants.COLON_SEPARATOR + mzPushMessage.getContent() + Constants.COLON_SEPARATOR + mzPushMessage.getSelfDefineContentString());
            String selfDefineContentString = mzPushMessage.getSelfDefineContentString();
            if (context2 != null && !TextUtils.isEmpty(selfDefineContentString)) {
                try {
                    JSONObject jSONObject = new JSONObject(selfDefineContentString);
                    if (jSONObject.has(MSG_KEY_PAYLOAD)) {
                        selfDefineContentString = jSONObject.getString(MSG_KEY_PAYLOAD);
                    }
                } catch (Throwable th) {
                    th.printStackTrace();
                }
                if (!TextUtils.isEmpty(selfDefineContentString)) {
                    MessageBean messageBean = new MessageBean(context2, AssistPushConsts.MSG_TYPE_PAYLOAD, selfDefineContentString);
                    messageBean.setMessageSource(AssistPushConsts.MZ_PREFIX);
                    MessageManger.getInstance().addMessage(messageBean);
                }
            }
            AssistUtils.startGetuiService(context2);
        } catch (Throwable th2) {
            Log.d("Assist_MZ", th2.getMessage());
        }
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onPushStatus(Context context2, PushSwitchStatus pushSwitchStatus) {
        Log.d("Assist_MZ", "onPushStatus:".concat(String.valueOf(pushSwitchStatus)));
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onReceive(Context context2, Intent intent) {
        this.context = context2.getApplicationContext();
        super.onReceive(context2, intent);
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onRegister(Context context2, String str) {
        try {
            Log.d("Assist_MZ", "onRegister :".concat(String.valueOf(str)));
            if (context2 != null && !TextUtils.isEmpty(str)) {
                MessageManger.getInstance().addMessage(new MessageBean(context2, "token", AssistPushConsts.MZ_PREFIX.concat(String.valueOf(str))));
            }
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onRegisterStatus(Context context2, RegisterStatus registerStatus) {
        try {
            Log.d("Assist_MZ", "onRegisterStatus :".concat(String.valueOf(registerStatus)));
            String pushId = registerStatus.getPushId();
            if (context2 != null && !TextUtils.isEmpty(pushId)) {
                MessageManger.getInstance().addMessage(new MessageBean(context2, "token", AssistPushConsts.MZ_PREFIX.concat(String.valueOf(pushId))));
            }
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onSubAliasStatus(Context context2, SubAliasStatus subAliasStatus) {
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onSubTagsStatus(Context context2, SubTagsStatus subTagsStatus) {
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onUnRegister(Context context2, boolean z) {
        Log.d("Assist_MZ", "onUnRegister:".concat(String.valueOf(z)));
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onUnRegisterStatus(Context context2, UnRegisterStatus unRegisterStatus) {
        Log.d("Assist_MZ", "onUnRegisterStatus:".concat(String.valueOf(unRegisterStatus)));
    }

    @Override // com.meizu.cloud.pushsdk.MzPushMessageReceiver
    public void onUpdateNotificationBuilder(PushNotificationBuilder pushNotificationBuilder) {
        try {
            if (this.statusBarIconId != 0) {
                pushNotificationBuilder.setStatusBarIcon(this.statusBarIconId);
            } else if (this.context != null) {
                int identifier = this.context.getResources().getIdentifier("mz_push_notification_small_icon", "drawable", this.context.getPackageName());
                this.statusBarIconId = identifier;
                if (identifier != 0) {
                    pushNotificationBuilder.setStatusBarIcon(identifier);
                }
            }
        } catch (Throwable th) {
            Log.d("Assist_MZ", th.getMessage());
        }
    }
}
