package com.igexin.sdk;

import android.app.Activity;
import android.app.Application;
import android.app.Service;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Base64;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.getui.gtc.api.GtcManager;
import com.getui.gtc.base.GtcProvider;
import com.getui.gtc.base.util.CommonUtil;
import com.getui.gtc.dim.Caller;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.c.a.c.a.c;
import com.igexin.push.core.ServiceManager;
import com.igexin.push.core.b;
import com.igexin.push.core.h;
import com.igexin.push.f.d;
import com.igexin.push.f.e;
import com.igexin.push.f.n;
import com.igexin.push.f.o;
import com.igexin.sdk.message.BindAliasCmdMessage;
import com.igexin.sdk.message.GTCmdMessage;
import com.igexin.sdk.message.SetTagCmdMessage;
import com.igexin.sdk.message.UnBindAliasCmdMessage;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.util.regex.Pattern;
import javax.crypto.KeyGenerator;

public class PushManager {
    private static final String TAG = "PushManager";
    private volatile h callback;
    private String intentService;
    private byte[] keyBytes;
    private long lastOpAliasTime;
    private long lastQueryTagTime;
    private long lastSendMessageTime;
    private long lastSetTagTime;
    private String safeCode;
    private String uActivty;
    private String uRegisteService;
    private Class uService;

    /* access modifiers changed from: package-private */
    public static class a {
        private static final PushManager a = new PushManager();

        private a() {
        }
    }

    private PushManager() {
        this.lastQueryTagTime = 0;
    }

    private static void checkContext(Context context) {
        if (context == null) {
            throw new IllegalArgumentException("NULL context");
        }
    }

    private int getAssistAction(int i, String str) {
        return (TextUtils.isEmpty(str) || !str.contains("_")) ? i : (i == 60001 || i == 60002) ? str.startsWith(AssistPushConsts.HW_PREFIX) ? i + 18 : str.startsWith(AssistPushConsts.XM_PREFIX) ? i + 48 : str.startsWith(AssistPushConsts.OPPO_PREFIX) ? i + 28 : str.startsWith(AssistPushConsts.VIVO_PREFIX) ? i + 38 : str.startsWith(AssistPushConsts.MZ_PREFIX) ? i + 58 : str.startsWith(AssistPushConsts.ST_PREFIX) ? i + 78 : str.startsWith(AssistPushConsts.FCM_PREFIX) ? i + 98 : str.startsWith(AssistPushConsts.HONOR_PREFIX) ? i + 118 : i : i;
    }

    public static PushManager getInstance() {
        return a.a;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Application getMainApplication(Context context) {
        if (context == null || !isMainProcess(context)) {
            return null;
        }
        return context instanceof Application ? (Application) context : (Application) context.getApplicationContext();
    }

    private Class getUserPushService(Context context) {
        checkContext(context);
        Class cls = this.uService;
        return cls != null ? cls : ServiceManager.getInstance().b(context);
    }

    private boolean isMainProcess(Context context) {
        try {
            GtcProvider.setContext(context);
            return CommonUtil.isMainProcess();
        } catch (Throwable th) {
            return false;
        }
    }

    private void registerCallback(final Context context) {
        ServiceManager.b = context.getApplicationContext();
        com.igexin.b.a.a().a("GTALCallback").execute(new Runnable() {
            /* class com.igexin.sdk.PushManager.AnonymousClass1 */

            public final void run() {
                try {
                    if (PushManager.this.callback != null) {
                        return;
                    }
                    if (Build.VERSION.SDK_INT >= 14) {
                        Application mainApplication = PushManager.this.getMainApplication(context);
                        if (mainApplication != null) {
                            System.currentTimeMillis();
                            GtcManager.getInstance().initialize(context, Caller.PUSH, null);
                            System.currentTimeMillis();
                            if (PushManager.this.callback == null && mainApplication != null) {
                                PushManager.this.callback = new h();
                                mainApplication.registerActivityLifecycleCallbacks(PushManager.this.callback);
                                System.currentTimeMillis();
                                com.igexin.c.a.c.a.a("PushManager｜ registerCallback time = " + System.currentTimeMillis(), new Object[0]);
                            }
                        }
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                }
            }
        });
    }

    private <T extends Activity> void registerPushActivity(Context context, Class<T> cls) {
        String str;
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            if (cls != null) {
                try {
                    Class.forName(cls.getName());
                    str = cls.getName();
                } catch (Exception e) {
                    c a2 = c.a();
                    a2.a("[PushManager] can't load activity = " + e.toString());
                    com.igexin.c.a.c.a.a("PushManager|registerPushActivity|" + e.toString(), new Object[0]);
                    return;
                }
            } else {
                c.a().a("[PushManager] call -> registerPushActivity, parameter [activity] is null");
                str = "";
            }
            this.uActivty = str;
            if (this.uService != null) {
                Bundle bundle = new Bundle();
                bundle.putString("action", "registerPushActivity");
                bundle.putString("ua", this.uActivty);
                Intent intent = new Intent(context.getApplicationContext(), this.uService);
                intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                intent.putExtra("ua", this.uActivty);
                startService(context, intent);
            }
        } catch (Throwable th) {
            com.igexin.c.a.c.a.a(th);
            c a3 = c.a();
            a3.a("[PushManager] registerPushActivity sdk error = " + th.toString());
        }
    }

    private <T extends Service> void registerUserService(Context context, Class<T> cls) {
        String str;
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            if (cls != null) {
                try {
                    Class.forName(cls.getName());
                    str = cls.getName();
                } catch (Exception e) {
                    c a2 = c.a();
                    a2.a("[PushManager] can't load service = " + e.toString());
                    com.igexin.c.a.c.a.a("PushManager|registerUserService|" + e.toString(), new Object[0]);
                    return;
                }
            } else {
                c.a().a("[PushManager] call -> registerUserService, parameter [service] is null");
                str = "";
            }
            this.uRegisteService = str;
            if (this.uService != null) {
                Bundle bundle = new Bundle();
                bundle.putString("action", "registerUserService");
                bundle.putString(o.a, this.uRegisteService);
                Intent intent = new Intent(context.getApplicationContext(), this.uService);
                intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                intent.putExtra(o.a, this.uRegisteService);
                startService(context, intent);
            }
        } catch (Throwable th) {
            com.igexin.c.a.c.a.a(th);
            c a3 = c.a();
            a3.a("[PushManager] registerUserService  error = " + th.toString());
        }
    }

    private void sendBindAliasResult(Context context, String str, String str2) {
        sendResult(context, new BindAliasCmdMessage(str, str2, 10010));
    }

    private void sendResult(Context context, GTCmdMessage gTCmdMessage) {
        try {
            Class c = ServiceManager.getInstance().c(context);
            if (c != null && context != null) {
                Intent intent = new Intent(context, c);
                Bundle bundle = new Bundle();
                bundle.putInt("action", 10010);
                bundle.putSerializable(PushConsts.KEY_CMD_MSG, gTCmdMessage);
                intent.putExtras(bundle);
                context.startService(intent);
            }
        } catch (Throwable th) {
            com.igexin.c.a.c.a.a(th);
            com.igexin.c.a.c.a.a("PushManager|" + th.toString(), new Object[0]);
        }
    }

    private void sendSetTagResult(Context context, String str, String str2) {
        sendResult(context, new SetTagCmdMessage(str, str2, 10009));
    }

    private void sendUnBindAliasResult(Context context, String str, String str2) {
        sendResult(context, new UnBindAliasCmdMessage(str, str2, 10011));
    }

    private boolean startService(Context context, Intent intent) {
        try {
            if (TextUtils.isEmpty(this.safeCode)) {
                String obj = o.b(context, o.e, "").toString();
                this.safeCode = obj;
                if (TextUtils.isEmpty(obj)) {
                    KeyGenerator instance = KeyGenerator.getInstance("AES");
                    instance.init(128);
                    String a2 = e.a(instance.generateKey().getEncoded());
                    this.safeCode = a2;
                    o.a(context, o.e, a2);
                }
            }
            intent.putExtra(o.e, this.safeCode);
        } catch (Exception e) {
            com.igexin.c.a.c.a.a(e);
        }
        return ServiceManager.getInstance().b(context, intent);
    }

    private void unRegisterCallback(final Context context) {
        com.igexin.b.a.a().a("GTALCallback").execute(new Runnable() {
            /* class com.igexin.sdk.PushManager.AnonymousClass2 */

            public final void run() {
                try {
                    if (PushManager.this.callback == null) {
                        return;
                    }
                    if (Build.VERSION.SDK_INT >= 14) {
                        Application mainApplication = PushManager.this.getMainApplication(context);
                        if (mainApplication != null) {
                            mainApplication.unregisterActivityLifecycleCallbacks(PushManager.this.callback);
                            PushManager.this.callback = null;
                            System.currentTimeMillis();
                            com.igexin.c.a.c.a.a("PushManager | unRegisterCallback time= " + System.currentTimeMillis(), new Object[0]);
                        }
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                }
            }
        });
    }

    public boolean areNotificationsEnabled(Context context) {
        return com.igexin.push.f.c.b(context);
    }

    public boolean bindAlias(Context context, String str) {
        return bindAlias(context, str, "bindAlias_" + System.currentTimeMillis());
    }

    public boolean bindAlias(Context context, String str, String str2) {
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            c.a().a("PushManager|call bindAlias");
            com.igexin.c.a.c.a.a("PushManager|call bindAlias", new Object[0]);
            long currentTimeMillis = System.currentTimeMillis();
            if (currentTimeMillis - this.lastOpAliasTime < 1000) {
                c.a().a("[PushManager] call - > bindAlias failed, it be called too frequently");
                sendBindAliasResult(context, str2, "30001");
                return false;
            }
            this.lastOpAliasTime = currentTimeMillis;
            Bundle bundle = new Bundle();
            bundle.putString("action", "bindAlias");
            bundle.putString("alias", str);
            bundle.putString("sn", str2);
            Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
            intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
            intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
            return startService(context, intent);
        } catch (Throwable th) {
            com.igexin.c.a.c.a.a(th);
            c a2 = c.a();
            a2.a("[PushManager] bindAlias  error = " + th.toString());
            return false;
        }
    }

    public void checkManifest(Context context) throws GetuiPushException {
        if (isMainProcess(context)) {
            com.igexin.push.f.c.c(context);
        }
    }

    public synchronized String getClientid(Context context) {
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            if (this.keyBytes == null) {
                try {
                    ApplicationInfo b = n.b(context);
                    if (!(b == null || b.metaData == null)) {
                        String a2 = d.a(b);
                        if (TextUtils.isEmpty(a2)) {
                            a2 = b.metaData.getString(b.b);
                        }
                        if (TextUtils.isEmpty(a2)) {
                            a2 = b.metaData.getString("GETUI_APPID");
                        }
                        if (a2 != null) {
                            a2 = a2.trim();
                        }
                        if (!TextUtils.isEmpty(a2)) {
                            String a3 = com.igexin.c.b.a.a(a2 + context.getPackageName());
                            if (a3 != null) {
                                this.keyBytes = a3.getBytes();
                            }
                        }
                    }
                } catch (Exception e) {
                    com.igexin.c.a.c.a.a("PushManager|" + e.toString(), new Object[0]);
                }
            }
            if (this.keyBytes != null) {
                ServiceManager.b = context.getApplicationContext();
                if (TextUtils.isEmpty(com.igexin.push.core.d.d.a().a("c"))) {
                    return "";
                }
                byte[] decode = Base64.decode(com.igexin.push.core.d.d.a().a("c"), 0);
                if (decode != null && this.keyBytes.length == decode.length) {
                    int length = decode.length;
                    byte[] bArr = new byte[length];
                    for (int i = 0; i < length; i++) {
                        bArr[i] = (byte) (this.keyBytes[i] ^ decode[i]);
                    }
                    if (Pattern.matches("[a-zA-Z0-9]+", new String(bArr))) {
                        return new String(bArr);
                    }
                }
            }
        } catch (Throwable th) {
            com.igexin.c.a.c.a.a(th);
            c a4 = c.a();
            a4.a("[PushManager] getClientid  error = " + th.toString());
        }
        return null;
    }

    public String getVersion(Context context) {
        return "3.2.17.0";
    }

    public void initialize(Context context) {
        Class cls;
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            if (TextUtils.isEmpty(this.intentService) && (cls = (Class) d.a(context, GTIntentService.class).second) != null) {
                this.intentService = cls.getName();
            }
            if (this.uService == null) {
                this.uService = (Class) d.a(context, PushService.class).second;
            }
            initialize(context, this.uService);
        } catch (Throwable th) {
            c a2 = c.a();
            a2.a("[PushManager] initialize sdk error = " + th.toString());
        }
    }

    @Deprecated
    public <T extends Service> void initialize(Context context, Class<T> cls) {
        try {
            checkContext(context);
            GtcProvider.setContext(context);
            if (cls == null || b.am.equals(cls.getName())) {
                cls = PushService.class;
            }
            context.getPackageManager().setComponentEnabledSetting(new ComponentName(context, (Class<?>) cls), 1, 1);
            Intent intent = new Intent(context.getApplicationContext(), (Class<?>) cls);
            intent.putExtra("action", PushConsts.ACTION_SERVICE_INITIALIZE);
            intent.putExtra(o.b, cls.getName());
            if (this.intentService != null) {
                intent.putExtra(o.c, this.intentService);
            }
            if (!TextUtils.isEmpty(this.uActivty)) {
                intent.putExtra("ua", this.uActivty);
            }
            if (!TextUtils.isEmpty(this.uRegisteService)) {
                intent.putExtra(o.a, this.uRegisteService);
            }
            if (startService(context, intent)) {
                this.uService = cls;
            }
            registerCallback(context);
            try {
                com.igexin.d.a a2 = com.igexin.d.a.a();
                a2.a = context.getApplicationContext();
                com.igexin.b.a.a().b().schedule(
                /*  JADX ERROR: Method code generation error
                    jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x008f: INVOKE  
                      (wrap: java.util.concurrent.ScheduledThreadPoolExecutor : 0x0082: INVOKE  (r4v7 java.util.concurrent.ScheduledThreadPoolExecutor) = (wrap: com.igexin.b.a : 0x007e: INVOKE  (r4v6 com.igexin.b.a) =  type: STATIC call: com.igexin.b.a.a():com.igexin.b.a) type: VIRTUAL call: com.igexin.b.a.b():java.util.concurrent.ScheduledThreadPoolExecutor)
                      (wrap: com.igexin.d.a$1 : 0x0088: CONSTRUCTOR  (r0v4 com.igexin.d.a$1) = (r5v3 'a2' com.igexin.d.a) call: com.igexin.d.a.1.<init>(com.igexin.d.a):void type: CONSTRUCTOR)
                      (2000 long)
                      (wrap: java.util.concurrent.TimeUnit : 0x008d: SGET  (r5v4 java.util.concurrent.TimeUnit) =  java.util.concurrent.TimeUnit.MILLISECONDS java.util.concurrent.TimeUnit)
                     type: VIRTUAL call: java.util.concurrent.ScheduledThreadPoolExecutor.schedule(java.lang.Runnable, long, java.util.concurrent.TimeUnit):java.util.concurrent.ScheduledFuture in method: com.igexin.sdk.PushManager.initialize(android.content.Context, java.lang.Class<T extends android.app.Service>):void, file: classes3.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:217)
                    	at jadx.core.codegen.RegionGen.makeSimpleBlock(RegionGen.java:110)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:56)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeTryCatch(RegionGen.java:306)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:69)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.RegionGen.makeRegionIndent(RegionGen.java:99)
                    	at jadx.core.codegen.RegionGen.makeTryCatch(RegionGen.java:306)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:69)
                    	at jadx.core.codegen.RegionGen.makeSimpleRegion(RegionGen.java:93)
                    	at jadx.core.codegen.RegionGen.makeRegion(RegionGen.java:59)
                    	at jadx.core.codegen.MethodGen.addRegionInsns(MethodGen.java:244)
                    	at jadx.core.codegen.MethodGen.addInstructions(MethodGen.java:237)
                    	at jadx.core.codegen.ClassGen.addMethodCode(ClassGen.java:342)
                    	at jadx.core.codegen.ClassGen.addMethod(ClassGen.java:295)
                    	at jadx.core.codegen.ClassGen.lambda$addInnerClsAndMethods$2(ClassGen.java:264)
                    	at java.util.stream.ForEachOps$ForEachOp$OfRef.accept(ForEachOps.java:184)
                    	at java.util.ArrayList.forEach(ArrayList.java:1259)
                    	at java.util.stream.SortedOps$RefSortingSink.end(SortedOps.java:390)
                    	at java.util.stream.Sink$ChainedReference.end(Sink.java:258)
                    Caused by: jadx.core.utils.exceptions.CodegenException: Error generate insn: 0x0088: CONSTRUCTOR  (r0v4 com.igexin.d.a$1) = (r5v3 'a2' com.igexin.d.a) call: com.igexin.d.a.1.<init>(com.igexin.d.a):void type: CONSTRUCTOR in method: com.igexin.sdk.PushManager.initialize(android.content.Context, java.lang.Class<T extends android.app.Service>):void, file: classes3.dex
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:255)
                    	at jadx.core.codegen.InsnGen.addWrappedArg(InsnGen.java:119)
                    	at jadx.core.codegen.InsnGen.addArg(InsnGen.java:103)
                    	at jadx.core.codegen.InsnGen.generateMethodArguments(InsnGen.java:806)
                    	at jadx.core.codegen.InsnGen.makeInvoke(InsnGen.java:746)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:367)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:249)
                    	... 24 more
                    Caused by: jadx.core.utils.exceptions.JadxRuntimeException: Expected class to be processed at this point, class: com.igexin.d.a, state: GENERATED_AND_UNLOADED
                    	at jadx.core.dex.nodes.ClassNode.ensureProcessed(ClassNode.java:215)
                    	at jadx.core.codegen.InsnGen.makeConstructor(InsnGen.java:630)
                    	at jadx.core.codegen.InsnGen.makeInsnBody(InsnGen.java:363)
                    	at jadx.core.codegen.InsnGen.makeInsn(InsnGen.java:230)
                    	... 30 more
                    */
                /*
                // Method dump skipped, instructions count: 179
                */
                throw new UnsupportedOperationException("Method not decompiled: com.igexin.sdk.PushManager.initialize(android.content.Context, java.lang.Class):void");
            }

            public boolean isPushTurnedOn(Context context) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    ServiceManager.b = context.getApplicationContext();
                    return com.igexin.push.core.d.d.a().b("p");
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] turnOffPush  error = " + th.toString());
                    return false;
                }
            }

            public void openNotification(Context context) {
                try {
                    Intent intent = new Intent();
                    if (Build.VERSION.SDK_INT >= 26) {
                        intent.setAction("android.settings.APP_NOTIFICATION_SETTINGS");
                        intent.putExtra("android.provider.extra.APP_PACKAGE", context.getPackageName());
                        intent.putExtra("android.provider.extra.CHANNEL_ID", context.getApplicationInfo().uid);
                    } else if (Build.VERSION.SDK_INT >= 21) {
                        intent.setAction("android.settings.APP_NOTIFICATION_SETTINGS");
                        intent.putExtra("app_package", context.getPackageName());
                        intent.putExtra("app_uid", context.getApplicationInfo().uid);
                    } else {
                        intent.setAction("android.settings.APPLICATION_DETAILS_SETTINGS");
                        intent.setData(Uri.fromParts("package", context.getPackageName(), null));
                    }
                    intent.setFlags(AMapEngineUtils.MAX_P20_WIDTH);
                    context.startActivity(intent);
                } catch (Throwable th) {
                }
            }

            public boolean queryPushOnLine(Context context) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "queryPushOnLine");
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] queryPushOnLine  error = " + th.toString());
                    return false;
                }
            }

            public int queryTag(Context context, String str) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (str == null) {
                        c.a().a("[PushManager]call -> queryTag failed, parameter [sn] is null");
                        return 20007;
                    }
                    long currentTimeMillis = System.currentTimeMillis();
                    if (currentTimeMillis - this.lastQueryTagTime < 1000) {
                        c.a().a("[PushManager]call -> queryTag failed, it be called too frequently");
                        return 20002;
                    }
                    Bundle bundle = new Bundle();
                    bundle.putString("action", PushConsts.QUERY_TAG);
                    bundle.putString("sn", str);
                    this.lastQueryTagTime = currentTimeMillis;
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    startService(context, intent);
                    return 0;
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] queryTag  error = " + th.toString());
                    return 0;
                }
            }

            @Deprecated
            public <T extends GTIntentService> void registerPushIntentService(Context context, Class<T> cls) {
                String str;
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    com.igexin.c.a.c.a.a("PushManager|call registerPushIntentService", new Object[0]);
                    if (cls != null) {
                        try {
                            Class.forName(cls.getName());
                            if (!com.igexin.push.f.c.a(new Intent(context, (Class<?>) cls), context)) {
                                com.igexin.c.a.c.a.e.a(TAG, "call - > registerPushIntentService, parameter [userIntentService] is set, but didn't find class \"" + cls.getName() + "\", please check your AndroidManifest");
                                return;
                            }
                            str = cls.getName();
                        } catch (Exception e) {
                            com.igexin.c.a.c.a.a("PushManager|registerPushIntentService|" + e.toString(), new Object[0]);
                            return;
                        }
                    } else {
                        str = "";
                    }
                    this.intentService = str;
                    if (this.uService != null) {
                        com.igexin.c.a.c.a.b(TAG, "start service to save intent service");
                        Intent intent = new Intent(context.getApplicationContext(), this.uService);
                        intent.putExtra(o.c, this.intentService);
                        startService(context, intent);
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] registerPushIntentService  error = " + th.toString());
                }
            }

            public boolean sendApplinkFeedback(Context context, String str) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (TextUtils.isEmpty(str)) {
                        c.a().a("[PushManager] call - > sendApplinkFeedback failed, parameter is illegal");
                        return false;
                    }
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "sendApplinkFeedback");
                    bundle.putString("url", str);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] sendApplinkFeedback  error = " + th.toString());
                    return false;
                }
            }

            public boolean sendFeedbackMessage(Context context, String str, String str2, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    boolean z = (i >= 60001 && i <= 60999) || (i >= 90001 && i <= 90999);
                    if (!(str == null || str2 == null)) {
                        if (z) {
                            int assistAction = getAssistAction(i, str2);
                            Bundle bundle = new Bundle();
                            bundle.putString("action", "sendFeedbackMessage");
                            bundle.putString("taskid", str);
                            bundle.putString("messageid", str2);
                            bundle.putString("actionid", String.valueOf(assistAction));
                            Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                            intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                            intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                            return startService(context, intent);
                        }
                    }
                    c.a().a("[PushManager] call - > sendFeedbackMessage failed, parameter is illegal");
                    return false;
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] sendFeedbackMessage  error = " + th.toString());
                    return false;
                }
            }

            public boolean sendMessage(Context context, String str, byte[] bArr) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    long currentTimeMillis = System.currentTimeMillis();
                    if (!(str == null || bArr == null || ((long) bArr.length) > 4096)) {
                        if (currentTimeMillis - this.lastSendMessageTime >= 1000) {
                            this.lastSendMessageTime = currentTimeMillis;
                            Bundle bundle = new Bundle();
                            bundle.putString("action", "sendMessage");
                            bundle.putString("taskid", str);
                            bundle.putByteArray("extraData", bArr);
                            Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                            intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                            intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                            return startService(context, intent);
                        }
                    }
                    c.a().a("[PushManager] call - > sendMessage failed, parameter is illegal or it be called too frequently");
                    return false;
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] sendMessage  error = " + th.toString());
                    return false;
                }
            }

            public boolean setBadgeNum(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("[PushManager] call - > setBadgeNum");
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setBadgeNum");
                    bundle.putInt("badgeNum", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setBadgeNum  error = " + th.toString());
                    return false;
                }
            }

            public void setDebugLogger(Context context, IUserLoggerInterface iUserLoggerInterface) {
                if (context == null || iUserLoggerInterface == null) {
                    throw new IllegalArgumentException("context or loggerInterface can not be null");
                }
                try {
                    GtcProvider.setContext(context);
                    if (!com.igexin.push.f.c.a(context)) {
                        iUserLoggerInterface.log("only run in debug mode");
                    } else if (!isMainProcess(context)) {
                        iUserLoggerInterface.log("Must be called in main process!");
                    } else {
                        try {
                            checkManifest(context);
                        } catch (GetuiPushException e) {
                            iUserLoggerInterface.log(e.toString());
                        }
                        c a2 = c.a();
                        if (iUserLoggerInterface == null) {
                            com.igexin.c.a.c.a.e.a("LogController", "user logger register parameter can not be null!");
                            return;
                        }
                        Context applicationContext = context.getApplicationContext();
                        a2.a(applicationContext);
                        a2.b.a(iUserLoggerInterface);
                        a2.b.a();
                        a2.a("[LogController] Sdk version = " + getInstance().getVersion(applicationContext));
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                }
            }

            public boolean setDeviceToken(Context context, String str) {
                try {
                    Context applicationContext = context.getApplicationContext();
                    if (TextUtils.isEmpty(str)) {
                        c.a().a("[PushManager] setDeviceToken  error =  token is empty");
                        return false;
                    } else if (str.equalsIgnoreCase("InvalidAppKey")) {
                        c.a().a("[PushManager] setDeviceToken  error =  token is InvalidAppKey");
                        return false;
                    } else {
                        checkContext(applicationContext);
                        GtcProvider.setContext(applicationContext);
                        Bundle bundle = new Bundle();
                        bundle.putString("action", "setDeviceToken");
                        bundle.putString("token", str);
                        Intent intent = new Intent(applicationContext.getApplicationContext(), getUserPushService(applicationContext));
                        intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                        intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                        return startService(applicationContext, intent);
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setDeviceToken  error = " + th.toString());
                    return false;
                }
            }

            public boolean setGuardOptions(Context context, boolean z, boolean z2) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setGuardOptions");
                    bundle.putBoolean("guardMe", z);
                    bundle.putBoolean("guardOthers", z2);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setGuardOptions  error = " + th.toString());
                    return false;
                }
            }

            public boolean setHeartbeatInterval(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (i < 0) {
                        c.a().a("[PushManager] call -> setHeartbeatInterval failed, parameter [interval] < 0, illegal");
                        return false;
                    }
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setHeartbeatInterval");
                    bundle.putInt("interval", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setHeartbeatInterval  error = " + th.toString());
                    return false;
                }
            }

            @Deprecated
            public boolean setHwBadgeNum(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("[PushManager] call - > setHwBadgeNum");
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setHwBadgeNum");
                    bundle.putInt("badgeNum", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setHwBadgeNum  error = " + th.toString());
                    return false;
                }
            }

            public boolean setNotificationIcon(Context context, String str, String str2) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setNotificationIcon");
                    bundle.putString("smallIcon", str);
                    bundle.putString("largeIcon", str2);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setNotificationIcon  error = " + th.toString());
                    return false;
                }
            }

            @Deprecated
            public boolean setOPPOBadgeNum(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("[PushManager] call - > setHwBadgeNum");
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setOppoBadgeNum");
                    bundle.putInt("badgeNum", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setOPPOBadgeNum  error = " + th.toString());
                    return false;
                }
            }

            public boolean setSilentTime(Context context, int i, int i2) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (i >= 0 && i < 24 && i2 >= 0) {
                        if (i2 <= 23) {
                            Bundle bundle = new Bundle();
                            bundle.putString("action", "setSilentTime");
                            bundle.putInt("beginHour", i);
                            bundle.putInt("duration", i2);
                            Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                            intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                            intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                            return startService(context, intent);
                        }
                    }
                    c.a().a("[PushManager] call - > setSilentTime failed, parameter [beginHour] or [duration] value exceeding");
                    return false;
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] queryTag  error = " + th.toString());
                    return false;
                }
            }

            public boolean setSocketTimeout(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (i < 0) {
                        c.a().a("[PushManager] call - > setSocketTimeout failed, parameter [timeout] < 0, illegal");
                        return false;
                    }
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setSocketTimeout");
                    bundle.putInt("timeout", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setSocketTimeout  error = " + th.toString());
                    return false;
                }
            }

            public int setTag(Context context, Tag[] tagArr, String str) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    if (tagArr == null) {
                        c.a().a("[PushManager] call -> setTag failed, parameter [tags] is null");
                        com.igexin.c.a.c.a.a("PushManager|tags is null", new Object[0]);
                        sendSetTagResult(context, str, "20006");
                        return 20006;
                    } else if (str == null) {
                        c.a().a("[PushManager] call -> setTag failed, parameter [sn] is null");
                        sendSetTagResult(context, str, "20007");
                        return 20007;
                    } else if (((long) tagArr.length) > 200) {
                        c.a().a("[PushManager] call -> setTag failed, parameter [tags] len > 200 is exceeds");
                        sendSetTagResult(context, str, PushConsts.SEND_MESSAGE_ERROR_GENERAL);
                        return 20001;
                    } else {
                        long currentTimeMillis = System.currentTimeMillis();
                        if (currentTimeMillis - this.lastSetTagTime < 1000) {
                            c.a().a("[PushManager] call - > setTag failed, it be called too frequently");
                            sendSetTagResult(context, str, PushConsts.SEND_MESSAGE_ERROR_TIME_OUT);
                            return 20002;
                        }
                        StringBuilder sb = new StringBuilder();
                        for (Tag tag : tagArr) {
                            if (!(tag == null || tag.getName() == null)) {
                                if (tag.getName().contains(Operators.SPACE_STR) || tag.getName().contains(",")) {
                                    c.a().a("[PushManager] call -> setTag failed, the tag [" + tag.getName() + "] is not illegal");
                                    sendSetTagResult(context, str, "20011");
                                    return 20011;
                                }
                                sb.append(tag.getName());
                                sb.append(",");
                            }
                        }
                        if (sb.length() > 0) {
                            sb.deleteCharAt(sb.length() - 1);
                            c.a().a("[PushManager] call setTag");
                            Bundle bundle = new Bundle();
                            bundle.putString("action", "setTag");
                            bundle.putString("tags", sb.toString());
                            bundle.putString("sn", str);
                            this.lastSetTagTime = currentTimeMillis;
                            Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                            intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                            intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                            startService(context, intent);
                            return 0;
                        }
                        sendSetTagResult(context, str, "20006");
                        return 20006;
                    }
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c.a().a("[PushManager] setTag  error = " + th.toString());
                    return 20005;
                }
            }

            @Deprecated
            public boolean setVivoAppBadgeNum(Context context, int i) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("[PushManager] call - > setHwBadgeNum");
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "setVivoBadgeNum");
                    bundle.putInt("badgeNum", i);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] setOPPOBadgeNum  error = " + th.toString());
                    return false;
                }
            }

            public void turnOffPush(Context context) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("PushManager|call turnOffPush");
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "turnOffPush");
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    startService(context, intent);
                    unRegisterCallback(context);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] turnOffPush  error = " + th.toString());
                }
            }

            public void turnOnPush(Context context) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("PushManager|call turnOnPush");
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_SERVICE_INITIALIZE_SLAVE);
                    intent.putExtra("op_app", context.getApplicationContext().getPackageName());
                    intent.putExtra("isSlave", true);
                    startService(context, intent);
                    registerCallback(context);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] turnOnPush  error = " + th.toString());
                }
            }

            public boolean unBindAlias(Context context, String str, boolean z) {
                return unBindAlias(context, str, z, "unBindAlias_" + System.currentTimeMillis());
            }

            public boolean unBindAlias(Context context, String str, boolean z, String str2) {
                try {
                    checkContext(context);
                    GtcProvider.setContext(context);
                    c.a().a("PushManager|call unBindAlias");
                    long currentTimeMillis = System.currentTimeMillis();
                    if (currentTimeMillis - this.lastOpAliasTime < 1000) {
                        c.a().a("[PushManager] call - > unBindAlias failed, it be called too frequently");
                        sendUnBindAliasResult(context, str2, "30001");
                        return false;
                    }
                    this.lastOpAliasTime = currentTimeMillis;
                    Bundle bundle = new Bundle();
                    bundle.putString("action", "unbindAlias");
                    bundle.putString("alias", str);
                    bundle.putBoolean("isSeft", z);
                    bundle.putString("sn", str2);
                    Intent intent = new Intent(context.getApplicationContext(), getUserPushService(context));
                    intent.putExtra("action", PushConsts.ACTION_BROADCAST_PUSHMANAGER);
                    intent.putExtra(AbsURIAdapter.BUNDLE, bundle);
                    return startService(context, intent);
                } catch (Throwable th) {
                    com.igexin.c.a.c.a.a(th);
                    c a2 = c.a();
                    a2.a("[PushManager] unBindAlias  error = " + th.toString());
                    return false;
                }
            }
        }
