package com.nostra13.dcloudimageloader.core.display;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.widget.ImageView;
import com.nostra13.dcloudimageloader.core.assist.LoadedFrom;
import com.nostra13.dcloudimageloader.core.imageaware.ImageAware;
import com.nostra13.dcloudimageloader.core.imageaware.ImageViewAware;
import com.nostra13.dcloudimageloader.utils.L;

public class RoundedBitmapDisplayer implements BitmapDisplayer {
    private final int roundPixels;

    public RoundedBitmapDisplayer(int i) {
        this.roundPixels = i;
    }

    private static Bitmap getRoundedCornerBitmap(Bitmap bitmap, int i, Rect rect, Rect rect2, int i2, int i3) {
        Bitmap createBitmap = Bitmap.createBitmap(i2, i3, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint();
        RectF rectF = new RectF(rect2);
        paint.setAntiAlias(true);
        canvas.drawARGB(0, 0, 0, 0);
        paint.setColor(-16777216);
        float f = (float) i;
        canvas.drawRoundRect(rectF, f, f, paint);
        paint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.SRC_IN));
        canvas.drawBitmap(bitmap, rect, rectF, paint);
        return createBitmap;
    }

    public static Bitmap roundCorners(Bitmap bitmap, ImageViewAware imageViewAware, int i) {
        int i2;
        int i3;
        Rect rect;
        Rect rect2;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        ImageView wrappedView = imageViewAware.getWrappedView();
        if (wrappedView == null) {
            L.w("View is collected probably. Can't round bitmap corners without view properties.", new Object[0]);
            return bitmap;
        }
        int width = bitmap.getWidth();
        int height = bitmap.getHeight();
        int width2 = imageViewAware.getWidth();
        int height2 = imageViewAware.getHeight();
        if (width2 <= 0) {
            width2 = width;
        }
        if (height2 <= 0) {
            height2 = height;
        }
        ImageView.ScaleType scaleType = wrappedView.getScaleType();
        if (scaleType == null) {
            return bitmap;
        }
        int ordinal = scaleType.ordinal();
        if (ordinal == 1) {
            float f = (float) width;
            float f2 = (float) height;
            if (((float) width2) / ((float) height2) > f / f2) {
                i5 = Math.min(height2, height);
                i4 = (int) (f / (f2 / ((float) i5)));
            } else {
                int min = Math.min(width2, width);
                i4 = min;
                i5 = (int) (f2 / (f / ((float) min)));
            }
            int i10 = (width2 - i4) / 2;
            int i11 = (height2 - i5) / 2;
            Rect rect3 = new Rect(0, 0, width, height);
            Rect rect4 = new Rect(i10, i11, i4 + i10, i5 + i11);
            i3 = width2;
            i2 = height2;
            rect2 = rect3;
            rect = rect4;
        } else if (ordinal == 5) {
            float f3 = (float) width2;
            float f4 = (float) height2;
            float f5 = (float) width;
            float f6 = (float) height;
            if (f3 / f4 > f5 / f6) {
                int i12 = (int) (f4 * (f5 / f3));
                i7 = (height - i12) / 2;
                i6 = i12;
                i9 = width;
                i8 = 0;
            } else {
                i9 = (int) (f3 * (f6 / f4));
                i8 = (width - i9) / 2;
                i6 = height;
                i7 = 0;
            }
            Rect rect5 = new Rect(i8, i7, i8 + i9, i7 + i6);
            Rect rect6 = new Rect(0, 0, i9, i6);
            i3 = i9;
            i2 = i6;
            rect2 = rect5;
            rect = rect6;
        } else if (ordinal == 6) {
            Rect rect7 = new Rect(0, 0, width, height);
            Rect rect8 = new Rect(0, 0, width2, height2);
            i3 = width2;
            i2 = height2;
            rect2 = rect7;
            rect = rect8;
        } else if (ordinal == 7 || ordinal == 8) {
            int min2 = Math.min(width2, width);
            int min3 = Math.min(height2, height);
            int i13 = (width - min2) / 2;
            int i14 = (height - min3) / 2;
            Rect rect9 = new Rect(i13, i14, i13 + min2, i14 + min3);
            Rect rect10 = new Rect(0, 0, min2, min3);
            i3 = min2;
            i2 = min3;
            rect2 = rect9;
            rect = rect10;
        } else {
            float f7 = (float) width2;
            float f8 = (float) height2;
            float f9 = (float) width;
            float f10 = (float) height;
            if (f7 / f8 > f9 / f10) {
                width2 = (int) (f9 / (f10 / f8));
            } else {
                height2 = (int) (f10 / (f9 / f7));
            }
            Rect rect11 = new Rect(0, 0, width, height);
            Rect rect12 = new Rect(0, 0, width2, height2);
            i3 = width2;
            i2 = height2;
            rect2 = rect11;
            rect = rect12;
        }
        try {
            return getRoundedCornerBitmap(bitmap, i, rect2, rect, i3, i2);
        } catch (OutOfMemoryError e) {
            L.e(e, "Can't create bitmap with rounded corners. Not enough memory.", new Object[0]);
            return bitmap;
        }
    }

    @Override // com.nostra13.dcloudimageloader.core.display.BitmapDisplayer
    public Bitmap display(Bitmap bitmap, ImageAware imageAware, LoadedFrom loadedFrom) {
        if (imageAware instanceof ImageViewAware) {
            Bitmap roundCorners = roundCorners(bitmap, (ImageViewAware) imageAware, this.roundPixels);
            imageAware.setImageBitmap(roundCorners);
            return roundCorners;
        }
        throw new IllegalArgumentException("ImageAware should wrap ImageView. ImageViewAware is expected.");
    }
}
