package com.seu.magicfilter.advanced;

import android.opengl.GLES20;
import com.seu.magicfilter.base.gpuimage.GPUImageFilter;
import com.seu.magicfilter.utils.DCOpenGLUtil;
import com.seu.magicfilter.utils.MagicFilterType;
import io.dcloud.feature.livepusher.R;

public class MagicFreudFilter extends GPUImageFilter {
    private int[] inputTextureHandles = {-1};
    private int[] inputTextureUniformLocations = {-1};
    private int mGLStrengthLocation;
    private int mTexelHeightUniformLocation;
    private int mTexelWidthUniformLocation;

    public MagicFreudFilter() {
        super(MagicFilterType.FREUD, R.raw.freud);
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDestroy() {
        super.onDestroy();
        GLES20.glDeleteTextures(1, this.inputTextureHandles, 0);
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureHandles;
            if (i < iArr.length) {
                iArr[i] = -1;
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysAfter() {
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureHandles;
            if (i < iArr.length && iArr[i] != -1) {
                GLES20.glActiveTexture(i + 3 + 33984);
                GLES20.glBindTexture(3553, 0);
                GLES20.glActiveTexture(33984);
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysPre() {
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureHandles;
            if (i < iArr.length && iArr[i] != -1) {
                GLES20.glActiveTexture(i + 3 + 33984);
                GLES20.glBindTexture(3553, this.inputTextureHandles[i]);
                GLES20.glUniform1i(this.inputTextureUniformLocations[i], i + 3);
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInit() {
        super.onInit();
        this.inputTextureUniformLocations[0] = GLES20.glGetUniformLocation(getProgram(), "inputImageTexture2");
        this.mTexelWidthUniformLocation = GLES20.glGetUniformLocation(getProgram(), "inputImageTextureWidth");
        this.mTexelHeightUniformLocation = GLES20.glGetUniformLocation(getProgram(), "inputImageTextureHeight");
        this.mGLStrengthLocation = GLES20.glGetUniformLocation(getProgram(), "strength");
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInitialized() {
        super.onInitialized();
        setFloat(this.mGLStrengthLocation, 1.0f);
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.advanced.MagicFreudFilter.AnonymousClass1 */

            public void run() {
                MagicFreudFilter.this.inputTextureHandles[0] = DCOpenGLUtil.loadTexture(MagicFreudFilter.this.getContext(), "filter/freud_rand.png");
            }
        });
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInputSizeChanged(int width, int height) {
        super.onInputSizeChanged(width, height);
        GLES20.glUniform1f(this.mTexelWidthUniformLocation, (float) width);
        GLES20.glUniform1f(this.mTexelHeightUniformLocation, (float) height);
    }
}
