package com.seu.magicfilter.advanced;

import android.opengl.GLES20;
import com.seu.magicfilter.base.gpuimage.GPUImageFilter;
import com.seu.magicfilter.utils.DCOpenGLUtil;
import com.seu.magicfilter.utils.MagicFilterType;
import io.dcloud.feature.livepusher.R;

public class MagicHudsonFilter extends GPUImageFilter {
    private int[] inputTextureHandles = {-1, -1, -1};
    private int[] inputTextureUniformLocations = {-1, -1, -1};
    private int mGLStrengthLocation;

    public MagicHudsonFilter() {
        super(MagicFilterType.HUDSON, R.raw.hudson);
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDestroy() {
        super.onDestroy();
        int[] iArr = this.inputTextureHandles;
        GLES20.glDeleteTextures(iArr.length, iArr, 0);
        int i = 0;
        while (true) {
            int[] iArr2 = this.inputTextureHandles;
            if (i < iArr2.length) {
                iArr2[i] = -1;
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysAfter() {
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureHandles;
            if (i < iArr.length && iArr[i] != -1) {
                GLES20.glActiveTexture(i + 3 + 33984);
                GLES20.glBindTexture(3553, 0);
                GLES20.glActiveTexture(33984);
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysPre() {
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureHandles;
            if (i < iArr.length && iArr[i] != -1) {
                GLES20.glActiveTexture(i + 3 + 33984);
                GLES20.glBindTexture(3553, this.inputTextureHandles[i]);
                GLES20.glUniform1i(this.inputTextureUniformLocations[i], i + 3);
                i++;
            } else {
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInit() {
        super.onInit();
        int i = 0;
        while (true) {
            int[] iArr = this.inputTextureUniformLocations;
            if (i < iArr.length) {
                int program = getProgram();
                iArr[i] = GLES20.glGetUniformLocation(program, "inputImageTexture" + (i + 2));
                i++;
            } else {
                this.mGLStrengthLocation = GLES20.glGetUniformLocation(getProgram(), "strength");
                return;
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInitialized() {
        super.onInitialized();
        setFloat(this.mGLStrengthLocation, 1.0f);
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.advanced.MagicHudsonFilter.AnonymousClass1 */

            public void run() {
                MagicHudsonFilter.this.inputTextureHandles[0] = DCOpenGLUtil.loadTexture(MagicHudsonFilter.this.getContext(), "filter/ohudsonbackground.png");
                MagicHudsonFilter.this.inputTextureHandles[1] = DCOpenGLUtil.loadTexture(MagicHudsonFilter.this.getContext(), "filter/overlaymap.png");
                MagicHudsonFilter.this.inputTextureHandles[2] = DCOpenGLUtil.loadTexture(MagicHudsonFilter.this.getContext(), "filter/hudsonmap.png");
            }
        });
    }
}
