package com.seu.magicfilter.advanced;

import android.opengl.GLES20;
import com.alibaba.fastjson.asm.Opcodes;
import com.igexin.push.config.c;
import com.seu.magicfilter.base.gpuimage.GPUImageFilter;
import com.seu.magicfilter.utils.MagicFilterType;
import com.tencent.smtt.sdk.TbsListener;
import io.dcloud.feature.livepusher.R;
import java.nio.ByteBuffer;
import org.mozilla.universalchardet.prober.HebrewProber;
import org.mozilla.universalchardet.prober.contextanalysis.EUCJPContextAnalysis;
import org.mozilla.universalchardet.prober.distributionanalysis.EUCTWDistributionAnalysis;

public class MagicSakuraFilter extends GPUImageFilter {
    private int mTexelHeightUniformLocation;
    private int mTexelWidthUniformLocation;
    private int[] mToneCurveTexture = {-1};
    private int mToneCurveTextureUniformLocation;

    public MagicSakuraFilter() {
        super(MagicFilterType.SAKURA, R.raw.romance);
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDestroy() {
        super.onDestroy();
        GLES20.glDeleteTextures(1, this.mToneCurveTexture, 0);
        this.mToneCurveTexture[0] = -1;
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysAfter() {
        if (this.mToneCurveTexture[0] != -1) {
            GLES20.glActiveTexture(33987);
            GLES20.glBindTexture(3553, 0);
            GLES20.glActiveTexture(33984);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDrawArraysPre() {
        if (this.mToneCurveTexture[0] != -1) {
            GLES20.glActiveTexture(33987);
            GLES20.glBindTexture(3553, this.mToneCurveTexture[0]);
            GLES20.glUniform1i(this.mToneCurveTextureUniformLocation, 3);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInit() {
        super.onInit();
        this.mToneCurveTextureUniformLocation = GLES20.glGetUniformLocation(getProgram(), "curve");
        this.mTexelWidthUniformLocation = GLES20.glGetUniformLocation(getProgram(), "texelWidthOffset");
        this.mTexelHeightUniformLocation = GLES20.glGetUniformLocation(getProgram(), "texelHeightOffset");
    }

    /* access modifiers changed from: protected */
    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInitialized() {
        super.onInitialized();
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.advanced.MagicSakuraFilter.AnonymousClass1 */

            public void run() {
                GLES20.glGenTextures(1, MagicSakuraFilter.this.mToneCurveTexture, 0);
                GLES20.glBindTexture(3553, MagicSakuraFilter.this.mToneCurveTexture[0]);
                GLES20.glTexParameterf(3553, 10240, 9729.0f);
                GLES20.glTexParameterf(3553, 10241, 9729.0f);
                GLES20.glTexParameterf(3553, 10242, 33071.0f);
                GLES20.glTexParameterf(3553, 10243, 33071.0f);
                byte[] arrayOfByte = new byte[1024];
                int[] arrayOfInt = {95, 95, 96, 97, 97, 98, 99, 99, 100, 101, 101, 102, 103, 104, 104, 105, 106, 106, 107, 108, 108, 109, 110, 111, 111, 112, 113, 113, 114, 115, 115, 116, 117, 117, 118, 119, 120, 120, 121, 122, 122, 123, 124, 124, 125, 126, 127, 127, 128, 129, 129, 130, TbsListener.ErrorCode.DOWNLOAD_USER_CANCEL, TbsListener.ErrorCode.DOWNLOAD_USER_CANCEL, TbsListener.ErrorCode.DOWNLOAD_CDN_URL_IS_NULL, 133, 133, TbsListener.ErrorCode.DOWNLOAD_USER_PAUSE, 135, 136, 136, 137, 138, 138, 139, 140, 140, 141, EUCJPContextAnalysis.SINGLE_SHIFT_2, EUCJPContextAnalysis.SINGLE_SHIFT_3, EUCJPContextAnalysis.SINGLE_SHIFT_3, 144, c.G, c.G, 146, 147, 147, Opcodes.LCMP, Opcodes.FCMPL, Opcodes.FCMPL, 150, 151, TbsListener.ErrorCode.NEEDDOWNLOAD_TMPCORE_PREPARING, TbsListener.ErrorCode.NEEDDOWNLOAD_TMPCORE_PREPARING, 153, 154, 154, TbsListener.ErrorCode.NO_NEED_STARTDOWNLOAD, 156, 156, 157, Opcodes.IFLE, 159, 159, 160, 161, 161, Opcodes.IF_ICMPGE, Opcodes.IF_ICMPGT, Opcodes.IF_ICMPGT, 164, Opcodes.IF_ACMPEQ, Opcodes.IF_ACMPEQ, Opcodes.IF_ACMPNE, Opcodes.GOTO, 168, 168, Opcodes.RET, 170, 170, 171, 172, 172, 173, 174, 175, 175, 176, 177, 177, 178, 179, 179, 180, Opcodes.PUTFIELD, Opcodes.PUTFIELD, Opcodes.INVOKEVIRTUAL, Opcodes.INVOKESPECIAL, Opcodes.INVOKESTATIC, Opcodes.INVOKESTATIC, Opcodes.INVOKEINTERFACE, 186, 186, Opcodes.NEW, Opcodes.NEWARRAY, Opcodes.NEWARRAY, 189, 190, 191, 191, 192, Opcodes.INSTANCEOF, Opcodes.INSTANCEOF, 194, 195, 195, EUCTWDistributionAnalysis.HIGHBYTE_BEGIN, 197, 197, Opcodes.IFNULL, Opcodes.IFNONNULL, 200, 200, 201, 202, 202, 203, TbsListener.ErrorCode.APK_INVALID, TbsListener.ErrorCode.APK_INVALID, TbsListener.ErrorCode.UNZIP_DIR_ERROR, TbsListener.ErrorCode.UNZIP_IO_ERROR, TbsListener.ErrorCode.UNZIP_OTHER_ERROR, TbsListener.ErrorCode.UNZIP_OTHER_ERROR, 208, TbsListener.ErrorCode.DEXOPT_EXCEPTION, TbsListener.ErrorCode.DEXOPT_EXCEPTION, TbsListener.ErrorCode.ROM_NOT_ENOUGH, TbsListener.ErrorCode.EXCEED_COPY_RETRY_NUM, TbsListener.ErrorCode.EXCEED_COPY_RETRY_NUM, TbsListener.ErrorCode.COPY_FAIL, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, TbsListener.ErrorCode.COPY_SRCDIR_ERROR, TbsListener.ErrorCode.COPY_TMPDIR_ERROR, 215, 216, 216, 217, 218, 218, TbsListener.ErrorCode.RENAME_EXCEPTION, TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, TbsListener.ErrorCode.COPY_INSTALL_SUCCESS, TbsListener.ErrorCode.INCRUPDATE_INSTALL_SUCCESS, 222, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, TbsListener.ErrorCode.EXCEED_LZMA_RETRY_NUM, 224, 225, 225, TbsListener.ErrorCode.DEXOAT_EXCEPTION, TbsListener.ErrorCode.HOST_CONTEXT_IS_NULL, TbsListener.ErrorCode.HOST_CONTEXT_IS_NULL, TbsListener.ErrorCode.INCR_ERROR_DETAIL, TbsListener.ErrorCode.INSTALL_FROM_UNZIP, TbsListener.ErrorCode.INSTALL_FROM_UNZIP, TbsListener.ErrorCode.RENAME_SUCCESS, TbsListener.ErrorCode.RENAME_FAIL, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, TbsListener.ErrorCode.INSTALL_SUCCESS_AND_RELEASE_LOCK, TbsListener.ErrorCode.DECOUPLE_INSTLL_SUCCESS, 234, 234, 235, TbsListener.ErrorCode.TPATCH_INSTALL_SUCCESS, TbsListener.ErrorCode.TPATCH_INSTALL_SUCCESS, 237, 238, 239, 239, 240, 241, 241, TbsListener.ErrorCode.TPATCH_ENABLE_EXCEPTION, 243, 243, 244, HebrewProber.FINAL_TSADI, HebrewProber.FINAL_TSADI, HebrewProber.NORMAL_TSADI, 247, 248, 248, 249, 250, 250, 251, 252, 252, c.E, 254, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255};
                for (int i = 0; i < 256; i++) {
                    arrayOfByte[i * 4] = (byte) arrayOfInt[i];
                    arrayOfByte[(i * 4) + 1] = (byte) arrayOfInt[i];
                    arrayOfByte[(i * 4) + 2] = (byte) arrayOfInt[i];
                    arrayOfByte[(i * 4) + 3] = (byte) arrayOfInt[i];
                }
                GLES20.glTexImage2D(3553, 0, 6408, 256, 1, 0, 6408, 5121, ByteBuffer.wrap(arrayOfByte));
            }
        });
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInputSizeChanged(int width, int height) {
        super.onInputSizeChanged(width, height);
        GLES20.glUniform1f(this.mTexelWidthUniformLocation, 1.0f / ((float) width));
        GLES20.glUniform1f(this.mTexelHeightUniformLocation, 1.0f / ((float) height));
    }
}
