package com.seu.magicfilter.base;

import android.content.Context;
import android.opengl.GLES20;
import com.seu.magicfilter.base.gpuimage.GPUImageFilter;
import java.nio.FloatBuffer;
import java.util.List;

public class MagicBaseGroupFilter extends GPUImageFilter {
    private static int[] frameBufferTextures = null;
    private static int[] frameBuffers = null;
    protected List<GPUImageFilter> filters;
    private int frameHeight = -1;
    private int frameWidth = -1;

    public MagicBaseGroupFilter(List<GPUImageFilter> filters2) {
        this.filters = filters2;
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onDestroy() {
        for (GPUImageFilter filter : this.filters) {
            filter.destroy();
        }
        destroyFramebuffers();
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void init(Context context) {
        for (GPUImageFilter filter : this.filters) {
            filter.init(context);
        }
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public void onInputSizeChanged(int width, int height) {
        super.onInputSizeChanged(width, height);
        int size = this.filters.size();
        for (int i = 0; i < size; i++) {
            this.filters.get(i).onInputSizeChanged(width, height);
        }
        int[] iArr = frameBuffers;
        if (!(iArr == null || (this.frameWidth == width && this.frameHeight == height && iArr.length == size - 1))) {
            destroyFramebuffers();
            this.frameWidth = width;
            this.frameHeight = height;
        }
        if (frameBuffers == null) {
            frameBuffers = new int[(size - 1)];
            frameBufferTextures = new int[(size - 1)];
            for (int i2 = 0; i2 < size - 1; i2++) {
                GLES20.glGenFramebuffers(1, frameBuffers, i2);
                GLES20.glGenTextures(1, frameBufferTextures, i2);
                GLES20.glBindTexture(3553, frameBufferTextures[i2]);
                GLES20.glTexImage2D(3553, 0, 6408, width, height, 0, 6408, 5121, null);
                GLES20.glTexParameterf(3553, 10240, 9729.0f);
                GLES20.glTexParameterf(3553, 10241, 9729.0f);
                GLES20.glTexParameterf(3553, 10242, 33071.0f);
                GLES20.glTexParameterf(3553, 10243, 33071.0f);
                GLES20.glBindFramebuffer(36160, frameBuffers[i2]);
                GLES20.glFramebufferTexture2D(36160, 36064, 3553, frameBufferTextures[i2], 0);
                GLES20.glBindTexture(3553, 0);
                GLES20.glBindFramebuffer(36160, 0);
            }
        }
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public int onDrawFrame(int textureId, FloatBuffer cubeBuffer, FloatBuffer textureBuffer) {
        if (frameBuffers == null || frameBufferTextures == null) {
            return -1;
        }
        int size = this.filters.size();
        int previousTexture = textureId;
        int i = 0;
        while (true) {
            boolean isNotLast = true;
            if (i >= size) {
                return 1;
            }
            GPUImageFilter filter = this.filters.get(i);
            if (i >= size - 1) {
                isNotLast = false;
            }
            if (isNotLast) {
                GLES20.glViewport(0, 0, this.mInputWidth, this.mInputHeight);
                GLES20.glBindFramebuffer(36160, frameBuffers[i]);
                GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
                filter.onDrawFrame(previousTexture, this.mGLCubeBuffer, this.mGLTextureBuffer);
                GLES20.glBindFramebuffer(36160, 0);
                previousTexture = frameBufferTextures[i];
            } else {
                GLES20.glViewport(0, 0, this.mOutputWidth, this.mOutputHeight);
                filter.onDrawFrame(previousTexture, cubeBuffer, textureBuffer);
            }
            i++;
        }
    }

    @Override // com.seu.magicfilter.base.gpuimage.GPUImageFilter
    public int onDrawFrame(int textureId) {
        if (frameBuffers == null || frameBufferTextures == null) {
            return -1;
        }
        int size = this.filters.size();
        int previousTexture = textureId;
        int i = 0;
        while (true) {
            boolean isNotLast = true;
            if (i >= size) {
                return 1;
            }
            GPUImageFilter filter = this.filters.get(i);
            if (i >= size - 1) {
                isNotLast = false;
            }
            if (isNotLast) {
                GLES20.glBindFramebuffer(36160, frameBuffers[i]);
                GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
                filter.onDrawFrame(previousTexture, this.mGLCubeBuffer, this.mGLTextureBuffer);
                GLES20.glBindFramebuffer(36160, 0);
                previousTexture = frameBufferTextures[i];
            } else {
                filter.onDrawFrame(previousTexture, this.mGLCubeBuffer, this.mGLTextureBuffer);
            }
            i++;
        }
    }

    private void destroyFramebuffers() {
        int[] iArr = frameBufferTextures;
        if (iArr != null) {
            GLES20.glDeleteTextures(iArr.length, iArr, 0);
            frameBufferTextures = null;
        }
        int[] iArr2 = frameBuffers;
        if (iArr2 != null) {
            GLES20.glDeleteFramebuffers(iArr2.length, iArr2, 0);
            frameBuffers = null;
        }
    }

    public int getSize() {
        return this.filters.size();
    }
}
