package com.seu.magicfilter.base.gpuimage;

import android.content.Context;
import android.graphics.PointF;
import android.opengl.GLES20;
import com.seu.magicfilter.utils.DCOpenGLUtil;
import com.seu.magicfilter.utils.MagicFilterType;
import io.dcloud.feature.livepusher.R;
import java.nio.Buffer;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.FloatBuffer;
import java.nio.IntBuffer;
import java.util.LinkedList;

public class GPUImageFilter {
    private Context mContext;
    private int mFragmentShaderId;
    protected FloatBuffer mGLCubeBuffer;
    private int[] mGLCubeId;
    private IntBuffer mGLFboBuffer;
    private int[] mGLFboId;
    private int[] mGLFboTexId;
    private int mGLInputImageTextureIndex;
    private int mGLPositionIndex;
    private int mGLProgId;
    protected FloatBuffer mGLTextureBuffer;
    private int[] mGLTextureCoordinateId;
    private int mGLTextureCoordinateIndex;
    private int mGLTextureTransformIndex;
    private float[] mGLTextureTransformMatrix;
    protected int mInputHeight;
    protected int mInputWidth;
    private boolean mIsInitialized;
    protected int mOutputHeight;
    protected int mOutputWidth;
    private final LinkedList<Runnable> mRunOnDraw;
    private MagicFilterType mType;
    private final int mVertexShaderId;

    public GPUImageFilter() {
        this(MagicFilterType.NONE);
    }

    public GPUImageFilter(MagicFilterType type) {
        this(type, R.raw.vertex, R.raw.fragment);
    }

    public GPUImageFilter(MagicFilterType type, int fragmentShaderId) {
        this(type, R.raw.vertex, fragmentShaderId);
    }

    public GPUImageFilter(MagicFilterType type, int vertexShaderId, int fragmentShaderId) {
        this.mType = MagicFilterType.NONE;
        this.mType = type;
        this.mRunOnDraw = new LinkedList<>();
        this.mVertexShaderId = vertexShaderId;
        this.mFragmentShaderId = fragmentShaderId;
    }

    public void updateShaderID(int fragmentShaderId) {
        this.mFragmentShaderId = fragmentShaderId;
    }

    public void init(Context context) {
        this.mContext = context;
        onInit();
        onInitialized();
    }

    /* access modifiers changed from: protected */
    public void onInit() {
        initVbo();
        loadSamplerShader();
    }

    /* access modifiers changed from: protected */
    public void onInitialized() {
        this.mIsInitialized = true;
    }

    public final void destroy() {
        this.mIsInitialized = false;
        destroyFboTexture();
        destoryVbo();
        GLES20.glDeleteProgram(this.mGLProgId);
        onDestroy();
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
    }

    public void onInputSizeChanged(int width, int height) {
        this.mInputWidth = width;
        this.mInputHeight = height;
        initFboTexture(width, height);
    }

    public void onDisplaySizeChanged(int width, int height) {
        this.mOutputWidth = width;
        this.mOutputHeight = height;
    }

    private void loadSamplerShader() {
        int loadProgram = DCOpenGLUtil.loadProgram(DCOpenGLUtil.readShaderFromRawResource(getContext(), this.mVertexShaderId), DCOpenGLUtil.readShaderFromRawResource(getContext(), this.mFragmentShaderId));
        this.mGLProgId = loadProgram;
        this.mGLPositionIndex = GLES20.glGetAttribLocation(loadProgram, "position");
        this.mGLTextureCoordinateIndex = GLES20.glGetAttribLocation(this.mGLProgId, "inputTextureCoordinate");
        this.mGLTextureTransformIndex = GLES20.glGetUniformLocation(this.mGLProgId, "textureTransform");
        this.mGLInputImageTextureIndex = GLES20.glGetUniformLocation(this.mGLProgId, "inputImageTexture");
    }

    private void initVbo() {
        float[] VEX_CUBE = {-1.0f, -1.0f, 1.0f, -1.0f, -1.0f, 1.0f, 1.0f, 1.0f};
        float[] TEX_COORD = {0.0f, 0.0f, 1.0f, 0.0f, 0.0f, 1.0f, 1.0f, 1.0f};
        FloatBuffer asFloatBuffer = ByteBuffer.allocateDirect(VEX_CUBE.length * 4).order(ByteOrder.nativeOrder()).asFloatBuffer();
        this.mGLCubeBuffer = asFloatBuffer;
        asFloatBuffer.put(VEX_CUBE).position(0);
        FloatBuffer asFloatBuffer2 = ByteBuffer.allocateDirect(TEX_COORD.length * 4).order(ByteOrder.nativeOrder()).asFloatBuffer();
        this.mGLTextureBuffer = asFloatBuffer2;
        asFloatBuffer2.put(TEX_COORD).position(0);
        int[] iArr = new int[1];
        this.mGLCubeId = iArr;
        this.mGLTextureCoordinateId = new int[1];
        GLES20.glGenBuffers(1, iArr, 0);
        GLES20.glBindBuffer(34962, this.mGLCubeId[0]);
        GLES20.glBufferData(34962, this.mGLCubeBuffer.capacity() * 4, this.mGLCubeBuffer, 35044);
        GLES20.glGenBuffers(1, this.mGLTextureCoordinateId, 0);
        GLES20.glBindBuffer(34962, this.mGLTextureCoordinateId[0]);
        GLES20.glBufferData(34962, this.mGLTextureBuffer.capacity() * 4, this.mGLTextureBuffer, 35044);
    }

    private void destoryVbo() {
        int[] iArr = this.mGLCubeId;
        if (iArr != null) {
            GLES20.glDeleteBuffers(1, iArr, 0);
            this.mGLCubeId = null;
        }
        int[] iArr2 = this.mGLTextureCoordinateId;
        if (iArr2 != null) {
            GLES20.glDeleteBuffers(1, iArr2, 0);
            this.mGLTextureCoordinateId = null;
        }
    }

    private void initFboTexture(int width, int height) {
        if (!(this.mGLFboId == null || (this.mInputWidth == width && this.mInputHeight == height))) {
            destroyFboTexture();
        }
        this.mGLFboId = new int[1];
        this.mGLFboTexId = new int[1];
        this.mGLFboBuffer = IntBuffer.allocate(width * height);
        GLES20.glGenFramebuffers(1, this.mGLFboId, 0);
        GLES20.glGenTextures(1, this.mGLFboTexId, 0);
        GLES20.glBindTexture(3553, this.mGLFboTexId[0]);
        GLES20.glTexImage2D(3553, 0, 6408, width, height, 0, 6408, 5121, null);
        GLES20.glTexParameterf(3553, 10240, 9729.0f);
        GLES20.glTexParameterf(3553, 10241, 9729.0f);
        GLES20.glTexParameterf(3553, 10242, 33071.0f);
        GLES20.glTexParameterf(3553, 10243, 33071.0f);
        GLES20.glBindFramebuffer(36160, this.mGLFboId[0]);
        GLES20.glFramebufferTexture2D(36160, 36064, 3553, this.mGLFboTexId[0], 0);
        GLES20.glBindTexture(3553, 0);
        GLES20.glBindFramebuffer(36160, 0);
    }

    private void destroyFboTexture() {
        int[] iArr = this.mGLFboTexId;
        if (iArr != null) {
            GLES20.glDeleteTextures(1, iArr, 0);
            this.mGLFboTexId = null;
        }
        int[] iArr2 = this.mGLFboId;
        if (iArr2 != null) {
            GLES20.glDeleteFramebuffers(1, iArr2, 0);
            this.mGLFboId = null;
        }
    }

    public int onDrawFrame(int textureId, FloatBuffer cubeBuffer, FloatBuffer textureBuffer) {
        if (!this.mIsInitialized) {
            return -1;
        }
        GLES20.glUseProgram(this.mGLProgId);
        runPendingOnDrawTasks();
        GLES20.glEnableVertexAttribArray(this.mGLPositionIndex);
        GLES20.glVertexAttribPointer(this.mGLPositionIndex, 2, 5126, false, 8, (Buffer) cubeBuffer);
        GLES20.glEnableVertexAttribArray(this.mGLTextureCoordinateIndex);
        GLES20.glVertexAttribPointer(this.mGLTextureCoordinateIndex, 2, 5126, false, 8, (Buffer) textureBuffer);
        if (textureId != -1) {
            GLES20.glActiveTexture(33984);
            GLES20.glBindTexture(3553, textureId);
            GLES20.glUniform1i(this.mGLInputImageTextureIndex, 0);
        }
        onDrawArraysPre();
        GLES20.glDrawArrays(5, 0, 4);
        onDrawArraysAfter();
        GLES20.glBindTexture(3553, 0);
        GLES20.glDisableVertexAttribArray(this.mGLPositionIndex);
        GLES20.glDisableVertexAttribArray(this.mGLTextureCoordinateIndex);
        return 1;
    }

    public int onDrawFrame(int cameraTextureId) {
        if (!this.mIsInitialized || this.mGLFboId == null) {
            return -1;
        }
        GLES20.glUseProgram(this.mGLProgId);
        runPendingOnDrawTasks();
        GLES20.glBindBuffer(34962, this.mGLCubeId[0]);
        GLES20.glEnableVertexAttribArray(this.mGLPositionIndex);
        GLES20.glVertexAttribPointer(this.mGLPositionIndex, 2, 5126, false, 8, 0);
        GLES20.glBindBuffer(34962, this.mGLTextureCoordinateId[0]);
        GLES20.glEnableVertexAttribArray(this.mGLTextureCoordinateIndex);
        GLES20.glVertexAttribPointer(this.mGLTextureCoordinateIndex, 2, 5126, false, 8, 0);
        GLES20.glUniformMatrix4fv(this.mGLTextureTransformIndex, 1, false, this.mGLTextureTransformMatrix, 0);
        GLES20.glActiveTexture(33984);
        GLES20.glBindTexture(36197, cameraTextureId);
        GLES20.glUniform1i(this.mGLInputImageTextureIndex, 0);
        onDrawArraysPre();
        GLES20.glViewport(0, 0, this.mInputWidth, this.mInputHeight);
        GLES20.glBindFramebuffer(36160, this.mGLFboId[0]);
        GLES20.glDrawArrays(5, 0, 4);
        GLES20.glReadPixels(0, 0, this.mInputWidth, this.mInputHeight, 6408, 5121, this.mGLFboBuffer);
        GLES20.glBindFramebuffer(36160, 0);
        GLES20.glViewport(0, 0, this.mOutputWidth, this.mOutputHeight);
        GLES20.glDrawArrays(5, 0, 4);
        onDrawArraysAfter();
        GLES20.glBindTexture(36197, 0);
        GLES20.glDisableVertexAttribArray(this.mGLPositionIndex);
        GLES20.glDisableVertexAttribArray(this.mGLTextureCoordinateIndex);
        GLES20.glBindBuffer(34962, 0);
        return this.mGLFboTexId[0];
    }

    /* access modifiers changed from: protected */
    public void onDrawArraysPre() {
    }

    /* access modifiers changed from: protected */
    public void onDrawArraysAfter() {
    }

    private void runPendingOnDrawTasks() {
        while (!this.mRunOnDraw.isEmpty()) {
            this.mRunOnDraw.removeFirst().run();
        }
    }

    public int getProgram() {
        return this.mGLProgId;
    }

    public IntBuffer getGLFboBuffer() {
        return this.mGLFboBuffer;
    }

    /* access modifiers changed from: protected */
    public Context getContext() {
        return this.mContext;
    }

    /* access modifiers changed from: protected */
    public MagicFilterType getFilterType() {
        return this.mType;
    }

    public void setTextureTransformMatrix(float[] mtx) {
        this.mGLTextureTransformMatrix = mtx;
    }

    /* access modifiers changed from: protected */
    public void setInteger(final int location, final int intValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass1 */

            public void run() {
                GLES20.glUniform1i(location, intValue);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setFloat(final int location, final float floatValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass2 */

            public void run() {
                GLES20.glUniform1f(location, floatValue);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setFloatVec2(final int location, final float[] arrayValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass3 */

            public void run() {
                GLES20.glUniform2fv(location, 1, FloatBuffer.wrap(arrayValue));
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setFloatVec3(final int location, final float[] arrayValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass4 */

            public void run() {
                GLES20.glUniform3fv(location, 1, FloatBuffer.wrap(arrayValue));
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setFloatVec4(final int location, final float[] arrayValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass5 */

            public void run() {
                GLES20.glUniform4fv(location, 1, FloatBuffer.wrap(arrayValue));
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setFloatArray(final int location, final float[] arrayValue) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass6 */

            public void run() {
                int i = location;
                float[] fArr = arrayValue;
                GLES20.glUniform1fv(i, fArr.length, FloatBuffer.wrap(fArr));
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setPoint(final int location, final PointF point) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass7 */

            public void run() {
                GLES20.glUniform2fv(location, 1, new float[]{point.x, point.y}, 0);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setUniformMatrix3f(final int location, final float[] matrix) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass8 */

            public void run() {
                GLES20.glUniformMatrix3fv(location, 1, false, matrix, 0);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void setUniformMatrix4f(final int location, final float[] matrix) {
        runOnDraw(new Runnable() {
            /* class com.seu.magicfilter.base.gpuimage.GPUImageFilter.AnonymousClass9 */

            public void run() {
                GLES20.glUniformMatrix4fv(location, 1, false, matrix, 0);
            }
        });
    }

    /* access modifiers changed from: protected */
    public void runOnDraw(Runnable runnable) {
        synchronized (this.mRunOnDraw) {
            this.mRunOnDraw.addLast(runnable);
        }
    }
}
