package com.taobao.gcanvas;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Build;
import com.taobao.gcanvas.util.GLog;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class GCanvasJNI {
    public static boolean GCanvaslibEnable = false;
    static Map<String, Integer> contextTypeMap = new HashMap();
    static Map<String, Double> devicePixelRatioMap = new HashMap();
    static Map<String, Boolean> qualityMap = new HashMap();

    public static native void addFallbackFontFamily(String[] strArr);

    public static native void addFontFamily(String[] strArr, String[] strArr2);

    public static native void bindTexture(String str, Bitmap bitmap, int i, int i2, int i3, int i4, int i5, int i6);

    public static native String getImageData(String str, int i, int i2, int i3, int i4);

    public static native int getNativeFps(String str);

    public static native boolean isFboSupport(String str);

    public static native boolean isNeonSupport();

    public static native float measureText(String str, String str2);

    public static native void putImageData(String str, String str2, int i, int i2, int i3, int i4, int i5);

    public static native void registerCallback(String str, int i);

    public static native void release();

    public static native String render(String str, String str2, boolean z);

    public static native boolean sendEvent(String str);

    public static native void setBackgroundColor(String str, int i, int i2, int i3);

    public static native void setClearColor(String str, String str2);

    public static native void setConfig(String str, int i);

    public static native void setContextType(String str, int i);

    public static native void setDevicePixelRatio(String str, double d);

    public static native void setFallbackFont(String str, String str2);

    public static native void setHiQuality(String str, boolean z);

    public static native void setLogLevel(String str);

    public static native void setOrtho(String str, int i, int i2);

    public static native void setPreCompilePath(String str);

    public static native void setTyOffsetFlag(String str, boolean z);

    public static native void texSubImage2D(String str, Bitmap bitmap, int i, int i2, int i3, int i4, int i5, int i6, int i7);

    static {
        load();
    }

    public static void load() {
        if (!GCanvaslibEnable) {
            try {
                System.loadLibrary("freetype");
                System.loadLibrary("gcanvas");
                GCanvaslibEnable = true;
            } catch (UnsatisfiedLinkError e) {
                GLog.e(GLog.TAG, "gcanvas is not found.");
            } catch (Exception e2) {
                GLog.e(GLog.TAG, "fail to load gcanvas.");
            }
        }
    }

    public static void setWrapperDevicePixelRatio(String contextID, double ratio) {
        setDevicePixelRatio(contextID, ratio);
        devicePixelRatioMap.put(contextID, Double.valueOf(ratio));
    }

    public static void setWrapperContextType(String contextID, int type) {
        setContextType(contextID, type);
        contextTypeMap.put(contextID, Integer.valueOf(type));
    }

    public static void setWrapperHiQuality(String contextID, boolean isHiQuality) {
        setHiQuality(contextID, isHiQuality);
        qualityMap.put(contextID, Boolean.valueOf(isHiQuality));
    }

    public static void refreshArguments(String contextID) {
        Integer type = contextTypeMap.get(contextID);
        if (type != null) {
            setContextType(contextID, type.intValue());
        }
        Double ratio = devicePixelRatioMap.get(contextID);
        if (ratio != null) {
            setDevicePixelRatio(contextID, ratio.doubleValue());
        }
        Boolean isHiQuality = qualityMap.get(contextID);
        if (isHiQuality != null && isHiQuality.booleanValue()) {
            setHiQuality(contextID, isHiQuality.booleanValue());
        }
    }

    public static void registerWXCallNativeFunc(Context context) {
        String libraryPath = null;
        if (Build.VERSION.SDK_INT >= 24) {
            libraryPath = context.getApplicationInfo().nativeLibraryDir + "/libweexcore.so";
            GLog.i("start to load gcanvas library,path=" + libraryPath);
        }
        registerCallback(libraryPath, Build.VERSION.SDK_INT);
    }

    public static void setFontFamilies() {
        GFontConfigParser parser = new GFontConfigParser();
        setFallbackFont(parser.getFallbackFont(), parser.getSystemFontLocation());
        HashMap<List<String>, List<String>> fontFamilies = parser.getFontFamilies();
        if (fontFamilies != null) {
            GLog.d(GLog.TAG, "setFontFamilies() fontFamilies.size() " + fontFamilies.size());
        } else {
            GLog.d(GLog.TAG, "setFontFamilies() error! fontFamilies is empty");
        }
        if (fontFamilies != null) {
            for (List<String> fontNames : fontFamilies.keySet()) {
                int fontNameSize = fontNames.size();
                String[] fontNameArray = new String[fontNameSize];
                for (int i = 0; i < fontNameSize; i++) {
                    fontNameArray[i] = fontNames.get(i);
                }
                List<String> fontFiles = fontFamilies.get(fontNames);
                int fontFileSize = fontFiles.size();
                String[] fontFileArray = new String[fontFileSize];
                for (int i2 = 0; i2 < fontFileSize; i2++) {
                    fontFileArray[i2] = fontFiles.get(i2);
                }
                addFontFamily(fontNameArray, fontFileArray);
            }
        }
        List<String> fallbackfontFiles = parser.getFallbackFontsList();
        if (fallbackfontFiles != null) {
            int fallbackfontFileSize = fallbackfontFiles.size();
            String[] FallbackFileArray = new String[fallbackfontFileSize];
            for (int i3 = 0; i3 < fallbackfontFileSize; i3++) {
                FallbackFileArray[i3] = fallbackfontFiles.get(i3);
            }
            addFallbackFontFamily(FallbackFileArray);
        }
    }
}
