package com.taobao.gcanvas;

import android.app.Activity;
import org.json.JSONArray;
import org.json.JSONObject;

public class GCanvasResult<T> {
    protected Activity mActivity;
    protected String mCallbackId;
    protected int mChangingThreads;
    protected T mCustomData;
    protected boolean mFinished;
    protected ResultCode mResultCode;
    protected Listener mResultListener;
    protected Object mResultMessage;

    public interface Listener {
        void onCallJS(String str);

        void onResult(GCanvasResult gCanvasResult, ResultCode resultCode, Object obj);
    }

    public enum ResultCode {
        NO_RESULT,
        OK,
        ERROR
    }

    public Activity getActivity() {
        return this.mActivity;
    }

    public void setActivity(Activity act) {
        this.mActivity = act;
    }

    public GCanvasResult() {
        this.mResultCode = ResultCode.NO_RESULT;
        this.mActivity = null;
        this.mCallbackId = "";
    }

    public GCanvasResult(T data) {
        this.mResultCode = ResultCode.NO_RESULT;
        this.mActivity = null;
        this.mCustomData = data;
        this.mCallbackId = "";
    }

    public GCanvasResult(String callbackId, Listener listener) {
        this.mResultCode = ResultCode.NO_RESULT;
        this.mActivity = null;
        this.mCallbackId = callbackId;
        this.mResultListener = listener;
    }

    public ResultCode getResultCode() {
        return this.mResultCode;
    }

    public Object getResultMessage() {
        return this.mResultMessage;
    }

    public boolean isFinished() {
        return this.mFinished;
    }

    public boolean isChangingThreads() {
        return this.mChangingThreads > 0;
    }

    public String getCallbackId() {
        return this.mCallbackId;
    }

    public T getCustomData() {
        return this.mCustomData;
    }

    public void setResult(ResultCode result, Object message) {
        this.mResultCode = result;
        this.mResultMessage = message;
        onResult(result, message);
    }

    /* access modifiers changed from: protected */
    public void onResult(ResultCode resultCode, Object resultMessage) {
        Listener listener = this.mResultListener;
        if (listener != null) {
            listener.onResult(this, resultCode, resultMessage);
        }
    }

    /* access modifiers changed from: protected */
    public void onCallJS(String code) {
        Listener listener = this.mResultListener;
        if (listener != null) {
            listener.onCallJS(code);
        }
    }

    public void success(JSONObject message) {
        setResult(ResultCode.OK, message);
    }

    public void success(JSONArray message) {
        setResult(ResultCode.OK, message);
    }

    public void success(int message) {
        setResult(ResultCode.OK, Integer.valueOf(message));
    }

    public void success(String message) {
        setResult(ResultCode.OK, message);
    }

    public void success(boolean message) {
        setResult(ResultCode.OK, Boolean.valueOf(message));
    }

    public void success(float message) {
        setResult(ResultCode.OK, Float.valueOf(message));
    }

    public void success(Object message) {
        setResult(ResultCode.OK, message);
    }

    public void success() {
        setResult(ResultCode.OK, "");
    }

    public void error() {
        setResult(ResultCode.ERROR, "");
    }

    public void error(JSONObject message) {
        setResult(ResultCode.ERROR, message.toString());
    }

    public void error(String message) {
        setResult(ResultCode.ERROR, message);
    }

    public void error(Object message) {
        setResult(ResultCode.ERROR, message);
    }

    public void calljs(String code) {
        onCallJS(code);
    }
}
