package com.taobao.gcanvas;

import android.os.Build;
import android.util.Log;
import com.taobao.gcanvas.util.GLog;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.io.File;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class GFontConfigParser {
    private static final String FALLBACK_FONT = "DroidSansFallback.ttf";
    private static final String FALLBACK_FONTS_FILE = "/system/etc/fallback_fonts.xml";
    private static final String SYSTEM_FONTS_FILE = "/system/etc/system_fonts.xml";
    private static final String SYSTEM_FONTS_FILE_LOLLIPOP = "/system/etc/fonts.xml";
    private static final String SYSTEM_FONT_LOCATION = "/system/fonts/";
    private List<String> mFallbackFonts = null;
    private HashMap<List<String>, List<String>> mFontFamilies = null;
    private boolean mIsInitialized = false;

    public GFontConfigParser() {
        if (0 == 0) {
            readConfigFile();
            readFallbackConfigFile();
            this.mIsInitialized = true;
        }
    }

    public HashMap<List<String>, List<String>> getFontFamilies() {
        return this.mFontFamilies;
    }

    public List<String> getFallbackFontsList() {
        return this.mFallbackFonts;
    }

    public String getFallbackFont() {
        if (new File("/system/fonts/DroidSansFallbackBBK.ttf").exists()) {
            return "DroidSansFallbackBBK.ttf";
        }
        if (new File("/system/fonts/NotoSansHans-Regular.otf").exists()) {
            return "NotoSansHans-Regular.otf";
        }
        if (new File("/system/fonts/NotoSansSC-Regular.otf").exists()) {
            return "NotoSansSC-Regular.otf";
        }
        if (new File("/system/fonts/NotoSansCJK-Regular.ttc").exists()) {
            return "NotoSansCJK-Regular.ttc";
        }
        if (new File("/system/fonts/DroidSansFallback.ttf").exists()) {
            return FALLBACK_FONT;
        }
        return "DroidSans.ttf";
    }

    public String getSystemFontLocation() {
        return SYSTEM_FONT_LOCATION;
    }

    private void readFallbackConfigFile() {
        try {
            DocumentBuilder db = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            File file = new File(FALLBACK_FONTS_FILE);
            if (file.exists()) {
                parseFallbackXML(db.parse(file));
            }
        } catch (Exception e) {
            Log.e("GFontConfigParser", "readFallbackConfigFile " + e.getMessage());
        }
    }

    private void readConfigFile() {
        Document doc;
        try {
            DocumentBuilder db = DocumentBuilderFactory.newInstance().newDocumentBuilder();
            if (Build.VERSION.SDK_INT >= 21) {
                doc = db.parse(new File(SYSTEM_FONTS_FILE_LOLLIPOP));
            } else {
                doc = db.parse(new File(SYSTEM_FONTS_FILE));
            }
            parseXML(doc);
        } catch (Exception e) {
            GLog.e("GFontConfigParser", "readConfigFile exception:" + e.getMessage());
        }
    }

    private void parseXML(Document doc) throws Exception {
        Node familyNode;
        List<String> fileList;
        HashMap<List<String>, List<String>> hashMap = this.mFontFamilies;
        if (hashMap == null) {
            this.mFontFamilies = new HashMap<>();
        } else {
            hashMap.clear();
        }
        Element root = doc.getDocumentElement();
        if (!root.getTagName().equals("familyset")) {
            GLog.w("GFontConfigParser", "Can't find familyset.");
        } else if (Build.VERSION.SDK_INT >= 21) {
            List<String> aliasNameList = null;
            NodeList nodeList = root.getElementsByTagName("family");
            int length = nodeList.getLength();
            int i = 0;
            while (true) {
                if (i >= length) {
                    break;
                }
                Node familyNode2 = nodeList.item(i);
                NamedNodeMap n = familyNode2.getAttributes();
                Node s = familyNode2.getAttributes().getNamedItem("name");
                if (s == null) {
                    break;
                }
                NodeList fontNodes = ((Element) familyNode2).getElementsByTagName(AbsURIAdapter.FONT);
                if (fontNodes == null) {
                    GLog.w("GFontConfigParser", "nameset or fileset is invalid.");
                    break;
                }
                int namesetLength = fontNodes.getLength();
                List<String> nameList = new ArrayList<>();
                List<String> aliasNameList2 = aliasNameList;
                nameList.add(s.getNodeValue());
                List<String> fileList2 = new ArrayList<>();
                int j = 0;
                while (j < namesetLength) {
                    Node fileNode = fontNodes.item(j);
                    if (fileNode instanceof Element) {
                        fileList2.add(((Element) fileNode).getTextContent());
                    }
                    j++;
                    nodeList = nodeList;
                    length = length;
                }
                NodeList aliasList = root.getElementsByTagName("alias");
                int aliasLength = aliasList.getLength();
                int k = 0;
                while (true) {
                    if (k >= aliasLength) {
                        break;
                    }
                    Node aliasNode = aliasList.item(k);
                    Node nameA = aliasNode.getAttributes().getNamedItem("name");
                    Node toA = aliasNode.getAttributes().getNamedItem("to");
                    if (nameA == null || toA == null) {
                        break;
                    }
                    List<String> aliasNameList3 = new ArrayList<>();
                    for (String name : nameList) {
                        if (name.equals(toA.getNodeValue())) {
                            aliasNameList3.add(nameA.getNodeValue());
                        }
                        s = s;
                        n = n;
                    }
                    nameList.addAll(aliasNameList3);
                    k++;
                    aliasNameList2 = aliasNameList3;
                    aliasList = aliasList;
                    aliasLength = aliasLength;
                    familyNode2 = familyNode2;
                }
                this.mFontFamilies.put(nameList, fileList2);
                i++;
                aliasNameList = aliasNameList2;
                nodeList = nodeList;
                length = length;
            }
        } else {
            NodeList nodeList2 = root.getElementsByTagName("family");
            int length2 = nodeList2.getLength();
            int i2 = 0;
            while (i2 < length2) {
                Node familyNode3 = nodeList2.item(i2);
                Node namesetNode = null;
                Node filesetNode = null;
                if (familyNode3 instanceof Element) {
                    Element familyElement = (Element) familyNode3;
                    NodeList namesetNodes = familyElement.getElementsByTagName("nameset");
                    NodeList filesetNodes = familyElement.getElementsByTagName("fileset");
                    if (namesetNodes == null || filesetNodes == null || namesetNodes.getLength() != 1 || filesetNodes.getLength() != 1) {
                        GLog.w("GFontConfigParser", "nameset or fileset node doesn't exist.");
                        return;
                    } else {
                        namesetNode = namesetNodes.item(0);
                        filesetNode = filesetNodes.item(0);
                    }
                }
                if (namesetNode != null) {
                    if (filesetNode != null) {
                        NodeList nameset = namesetNode.getChildNodes();
                        NodeList fileset = filesetNode.getChildNodes();
                        if (nameset != null) {
                            if (fileset != null) {
                                int namesetLength2 = nameset.getLength();
                                int filesetLength = fileset.getLength();
                                List<String> nameList2 = new ArrayList<>();
                                List<String> fileList3 = new ArrayList<>();
                                int j2 = 0;
                                while (j2 < filesetLength) {
                                    Node fileNode2 = fileset.item(j2);
                                    if (fileNode2 instanceof Element) {
                                        Element fileElement = (Element) fileNode2;
                                        familyNode = familyNode3;
                                        if (fileElement.getTagName().equals("file")) {
                                            fileList = fileList3;
                                            fileList.add(fileElement.getTextContent());
                                        } else {
                                            fileList = fileList3;
                                        }
                                    } else {
                                        familyNode = familyNode3;
                                        fileList = fileList3;
                                    }
                                    j2++;
                                    fileList3 = fileList;
                                    nodeList2 = nodeList2;
                                    length2 = length2;
                                    familyNode3 = familyNode;
                                }
                                for (int j3 = 0; j3 < namesetLength2; j3++) {
                                    Node nameNode = nameset.item(j3);
                                    if (nameNode instanceof Element) {
                                        Element nameElement = (Element) nameNode;
                                        if (nameElement.getTagName().equals("name")) {
                                            nameList2.add(nameElement.getTextContent());
                                        }
                                    }
                                }
                                this.mFontFamilies.put(nameList2, fileList3);
                                i2++;
                                nodeList2 = nodeList2;
                                root = root;
                                length2 = length2;
                            }
                        }
                        GLog.w("GFontConfigParser", "nameset or fileset is empty.");
                        return;
                    }
                }
                GLog.w("GFontConfigParser", "nameset or fileset is invalid.");
                return;
            }
        }
    }

    private void parseFallbackXML(Document doc) throws Exception {
        List<String> list = this.mFallbackFonts;
        if (list == null) {
            this.mFallbackFonts = new ArrayList();
        } else {
            list.clear();
        }
        Element root = doc.getDocumentElement();
        if (!root.getTagName().equals("familyset")) {
            GLog.w("GFontConfigParser", "Can't find familyset.");
            return;
        }
        NodeList nodeList = root.getElementsByTagName("family");
        int length = nodeList.getLength();
        for (int i = 0; i < length; i++) {
            Node familyNode = nodeList.item(i);
            Node filesetNode = null;
            if (familyNode instanceof Element) {
                NodeList filesetNodes = ((Element) familyNode).getElementsByTagName("fileset");
                if (filesetNodes == null || filesetNodes.getLength() != 1) {
                    GLog.w("GFontConfigParser", "nameset or fileset node doesn't exist.");
                    return;
                }
                filesetNode = filesetNodes.item(0);
            }
            if (filesetNode == null) {
                GLog.w("GFontConfigParser", "nameset or fileset is invalid.");
                return;
            }
            NodeList fileset = filesetNode.getChildNodes();
            if (fileset == null) {
                GLog.w("GFontConfigParser", "nameset or fileset is empty.");
                return;
            }
            int filesetLength = fileset.getLength();
            for (int j = 0; j < filesetLength; j++) {
                Node fileNode = fileset.item(j);
                if (fileNode instanceof Element) {
                    Element fileElement = (Element) fileNode;
                    if (fileElement.getTagName().equals("file")) {
                        this.mFallbackFonts.add(fileElement.getTextContent());
                    }
                }
            }
        }
    }
}
