package com.taobao.gcanvas.adapters.img.impl.fresco;

import android.content.Context;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;
import com.facebook.common.executors.CallerThreadExecutor;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.DataSource;
import com.facebook.datasource.DataSubscriber;
import com.facebook.drawee.backends.pipeline.DraweeConfig;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.imagepipeline.common.RotationOptions;
import com.facebook.imagepipeline.core.ImagePipelineConfig;
import com.facebook.imagepipeline.image.CloseableBitmap;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.taobao.gcanvas.adapters.img.IGImageLoader;

public class GCanvasFrescoImageLoader implements IGImageLoader {
    private static final String TAG = GCanvasFrescoImageLoader.class.getSimpleName();
    private DraweeConfig draweeConfig;
    private ImagePipelineConfig imagePipelineConfig;
    private Handler mHandler;

    public GCanvasFrescoImageLoader() {
        this(null, null);
    }

    public GCanvasFrescoImageLoader(DraweeConfig draweeConfig2) {
        this(null, draweeConfig2);
    }

    public GCanvasFrescoImageLoader(ImagePipelineConfig imagePipelineConfig2) {
        this(imagePipelineConfig2, null);
    }

    public GCanvasFrescoImageLoader(ImagePipelineConfig imagePipelineConfig2, DraweeConfig draweeConfig2) {
        this.imagePipelineConfig = imagePipelineConfig2;
        this.draweeConfig = draweeConfig2;
    }

    @Override // com.taobao.gcanvas.adapters.img.IGImageLoader
    public void load(Context context, String url, IGImageLoader.ImageCallback callback) {
        if (TextUtils.isEmpty(url)) {
            Log.i(TAG, "url is null or empty");
            return;
        }
        if (!Fresco.hasBeenInitialized()) {
            Log.i(TAG, "fresco not init, do initialization");
            Fresco.initialize(context, this.imagePipelineConfig, this.draweeConfig);
        }
        ImageLoadRunnable runnable = new ImageLoadRunnable(context, url, callback);
        if (Looper.myLooper() != Looper.getMainLooper()) {
            if (this.mHandler == null) {
                this.mHandler = new Handler(Looper.getMainLooper());
            }
            this.mHandler.post(runnable);
            return;
        }
        runnable.run();
    }

    private static class ImageLoadRunnable implements Runnable {
        private final IGImageLoader.ImageCallback callback;
        private Context context;
        private String url;

        public ImageLoadRunnable(Context context2, String url2, IGImageLoader.ImageCallback callback2) {
            this.context = context2;
            this.url = url2;
            this.callback = callback2;
        }

        public void run() {
            DataSource<CloseableReference<CloseableImage>> ds;
            Uri uri = Uri.parse(this.url);
            ImageRequestBuilder builder = ImageRequestBuilder.newBuilderWithSource(uri);
            builder.setAutoRotateEnabled(false);
            builder.setRotationOptions(RotationOptions.disableRotation());
            ImageRequest request = builder.build();
            if (Fresco.getImagePipeline().isInBitmapMemoryCache(uri)) {
                ds = Fresco.getImagePipeline().fetchImageFromBitmapCache(request, this);
            } else {
                ds = Fresco.getImagePipeline().fetchDecodedImage(request, this);
            }
            ds.subscribe(new DataSubscriber<CloseableReference<CloseableImage>>() {
                /* class com.taobao.gcanvas.adapters.img.impl.fresco.GCanvasFrescoImageLoader.ImageLoadRunnable.AnonymousClass1 */

                @Override // com.facebook.datasource.DataSubscriber
                public void onNewResult(DataSource<CloseableReference<CloseableImage>> dataSource) {
                    CloseableReference<CloseableImage> ref;
                    if (dataSource.isFinished() && (ref = dataSource.getResult()) != null) {
                        try {
                            CloseableImage result = ref.get();
                            if (result instanceof CloseableBitmap) {
                                ImageLoadRunnable.this.callback.onSuccess(((CloseableBitmap) result).getUnderlyingBitmap());
                            } else {
                                byte[] array = new byte[result.getSizeInBytes()];
                                ImageLoadRunnable.this.callback.onSuccess(BitmapFactory.decodeByteArray(array, 0, array.length));
                            }
                        } catch (Throwable th) {
                            CloseableReference.closeSafely(ref);
                            throw th;
                        }
                        CloseableReference.closeSafely(ref);
                    }
                }

                @Override // com.facebook.datasource.DataSubscriber
                public void onFailure(DataSource<CloseableReference<CloseableImage>> dataSource) {
                    ImageLoadRunnable.this.callback.onFail(dataSource.getFailureCause() != null ? dataSource.getFailureCause().getMessage() : null);
                }

                @Override // com.facebook.datasource.DataSubscriber
                public void onCancellation(DataSource<CloseableReference<CloseableImage>> dataSource) {
                    ImageLoadRunnable.this.callback.onCancel();
                }

                @Override // com.facebook.datasource.DataSubscriber
                public void onProgressUpdate(DataSource<CloseableReference<CloseableImage>> dataSource) {
                }
            }, CallerThreadExecutor.getInstance());
        }
    }
}
