package com.taobao.gcanvas.audio;

import android.app.Activity;
import android.content.Context;
import android.database.ContentObserver;
import android.media.AudioManager;
import android.os.Handler;
import android.provider.Settings;
import com.taobao.gcanvas.GCanvasResult;
import com.taobao.gcanvas.GCanvasWebView;
import com.taobao.gcanvas.audio.GAudioPlayer;
import com.taobao.gcanvas.util.GLog;
import io.dcloud.common.adapter.util.DeviceInfo;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import org.json.JSONArray;
import org.json.JSONException;

public class GAudioHandler {
    public static String TAG = GAudioHandler.class.getName();
    private Activity activity;
    private ArrayList<GAudioPlayer> pausedForPhone = new ArrayList<>();
    private HashMap<String, GAudioPlayer> players = new HashMap<>();
    private VolumeObserver volumeObserver = null;
    private GCanvasWebView webView;

    public static String stripFileProtocol(String uriString) {
        if (uriString.startsWith(DeviceInfo.FILE_PROTOCOL)) {
            return uriString.substring(7);
        }
        return uriString;
    }

    public void initialize(Context context, GCanvasWebView webView2) {
        if (context instanceof Activity) {
            this.activity = (Activity) context;
        }
        this.webView = webView2;
    }

    public Activity getActivity() {
        return this.activity;
    }

    public GCanvasWebView getWebView() {
        return this.webView;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private HashMap<String, GAudioPlayer> getPlayers() {
        return this.players;
    }

    public boolean execute(String action, JSONArray args, GCanvasResult resultContext) throws JSONException {
        if (action == null) {
            GLog.e(GLog.TAG, " ~ GAutioHandler ::: action is null");
            return false;
        }
        if (action.equals("startRecordingAudio")) {
            startRecordingAudio(args.getString(0), stripFileProtocol(args.getString(1)), resultContext);
        } else if (action.equals("stopRecordingAudio")) {
            stopRecordingAudio(args.getString(0));
        } else if (action.equals("startPlayingAudio")) {
            startPlayingAudio(args.getString(0), stripFileProtocol(args.getString(1)), resultContext);
        } else if (action.equals("seekToAudio")) {
            seekToAudio(args.getString(0), args.getInt(1));
        } else if (action.equals("pausePlayingAudio")) {
            pausePlayingAudio(args.getString(0));
        } else if (action.equals("stopPlayingAudio")) {
            stopPlayingAudio(args.getString(0));
        } else if (action.equals("setVolume")) {
            try {
                setVolume(args.getString(0), Float.parseFloat(args.getString(1)));
            } catch (NumberFormatException e) {
            }
        } else if (action.equals("getCurrentPositionAudio")) {
            resultContext.success(getCurrentPositionAudio(args.getString(0)));
            return true;
        } else if (action.equals("getDurationAudio")) {
            resultContext.success(getDurationAudio(args.getString(0), args.getString(1), resultContext));
            return true;
        } else if (action.equals("create")) {
            String id = args.getString(0);
            this.players.put(id, new GAudioPlayer(this, id, stripFileProtocol(args.getString(1)), resultContext));
        } else if (action.equals("release")) {
            resultContext.success(release(args.getString(0)));
            return true;
        } else if (action.equals("disable")) {
            onDestroy();
            return true;
        } else if (action.equals("setSourceAudio")) {
            String id2 = args.getString(0);
            String src = stripFileProtocol(args.getString(1));
            GAudioPlayer audio = this.players.get(id2);
            if (audio == null || src.isEmpty()) {
                GLog.e(GLog.TAG, "audio's id error");
                return false;
            }
            audio.setSourceAudio(src);
        } else if (!action.equals("startLoadingAudio")) {
            return false;
        } else {
            startLoadingAudio(args.getString(0));
        }
        resultContext.success("");
        return true;
    }

    private boolean release(String id) {
        if (!this.players.containsKey(id)) {
            return false;
        }
        this.players.remove(id);
        this.players.get(id).destroy();
        return true;
    }

    public void onReset() {
        onDestroy();
    }

    public void onDestroy() {
        for (GAudioPlayer audio : this.players.values()) {
            audio.destroy();
        }
        if (this.volumeObserver != null) {
            this.activity.getContentResolver().unregisterContentObserver(this.volumeObserver);
        }
        this.players.clear();
    }

    public Object onMessage(String id, Object data) {
        if (id.equals("telephone")) {
            if ("ringing".equals(data) || "offhook".equals(data)) {
                for (GAudioPlayer audio : this.players.values()) {
                    if (audio.getState() == GAudioPlayer.STATE.MEDIA_RUNNING.ordinal()) {
                        this.pausedForPhone.add(audio);
                        audio.pausePlaying();
                    }
                }
            } else if ("idle".equals(data)) {
                Iterator<GAudioPlayer> it = this.pausedForPhone.iterator();
                while (it.hasNext()) {
                    it.next().startPlaying(null);
                }
                this.pausedForPhone.clear();
            }
        }
        return null;
    }

    public void startRecordingAudio(String id, String file, GCanvasResult resultContext) {
        GAudioPlayer audio = this.players.get(id);
        if (audio == null) {
            audio = new GAudioPlayer(this, id, file, resultContext);
            this.players.put(id, audio);
        }
        audio.startRecording(file);
    }

    public void stopRecordingAudio(String id) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.stopRecording();
        }
    }

    public void startPlayingAudio(String id, String file, GCanvasResult resultContext) {
        GAudioPlayer audio = this.players.get(id);
        if (audio == null) {
            audio = new GAudioPlayer(this, id, file, resultContext);
            this.players.put(id, audio);
        }
        audio.startPlaying(file);
        if (Settings.System.getInt(this.activity.getContentResolver(), "mode_ringer", 2) != 2) {
            audio.setVolume(0.0f);
        } else {
            audio.setVolume(1.0f);
        }
    }

    public void seekToAudio(String id, int milliseconds) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.seekToPlaying(milliseconds);
        }
    }

    public void pausePlayingAudio(String id) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.pausePlaying();
        }
    }

    public void stopPlayingAudio(String id) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.stopPlaying();
        }
    }

    public void startLoadingAudio(String id) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.loadingAudio();
        }
    }

    public float getCurrentPositionAudio(String id) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            return ((float) audio.getCurrentPosition()) / 1000.0f;
        }
        return -1.0f;
    }

    public float getDurationAudio(String id, String file, GCanvasResult resultContext) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            return audio.getDuration(file);
        }
        GAudioPlayer audio2 = new GAudioPlayer(this, id, file, resultContext);
        this.players.put(id, audio2);
        return audio2.getDuration(file);
    }

    public int getAudioOutputDevice() {
        AudioManager audiMgr = (AudioManager) this.activity.getSystemService("audio");
        if (audiMgr.getRouting(0) == 1) {
            return 1;
        }
        if (audiMgr.getRouting(0) == 2) {
            return 2;
        }
        return -1;
    }

    public void setAudioOutputDevice(int output) {
        AudioManager audiMgr = (AudioManager) this.activity.getSystemService("audio");
        if (output == 2) {
            audiMgr.setRouting(0, 2, -1);
        } else if (output == 1) {
            audiMgr.setRouting(0, 1, -1);
        } else {
            GLog.w("AudioHandler setAudioOutputDevice Error: Unknown output device.");
        }
    }

    public void setVolume(String id, float volume) {
        GAudioPlayer audio = this.players.get(id);
        if (audio != null) {
            audio.setVolume(volume);
            return;
        }
        GLog.w("AudioHandler setVolume Error: Unknown Audio Player " + id);
    }

    /* access modifiers changed from: private */
    public static class VolumeObserver extends ContentObserver {
        private final WeakReference<GAudioHandler> mGAudioHandlerRef;

        public VolumeObserver(GAudioHandler gAudioHandler, Handler handler) {
            super(handler);
            this.mGAudioHandlerRef = new WeakReference<>(gAudioHandler);
        }

        public void onChange(boolean selfChange) {
            super.onChange(selfChange);
            GAudioHandler audioHandler = this.mGAudioHandlerRef.get();
            if (audioHandler == null) {
                return;
            }
            if (Settings.System.getInt(audioHandler.getActivity().getContentResolver(), "mode_ringer", 2) != 2) {
                for (String i : audioHandler.getPlayers().keySet()) {
                    ((GAudioPlayer) audioHandler.getPlayers().get(i)).setVolume(0.0f);
                }
                return;
            }
            for (String i2 : audioHandler.getPlayers().keySet()) {
                ((GAudioPlayer) audioHandler.getPlayers().get(i2)).setVolume(1.0f);
            }
        }
    }
}
