package com.taobao.gcanvas.audio;

import android.content.res.AssetFileDescriptor;
import android.media.MediaPlayer;
import android.media.MediaRecorder;
import android.os.Environment;
import com.taobao.gcanvas.GCanvasResult;
import com.taobao.gcanvas.util.GLog;
import io.dcloud.common.adapter.util.DeviceInfo;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

public class GAudioPlayer implements MediaPlayer.OnCompletionListener, MediaPlayer.OnPreparedListener, MediaPlayer.OnErrorListener {
    private static final String LOG_TAG = "GAudioPlayer";
    private static int MEDIA_DURATION = 2;
    private static int MEDIA_ERROR = 9;
    private static int MEDIA_ERR_ABORTED = 1;
    private static int MEDIA_ERR_DECODE = 3;
    private static int MEDIA_ERR_NETWORK = 2;
    private static int MEDIA_ERR_NONE_ACTIVE = 0;
    private static int MEDIA_ERR_NONE_SUPPORTED = 4;
    private static int MEDIA_POSITION = 3;
    private static int MEDIA_READY = 4;
    private static int MEDIA_STATE = 1;
    private String audioFile = null;
    private float duration = -1.0f;
    private GAudioHandler handler;
    private String id;
    private MODE mode = MODE.NONE;
    private MediaPlayer player = null;
    private boolean prepareOnly = true;
    private MediaRecorder recorder = null;
    private int recorderCount = 0;
    private GCanvasResult resultContext;
    private int seekOnPrepared = 0;
    private STATE state = STATE.MEDIA_NONE;
    private String tempFile = null;

    public enum MODE {
        NONE,
        PLAY,
        RECORD
    }

    public enum STATE {
        MEDIA_NONE,
        MEDIA_STARTING,
        MEDIA_RUNNING,
        MEDIA_PAUSED,
        MEDIA_STOPPED,
        MEDIA_LOADING
    }

    public GAudioPlayer(GAudioHandler handler2, String id2, String file, GCanvasResult resultContext2) {
        this.handler = handler2;
        this.id = id2;
        this.audioFile = file;
        this.recorder = new MediaRecorder();
        this.resultContext = resultContext2;
        if (Environment.getExternalStorageState().equals("mounted")) {
            this.tempFile = Environment.getExternalStorageDirectory().getAbsolutePath() + "/tmprecording.3gp";
            return;
        }
        this.tempFile = "/data/data/" + handler2.getActivity().getPackageName() + "/cache/tmprecording.3gp";
    }

    public void setSourceAudio(String file) {
        this.audioFile = file;
    }

    private void sendJavascript(String js) {
        GCanvasResult gCanvasResult = this.resultContext;
        if (gCanvasResult != null) {
            gCanvasResult.calljs(js);
        }
    }

    public void startRecording(String file) {
        int i = AnonymousClass1.$SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE[this.mode.ordinal()];
        if (i == 1) {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
        } else if (i == 2) {
            this.audioFile = file;
            this.recorder.setOutputFormat(0);
            this.recorder.setAudioEncoder(0);
            this.recorder.setOutputFile(this.tempFile);
            try {
                this.recorder.prepare();
                this.recorder.start();
                setState(STATE.MEDIA_RUNNING);
                this.recorderCount++;
            } catch (IllegalStateException e) {
                e.printStackTrace();
                sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
            } catch (IOException e2) {
                e2.printStackTrace();
                sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
            }
        } else if (i == 3) {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
        }
    }

    public void moveFile(String file) {
        File f = new File(this.tempFile);
        if (!file.startsWith("/")) {
            if (Environment.getExternalStorageState().equals("mounted")) {
                file = Environment.getExternalStorageDirectory().getAbsolutePath() + File.separator + file;
            } else {
                file = "/data/data/" + this.handler.getActivity().getPackageName() + "/cache/" + file;
            }
        }
        if (!f.renameTo(new File(file))) {
            GLog.e(LOG_TAG, "FAILED " + ("renaming " + this.tempFile + " to " + file));
        }
    }

    public void stopRecording() {
        if (this.recorder != null && this.recorderCount > 0) {
            try {
                if (this.state == STATE.MEDIA_RUNNING) {
                    this.recorder.stop();
                    setState(STATE.MEDIA_STOPPED);
                }
                this.recorderCount--;
                this.recorder.reset();
                moveFile(this.audioFile);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void startPlaying(String file) {
        MediaPlayer mediaPlayer;
        if (!readyPlayer(file) || (mediaPlayer = this.player) == null) {
            this.prepareOnly = false;
            return;
        }
        mediaPlayer.start();
        setState(STATE.MEDIA_RUNNING);
        this.seekOnPrepared = 0;
    }

    public void seekToPlaying(int milliseconds) {
        if (readyPlayer(this.audioFile)) {
            this.player.seekTo(milliseconds);
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_POSITION + ", " + (((float) milliseconds) / 1000.0f) + ");");
            return;
        }
        this.seekOnPrepared = milliseconds;
    }

    public void loadingAudio() {
        if (readyPlayer(this.audioFile)) {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_READY + ");");
        }
    }

    public void pausePlaying() {
        MediaPlayer mediaPlayer;
        if (this.state != STATE.MEDIA_RUNNING || (mediaPlayer = this.player) == null) {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_NONE_ACTIVE + "});");
            return;
        }
        mediaPlayer.pause();
        setState(STATE.MEDIA_PAUSED);
    }

    public void stopPlaying() {
        if (this.state == STATE.MEDIA_RUNNING || this.state == STATE.MEDIA_PAUSED) {
            this.player.pause();
            this.player.seekTo(0);
            setState(STATE.MEDIA_STOPPED);
            return;
        }
        sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_NONE_ACTIVE + "});");
    }

    public void onCompletion(MediaPlayer player2) {
        setState(STATE.MEDIA_STOPPED);
    }

    public long getCurrentPosition() {
        if (this.state != STATE.MEDIA_RUNNING && this.state != STATE.MEDIA_PAUSED) {
            return -1;
        }
        int curPos = this.player.getCurrentPosition();
        sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_POSITION + ", " + (((float) curPos) / 1000.0f) + ");");
        return (long) curPos;
    }

    public boolean isStreaming(String file) {
        if (file.contains(DeviceInfo.HTTP_PROTOCOL) || file.contains(DeviceInfo.HTTPS_PROTOCOL)) {
            return true;
        }
        return false;
    }

    public float getDuration(String file) {
        if (this.recorder != null) {
            return -2.0f;
        }
        if (this.player != null) {
            return this.duration;
        }
        this.prepareOnly = true;
        startPlaying(file);
        return this.duration;
    }

    public void onPrepared(MediaPlayer player2) {
        this.player.setOnCompletionListener(this);
        seekToPlaying(this.seekOnPrepared);
        if (!this.prepareOnly) {
            this.player.start();
            setState(STATE.MEDIA_RUNNING);
            this.seekOnPrepared = 0;
        } else {
            setState(STATE.MEDIA_STARTING);
        }
        this.duration = getDurationInSeconds();
        this.prepareOnly = true;
        sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_DURATION + "," + this.duration + ");");
    }

    private float getDurationInSeconds() {
        return ((float) this.player.getDuration()) / 1000.0f;
    }

    public boolean onError(MediaPlayer player2, int arg1, int arg2) {
        this.player.stop();
        this.player.release();
        sendJavascript("Media.onStatus('" + this.id + "', { \"code\":" + arg1 + "});");
        return false;
    }

    private void setMode(MODE mode2) {
        this.mode = mode2;
    }

    public int getState() {
        return this.state.ordinal();
    }

    private void setState(STATE state2) {
        if (this.state != state2) {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_STATE + ", " + state2.ordinal() + ");");
        }
        this.state = state2;
    }

    public void setVolume(float volume) {
        MediaPlayer mediaPlayer = this.player;
        if (mediaPlayer != null) {
            mediaPlayer.setVolume(volume, volume);
        }
    }

    public void destroy() {
        if (this.player != null) {
            if (this.state == STATE.MEDIA_RUNNING || this.state == STATE.MEDIA_PAUSED) {
                this.player.stop();
                setState(STATE.MEDIA_STOPPED);
            }
            this.player.release();
            this.player = null;
        }
        if (this.recorder != null) {
            stopRecording();
            this.recorder.release();
            this.recorder = null;
        }
    }

    private boolean playMode() {
        int i = AnonymousClass1.$SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE[this.mode.ordinal()];
        if (i == 2) {
            setMode(MODE.PLAY);
            return true;
        } else if (i != 3) {
            return true;
        } else {
            sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
            return false;
        }
    }

    /* access modifiers changed from: package-private */
    /* renamed from: com.taobao.gcanvas.audio.GAudioPlayer$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE;
        static final /* synthetic */ int[] $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE;

        static {
            int[] iArr = new int[STATE.values().length];
            $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE = iArr;
            try {
                iArr[STATE.MEDIA_NONE.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[STATE.MEDIA_LOADING.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[STATE.MEDIA_STARTING.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[STATE.MEDIA_RUNNING.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[STATE.MEDIA_PAUSED.ordinal()] = 5;
            } catch (NoSuchFieldError e5) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[STATE.MEDIA_STOPPED.ordinal()] = 6;
            } catch (NoSuchFieldError e6) {
            }
            int[] iArr2 = new int[MODE.values().length];
            $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE = iArr2;
            try {
                iArr2[MODE.PLAY.ordinal()] = 1;
            } catch (NoSuchFieldError e7) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE[MODE.NONE.ordinal()] = 2;
            } catch (NoSuchFieldError e8) {
            }
            try {
                $SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$MODE[MODE.RECORD.ordinal()] = 3;
            } catch (NoSuchFieldError e9) {
            }
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private boolean readyPlayer(String file) {
        if (playMode()) {
            switch (AnonymousClass1.$SwitchMap$com$taobao$gcanvas$audio$GAudioPlayer$STATE[this.state.ordinal()]) {
                case 1:
                    if (this.player == null) {
                        this.player = new MediaPlayer();
                    }
                    try {
                        loadAudioFile(file);
                    } catch (Exception e) {
                        sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
                    }
                    return false;
                case 2:
                    this.prepareOnly = false;
                    return false;
                case 3:
                case 4:
                case 5:
                    return true;
                case 6:
                    if (this.audioFile.compareTo(file) == 0) {
                        this.player.seekTo(0);
                        this.player.pause();
                        return true;
                    }
                    this.player.reset();
                    try {
                        loadAudioFile(file);
                    } catch (Exception e2) {
                        sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
                    }
                    return false;
                default:
                    sendJavascript("Media.onStatus('" + this.id + "', " + MEDIA_ERROR + ", { \"code\":" + MEDIA_ERR_ABORTED + "});");
                    break;
            }
        }
        return false;
    }

    private void loadAudioFile(String file) throws IllegalArgumentException, SecurityException, IllegalStateException, IOException {
        if (isStreaming(file)) {
            this.player.setDataSource(file);
            this.player.setAudioStreamType(3);
            setMode(MODE.PLAY);
            setState(STATE.MEDIA_STARTING);
            this.player.setOnPreparedListener(this);
            this.player.prepareAsync();
            return;
        }
        if (file.startsWith("/android_asset/")) {
            AssetFileDescriptor fd = this.handler.getActivity().getAssets().openFd(file.substring(15));
            this.player.setDataSource(fd.getFileDescriptor(), fd.getStartOffset(), fd.getLength());
        } else if (new File(file).exists()) {
            FileInputStream fileInputStream = new FileInputStream(file);
            this.player.setDataSource(fileInputStream.getFD());
            fileInputStream.close();
        } else {
            throw new IOException();
        }
        setState(STATE.MEDIA_STARTING);
        this.player.setOnPreparedListener(this);
        this.player.prepare();
        this.duration = getDurationInSeconds();
    }
}
