package com.taobao.gcanvas.bridges.spec.module;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.text.TextUtils;
import android.util.Log;
import com.taobao.gcanvas.GCanvasJNI;
import com.taobao.gcanvas.adapters.img.IGImageLoader;
import com.taobao.gcanvas.bridges.spec.bridge.IJSCallbackDataFactory;
import com.taobao.gcanvas.bridges.spec.bridge.IJSCallbackMap;
import com.taobao.gcanvas.util.GLog;
import com.umeng.analytics.pro.cv;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.concurrent.atomic.AtomicBoolean;
import org.json.JSONArray;
import org.json.JSONException;

public abstract class AbsGBridgeModule<JSCallback> implements IGBridgeModule<JSCallback> {
    public static final String TAG = AbsGBridgeModule.class.getSimpleName();
    protected HashMap<String, ArrayList<JSCallback>> mCallbacks = new HashMap<>();
    protected HashMap<String, GImageLoadInfo> mImageIdCache = new HashMap<>();
    protected IGImageLoader mImageLoader;

    public abstract Context getContext();

    /* access modifiers changed from: protected */
    public abstract IJSCallbackDataFactory getDataFactory();

    /* access modifiers changed from: protected */
    public abstract void invokeCallback(JSCallback jscallback, Object obj);

    public void setImageLoader(IGImageLoader mImageLoader2) {
        this.mImageLoader = mImageLoader2;
    }

    private static abstract class AbsImageCallback implements IGImageLoader.ImageCallback {
        final AtomicBoolean finished;
        private final Object sync;

        /* access modifiers changed from: protected */
        public abstract void doSuccessAction(Bitmap bitmap);

        private AbsImageCallback() {
            this.sync = new Object();
            this.finished = new AtomicBoolean(false);
        }

        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
        public void onSuccess(Bitmap bitmap) {
            doSuccessAction(bitmap);
            synchronized (this.sync) {
                this.sync.notifyAll();
                this.finished.set(true);
            }
        }

        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
        public void onFail(Object error) {
            synchronized (this.sync) {
                this.sync.notifyAll();
                this.finished.set(true);
            }
        }

        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
        public void onCancel() {
            synchronized (this.sync) {
                this.sync.notifyAll();
                this.finished.set(true);
            }
        }

        /* access modifiers changed from: protected */
        public void waitTillFinish() {
            synchronized (this.sync) {
                while (!this.finished.get()) {
                    try {
                        this.sync.wait();
                    } catch (InterruptedException e) {
                    }
                }
            }
        }
    }

    @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
    public void bindImageTexture(final String canvasId, final String src, final int id, final JSCallback callback) {
        if (!TextUtils.isEmpty(src)) {
            try {
                if (src.startsWith("data:image")) {
                    Bitmap bmp = handleBase64Texture(src.substring(src.indexOf("base64,") + "base64,".length()));
                    if (bmp != null) {
                        GCanvasJNI.bindTexture(canvasId, bmp, 0, 3553, 0, 6408, 6408, 5121);
                    } else {
                        GLog.d("decode base64 texture failed,bitmap is null.");
                    }
                    return;
                }
                final IJSCallbackMap callbackMap = getDataFactory().createJSCallbackMap();
                AbsImageCallback imgCb = new AbsImageCallback() {
                    /* class com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AnonymousClass1 */

                    /* access modifiers changed from: protected */
                    @Override // com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AbsImageCallback
                    public void doSuccessAction(Bitmap bitmap) {
                        if (bitmap != null) {
                            GCanvasJNI.bindTexture(canvasId, bitmap, id, 3553, 0, 6408, 6408, 5121);
                        } else {
                            GLog.d("bitmap is null in teximage2D.");
                        }
                        if (callback != null && bitmap != null) {
                            callbackMap.putString("url", src);
                            callbackMap.putInt("width", bitmap.getWidth());
                            callbackMap.putInt("height", bitmap.getHeight());
                        }
                    }
                };
                this.mImageLoader.load(getContext(), src, imgCb);
                imgCb.waitTillFinish();
                invokeCallback(callback, callbackMap);
            } catch (Throwable e) {
                GLog.e(TAG, e.getMessage(), e);
            }
        }
    }

    @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
    public void setLogLevel(int level) {
        String logLevel = "debug";
        if (level == 0) {
            logLevel = "debug";
        } else if (level == 1) {
            logLevel = "info";
        } else if (level == 2) {
            logLevel = "warn";
        } else if (level == 3) {
            logLevel = "error";
        }
        GCanvasJNI.setLogLevel(logLevel);
    }

    @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
    public void texSubImage2D(final String canvasid, final int target, final int level, final int xoffset, final int yoffset, final int format, final int type, String path) {
        if (!TextUtils.isEmpty(path)) {
            try {
                if (path.startsWith("data:image")) {
                    Bitmap bmp = handleBase64Texture(path.substring(path.indexOf("base64," + "base64,".length())));
                    if (bmp != null) {
                        GCanvasJNI.texSubImage2D(canvasid, bmp, 0, target, level, xoffset, yoffset, format, type);
                    } else {
                        GLog.d("[texSubImage2D] decode base64 texture failed,bitmap is null.");
                    }
                    return;
                }
                AbsImageCallback imgCb = new AbsImageCallback() {
                    /* class com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AnonymousClass2 */

                    /* access modifiers changed from: protected */
                    @Override // com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AbsImageCallback
                    public void doSuccessAction(Bitmap bitmap) {
                        if (bitmap != null) {
                            GLog.d("[texSubImage2D] start to bindtexture in 3dmodule.");
                            GCanvasJNI.texSubImage2D(canvasid, bitmap, 0, target, level, xoffset, yoffset, format, type);
                            return;
                        }
                        GLog.d("[texSubImage2D] bitmap is null.");
                    }
                };
                this.mImageLoader.load(getContext(), path, imgCb);
                imgCb.waitTillFinish();
            } catch (Throwable e) {
                GLog.e(TAG, e.getMessage(), e);
            }
        }
    }

    @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
    public void texImage2D(final String canvasId, final int target, final int level, final int internalformat, final int format, final int type, String path) {
        if (!TextUtils.isEmpty(path)) {
            try {
                if (path.startsWith("data:image")) {
                    Bitmap bmp = handleBase64Texture(path.substring(path.indexOf("base64,") + "base64,".length()));
                    if (bmp != null) {
                        GCanvasJNI.bindTexture(canvasId, bmp, 0, target, level, internalformat, format, type);
                    } else {
                        GLog.d("decode base64 texture failed,bitmap is null.");
                    }
                    return;
                }
                AbsImageCallback imgCb = new AbsImageCallback() {
                    /* class com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AnonymousClass3 */

                    /* access modifiers changed from: protected */
                    @Override // com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AbsImageCallback
                    public void doSuccessAction(Bitmap bitmap) {
                        if (bitmap != null) {
                            GCanvasJNI.bindTexture(canvasId, bitmap, 0, target, level, internalformat, format, type);
                        } else {
                            GLog.d("bitmap is null in teximage2D.");
                        }
                    }
                };
                this.mImageLoader.load(getContext(), path, imgCb);
                imgCb.waitTillFinish();
            } catch (Throwable e) {
                GLog.e(TAG, e.getMessage(), e);
            }
        }
    }

    @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
    public void preLoadImage(JSONArray arrayPara, final JSCallback callback) {
        ArrayList<JSCallback> callbacks;
        IJSCallbackMap result = getDataFactory().createJSCallbackMap();
        if (arrayPara == null || arrayPara.length() != 2) {
            result.putString("error", "invalid input param. specify an json array which length is 2, and index 0 is url to load, index 1 is image id.");
            invokeCallback(callback, result);
            return;
        }
        try {
            final String url = arrayPara.getString(0);
            final int imageId = arrayPara.getInt(1);
            if (TextUtils.isEmpty(url)) {
                result.putString("error", "invalid input param. specify an json array which length is 2, and index 0 is url to load, index 1 is image id.");
                return;
            }
            try {
                final IJSCallbackMap resultMap = getDataFactory().createJSCallbackMap();
                if (url.startsWith("data:image")) {
                    Bitmap bmp = handleBase64Texture(url.substring(url.indexOf("base64,") + "base64,".length()));
                    if (bmp != null) {
                        resultMap.putInt("id", imageId);
                        resultMap.putString("url", url);
                        resultMap.putInt("width", bmp.getWidth());
                        resultMap.putInt("height", bmp.getHeight());
                    } else {
                        resultMap.putString("error", "process base64 failed,url=" + url);
                    }
                    invokeCallback(callback, resultMap);
                    return;
                }
                GImageLoadInfo imgInfo = this.mImageIdCache.get(url);
                if (imgInfo == null) {
                    imgInfo = new GImageLoadInfo();
                    this.mImageIdCache.put(url, imgInfo);
                }
                if (imgInfo.status.get() == -1) {
                    imgInfo.status.set(256);
                    imgInfo.id = imageId;
                    ArrayList<JSCallback> callbacks2 = this.mCallbacks.get(url);
                    if (callbacks2 == null) {
                        ArrayList<JSCallback> callbacks3 = new ArrayList<>();
                        this.mCallbacks.put(url, callbacks3);
                        callbacks = callbacks3;
                    } else {
                        callbacks = callbacks2;
                    }
                    callbacks.add(callback);
                    this.mImageLoader.load(getContext(), url, new IGImageLoader.ImageCallback() {
                        /* class com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule.AnonymousClass4 */

                        /* JADX DEBUG: Multi-variable search result rejected for r1v1, resolved type: com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule */
                        /* JADX DEBUG: Multi-variable search result rejected for r2v10, resolved type: com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule */
                        /* JADX WARN: Multi-variable type inference failed */
                        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
                        public void onSuccess(Bitmap bitmap) {
                            if (bitmap != null) {
                                GImageLoadInfo imageInfo = AbsGBridgeModule.this.mImageIdCache.get(url);
                                imageInfo.width = bitmap.getWidth();
                                imageInfo.height = bitmap.getHeight();
                                resultMap.putInt("id", imageId);
                                resultMap.putString("url", url);
                                resultMap.putInt("width", imageInfo.width);
                                resultMap.putInt("height", imageInfo.height);
                                imageInfo.status.set(512);
                                try {
                                    ArrayList<JSCallback> callbackList = AbsGBridgeModule.this.mCallbacks.remove(url);
                                    if (callbackList != null) {
                                        Iterator<JSCallback> it = callbackList.iterator();
                                        while (it.hasNext()) {
                                            AbsGBridgeModule.this.invokeCallback(it.next(), resultMap);
                                        }
                                    }
                                } catch (Throwable th) {
                                    imageInfo.status.set(-1);
                                    AbsGBridgeModule.this.invokeCallback(callback, resultMap);
                                }
                            } else {
                                resultMap.putString("error", "bitmap load failed");
                                try {
                                    ArrayList<JSCallback> callbackList2 = AbsGBridgeModule.this.mCallbacks.remove(url);
                                    if (callbackList2 != null) {
                                        Iterator<JSCallback> it2 = callbackList2.iterator();
                                        while (it2.hasNext()) {
                                            AbsGBridgeModule.this.invokeCallback(it2.next(), resultMap);
                                        }
                                    }
                                } catch (Throwable th2) {
                                    AbsGBridgeModule.this.invokeCallback(callback, resultMap);
                                }
                            }
                        }

                        /* JADX DEBUG: Multi-variable search result rejected for r1v1, resolved type: com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule */
                        /* JADX WARN: Multi-variable type inference failed */
                        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
                        public void onFail(Object error) {
                            resultMap.putString("error", "bitmap load failed");
                            try {
                                ArrayList<JSCallback> callbackList = AbsGBridgeModule.this.mCallbacks.remove(url);
                                if (callbackList != null) {
                                    Iterator<JSCallback> it = callbackList.iterator();
                                    while (it.hasNext()) {
                                        AbsGBridgeModule.this.invokeCallback(it.next(), resultMap);
                                    }
                                }
                            } catch (Throwable th) {
                                AbsGBridgeModule.this.invokeCallback(callback, resultMap);
                            }
                        }

                        @Override // com.taobao.gcanvas.adapters.img.IGImageLoader.ImageCallback
                        public void onCancel() {
                        }
                    });
                } else if (256 == imgInfo.status.get()) {
                    ArrayList<JSCallback> callbacks4 = this.mCallbacks.get(url);
                    if (callbacks4 == null) {
                        callbacks4 = new ArrayList<>();
                        this.mCallbacks.put(url, callbacks4);
                    }
                    callbacks4.add(callback);
                } else if (512 == imgInfo.status.get()) {
                    resultMap.putInt("id", imageId);
                    resultMap.putString("url", url);
                    resultMap.putInt("width", imgInfo.width);
                    resultMap.putInt("height", imgInfo.height);
                    ArrayList<JSCallback> callbackList = this.mCallbacks.remove(url);
                    if (callbackList != null) {
                        Iterator<JSCallback> it = callbackList.iterator();
                        while (it.hasNext()) {
                            it.next();
                            invokeCallback(callback, resultMap);
                        }
                    }
                    invokeCallback(callback, resultMap);
                }
            } catch (Throwable e) {
                Log.e(TAG, e.getMessage(), e);
            }
        } catch (JSONException e2) {
            result.putString("error", "invalid input param. specify an json array which length is 2, and index 0 is url to load, index 1 is image id.");
            String str = TAG;
            GLog.d(str, "error parse preload image data:" + e2.getMessage());
            invokeCallback(callback, result);
        }
    }

    public Bitmap handleBase64Texture(String url) {
        try {
            byte[] decodedBytes = decode(url.getBytes());
            return BitmapFactory.decodeByteArray(decodedBytes, 0, decodedBytes.length);
        } catch (Throwable e) {
            String str = TAG;
            Log.e(str, "error in processing base64Texture,error=" + e);
            return null;
        }
    }

    public static byte[] decode(byte[] in) {
        return decode(in, in.length);
    }

    /* JADX INFO: Multiple debug info for r1v1 byte[]: [D('result' byte[]), D('outIndex' int)] */
    public static byte[] decode(byte[] in, int len) {
        byte b;
        byte b2;
        int bits;
        int length = (len / 4) * 3;
        if (length == 0) {
            return new byte[0];
        }
        byte[] out = new byte[length];
        int pad = 0;
        int len2 = len;
        while (true) {
            byte chr = in[len2 - 1];
            b = 10;
            if (chr != 10) {
                b2 = cv.k;
                if (!(chr == 13 || chr == 32 || chr == 9)) {
                    if (chr != 61) {
                        break;
                    }
                    pad++;
                }
            }
            len2--;
        }
        int outIndex = 0;
        int inIndex = 0;
        int quantum = 0;
        int i = 0;
        while (i < len2) {
            byte chr2 = in[i];
            if (!(chr2 == b || chr2 == b2 || chr2 == 32 || chr2 == 9)) {
                if (chr2 >= 65 && chr2 <= 90) {
                    bits = chr2 - 65;
                } else if (chr2 >= 97 && chr2 <= 122) {
                    bits = chr2 - 71;
                } else if (chr2 >= 48 && chr2 <= 57) {
                    bits = chr2 + 4;
                } else if (chr2 == 43) {
                    bits = 62;
                } else if (chr2 != 47) {
                    return null;
                } else {
                    bits = 63;
                }
                int quantum2 = ((byte) bits) | (quantum << 6);
                if (inIndex % 4 == 3) {
                    int outIndex2 = outIndex + 1;
                    out[outIndex] = (byte) (quantum2 >> 16);
                    int outIndex3 = outIndex2 + 1;
                    out[outIndex2] = (byte) (quantum2 >> 8);
                    out[outIndex3] = (byte) quantum2;
                    outIndex = outIndex3 + 1;
                }
                inIndex++;
                quantum = quantum2;
            }
            i++;
            b = 10;
            b2 = cv.k;
        }
        if (pad > 0) {
            int quantum3 = quantum << (pad * 6);
            int outIndex4 = outIndex + 1;
            out[outIndex] = (byte) (quantum3 >> 16);
            if (pad == 1) {
                outIndex = outIndex4 + 1;
                out[outIndex4] = (byte) (quantum3 >> 8);
            } else {
                outIndex = outIndex4;
            }
        }
        byte[] result = new byte[outIndex];
        System.arraycopy(out, 0, result, 0, outIndex);
        return result;
    }
}
