package com.taobao.gcanvas.bridges.weex;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.net.Uri;
import android.text.TextUtils;
import com.alipay.sdk.m.u.i;
import com.taobao.gcanvas.GCanvasJNI;
import com.taobao.gcanvas.adapters.img.impl.fresco.GCanvasFrescoImageLoader;
import com.taobao.gcanvas.bridges.spec.bridge.IJSCallbackDataFactory;
import com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule;
import com.taobao.gcanvas.bridges.spec.module.IGBridgeModule;
import com.taobao.gcanvas.bridges.weex.bridge.WeexJSCallbackDataFactory;
import com.taobao.gcanvas.surface.GTextureView;
import com.taobao.gcanvas.util.GCanvasBase64;
import com.taobao.gcanvas.util.GLog;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class GCanvasWeexModule extends WXModule implements Destroyable {
    private static final String TAG = "GCanvasWeexModule";
    private HashMap<String, WXGCanvasWeexComponent> mComponentMap = new HashMap<>(1);
    private WeexModuleImpl mImpl;

    private static class WeexModuleImpl extends AbsGBridgeModule<JSCallback> {
        private WeexJSCallbackDataFactory mFactory = new WeexJSCallbackDataFactory();
        private WeakReference<GCanvasWeexModule> mOutRef;

        public WeexModuleImpl(GCanvasWeexModule module) {
            this.mOutRef = new WeakReference<>(module);
        }

        @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
        public String enable(JSONObject data) {
            GCanvasWeexModule module = this.mOutRef.get();
            if (module == null) {
                return Boolean.FALSE.toString();
            }
            try {
                String refId = data.getString("componentId");
                WXComponent myComponent = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(module.mWXSDKInstance.getInstanceId(), refId);
                if (myComponent instanceof WXGCanvasWeexComponent) {
                    module.mComponentMap.put(refId, (WXGCanvasWeexComponent) myComponent);
                }
                return Boolean.TRUE.toString();
            } catch (JSONException e) {
                return Boolean.FALSE.toString();
            }
        }

        @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
        public void setContextType(String canvasId, IGBridgeModule.ContextType type) {
            GCanvasWeexModule module = this.mOutRef.get();
            if (module != null) {
                int width = ((Activity) getContext()).getWindowManager().getDefaultDisplay().getWidth();
                double devicePixelRatio = (double) (((float) width) / module.mWXSDKInstance.getInstanceViewPortWidthWithFloat());
                String str = TAG;
                GLog.d(str, "enable width " + width);
                String str2 = TAG;
                GLog.d(str2, "enable devicePixelRatio " + devicePixelRatio);
                GCanvasJNI.setWrapperHiQuality(canvasId, true);
                GCanvasJNI.setWrapperDevicePixelRatio(canvasId, devicePixelRatio);
                GCanvasJNI.setWrapperContextType(canvasId, type.value());
                if (GCanvasJNI.sendEvent(canvasId)) {
                    GLog.d("start to send event in module.");
                    WXGCanvasWeexComponent component = (WXGCanvasWeexComponent) module.mComponentMap.get(canvasId);
                    if (component != null) {
                        component.sendEvent();
                    }
                }
                WXGCanvasWeexComponent component2 = (WXGCanvasWeexComponent) module.mComponentMap.get(canvasId);
                if (component2 != null) {
                    component2.mType = type;
                }
            }
        }

        @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
        public void setDevicePixelRatio(String canvasId, double ratio) {
        }

        @Override // com.taobao.gcanvas.bridges.spec.module.IGBridgeModule
        public String render(String canvasId, String cmd, boolean flag) {
            return GCanvasJNI.render(canvasId, cmd, flag);
        }

        @Override // com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule
        public Context getContext() {
            GCanvasWeexModule module = this.mOutRef.get();
            if (module == null) {
                return null;
            }
            return module.mWXSDKInstance.getContext();
        }

        /* access modifiers changed from: protected */
        public void invokeCallback(JSCallback jsCallback, Object args) {
            if (jsCallback != null) {
                jsCallback.invoke(args);
            }
        }

        /* access modifiers changed from: protected */
        @Override // com.taobao.gcanvas.bridges.spec.module.AbsGBridgeModule
        public IJSCallbackDataFactory getDataFactory() {
            return this.mFactory;
        }
    }

    public GCanvasWeexModule() {
        GCanvasJNI.registerWXCallNativeFunc(WXEnvironment.getApplication());
        WeexModuleImpl weexModuleImpl = new WeexModuleImpl(this);
        this.mImpl = weexModuleImpl;
        weexModuleImpl.setImageLoader(new GCanvasFrescoImageLoader());
    }

    @JSMethod(uiThread = false)
    public void bindImageTexture(String args, String refId, JSCallback callback) {
        String url = null;
        int rid = 0;
        if (!TextUtils.isEmpty(args)) {
            try {
                JSONArray dataArray = new JSONArray(args);
                url = dataArray.getString(0);
                rid = dataArray.getInt(1);
            } catch (Throwable e) {
                GLog.e(TAG, e.getMessage(), e);
            }
        }
        this.mImpl.bindImageTexture(refId, url, rid, callback);
    }

    @JSMethod(uiThread = false)
    public void resetComponent(String refId) {
    }

    @JSMethod(uiThread = false)
    public void setup(String args, String refId, JSCallback callback) {
    }

    @JSMethod(uiThread = false)
    public void preLoadImage(String args, JSCallback callBack) {
        GLog.d(TAG, "preLoadImage() in GCanvasWeexModule,args: " + args);
        if (!TextUtils.isEmpty(args)) {
            try {
                this.mImpl.preLoadImage(new JSONArray(args), callBack);
            } catch (Throwable e) {
                GLog.e(TAG, e.getMessage(), e);
            }
        }
    }

    @JSMethod(uiThread = false)
    public void setHiQuality(String args, String refId) {
    }

    @JSMethod(uiThread = false)
    public void setLogLevel(String args) {
        GLog.d(TAG, "setLogLevel() args: " + args);
        int level = 0;
        try {
            level = Integer.parseInt(args);
        } catch (Throwable th) {
            char c = 65535;
            switch (args.hashCode()) {
                case 3237038:
                    if (args.equals("info")) {
                        c = 1;
                        break;
                    }
                    break;
                case 3641990:
                    if (args.equals("warn")) {
                        c = 2;
                        break;
                    }
                    break;
                case 95458899:
                    if (args.equals("debug")) {
                        c = 0;
                        break;
                    }
                    break;
                case 96784904:
                    if (args.equals("error")) {
                        c = 3;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                level = 0;
            } else if (c == 1) {
                level = 1;
            } else if (c == 2) {
                level = 2;
            } else if (c == 3) {
                level = 3;
            }
        }
        this.mImpl.setLogLevel(level);
    }

    @JSMethod(uiThread = false)
    public String enable(String args) {
        try {
            return this.mImpl.enable(new JSONObject(args));
        } catch (Throwable th) {
            return Boolean.FALSE.toString();
        }
    }

    @JSMethod(uiThread = false)
    public void render(String cmd, String refId, JSCallback callback) {
        this.mImpl.render(refId, cmd, true);
        if (callback != null) {
            callback.invoke(new HashMap());
        }
    }

    @JSMethod(uiThread = false)
    public void getDeviceInfo(String args, JSCallback callBack) {
        if (!TextUtils.isEmpty(args)) {
            HashMap<String, Object> hm = new HashMap<>();
            JSONObject data = new JSONObject();
            try {
                data.put("platform", "Android");
            } catch (JSONException e) {
            }
            hm.put("data", data.toString());
            callBack.invoke(hm);
        }
    }

    @JSMethod(uiThread = false)
    public void setContextType(String args, String refId) {
        if (!TextUtils.isEmpty(args) && !TextUtils.isEmpty(refId)) {
            Context ctx = this.mWXSDKInstance.getContext();
            if (ctx == null) {
                GLog.e(TAG, "setDevicePixelRatio error ctx == null");
                return;
            }
            int width = ((Activity) ctx).getWindowManager().getDefaultDisplay().getWidth();
            GLog.d(TAG, "enable width " + width);
            GLog.d(TAG, "enable devicePixelRatio " + ((double) (((float) width) / this.mWXSDKInstance.getInstanceViewPortWidthWithFloat())));
            IGBridgeModule.ContextType type = IGBridgeModule.ContextType._2D;
            if ("3d".equals(args) || "1".equals(args)) {
                type = IGBridgeModule.ContextType._3D;
            }
            this.mImpl.setContextType(refId, type);
        }
    }

    @JSMethod(uiThread = false)
    public void setAlpha(String refId, float alpha) {
        GTextureView view;
        GLog.d("start to set alpha in 3dmodule.");
        WXGCanvasWeexComponent component = this.mComponentMap.get(refId);
        if (component != null && (view = component.getSurfaceView()) != null) {
            GLog.d("set alpha success in 3dmodule.");
            view.setAlpha(alpha);
        }
    }

    @JSMethod(uiThread = false)
    public void setDevicePixelRatio(String refId) {
    }

    @JSMethod(uiThread = false)
    public String execGcanvaSyncCMD(String refId, String action, String args) {
        return "";
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        for (Map.Entry<String, WXGCanvasWeexComponent> entry : this.mComponentMap.entrySet()) {
            entry.getValue();
            GLog.d("component destroy id=" + ((Object) entry.getKey()));
        }
        this.mComponentMap.clear();
    }

    @JSMethod(uiThread = false)
    public void texImage2D(String refid, int target, int level, int internalformat, int format, int type, String path) {
        if (!TextUtils.isEmpty(path)) {
            this.mImpl.texImage2D(refid, target, level, internalformat, format, type, path);
        }
    }

    @JSMethod(uiThread = false)
    public void texSubImage2D(String refid, int target, int level, int xoffset, int yoffset, int format, int type, String path) {
        if (!TextUtils.isEmpty(path)) {
            this.mImpl.texSubImage2D(refid, target, level, xoffset, yoffset, format, type, path);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0085  */
    /* JADX WARNING: Removed duplicated region for block: B:24:? A[RETURN, SYNTHETIC] */
    @JSMethod(uiThread = false)
    public void getImageData(String rectArray, String refid, JSCallback callback) {
        int x;
        int y;
        int width;
        int height;
        try {
            try {
                JSONArray param = new JSONArray(rectArray);
                x = param.optInt(0);
                y = param.optInt(1);
                width = param.optInt(2);
                height = param.optInt(3);
            } catch (JSONException e) {
                if (callback == null) {
                }
            }
            try {
                try {
                    Object imagedata = this.mImpl.render(refid, "R" + x + "," + y + "," + width + "," + height + i.b, true);
                    if (callback != null) {
                        Map<String, Object> values = new HashMap<>();
                        values.put("data", imagedata);
                        values.put("height", Integer.valueOf(height));
                        values.put("width", Integer.valueOf(width));
                        callback.invoke(values);
                    }
                } catch (JSONException e2) {
                    if (callback == null) {
                        Map<String, Object> values2 = new HashMap<>();
                        values2.put("data", "");
                        values2.put("height", 0);
                        values2.put("width", 0);
                        callback.invoke(values2);
                    }
                }
            } catch (JSONException e3) {
                if (callback == null) {
                }
            }
        } catch (JSONException e4) {
            if (callback == null) {
            }
        }
    }

    @JSMethod(uiThread = false)
    public void putImageData(String rectArray, String componentId, JSCallback callback) {
        try {
            JSONArray param = new JSONArray(rectArray);
            int x = param.optInt(0);
            int y = param.optInt(1);
            int width = param.optInt(2);
            int height = param.optInt(3);
            String imageData = param.optString(4);
            this.mImpl.render(componentId, "P" + x + "," + y + "," + width + "," + height + "," + width + "," + height + "," + imageData + i.b, false);
            if (callback != null) {
                callback.invoke(new HashMap());
            }
        } catch (JSONException e) {
            if (callback != null) {
                callback.invoke(new HashMap());
            }
        }
    }

    @JSMethod(uiThread = false)
    public com.alibaba.fastjson.JSONObject measureText(String textStyle, String componentId) {
        com.alibaba.fastjson.JSONObject fjob = new com.alibaba.fastjson.JSONObject();
        try {
            String text = new JSONArray(textStyle).optString(0);
            String width = this.mImpl.render(componentId, "K" + text + i.b, true);
            fjob.put("width", (Object) String.format(Locale.US, "%.2f", Float.valueOf(Float.parseFloat(width))));
            return fjob;
        } catch (JSONException e) {
            fjob.put("width", (Object) "-1");
            return fjob;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:44:0x014a  */
    /* JADX WARNING: Removed duplicated region for block: B:64:? A[RETURN, SYNTHETIC] */
    @JSMethod(uiThread = false)
    public void toTempFilePath(String params, String refid, JSCallback callback) {
        Bitmap bitmap;
        HashMap<String, Object> values;
        HashMap<String, Object> values2;
        String str = "jpg";
        try {
            JSONArray param = new JSONArray(params);
            int x = param.optInt(0);
            int y = param.optInt(1);
            int width = param.optInt(2);
            int height = param.optInt(3);
            int destwidth = param.optInt(4);
            int destheight = param.optInt(5);
            String filetype = param.optString(6);
            float quality = (float) param.optInt(7);
            int[] colorInt = btoi(GCanvasBase64.decode(this.mImpl.render(refid, "R" + x + "," + y + "," + width + "," + height + i.b, true).getBytes()));
            if (colorInt != null) {
                bitmap = Bitmap.createBitmap(colorInt, destwidth, destheight, Bitmap.Config.ARGB_8888);
            } else {
                bitmap = null;
            }
            Bitmap.CompressFormat format = filetype.equals(str) ? Bitmap.CompressFormat.JPEG : Bitmap.CompressFormat.PNG;
            float quality2 = quality * 100.0f;
            HashMap<String, Object> values3 = new HashMap<>();
            if (quality2 > 100.0f) {
                values = values3;
            } else if (quality2 < 0.0f) {
                values = values3;
            } else if (bitmap != null) {
                try {
                    StringBuilder sb = new StringBuilder();
                    sb.append(AbsoluteConst.MINI_SERVER_APP_DOC);
                    try {
                        sb.append(System.currentTimeMillis());
                        sb.append(Operators.DOT_STR);
                        if (!filetype.equals(str)) {
                            str = "png";
                        }
                        sb.append(str);
                        Uri pathUri = this.mWXSDKInstance.rewriteUri(Uri.parse(sb.toString()), "image");
                        FileOutputStream fos = new FileOutputStream(new File(pathUri.getPath()));
                        try {
                            bitmap.compress(format, (int) quality2, fos);
                            fos.flush();
                            fos.close();
                            values2 = values3;
                        } catch (IOException e) {
                            values2 = values3;
                            values2.put("type", Constants.Event.FAIL);
                            if (callback == null) {
                            }
                        }
                        try {
                            values2.put("type", WXImage.SUCCEED);
                            values2.put("tempFilePath", pathUri.getPath());
                            if (callback != null) {
                                callback.invoke(values2);
                                return;
                            }
                            return;
                        } catch (IOException e2) {
                            values2.put("type", Constants.Event.FAIL);
                            if (callback == null) {
                            }
                        }
                    } catch (IOException e3) {
                        values2 = values3;
                        values2.put("type", Constants.Event.FAIL);
                        if (callback == null) {
                            callback.invoke(values2);
                            return;
                        }
                        return;
                    }
                } catch (IOException e4) {
                    values2 = values3;
                    values2.put("type", Constants.Event.FAIL);
                    if (callback == null) {
                    }
                }
            } else {
                values3.put("type", Constants.Event.FAIL);
                if (callback != null) {
                    callback.invoke(values3);
                    return;
                }
                return;
            }
            values.put("type", Constants.Event.FAIL);
            if (callback != null) {
                callback.invoke(values);
            }
        } catch (JSONException e5) {
            HashMap<String, Object> values4 = new HashMap<>();
            values4.put("type", Constants.Event.FAIL);
            if (callback != null) {
                callback.invoke(values4);
            }
        }
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:9:0x0023 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:11:0x0027 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:19:0x002f */
    /* JADX DEBUG: Multi-variable search result rejected for r10v0, resolved type: byte[] */
    /* JADX DEBUG: Multi-variable search result rejected for r3v1, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r4v1, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r5v1, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r6v1, resolved type: byte */
    /* JADX DEBUG: Multi-variable search result rejected for r6v3, resolved type: int */
    /* JADX DEBUG: Multi-variable search result rejected for r5v3, resolved type: int */
    /* JADX DEBUG: Multi-variable search result rejected for r4v3, resolved type: int */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v2 */
    /* JADX WARN: Type inference failed for: r5v2 */
    /* JADX WARN: Type inference failed for: r6v2 */
    private int[] btoi(byte[] btarr) {
        if (btarr.length % 4 != 0) {
            return null;
        }
        int[] intarr = new int[(btarr.length / 4)];
        int j = 0;
        int k = 0;
        while (j < intarr.length) {
            byte b = btarr[k];
            byte i2 = btarr[k + 1];
            byte i3 = btarr[k + 2];
            byte i4 = btarr[k + 3];
            int i1 = b;
            if (b < 0) {
                i1 = b + 256;
            }
            if (i2 < 0) {
                i2 += 256;
            }
            if (i3 < 0) {
                i3 += 256;
            }
            if (i4 < 0) {
                i4 += 256;
            }
            intarr[j] = (((i4 == true ? 1 : 0) & 255) << 24) | (((i1 == 1 ? 1 : 0) & 255) << 16) | (((i2 == true ? 1 : 0) & 255) << 8) | ((i3 == true ? 1 : 0) & 255);
            j++;
            k += 4;
        }
        return intarr;
    }
}
