package com.taobao.gcanvas.bridges.weex;

import android.app.Activity;
import android.content.Context;
import android.graphics.SurfaceTexture;
import android.view.TextureView;
import com.taobao.gcanvas.GCanvasJNI;
import com.taobao.gcanvas.bridges.spec.module.IGBridgeModule;
import com.taobao.gcanvas.surface.GTextureView;
import com.taobao.gcanvas.util.GLog;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;

@Component(lazyload = false)
public class WXGCanvasWeexComponent extends WXComponent<GWXTextureView> implements TextureView.SurfaceTextureListener {
    private static final String TAG = WXGCanvasWeexComponent.class.getSimpleName();
    public AtomicBoolean mSended = new AtomicBoolean(false);
    private GWXTextureView mSurfaceView;
    public IGBridgeModule.ContextType mType;

    public WXGCanvasWeexComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
    }

    public WXGCanvasWeexComponent(WXSDKInstance instance, WXVContainer parent, int type, BasicComponentData basicComponentData) {
        super(instance, parent, type, basicComponentData);
    }

    private void addGCanvasView() {
        String backgroundColor = getStyles().getBackgroundColor();
        this.mSurfaceView = new GWXTextureView(getContext(), this);
        GCanvasJNI.registerWXCallNativeFunc(getContext());
        if (backgroundColor.isEmpty()) {
            backgroundColor = "rgba(0,0,0,0)";
        }
        this.mSurfaceView.setBackgroundColor(backgroundColor);
        this.mSurfaceView.addSurfaceTextureListener(this);
    }

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXGCanvasWeexComponent(instance, parent, basicComponentData);
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        GWXTextureView gWXTextureView = this.mSurfaceView;
        if (gWXTextureView != null) {
            gWXTextureView.resume();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityDestroy() {
        GWXTextureView gWXTextureView = this.mSurfaceView;
        if (gWXTextureView != null) {
            gWXTextureView.setSurfaceTextureListener(null);
            this.mSurfaceView.requestExit();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        GWXTextureView gWXTextureView = this.mSurfaceView;
        if (gWXTextureView != null) {
            gWXTextureView.pause();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setBackgroundColor(String color) {
        ((GWXTextureView) getHostView()).setBackgroundColor(color);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public GWXTextureView initComponentHostView(Context context) {
        this.mSended.set(false);
        addGCanvasView();
        return this.mSurfaceView;
    }

    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
    }

    public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {
        Context ctx = getContext();
        if (ctx == null) {
            GLog.e(TAG, "setDevicePixelRatio error ctx == null");
            return;
        }
        int screenWidth = ((Activity) ctx).getWindowManager().getDefaultDisplay().getWidth();
        double devicePixelRatio = (double) (((float) width) / getInstance().getInstanceViewPortWidthWithFloat());
        String str = TAG;
        GLog.d(str, "enable width = " + screenWidth + ",devicePixelRatio = " + devicePixelRatio);
        GCanvasJNI.setWrapperDevicePixelRatio(getRef(), devicePixelRatio);
    }

    public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
        return true;
    }

    public void onSurfaceTextureUpdated(SurfaceTexture surface) {
    }

    public GTextureView getSurfaceView() {
        return this.mSurfaceView;
    }

    public void sendEvent() {
        synchronized (this) {
            if (!this.mSended.get()) {
                Map<String, Object> params = new HashMap<>();
                params.put("ref", getRef());
                getInstance().fireGlobalEventCallback("GCanvasReady", params);
                this.mSended.set(true);
            } else {
                GLog.d("event sent.");
            }
        }
    }
}
