package com.taobao.gcanvas.surface;

import android.content.Context;
import android.util.AttributeSet;
import android.view.TextureView;
import com.taobao.gcanvas.util.GLog;

public class GTextureView extends TextureView {
    private GTextureViewCallback mCallback;

    public GTextureView(Context context, String id) {
        super(context);
        init(id);
    }

    public GTextureView(Context context, String id, AttributeSet attrs) {
        super(context, attrs);
        init(id);
    }

    public GTextureView(Context context, String id, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(id);
    }

    public GTextureView(Context context, String id, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init(id);
    }

    public void setBackgroundColor(String color) {
        GTextureViewCallback gTextureViewCallback = this.mCallback;
        if (gTextureViewCallback != null) {
            gTextureViewCallback.setBackgroundColor(color);
        }
    }

    public void addSurfaceTextureListener(TextureView.SurfaceTextureListener listener) {
        GTextureViewCallback gTextureViewCallback;
        if (listener != null && (gTextureViewCallback = this.mCallback) != null) {
            gTextureViewCallback.addSurfaceTextureListener(listener);
        }
    }

    public void removeSurfaceTextureListener(TextureView.SurfaceTextureListener listener) {
        GTextureViewCallback gTextureViewCallback;
        if (listener != null && (gTextureViewCallback = this.mCallback) != null) {
            gTextureViewCallback.removeSurfaceTextureListener(listener);
        }
    }

    private void init(String id) {
        GTextureViewCallback gTextureViewCallback = new GTextureViewCallback(this, id);
        this.mCallback = gTextureViewCallback;
        setSurfaceTextureListener(gTextureViewCallback);
        setOpaque(false);
        setLayerType(2, null);
    }

    public void resume() {
    }

    public void pause() {
    }

    /* access modifiers changed from: protected */
    public void onWindowVisibilityChanged(int visibility) {
        super.onWindowVisibilityChanged(visibility);
        GLog.d("on window visibility changed.visibility=" + visibility);
    }

    public void requestExit() {
        GLog.d("on request Exit in GSurfaceView.");
        if (this.mCallback != null) {
            GLog.d("start to request Exit.");
            this.mCallback.onRequestExit();
        }
    }

    public void sendEvent() {
    }

    public String getCanvasKey() {
        GTextureViewCallback gTextureViewCallback = this.mCallback;
        if (gTextureViewCallback != null) {
            return gTextureViewCallback.getKey();
        }
        return "";
    }
}
