package com.taobao.gcanvas.surface;

import android.graphics.SurfaceTexture;
import android.os.Build;
import android.text.TextUtils;
import android.view.Surface;
import android.view.TextureView;
import com.taobao.gcanvas.GCanvasJNI;
import com.taobao.gcanvas.util.GLog;
import java.util.ArrayList;
import java.util.Iterator;

public class GTextureViewCallback implements TextureView.SurfaceTextureListener {
    private String mBackgroundColor = "#ffffff";
    private ArrayList<TextureView.SurfaceTextureListener> mDelegateLists;
    private final String mKey;
    private Surface mSurface;
    private SurfaceTexture mSurfaceTexture;
    private TextureView mTextureview;

    private native void onRenderExit(String str);

    private native void onSurfaceChanged(String str, Surface surface, int i, int i2, int i3, String str2);

    private native void onSurfaceCreated(String str, Surface surface);

    private native void onSurfaceDestroyed(String str, Surface surface);

    static {
        GCanvasJNI.load();
    }

    public GTextureViewCallback(TextureView v, String id) {
        this.mKey = id;
        this.mTextureview = v;
    }

    public void addSurfaceTextureListener(TextureView.SurfaceTextureListener listener) {
        if (this.mDelegateLists == null) {
            this.mDelegateLists = new ArrayList<>(1);
        }
        if (!this.mDelegateLists.contains(listener)) {
            this.mDelegateLists.add(listener);
        }
    }

    public void removeSurfaceTextureListener(TextureView.SurfaceTextureListener listener) {
        ArrayList<TextureView.SurfaceTextureListener> arrayList = this.mDelegateLists;
        if (arrayList != null) {
            arrayList.remove(listener);
        }
    }

    public void setBackgroundColor(String color) {
        if (!TextUtils.isEmpty(color)) {
            this.mBackgroundColor = color;
        }
    }

    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
        GLog.d("on surfaceTexture Available.");
        SurfaceTexture surfaceTexture = this.mSurfaceTexture;
        if (surfaceTexture == null) {
            this.mSurface = new Surface(surface);
            this.mSurfaceTexture = surface;
        } else {
            this.mTextureview.setSurfaceTexture(surfaceTexture);
        }
        onSurfaceChanged(this.mKey, this.mSurface, 0, width, height, this.mBackgroundColor);
        GCanvasJNI.refreshArguments(this.mKey);
        if (GCanvasJNI.sendEvent(this.mKey) && (this.mTextureview instanceof GTextureView)) {
            GLog.d("start to send event in GSurfaceCallback.");
            ((GTextureView) this.mTextureview).sendEvent();
        }
        ArrayList<TextureView.SurfaceTextureListener> arrayList = this.mDelegateLists;
        if (arrayList != null) {
            Iterator<TextureView.SurfaceTextureListener> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onSurfaceTextureAvailable(surface, width, height);
            }
        }
    }

    public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {
        GLog.d("on surfaceTexture changed.");
        if (this.mSurface == null) {
            this.mSurface = new Surface(surface);
            this.mSurfaceTexture = surface;
        }
        onSurfaceChanged(this.mKey, this.mSurface, 0, width, height, this.mBackgroundColor);
        ArrayList<TextureView.SurfaceTextureListener> arrayList = this.mDelegateLists;
        if (arrayList != null) {
            Iterator<TextureView.SurfaceTextureListener> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onSurfaceTextureSizeChanged(surface, width, height);
            }
        }
    }

    public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
        GLog.d("on surfaceTexture destroyed.");
        if (this.mSurfaceTexture == null || this.mSurface == null) {
            return true;
        }
        ArrayList<TextureView.SurfaceTextureListener> arrayList = this.mDelegateLists;
        if (arrayList != null) {
            Iterator<TextureView.SurfaceTextureListener> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onSurfaceTextureDestroyed(surface);
            }
        }
        onSurfaceDestroyed(this.mKey, this.mSurface);
        return false;
    }

    public void onSurfaceTextureUpdated(SurfaceTexture surface) {
    }

    public void onRequestExit() {
        GLog.d("on RequestExit");
        Surface surface = this.mSurface;
        if (surface != null) {
            surface.release();
            this.mSurface = null;
        }
        if (Build.VERSION.SDK_INT >= 21) {
            GLog.d("start to release surface textureview and surface in onRequestExit");
            SurfaceTexture surfaceTexture = this.mSurfaceTexture;
            if (surfaceTexture != null) {
                surfaceTexture.release();
                this.mSurfaceTexture = null;
            }
        }
        onRenderExit(this.mKey);
        ArrayList<TextureView.SurfaceTextureListener> arrayList = this.mDelegateLists;
        if (arrayList != null) {
            arrayList.clear();
        }
    }

    public String getKey() {
        return this.mKey;
    }
}
