package com.taobao.weex;

import android.net.Uri;
import android.text.TextUtils;
import com.efs.sdk.base.core.util.NetworkUtil;
import com.meizu.cloud.pushsdk.platform.message.BasicPushStatus;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXPerformance;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.tools.LogDetail;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class WXHttpListener implements IWXHttpAdapter.OnHttpListener {
    private WXRenderStrategy flag;
    private WXSDKInstance instance;
    private boolean isInstanceReady;
    public boolean isPreDownLoadMode;
    private boolean isResponseHasWait;
    private String jsonInitData;
    private WXInstanceApm mApmForInstance;
    private String mBundleUrl;
    private LogDetail mLogDetail;
    private WXResponse mResponse;
    private IWXUserTrackAdapter mUserTrackAdapter;
    private WXPerformance mWXPerformance;
    private Map<String, Object> options;
    private String pageName;
    private long startRequestTime;
    private int traceId;

    public WXHttpListener(WXSDKInstance instance2) {
        this.isPreDownLoadMode = false;
        this.isInstanceReady = false;
        this.isResponseHasWait = false;
        if (instance2 != null) {
            this.mLogDetail = instance2.mTimeCalculator.createLogDetail("downloadBundleJS");
        }
        this.instance = instance2;
        this.traceId = WXTracing.nextId();
        this.mWXPerformance = instance2.getWXPerformance();
        this.mApmForInstance = instance2.getApmForInstance();
        this.mUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
        if (WXTracing.isAvailable()) {
            WXTracing.TraceEvent event = WXTracing.newEvent("downloadBundleJS", instance2.getInstanceId(), -1);
            event.iid = instance2.getInstanceId();
            event.tname = "Network";
            event.ph = "B";
            event.traceId = this.traceId;
            event.submit();
        }
    }

    public WXHttpListener(WXSDKInstance instance2, String bundleUrl) {
        this(instance2);
        this.startRequestTime = System.currentTimeMillis();
        this.mBundleUrl = bundleUrl;
    }

    public WXHttpListener(WXSDKInstance instance2, String pageName2, Map<String, Object> options2, String jsonInitData2, WXRenderStrategy flag2, long startRequestTime2) {
        this(instance2);
        this.pageName = pageName2;
        this.options = options2;
        this.jsonInitData = jsonInitData2;
        this.flag = flag2;
        this.startRequestTime = startRequestTime2;
        this.mBundleUrl = instance2.getBundleUrl();
    }

    public void setSDKInstance(WXSDKInstance instance2) {
        this.instance = instance2;
    }

    /* access modifiers changed from: protected */
    public WXSDKInstance getInstance() {
        return this.instance;
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpStart() {
        WXSDKInstance wXSDKInstance = this.instance;
        if (wXSDKInstance != null && wXSDKInstance.getWXStatisticsListener() != null) {
            this.instance.getWXStatisticsListener().onHttpStart();
            LogDetail logDetail = this.mLogDetail;
            if (logDetail != null) {
                logDetail.taskStart();
            }
        }
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHeadersReceived(int statusCode, Map<String, List<String>> headers) {
        WXSDKInstance wXSDKInstance = this.instance;
        if (!(wXSDKInstance == null || wXSDKInstance.getWXStatisticsListener() == null)) {
            this.instance.getWXStatisticsListener().onHeadersReceived();
            this.instance.onHttpStart();
        }
        WXSDKInstance wXSDKInstance2 = this.instance;
        if (wXSDKInstance2 != null && wXSDKInstance2.responseHeaders != null && headers != null) {
            this.instance.responseHeaders.putAll(headers);
        }
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpUploadProgress(int uploadProgress) {
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpResponseProgress(int loadedLength) {
        this.instance.getApmForInstance().extInfo.put(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH, Integer.valueOf(loadedLength));
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
    public void onHttpFinish(WXResponse response) {
        LogDetail logDetail = this.mLogDetail;
        if (logDetail != null) {
            logDetail.taskEnd();
        }
        WXSDKInstance wXSDKInstance = this.instance;
        if (!(wXSDKInstance == null || wXSDKInstance.getWXStatisticsListener() == null)) {
            this.instance.getWXStatisticsListener().onHttpFinish();
        }
        if (WXTracing.isAvailable()) {
            WXTracing.TraceEvent event = WXTracing.newEvent("downloadBundleJS", this.instance.getInstanceId(), -1);
            event.traceId = this.traceId;
            event.tname = "Network";
            event.ph = "E";
            event.extParams = new HashMap();
            if (!(response == null || response.originalData == null)) {
                event.extParams.put("BundleSize", Integer.valueOf(response.originalData.length));
            }
            event.submit();
        }
        this.mWXPerformance.networkTime = System.currentTimeMillis() - this.startRequestTime;
        if (!(response == null || response.extendParams == null)) {
            this.mApmForInstance.updateRecordInfo(response.extendParams);
            Object actualNetworkTime = response.extendParams.get("actualNetworkTime");
            long j = 0;
            this.mWXPerformance.actualNetworkTime = actualNetworkTime instanceof Long ? ((Long) actualNetworkTime).longValue() : 0;
            Object pureNetworkTime = response.extendParams.get("pureNetworkTime");
            this.mWXPerformance.pureNetworkTime = pureNetworkTime instanceof Long ? ((Long) pureNetworkTime).longValue() : 0;
            Object connectionType = response.extendParams.get("connectionType");
            String str = "";
            this.mWXPerformance.connectionType = connectionType instanceof String ? (String) connectionType : str;
            Object packageSpendTime = response.extendParams.get("packageSpendTime");
            this.mWXPerformance.packageSpendTime = packageSpendTime instanceof Long ? ((Long) packageSpendTime).longValue() : 0;
            Object syncTaskTime = response.extendParams.get("syncTaskTime");
            WXPerformance wXPerformance = this.mWXPerformance;
            if (syncTaskTime instanceof Long) {
                j = ((Long) syncTaskTime).longValue();
            }
            wXPerformance.syncTaskTime = j;
            Object requestType = response.extendParams.get("requestType");
            this.mWXPerformance.requestType = requestType instanceof String ? (String) requestType : "none";
            Object cacheType = response.extendParams.get(WXPerformance.Dimension.cacheType.toString());
            if (cacheType instanceof String) {
                this.mWXPerformance.cacheType = (String) cacheType;
            }
            Object zCacheInfo = response.extendParams.get("zCacheInfo");
            WXPerformance wXPerformance2 = this.mWXPerformance;
            if (zCacheInfo instanceof String) {
                str = (String) zCacheInfo;
            }
            wXPerformance2.zCacheInfo = str;
            if (isNet(this.mWXPerformance.requestType) && this.mUserTrackAdapter != null) {
                WXPerformance performance = new WXPerformance(this.instance.getInstanceId());
                if (!TextUtils.isEmpty(this.mBundleUrl)) {
                    try {
                        performance.args = Uri.parse(this.mBundleUrl).buildUpon().clearQuery().toString();
                    } catch (Exception e) {
                        performance.args = this.pageName;
                    }
                }
                if (!BasicPushStatus.SUCCESS_CODE.equals(response.statusCode)) {
                    performance.errCode = WXErrorCode.WX_ERR_JSBUNDLE_DOWNLOAD.getErrorCode();
                    performance.appendErrMsg(response.errorCode);
                    performance.appendErrMsg("|");
                    performance.appendErrMsg(response.errorMsg);
                } else if (!BasicPushStatus.SUCCESS_CODE.equals(response.statusCode) || (response.originalData != null && response.originalData.length > 0)) {
                    performance.errCode = WXErrorCode.WX_SUCCESS.getErrorCode();
                } else {
                    performance.errCode = WXErrorCode.WX_ERR_JSBUNDLE_DOWNLOAD.getErrorCode();
                    performance.appendErrMsg(response.statusCode);
                    performance.appendErrMsg("|template is null!");
                }
                IWXUserTrackAdapter iWXUserTrackAdapter = this.mUserTrackAdapter;
                if (iWXUserTrackAdapter != null) {
                    iWXUserTrackAdapter.commit(this.instance.getContext(), null, IWXUserTrackAdapter.JS_DOWNLOAD, performance, null);
                }
            }
        }
        if (!this.isPreDownLoadMode) {
            didHttpFinish(response);
        } else if (this.isInstanceReady) {
            WXLogUtils.e("test->", "DownLoad didHttpFinish on http");
            didHttpFinish(response);
        } else {
            WXLogUtils.e("test->", "DownLoad end before activity created");
            this.mResponse = response;
            this.isResponseHasWait = true;
        }
    }

    public void onInstanceReady() {
        if (this.isPreDownLoadMode) {
            this.isInstanceReady = true;
            if (this.isResponseHasWait) {
                WXLogUtils.e("test->", "preDownLoad didHttpFinish on ready");
                didHttpFinish(this.mResponse);
            }
        }
    }

    private void didHttpFinish(WXResponse response) {
        String wxErrorCode = "0";
        if (response != null && response.originalData != null && TextUtils.equals(BasicPushStatus.SUCCESS_CODE, response.statusCode)) {
            this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_END);
            onSuccess(response);
        } else if (TextUtils.equals(WXErrorCode.WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR.getErrorCode(), response.statusCode)) {
            WXLogUtils.e("user intercept: WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR");
            wxErrorCode = WXErrorCode.WX_DEGRAD_ERR_BUNDLE_CONTENTTYPE_ERROR.getErrorCode();
            WXSDKInstance wXSDKInstance = this.instance;
            wXSDKInstance.onRenderError(wxErrorCode, "|response.errorMsg==" + response.errorMsg + "|instance bundleUrl = \n" + this.instance.getBundleUrl() + "|instance requestUrl = \n" + Uri.decode(WXSDKInstance.requestUrl));
            onFail(response);
        } else if (response == null || response.originalData == null || !TextUtils.equals("-206", response.statusCode)) {
            wxErrorCode = WXErrorCode.WX_DEGRAD_ERR_NETWORK_BUNDLE_DOWNLOAD_FAILED.getErrorCode();
            this.instance.onRenderError(wxErrorCode, response.errorMsg);
            onFail(response);
        } else {
            WXLogUtils.e("user intercept: WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED");
            wxErrorCode = WXErrorCode.WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED.getErrorCode();
            WXSDKInstance wXSDKInstance2 = this.instance;
            wXSDKInstance2.onRenderError(wxErrorCode, WXErrorCode.WX_DEGRAD_ERR_NETWORK_CHECK_CONTENT_LENGTH_FAILED.getErrorCode() + "|response.errorMsg==" + response.errorMsg);
            onFail(response);
        }
        if (!"0".equals(wxErrorCode)) {
            this.mApmForInstance.addProperty(WXInstanceApm.KEY_PROPERTIES_ERROR_CODE, wxErrorCode);
        }
    }

    private boolean isNet(String requestType) {
        return "network".equals(requestType) || "2g".equals(requestType) || NetworkUtil.NETWORK_CLASS_3G.equals(requestType) || NetworkUtil.NETWORK_CLASS_4G.equals(requestType) || "wifi".equals(requestType) || "other".equals(requestType) || "unknown".equals(requestType);
    }

    public void onSuccess(WXResponse response) {
        if (this.flag == WXRenderStrategy.DATA_RENDER_BINARY) {
            this.instance.render(this.pageName, response.originalData, this.options, this.jsonInitData);
            return;
        }
        this.instance.render(this.pageName, new String(response.originalData), this.options, this.jsonInitData, this.flag);
    }

    public void onFail(WXResponse response) {
    }
}
