package com.taobao.weex;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ScrollView;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.adapter.IDrawableLoader;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.adapter.IWXJscProcessManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.adapter.URIAdapter;
import com.taobao.weex.appfram.websocket.IWebSocketAdapter;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.bridge.NativeInvokeHelper;
import com.taobao.weex.bridge.SimpleJSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXModuleManager;
import com.taobao.weex.bridge.WXParams;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXPerformance;
import com.taobao.weex.common.WXRefreshData;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.http.WXHttpUtil;
import com.taobao.weex.instance.InstanceOnFireEventInterceptor;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import com.taobao.weex.performance.WhiteScreenUtils;
import com.taobao.weex.render.WXAbstractRenderContainer;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.ui.action.GraphicActionAddElement;
import com.taobao.weex.ui.component.NestedContainer;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXEmbed;
import com.taobao.weex.ui.flat.FlatGUIContext;
import com.taobao.weex.ui.view.WXScrollView;
import com.taobao.weex.utils.Trace;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXFileUtils;
import com.taobao.weex.utils.WXJsonUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import com.taobao.weex.utils.cache.RegisterCache;
import com.taobao.weex.utils.tools.LogDetail;
import com.taobao.weex.utils.tools.TimeCalculator;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.ErrorDialogUtil;
import io.dcloud.feature.uniapp.AbsSDKInstance;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import io.dcloud.feature.weex.WeexInstanceMgr;
import java.io.Serializable;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.PriorityQueue;
import java.util.concurrent.ConcurrentHashMap;

public class WXSDKInstance implements AbsSDKInstance {
    public static String ACTION_DEBUG_INSTANCE_REFRESH = "DEBUG_INSTANCE_REFRESH";
    public static String ACTION_INSTANCE_RELOAD = "INSTANCE_RELOAD";
    public static final String BUNDLE_URL = "bundleUrl";
    private static final String SOURCE_TEMPLATE_BASE64_MD5 = "templateSourceBase64MD5";
    public static String requestUrl = "requestUrl";
    static int sScreenHeight = -1;
    public WXBridgeManager.BundType bundleType;
    private List<JSONObject> componentsInfoExceedGPULimit;
    private boolean createInstanceHeartBeat;
    private boolean enableFullScreenHeight;
    private boolean enableLayerType;
    List<FrameViewEventListener> frameViewEventListeners;
    private boolean hasException;
    public PriorityQueue<WXEmbed> hiddenEmbeds;
    private Map<String, GraphicActionAddElement> inactiveAddElementAction;
    private boolean isCommit;
    private boolean isDestroy;
    private boolean isFrameShow;
    private boolean isImmersive;
    public boolean isNewFsEnd;
    private boolean isOnSizeChangedRender;
    private boolean isPreDownLoad;
    private boolean isPreInit;
    private volatile boolean isPreRenderMode;
    private boolean isRenderSuccess;
    private boolean isViewDisAppear;
    private WXInstanceApm mApmForInstance;
    private boolean mAutoAdjustDeviceWidth;
    private String mBundleUrl;
    private ComponentObserver mComponentObserver;
    private Map<String, String> mContainerInfo;
    private Map<Long, ContentBoxMeasurement> mContentBoxMeasurements;
    protected Context mContext;
    private boolean mCreateInstance;
    private boolean mCurrentGround;
    private CustomFontNetworkHandler mCustomFontNetworkHandler;
    private int mDefaultFontSize;
    private boolean mDisableSkipFrameworkInit;
    public boolean mEnd;
    public int mExecJSTraceId;
    private FlatGUIContext mFlatGUIContext;
    private WXGlobalEventReceiver mGlobalEventReceiver;
    private HashMap<String, List<String>> mGlobalEvents;
    public boolean mHasCreateFinish;
    private WXHttpListener mHttpListener;
    private ImageNetworkHandler mImageNetworkHandler;
    private final String mInstanceId;
    private List<InstanceOnFireEventInterceptor> mInstanceOnFireEventInterceptorList;
    private float mInstanceViewPortWidth;
    private WXRefreshData mLastRefreshData;
    private List<String> mLayerOverFlowListeners;
    private int mMaxDeepLayer;
    private NativeInvokeHelper mNativeInvokeHelper;
    private boolean mNeedReLoad;
    private boolean mNeedValidate;
    private NestedInstanceInterceptor mNestedInstanceInterceptor;
    IWXInstanceContainerOnSizeListener mOnSizeListener;
    private Context mOriginalContext;
    private WXSDKInstance mParentInstance;
    private long mRefreshStartTime;
    private WXAbstractRenderContainer mRenderContainer;
    private IWXRenderListener mRenderListener;
    public long mRenderStartNanos;
    public long mRenderStartTime;
    private WXRenderStrategy mRenderStrategy;
    private String mRenderType;
    private boolean mRendered;
    private WXComponent mRootComp;
    private ScrollView mScrollView;
    private IWXStatisticsListener mStatisticsListener;
    private StreamNetworkHandler mStreamNetworkHandler;
    public TimeCalculator mTimeCalculator;
    private String mUniPagePath;
    private boolean mUseScroller;
    private IWXUserTrackAdapter mUserTrackAdapter;
    private Map<String, Serializable> mUserTrackParams;
    private List<OnInstanceVisibleListener> mVisibleListeners;
    private List<ActionBarHandler> mWXActionbarHandlers;
    private List<OnBackPressedHandler> mWXBackPressedHandlers;
    private WXPerformance mWXPerformance;
    private List<OnWXScrollListener> mWXScrollListeners;
    private WXScrollView.WXScrollViewListener mWXScrollViewListener;
    private int maxHiddenEmbedsNum;
    public long[] measureTimes;
    public String[] mwxDims;
    public Map<String, List<String>> responseHeaders;
    public WeakReference<String> templateRef;
    private boolean trackComponent;

    public interface ActionBarHandler {
        boolean onSupportNavigateUp();
    }

    public interface CustomFontNetworkHandler {
        String fetchLocal(String str);
    }

    public interface FrameViewEventListener {
        void onShowAnimationEnd();
    }

    public interface ImageNetworkHandler {
        String fetchLocal(String str);
    }

    public interface NestedInstanceInterceptor {
        void onCreateNestInstance(WXSDKInstance wXSDKInstance, NestedContainer nestedContainer);
    }

    public interface OnBackPressedHandler {
        boolean onBackPressed();
    }

    public interface OnInstanceVisibleListener {
        void onAppear();

        void onDisappear();
    }

    public interface StreamNetworkHandler {
        String fetchLocal(String str);
    }

    public List<JSONObject> getComponentsExceedGPULimit() {
        return this.componentsInfoExceedGPULimit;
    }

    public void setComponentsInfoExceedGPULimit(JSONObject component) {
        if (component != null && !component.isEmpty()) {
            this.componentsInfoExceedGPULimit.add(component);
        }
    }

    public List<String> getLayerOverFlowListeners() {
        return this.mLayerOverFlowListeners;
    }

    public void addLayerOverFlowListener(String ref) {
        if (this.mLayerOverFlowListeners == null) {
            this.mLayerOverFlowListeners = new ArrayList();
        }
        this.mLayerOverFlowListeners.add(ref);
    }

    public void removeLayerOverFlowListener(String ref) {
        List<String> list = this.mLayerOverFlowListeners;
        if (list != null) {
            list.remove(ref);
        }
    }

    public ImageNetworkHandler getImageNetworkHandler() {
        return this.mImageNetworkHandler;
    }

    public void setImageNetworkHandler(ImageNetworkHandler imageNetworkHandler) {
        this.mImageNetworkHandler = imageNetworkHandler;
    }

    public StreamNetworkHandler getStreamNetworkHandler() {
        return this.mStreamNetworkHandler;
    }

    public void setStreamNetworkHandler(StreamNetworkHandler streamNetworkHandler) {
        this.mStreamNetworkHandler = streamNetworkHandler;
    }

    public CustomFontNetworkHandler getCustomFontNetworkHandler() {
        return this.mCustomFontNetworkHandler;
    }

    public void setCustomFontNetworkHandler(CustomFontNetworkHandler customFontNetworkHandler) {
        this.mCustomFontNetworkHandler = customFontNetworkHandler;
    }

    public void setUseSandBox(boolean flag) {
        WXBridgeManager.getInstance().setSandBoxContext(flag);
    }

    public int getMaxHiddenEmbedsNum() {
        return this.maxHiddenEmbedsNum;
    }

    public void setMaxHiddenEmbedsNum(int maxHiddenEmbedsNum2) {
        this.maxHiddenEmbedsNum = maxHiddenEmbedsNum2;
    }

    public void addInActiveAddElementAction(String ref, GraphicActionAddElement action) {
        this.inactiveAddElementAction.put(ref, action);
    }

    public void removeInActiveAddElmentAction(String ref) {
        this.inactiveAddElementAction.remove(ref);
    }

    public GraphicActionAddElement getInActiveAddElementAction(String ref) {
        return this.inactiveAddElementAction.get(ref);
    }

    public void setRenderContainer(RenderContainer a) {
        setWXAbstractRenderContainer(a);
    }

    public void setWXAbstractRenderContainer(WXAbstractRenderContainer a) {
        if (a != null) {
            a.setSDKInstance(this);
            a.addOnLayoutChangeListener(this);
        }
        this.mRenderContainer = a;
        if (a == null || a.getLayoutParams() == null || this.mRenderContainer.getLayoutParams().width != -2) {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass2 */

                public void run() {
                    WXBridgeManager.getInstance().setRenderContentWrapContentToCore(false, WXSDKInstance.this.getInstanceId());
                }
            });
        } else {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass1 */

                public void run() {
                    WXBridgeManager.getInstance().setRenderContentWrapContentToCore(true, WXSDKInstance.this.getInstanceId());
                }
            });
        }
    }

    public boolean isTrackComponent() {
        return this.trackComponent;
    }

    public void setTrackComponent(boolean trackComponent2) {
        this.trackComponent = trackComponent2;
    }

    public boolean isLayerTypeEnabled() {
        return this.enableLayerType;
    }

    public void enableLayerType(boolean enable) {
        this.enableLayerType = enable;
    }

    public FlatGUIContext getFlatUIContext() {
        return this.mFlatGUIContext;
    }

    public boolean isNeedValidate() {
        return this.mNeedValidate;
    }

    public boolean isNeedReLoad() {
        return this.mNeedReLoad;
    }

    public void setNeedLoad(boolean load) {
        this.mNeedReLoad = load;
    }

    public void setEnableFullScreenHeight(boolean fullScreenHeight) {
        this.enableFullScreenHeight = fullScreenHeight;
    }

    public boolean isFullScreenHeightEnabled() {
        return this.enableFullScreenHeight;
    }

    public boolean isUseScroller() {
        return this.mUseScroller;
    }

    public void setUseScroller(boolean use) {
        this.mUseScroller = use;
    }

    public void setInstanceViewPortWidth(float instanceViewPortWidth) {
        setInstanceViewPortWidth(instanceViewPortWidth, false);
    }

    public void setInstanceViewPortWidth(float instanceViewPortWidth, boolean fromMetaModule) {
        this.mInstanceViewPortWidth = instanceViewPortWidth;
        WXEnvironment.setViewProt(instanceViewPortWidth);
        if (fromMetaModule) {
            WXBridgeManager.getInstance().setViewPortWidth(getInstanceId(), this.mInstanceViewPortWidth);
        }
    }

    public void resetDeviceDisplayOfPage() {
        WXBridgeManager.getInstance().setDeviceDisplayOfPage(getInstanceId(), (float) WXViewUtils.getScreenWidth(getContext()), (float) WXViewUtils.getScreenHeight(getContext()));
    }

    public void setDeviceDisplayOfPage(int screenWidth, int screenHeight) {
        WXBridgeManager.getInstance().setDeviceDisplayOfPage(getInstanceId(), (float) screenWidth, (float) screenHeight);
    }

    public void setPageKeepRawCssStyles() {
        WXBridgeManager.getInstance().setPageArgument(getInstanceId(), "reserveCssStyles", AbsoluteConst.TRUE);
    }

    public void reloadPageLayout() {
        WXBridgeManager.getInstance().reloadPageLayout(getInstanceId());
    }

    public void setAutoAdjustDeviceWidth(boolean autoAdjustViewPort) {
        this.mAutoAdjustDeviceWidth = autoAdjustViewPort;
    }

    public boolean isAutoAdjustDeviceWidth() {
        return this.mAutoAdjustDeviceWidth;
    }

    private void setDeviceDisplay(float deviceWidth, float deviceHeight, float scale) {
        WXBridgeManager.getInstance().setDeviceDisplay(getInstanceId(), deviceWidth, deviceHeight, scale);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public float getInstanceViewPortWidthWithFloat() {
        return this.mInstanceViewPortWidth;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public int getInstanceViewPortWidth() {
        return Math.round(this.mInstanceViewPortWidth);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean isCompilerWithUniapp() {
        return false;
    }

    public WXSDKInstance(Context context) {
        this.mEnd = false;
        this.mHasCreateFinish = false;
        this.mBundleUrl = "";
        this.mUniPagePath = "";
        this.isDestroy = false;
        this.hasException = false;
        this.isRenderSuccess = false;
        this.createInstanceHeartBeat = false;
        this.isCommit = false;
        this.mGlobalEventReceiver = null;
        this.enableLayerType = true;
        this.mNeedValidate = false;
        this.mNeedReLoad = false;
        this.mUseScroller = false;
        this.mInstanceViewPortWidth = 750.0f;
        this.enableFullScreenHeight = false;
        this.mFlatGUIContext = new FlatGUIContext();
        this.isNewFsEnd = false;
        this.componentsInfoExceedGPULimit = new LinkedList();
        this.mExecJSTraceId = WXTracing.nextId();
        this.isViewDisAppear = false;
        this.mwxDims = new String[5];
        this.measureTimes = new long[5];
        this.responseHeaders = new HashMap();
        this.mRenderStrategy = WXRenderStrategy.APPEND_ASYNC;
        this.mDisableSkipFrameworkInit = false;
        this.mRenderType = "platform";
        this.mAutoAdjustDeviceWidth = WXEnvironment.AUTO_ADJUST_ENV_DEVICE_WIDTH;
        this.mCurrentGround = false;
        this.inactiveAddElementAction = new HashMap();
        this.mContentBoxMeasurements = new ArrayMap();
        this.maxHiddenEmbedsNum = -1;
        this.mVisibleListeners = new ArrayList();
        this.isPreInit = false;
        this.isPreDownLoad = false;
        this.mHttpListener = null;
        this.mCreateInstance = true;
        this.mGlobalEvents = new HashMap<>();
        this.mDefaultFontSize = 32;
        this.frameViewEventListeners = new ArrayList();
        this.isFrameShow = false;
        this.isImmersive = true;
        this.isOnSizeChangedRender = true;
        this.mInstanceId = WXSDKManager.getInstance().generateInstanceId();
        init(context);
    }

    public WXSDKInstance(Context context, Context originalContext) {
        this.mEnd = false;
        this.mHasCreateFinish = false;
        this.mBundleUrl = "";
        this.mUniPagePath = "";
        this.isDestroy = false;
        this.hasException = false;
        this.isRenderSuccess = false;
        this.createInstanceHeartBeat = false;
        this.isCommit = false;
        this.mGlobalEventReceiver = null;
        this.enableLayerType = true;
        this.mNeedValidate = false;
        this.mNeedReLoad = false;
        this.mUseScroller = false;
        this.mInstanceViewPortWidth = 750.0f;
        this.enableFullScreenHeight = false;
        this.mFlatGUIContext = new FlatGUIContext();
        this.isNewFsEnd = false;
        this.componentsInfoExceedGPULimit = new LinkedList();
        this.mExecJSTraceId = WXTracing.nextId();
        this.isViewDisAppear = false;
        this.mwxDims = new String[5];
        this.measureTimes = new long[5];
        this.responseHeaders = new HashMap();
        this.mRenderStrategy = WXRenderStrategy.APPEND_ASYNC;
        this.mDisableSkipFrameworkInit = false;
        this.mRenderType = "platform";
        this.mAutoAdjustDeviceWidth = WXEnvironment.AUTO_ADJUST_ENV_DEVICE_WIDTH;
        this.mCurrentGround = false;
        this.inactiveAddElementAction = new HashMap();
        this.mContentBoxMeasurements = new ArrayMap();
        this.maxHiddenEmbedsNum = -1;
        this.mVisibleListeners = new ArrayList();
        this.isPreInit = false;
        this.isPreDownLoad = false;
        this.mHttpListener = null;
        this.mCreateInstance = true;
        this.mGlobalEvents = new HashMap<>();
        this.mDefaultFontSize = 32;
        this.frameViewEventListeners = new ArrayList();
        this.isFrameShow = false;
        this.isImmersive = true;
        this.isOnSizeChangedRender = true;
        this.mInstanceId = WXSDKManager.getInstance().generateInstanceId();
        this.mOriginalContext = originalContext;
        init(context);
    }

    public WXSDKInstance() {
        this.mEnd = false;
        this.mHasCreateFinish = false;
        this.mBundleUrl = "";
        this.mUniPagePath = "";
        this.isDestroy = false;
        this.hasException = false;
        this.isRenderSuccess = false;
        this.createInstanceHeartBeat = false;
        this.isCommit = false;
        this.mGlobalEventReceiver = null;
        this.enableLayerType = true;
        this.mNeedValidate = false;
        this.mNeedReLoad = false;
        this.mUseScroller = false;
        this.mInstanceViewPortWidth = 750.0f;
        this.enableFullScreenHeight = false;
        this.mFlatGUIContext = new FlatGUIContext();
        this.isNewFsEnd = false;
        this.componentsInfoExceedGPULimit = new LinkedList();
        this.mExecJSTraceId = WXTracing.nextId();
        this.isViewDisAppear = false;
        this.mwxDims = new String[5];
        this.measureTimes = new long[5];
        this.responseHeaders = new HashMap();
        this.mRenderStrategy = WXRenderStrategy.APPEND_ASYNC;
        this.mDisableSkipFrameworkInit = false;
        this.mRenderType = "platform";
        this.mAutoAdjustDeviceWidth = WXEnvironment.AUTO_ADJUST_ENV_DEVICE_WIDTH;
        this.mCurrentGround = false;
        this.inactiveAddElementAction = new HashMap();
        this.mContentBoxMeasurements = new ArrayMap();
        this.maxHiddenEmbedsNum = -1;
        this.mVisibleListeners = new ArrayList();
        this.isPreInit = false;
        this.isPreDownLoad = false;
        this.mHttpListener = null;
        this.mCreateInstance = true;
        this.mGlobalEvents = new HashMap<>();
        this.mDefaultFontSize = 32;
        this.frameViewEventListeners = new ArrayList();
        this.isFrameShow = false;
        this.isImmersive = true;
        this.isOnSizeChangedRender = true;
        this.mInstanceId = WXSDKManager.getInstance().generateInstanceId();
        this.mWXPerformance = new WXPerformance(this.mInstanceId);
        this.mApmForInstance = new WXInstanceApm(this.mInstanceId);
        WXSDKManager.getInstance().getAllInstanceMap().put(this.mInstanceId, this);
    }

    public WXSDKInstance(Context context, String id) {
        this.mEnd = false;
        this.mHasCreateFinish = false;
        this.mBundleUrl = "";
        this.mUniPagePath = "";
        this.isDestroy = false;
        this.hasException = false;
        this.isRenderSuccess = false;
        this.createInstanceHeartBeat = false;
        this.isCommit = false;
        this.mGlobalEventReceiver = null;
        this.enableLayerType = true;
        this.mNeedValidate = false;
        this.mNeedReLoad = false;
        this.mUseScroller = false;
        this.mInstanceViewPortWidth = 750.0f;
        this.enableFullScreenHeight = false;
        this.mFlatGUIContext = new FlatGUIContext();
        this.isNewFsEnd = false;
        this.componentsInfoExceedGPULimit = new LinkedList();
        this.mExecJSTraceId = WXTracing.nextId();
        this.isViewDisAppear = false;
        this.mwxDims = new String[5];
        this.measureTimes = new long[5];
        this.responseHeaders = new HashMap();
        this.mRenderStrategy = WXRenderStrategy.APPEND_ASYNC;
        this.mDisableSkipFrameworkInit = false;
        this.mRenderType = "platform";
        this.mAutoAdjustDeviceWidth = WXEnvironment.AUTO_ADJUST_ENV_DEVICE_WIDTH;
        this.mCurrentGround = false;
        this.inactiveAddElementAction = new HashMap();
        this.mContentBoxMeasurements = new ArrayMap();
        this.maxHiddenEmbedsNum = -1;
        this.mVisibleListeners = new ArrayList();
        this.isPreInit = false;
        this.isPreDownLoad = false;
        this.mHttpListener = null;
        this.mCreateInstance = true;
        this.mGlobalEvents = new HashMap<>();
        this.mDefaultFontSize = 32;
        this.frameViewEventListeners = new ArrayList();
        this.isFrameShow = false;
        this.isImmersive = true;
        this.isOnSizeChangedRender = true;
        this.mInstanceId = id;
        init(context);
    }

    public WXComponent getRootComponent() {
        return this.mRootComp;
    }

    public void setNestedInstanceInterceptor(NestedInstanceInterceptor interceptor) {
        this.mNestedInstanceInterceptor = interceptor;
    }

    public final WXSDKInstance createNestedInstance(NestedContainer container) {
        WXSDKInstance sdkInstance = newNestedInstance();
        NestedInstanceInterceptor nestedInstanceInterceptor = this.mNestedInstanceInterceptor;
        if (nestedInstanceInterceptor != null) {
            nestedInstanceInterceptor.onCreateNestInstance(sdkInstance, container);
        }
        if (sdkInstance != null) {
            sdkInstance.setComponentObserver(getComponentObserver());
        }
        return sdkInstance;
    }

    /* access modifiers changed from: protected */
    public WXSDKInstance newNestedInstance() {
        return new WXSDKInstance(this.mContext);
    }

    public boolean isHasException() {
        return this.hasException;
    }

    public void setHasException(boolean hasException2) {
        this.hasException = hasException2;
    }

    public void createInstanceFuncHeartBeat() {
        WXLogUtils.d("createInstanceFuncHeartBeat: " + this.mInstanceId);
        this.createInstanceHeartBeat = true;
    }

    public void addOnInstanceVisibleListener(OnInstanceVisibleListener l) {
        this.mVisibleListeners.add(l);
    }

    public void removeOnInstanceVisibleListener(OnInstanceVisibleListener l) {
        this.mVisibleListeners.remove(l);
    }

    public void init(Context context) {
        String str;
        RegisterCache.getInstance().idle(true);
        this.mContext = context;
        this.mContainerInfo = new HashMap(4);
        this.mNativeInvokeHelper = new NativeInvokeHelper(this.mInstanceId);
        if (this.mWXPerformance == null) {
            this.mWXPerformance = new WXPerformance(this.mInstanceId);
        }
        if (this.mApmForInstance == null) {
            this.mApmForInstance = new WXInstanceApm(this.mInstanceId);
        }
        this.mWXPerformance.WXSDKVersion = WXEnvironment.WXSDK_VERSION;
        this.mWXPerformance.JSLibInitTime = WXEnvironment.sJSLibInitTime;
        this.mUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
        WXSDKManager.getInstance().getAllInstanceMap().put(this.mInstanceId, this);
        Map<String, String> map = this.mContainerInfo;
        if (context instanceof Activity) {
            str = context.getClass().getSimpleName();
        } else {
            str = "unKnowContainer";
        }
        map.put(WXInstanceApm.KEY_PAGE_PROPERTIES_CONTAINER_NAME, str);
        this.mContainerInfo.put(WXInstanceApm.KEY_PAGE_PROPERTIES_INSTANCE_TYPE, "page");
        this.mDisableSkipFrameworkInit = isDisableSkipFrameworkInDataRender();
        this.mTimeCalculator = new TimeCalculator(this);
    }

    public void setComponentObserver(ComponentObserver observer) {
        this.mComponentObserver = observer;
    }

    public ComponentObserver getComponentObserver() {
        return this.mComponentObserver;
    }

    public NativeInvokeHelper getNativeInvokeHelper() {
        return this.mNativeInvokeHelper;
    }

    @Deprecated
    public void setBizType(String bizType) {
        if (!TextUtils.isEmpty(bizType)) {
            this.mWXPerformance.bizType = bizType;
        }
    }

    public ScrollView getScrollView() {
        return this.mScrollView;
    }

    public void setRootScrollView(ScrollView scrollView) {
        this.mScrollView = scrollView;
        WXScrollView.WXScrollViewListener wXScrollViewListener = this.mWXScrollViewListener;
        if (wXScrollViewListener != null && (scrollView instanceof WXScrollView)) {
            ((WXScrollView) scrollView).addScrollViewListener(wXScrollViewListener);
        }
    }

    @Deprecated
    public void registerScrollViewListener(WXScrollView.WXScrollViewListener scrollViewListener) {
        this.mWXScrollViewListener = scrollViewListener;
    }

    @Deprecated
    public WXScrollView.WXScrollViewListener getScrollViewListener() {
        return this.mWXScrollViewListener;
    }

    @Deprecated
    public void setIWXUserTrackAdapter(IWXUserTrackAdapter adapter) {
    }

    public void setContainerInfo(String key, String val) {
        this.mContainerInfo.put(key, val);
    }

    public Map<String, String> getContainerInfo() {
        return this.mContainerInfo;
    }

    public void render(String template, Map<String, Object> options, String jsonInitData) {
        render(template, options, jsonInitData, WXRenderStrategy.APPEND_ASYNC);
    }

    @Deprecated
    public void render(String template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        render("default", template, options, jsonInitData, flag);
    }

    public void render(String pageName, String template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        render(pageName, new Script(template), options, jsonInitData, flag);
    }

    public void render(String pageName, Script template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        this.mWXPerformance.beforeInstanceRender(this.mInstanceId);
        if (!WXEnvironment.isApkDebugable() || !"default".equals(pageName)) {
            renderInternal(pageName, template, options, jsonInitData, flag);
        } else if (getUIContext() != null) {
            new AlertDialog.Builder(getUIContext()).setTitle("Error: Missing pageName").setMessage("We highly recommend you to set pageName. Call\nWXSDKInstance#render(String pageName, String template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag)\nto fix it.").show();
        }
    }

    public void render(String pageName, byte[] template, Map<String, Object> options, String jsonInitData) {
        render(pageName, new Script(template), options, jsonInitData, WXRenderStrategy.DATA_RENDER_BINARY);
    }

    private void ensureRenderArchor() {
        if (this.mRenderContainer == null && getContext() != null) {
            setRenderContainer(new RenderContainer(getContext()));
            this.mRenderContainer.setLayoutParams(new ViewGroup.LayoutParams(-1, -1));
            this.mRenderContainer.setBackgroundColor(0);
            this.mRenderContainer.setSDKInstance(this);
            this.mRenderContainer.addOnLayoutChangeListener(this);
        }
    }

    private void renderInternal(String pageName, String template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        if (!this.mRendered && !TextUtils.isEmpty(template)) {
            renderInternal(pageName, new Script(template), options, jsonInitData, flag);
        }
    }

    public boolean isPreInitMode() {
        return this.isPreInit;
    }

    public boolean isPreDownLoad() {
        return this.isPreDownLoad;
    }

    public void onInstanceReady() {
        WXLogUtils.e("test->", "onInstanceReady");
        this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_CONTAINER_READY);
        if (this.isPreInit || this.isPreDownLoad) {
            this.mApmForInstance.onInstanceReady(this.isPreDownLoad);
            if (this.isPreDownLoad) {
                this.mHttpListener.onInstanceReady();
            }
        }
    }

    public void preInit(String pageName, String script, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        this.isPreInit = true;
        this.mRenderStrategy = flag;
        Map<String, Object> renderOptions = options;
        if (renderOptions == null) {
            renderOptions = new HashMap<>();
        }
        this.mApmForInstance.isReady = false;
        WXSDKManager.getInstance().createInstance(this, new Script(script), renderOptions, jsonInitData);
    }

    public void preDownLoad(String url, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        this.isPreDownLoad = true;
        this.mRenderStrategy = flag;
        this.mApmForInstance.isReady = false;
        renderByUrl(url, url, options, jsonInitData, flag);
    }

    private void renderInternal(String pageName, Script template, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        Map<String, Object> renderOptions;
        if (!this.mRendered && template != null) {
            if (!template.isEmpty()) {
                LogDetail logDetail = this.mTimeCalculator.createLogDetail("renderInternal");
                this.mRenderStrategy = flag;
                if (!this.mApmForInstance.hasInit()) {
                    this.mApmForInstance.doInit();
                }
                this.mApmForInstance.setPageName(pageName);
                this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_RENDER_ORGIGIN);
                this.mApmForInstance.doDelayCollectData();
                this.mWXPerformance.pageName = TextUtils.isEmpty(pageName) ? "defaultBundleUrl" : pageName;
                if (TextUtils.isEmpty(this.mBundleUrl)) {
                    this.mBundleUrl = this.mWXPerformance.pageName;
                }
                if (WXTracing.isAvailable()) {
                    WXTracing.TraceEvent traceEvent = WXTracing.newEvent("executeBundleJS", this.mInstanceId, -1);
                    traceEvent.traceId = this.mExecJSTraceId;
                    traceEvent.iid = this.mInstanceId;
                    traceEvent.tname = "JSThread";
                    traceEvent.ph = "B";
                    traceEvent.submit();
                    this.mRenderStartNanos = System.nanoTime();
                }
                ensureRenderArchor();
                if (options == null) {
                    renderOptions = new HashMap<>();
                } else {
                    renderOptions = options;
                }
                if (!WXEnvironment.sDynamicMode || TextUtils.isEmpty(WXEnvironment.sDynamicUrl) || renderOptions.get("dynamicMode") != null) {
                    this.mWXPerformance.JSTemplateSize = (double) (((float) template.length()) / 1024.0f);
                    this.mApmForInstance.addStats(WXInstanceApm.KEY_PAGE_STATS_BUNDLE_SIZE, this.mWXPerformance.JSTemplateSize);
                    this.mRenderStartTime = System.currentTimeMillis();
                    WXSDKManager.getInstance().setCrashInfo(WXEnvironment.WEEX_CURRENT_KEY, pageName);
                    WXParams params = WXBridgeManager.getInstance().getInitParams();
                    float density = WXEnvironment.sApplication.getResources().getDisplayMetrics().density;
                    int deviceWidth = WXViewUtils.getScreenWidth(this.mContext);
                    if (!WeexInstanceMgr.self().getComplier().equalsIgnoreCase("weex")) {
                        setInstanceViewPortWidth(((float) deviceWidth) / density, true);
                    }
                    if (params != null && !TextUtils.equals(params.getDeviceWidth(), String.valueOf(deviceWidth))) {
                        params.setDeviceWidth(String.valueOf(deviceWidth));
                        params.setDeviceHeight(String.valueOf(WXViewUtils.getScreenHeight(this.mContext)));
                        WXEnvironment.addCustomOptions("scale", Float.toString(density));
                        String statusBarHeight = null;
                        if (WXViewUtils.getStatusBarHeight(this.mContext) > 0) {
                            statusBarHeight = String.valueOf(WXViewUtils.getStatusBarHeight(this.mContext));
                        }
                        WXBridgeManager.getInstance().updateInitDeviceParams(params.getDeviceWidth(), params.getDeviceHeight(), Float.toString(density), statusBarHeight);
                        setDeviceDisplay((float) WXViewUtils.getScreenWidth(this.mContext), (float) WXViewUtils.getScreenHeight(this.mContext), WXViewUtils.getScreenDensity(this.mContext));
                    }
                    logDetail.taskStart();
                    if (isPreInitMode()) {
                        getApmForInstance().onStage(WXInstanceApm.KEY_PAGE_STAGES_LOAD_BUNDLE_START);
                        WXBridgeManager.getInstance().loadJsBundleInPreInitMode(getInstanceId(), template.getContent());
                    } else {
                        WXSDKManager.getInstance().createInstance(this, template, renderOptions, jsonInitData);
                    }
                    logDetail.taskEnd();
                    this.mRendered = true;
                    final IWXJscProcessManager wxJscProcessManager = WXSDKManager.getInstance().getWXJscProcessManager();
                    if (wxJscProcessManager != null && wxJscProcessManager.shouldReboot()) {
                        WXSDKManager.getInstance().postOnUiThread(new Runnable() {
                            /* class com.taobao.weex.WXSDKInstance.AnonymousClass3 */

                            public void run() {
                                WXSDKInstance.this.checkWhiteScreen();
                                if (!WXSDKInstance.this.isDestroy && !WXSDKInstance.this.hasException && !WXSDKInstance.this.isRenderSuccess) {
                                    View containerView = WXSDKInstance.this.getContainerView();
                                    if ((containerView instanceof ViewGroup) && ((ViewGroup) containerView).getChildCount() == 0) {
                                        if (wxJscProcessManager.withException(WXSDKInstance.this)) {
                                            WXSDKInstance.this.onJSException(String.valueOf(WXErrorCode.WX_ERR_RELOAD_PAGE), "jsc reboot", "jsc reboot");
                                        }
                                        if (!WXSDKInstance.this.createInstanceHeartBeat) {
                                            WXBridgeManager.getInstance().callReportCrashReloadPage(WXSDKInstance.this.mInstanceId, null);
                                            WXLogUtils.e("callReportCrashReloadPage with jsc reboot");
                                        }
                                    }
                                }
                            }
                        }, wxJscProcessManager.rebootTimeout());
                        return;
                    }
                    return;
                }
                renderOptions.put("dynamicMode", AbsoluteConst.TRUE);
                renderByUrl(pageName, WXEnvironment.sDynamicUrl, renderOptions, jsonInitData, flag);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkWhiteScreen() {
        if (!this.isDestroy && WhiteScreenUtils.doWhiteScreenCheck() && WhiteScreenUtils.isWhiteScreen(this)) {
            WXErrorCode errorCode = WXErrorCode.WX_ERROR_WHITE_SCREEN;
            Map<String, String> args = new HashMap<>(1);
            String vieTreeMsg = WhiteScreenUtils.takeViewTreeSnapShot(this);
            args.put("viewTree", vieTreeMsg == null ? "null viewTreeMsg" : vieTreeMsg);
            args.put("weexCoreThreadStackTrace", WXBridgeManager.getInstance().getWeexCoreThreadStackTrace());
            for (Map.Entry<String, String> entry : WXStateRecord.getInstance().getStateInfo().entrySet()) {
                args.put(entry.getKey(), entry.getValue());
            }
            WXExceptionUtils.commitCriticalExceptionRT(getInstanceId(), errorCode, "checkEmptyScreen", errorCode.getErrorMsg(), args);
        }
    }

    public boolean skipFrameworkInit() {
        return isDataRender() && !this.mDisableSkipFrameworkInit;
    }

    private boolean isDataRender() {
        return getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY || getRenderStrategy() == WXRenderStrategy.DATA_RENDER;
    }

    private void renderByUrlInternal(String pageName, String url, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        Map<String, Object> renderOptions;
        boolean is_wlasm;
        WXRenderStrategy flag2;
        LogDetail logDetail = this.mTimeCalculator.createLogDetail("renderByUrlInternal");
        logDetail.taskStart();
        ensureRenderArchor();
        String pageName2 = wrapPageName(pageName, url);
        this.mBundleUrl = url;
        this.mRenderStrategy = flag;
        if (WXSDKManager.getInstance().getValidateProcessor() != null) {
            this.mNeedValidate = WXSDKManager.getInstance().getValidateProcessor().needValidate(this.mBundleUrl);
        }
        if (options == null) {
            renderOptions = new HashMap<>();
        } else {
            renderOptions = options;
        }
        if (!renderOptions.containsKey("bundleUrl")) {
            renderOptions.put("bundleUrl", url);
        }
        getWXPerformance().pageName = pageName2;
        this.mApmForInstance.doInit();
        this.mApmForInstance.setPageName(pageName2);
        Uri uri = Uri.parse(url);
        if (uri == null || !TextUtils.equals(uri.getScheme(), "file")) {
            if (uri == null || uri.getPath() == null || !uri.getPath().endsWith(".wlasm")) {
                is_wlasm = false;
            } else {
                is_wlasm = true;
            }
            if (is_wlasm) {
                flag2 = WXRenderStrategy.DATA_RENDER_BINARY;
            } else {
                flag2 = flag;
            }
            IWXHttpAdapter adapter = WXSDKManager.getInstance().getIWXHttpAdapter();
            WXRequest wxRequest = new WXRequest();
            wxRequest.url = rewriteUri(Uri.parse(url), AbsURIAdapter.BUNDLE).toString();
            if (!TextUtils.isEmpty(wxRequest.url)) {
                requestUrl = wxRequest.url;
            } else {
                requestUrl = pageName2;
            }
            if (wxRequest.paramMap == null) {
                wxRequest.paramMap = new HashMap();
            }
            wxRequest.instanceId = getInstanceId();
            wxRequest.paramMap.put(WXHttpUtil.KEY_USER_AGENT, WXHttpUtil.assembleUserAgent(this.mContext, WXEnvironment.getConfig()));
            wxRequest.paramMap.put("isBundleRequest", AbsoluteConst.TRUE);
            WXHttpListener wXHttpListener = new WXHttpListener(this, pageName2, renderOptions, jsonInitData, flag2, System.currentTimeMillis());
            this.mHttpListener = wXHttpListener;
            wXHttpListener.isPreDownLoadMode = this.isPreDownLoad;
            this.mHttpListener.setSDKInstance(this);
            this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_START);
            adapter.sendRequest(wxRequest, this.mHttpListener);
            logDetail.taskEnd();
            return;
        }
        this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_START);
        String template = WXFileUtils.loadFileOrAsset(assembleFilePath(uri), this.mContext);
        this.mApmForInstance.onStage(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_END);
        render(pageName2, template, renderOptions, jsonInitData, flag);
    }

    @Deprecated
    public void render(String pageName, String template, Map<String, Object> options, String jsonInitData, int width, int height, WXRenderStrategy flag) {
        render(pageName, template, options, jsonInitData, flag);
    }

    public void render(String template) {
        render("default", template, (Map<String, Object>) null, (String) null, this.mRenderStrategy);
    }

    @Deprecated
    public void render(String template, int width, int height) {
        render(template);
    }

    @Deprecated
    public void renderByUrl(String pageName, String url, Map<String, Object> options, String jsonInitData, int width, int height, WXRenderStrategy flag) {
        renderByUrl(pageName, url, options, jsonInitData, flag);
    }

    public void renderByUrl(String pageName, String url, Map<String, Object> options, String jsonInitData, WXRenderStrategy flag) {
        renderByUrlInternal(pageName, url, options, jsonInitData, flag);
    }

    private String wrapPageName(String pageName, String url) {
        if (!TextUtils.equals(pageName, "default")) {
            return pageName;
        }
        WXExceptionUtils.degradeUrl = url;
        try {
            Uri uri = Uri.parse(url);
            if (uri == null) {
                return url;
            }
            Uri.Builder builder = new Uri.Builder();
            builder.scheme(uri.getScheme());
            builder.authority(uri.getAuthority());
            builder.path(uri.getPath());
            return builder.toString();
        } catch (Exception e) {
            return url;
        }
    }

    private String assembleFilePath(Uri uri) {
        if (uri == null || uri.getPath() == null) {
            return "";
        }
        return uri.getPath().replaceFirst("/", "");
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void reloadPage(boolean reloadThis) {
        WXSDKEngine.reload();
        if (!reloadThis) {
            IWXConfigAdapter adapter = WXSDKManager.getInstance().getWxConfigAdapter();
            if (adapter != null) {
                boolean degrade = Boolean.parseBoolean(adapter.getConfig("android_weex_ext_config", "degrade_to_h5_if_not_reload", AbsoluteConst.TRUE));
                WXLogUtils.e("degrade : " + degrade);
                if (degrade) {
                    onJSException(String.valueOf(WXErrorCode.WX_ERR_RELOAD_PAGE.getErrorCode()), "Do not reloadPage", "Do not reloadPage degradeToH5");
                    WXLogUtils.e("Do not reloadPage degradeToH5");
                }
            }
        } else if (this.mContext != null) {
            Intent intent = new Intent();
            intent.setAction(ACTION_INSTANCE_RELOAD);
            intent.putExtra("url", this.mBundleUrl);
            this.mContext.sendBroadcast(intent);
        }
    }

    public void refreshInstance(Map<String, Object> data) {
        if (data != null) {
            refreshInstance(WXJsonUtils.fromObjectToJSONString(data));
        }
    }

    public void refreshInstance(String jsonData) {
        if (jsonData != null) {
            this.mRefreshStartTime = System.currentTimeMillis();
            WXRefreshData wXRefreshData = this.mLastRefreshData;
            if (wXRefreshData != null) {
                wXRefreshData.isDirty = true;
            }
            this.mLastRefreshData = new WXRefreshData(jsonData, false);
            WXSDKManager.getInstance().refreshInstance(this.mInstanceId, this.mLastRefreshData);
        }
    }

    public WXRenderStrategy getRenderStrategy() {
        return this.mRenderStrategy;
    }

    public Context getUIContext() {
        return this.mContext;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public String getInstanceId() {
        return this.mInstanceId;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public Context getContext() {
        return this.mContext;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public int getWeexHeight() {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer == null) {
            return 0;
        }
        return wXAbstractRenderContainer.getHeight();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public int getWeexWidth() {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer == null) {
            return 0;
        }
        return wXAbstractRenderContainer.getWidth();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public IWXImgLoaderAdapter getImgLoaderAdapter() {
        return WXSDKManager.getInstance().getIWXImgLoaderAdapter();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public IDrawableLoader getDrawableLoader() {
        return WXSDKManager.getInstance().getDrawableLoader();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public URIAdapter getURIAdapter() {
        return WXSDKManager.getInstance().getURIAdapter();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public Uri rewriteUri(Uri uri, String type) {
        return getURIAdapter().rewrite(this, type, uri);
    }

    public IWXHttpAdapter getWXHttpAdapter() {
        return WXSDKManager.getInstance().getIWXHttpAdapter();
    }

    public IWXStatisticsListener getWXStatisticsListener() {
        return this.mStatisticsListener;
    }

    public IWebSocketAdapter getWXWebSocketAdapter() {
        return WXSDKManager.getInstance().getIWXWebSocketAdapter();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    @Deprecated
    public void reloadImages() {
        if (this.mScrollView != null) {
        }
    }

    public boolean isPreRenderMode() {
        return this.isPreRenderMode;
    }

    public void setPreRenderMode(final boolean isPreRenderMode2) {
        WXSDKManager.getInstance().getWXRenderManager().postOnUiThread(new Runnable() {
            /* class com.taobao.weex.WXSDKInstance.AnonymousClass4 */

            public void run() {
                WXSDKInstance.this.isPreRenderMode = isPreRenderMode2;
            }
        }, 0);
    }

    public void setContext(Context context) {
        this.mContext = context;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void registerRenderListener(IWXRenderListener listener) {
        this.mRenderListener = listener;
    }

    @Deprecated
    public void registerActivityStateListener(IWXActivityStateListener listener) {
    }

    public void registerStatisticsListener(IWXStatisticsListener listener) {
        this.mStatisticsListener = listener;
    }

    public void setRenderStartTime(long renderStartTime) {
        this.mRenderStartTime = renderStartTime;
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityCreate() {
        WXModuleManager.onActivityCreate(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityCreate();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely,onActivityCreate can not be call!");
        }
        this.mGlobalEventReceiver = new WXGlobalEventReceiver(this);
        try {
            if (Build.VERSION.SDK_INT >= 33) {
                getContext().registerReceiver(this.mGlobalEventReceiver, new IntentFilter(WXGlobalEventReceiver.EVENT_ACTION), 4);
            } else {
                getContext().registerReceiver(this.mGlobalEventReceiver, new IntentFilter(WXGlobalEventReceiver.EVENT_ACTION));
            }
        } catch (Throwable e) {
            WXLogUtils.e(e.getMessage());
            this.mGlobalEventReceiver = null;
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStart() {
        WXModuleManager.onActivityStart(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityStart();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely,onActivityStart can not be call!");
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean onCreateOptionsMenu(Menu menu) {
        WXModuleManager.onCreateOptionsMenu(getInstanceId(), menu);
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onCreateOptionsMenu(menu);
            return true;
        } else if (!WXEnvironment.isApkDebugable()) {
            return true;
        } else {
            WXLogUtils.w("Warning :Component tree has not build completely,onActivityStart can not be call!");
            return true;
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityPause() {
        onViewDisappear();
        if (!this.isCommit) {
            if (this.mUseScroller) {
                this.mWXPerformance.useScroller = 1;
            }
            this.mWXPerformance.maxDeepViewLayer = getMaxDeepLayer();
            this.mWXPerformance.wxDims = this.mwxDims;
            this.mWXPerformance.measureTimes = this.measureTimes;
            IWXUserTrackAdapter iWXUserTrackAdapter = this.mUserTrackAdapter;
            if (iWXUserTrackAdapter != null) {
                iWXUserTrackAdapter.commit(this.mContext, null, "load", this.mWXPerformance, getUserTrackParams());
            }
            this.isCommit = true;
        }
        WXModuleManager.onActivityPause(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityPause();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely,onActivityPause can not be call!");
        }
        if (!this.mCurrentGround) {
            WXLogUtils.i("Application to be in the backround");
            Intent intent = new Intent(WXGlobalEventReceiver.EVENT_ACTION);
            intent.putExtra(WXGlobalEventReceiver.EVENT_NAME, Constants.Event.PAUSE_EVENT);
            intent.putExtra(WXGlobalEventReceiver.EVENT_WX_INSTANCEID, getInstanceId());
            Context context = this.mContext;
            if (context != null) {
                intent.setPackage(context.getPackageName());
                this.mContext.sendBroadcast(intent);
            } else {
                try {
                    WXEnvironment.getApplication().sendBroadcast(intent);
                } catch (Exception e) {
                    WXLogUtils.e("weex", e);
                }
            }
            this.mCurrentGround = true;
        }
        if ((WXEnvironment.isApkDebugable() || WXEnvironment.isPerf()) && this.mApmForInstance != null) {
            WXLogUtils.e("PerformanceData " + this.mApmForInstance.toPerfString());
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
        WXModuleManager.onActivityResume(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityResume();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely, onActivityResume can not be call!");
        }
        if (this.mCurrentGround) {
            WXLogUtils.i("Application  to be in the foreground");
            Intent intent = new Intent(WXGlobalEventReceiver.EVENT_ACTION);
            intent.putExtra(WXGlobalEventReceiver.EVENT_NAME, Constants.Event.RESUME_EVENT);
            intent.putExtra(WXGlobalEventReceiver.EVENT_WX_INSTANCEID, getInstanceId());
            Context context = this.mContext;
            if (context != null) {
                intent.setPackage(context.getPackageName());
                this.mContext.sendBroadcast(intent);
            } else {
                WXEnvironment.getApplication().sendBroadcast(intent);
            }
            this.mCurrentGround = false;
        }
        onViewAppear();
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStop() {
        WXModuleManager.onActivityStop(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityStop();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely, onActivityStop can not be call!");
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityDestroy() {
        WXModuleManager.onActivityDestroy(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityDestroy();
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely, onActivityDestroy can not be call!");
        }
        this.mTimeCalculator.println();
        destroy();
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public boolean onActivityBack() {
        WXModuleManager.onActivityBack(getInstanceId());
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            return wXComponent.onActivityBack();
        }
        if (!WXEnvironment.isApkDebugable()) {
            return false;
        }
        WXLogUtils.w("Warning :Component tree has not build completely, onActivityBack can not be call!");
        return false;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean onSupportNavigateUp() {
        List<ActionBarHandler> list = this.mWXActionbarHandlers;
        if (list == null) {
            return false;
        }
        for (ActionBarHandler handler : list) {
            if (handler.onSupportNavigateUp()) {
                return true;
            }
        }
        return false;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean onBackPressed() {
        List<OnBackPressedHandler> list = this.mWXBackPressedHandlers;
        if (list != null) {
            for (OnBackPressedHandler handler : list) {
                if (handler.onBackPressed()) {
                    return true;
                }
            }
        }
        WXComponent comp = getRootComponent();
        if (comp == null) {
            return false;
        }
        WXEvent events = comp.getEvents();
        if (events.contains(Constants.Event.NATIVE_BACK) && WXUtils.getBoolean(comp.fireEventWait(Constants.Event.NATIVE_BACK, null).getResult(), false).booleanValue()) {
            return true;
        }
        boolean hasBackPressed = events.contains(Constants.Event.CLICKBACKITEM);
        if (hasBackPressed) {
            fireEvent(comp.getRef(), Constants.Event.CLICKBACKITEM, null, null);
        }
        return hasBackPressed;
    }

    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        WXModuleManager.onActivityResult(getInstanceId(), requestCode, resultCode, data);
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onActivityResult(requestCode, resultCode, data);
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely, onActivityResult can not be call!");
        }
    }

    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        WXModuleManager.onRequestPermissionsResult(getInstanceId(), requestCode, permissions, grantResults);
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent != null) {
            wXComponent.onRequestPermissionsResult(requestCode, permissions, grantResults);
        } else if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.w("Warning :Component tree has not build completely, onRequestPermissionsResult can not be call!");
        }
    }

    public void onViewDisappear() {
        this.isViewDisAppear = false;
        this.mApmForInstance.onDisAppear();
        WXComponent comp = getRootComponent();
        if (comp != null) {
            fireEvent(comp.getRef(), Constants.Event.VIEWDISAPPEAR, null, null);
            for (OnInstanceVisibleListener instance : this.mVisibleListeners) {
                instance.onDisappear();
            }
        }
    }

    public boolean isViewDisAppear() {
        return this.isViewDisAppear;
    }

    public void onViewAppear() {
        this.isViewDisAppear = true;
        this.mApmForInstance.onAppear();
        WXComponent comp = getRootComponent();
        if (comp != null) {
            fireEvent(comp.getRef(), Constants.Event.VIEWAPPEAR, null, null);
            for (OnInstanceVisibleListener instance : this.mVisibleListeners) {
                instance.onAppear();
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void onCreateFinish() {
        if (!this.mHasCreateFinish && this.mContext != null) {
            onViewAppear();
            View wxView = this.mRenderContainer;
            IWXRenderListener iWXRenderListener = this.mRenderListener;
            if (iWXRenderListener != null) {
                iWXRenderListener.onViewCreated(this, wxView);
            }
            IWXStatisticsListener iWXStatisticsListener = this.mStatisticsListener;
            if (iWXStatisticsListener != null) {
                iWXStatisticsListener.onFirstView();
            }
        }
    }

    public void onUpdateFinish() {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("Instance onUpdateSuccess");
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void runOnUiThread(Runnable action) {
        WXSDKManager.getInstance().postOnUiThread(action, 0);
    }

    public void onRenderSuccess(int width, int height) {
        this.isRenderSuccess = true;
        if (!this.isNewFsEnd) {
            getApmForInstance().arriveNewFsRenderTime();
        }
        long time = System.currentTimeMillis() - this.mRenderStartTime;
        long[] renderFinishTime = WXBridgeManager.getInstance().getRenderFinishTime(getInstanceId());
        this.mWXPerformance.callBridgeTime = renderFinishTime[0];
        this.mWXPerformance.cssLayoutTime = renderFinishTime[1];
        this.mWXPerformance.parseJsonTime = renderFinishTime[2];
        this.mWXPerformance.totalTime = (double) time;
        if (((double) this.mWXPerformance.screenRenderTime) < 0.001d) {
            this.mWXPerformance.screenRenderTime = time;
        }
        IWXRenderListener iWXRenderListener = this.mRenderListener;
        if (!(iWXRenderListener == null || this.mContext == null)) {
            iWXRenderListener.onRenderSuccess(this, width, height);
            if (this.mUserTrackAdapter != null) {
                WXPerformance performance = new WXPerformance(this.mInstanceId);
                performance.errCode = WXErrorCode.WX_SUCCESS.getErrorCode();
                performance.args = getBundleUrl();
                this.mUserTrackAdapter.commit(this.mContext, null, IWXUserTrackAdapter.JS_BRIDGE, performance, getUserTrackParams());
            }
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d(WXLogUtils.WEEX_PERF_TAG, this.mWXPerformance.toString());
            }
        }
        if (WXEnvironment.isPerf()) {
            WXLogUtils.e(WXLogUtils.WEEX_PERF_TAG, this.mWXPerformance.getPerfData());
        }
    }

    public void onRefreshSuccess(int width, int height) {
        IWXRenderListener iWXRenderListener = this.mRenderListener;
        if (iWXRenderListener != null && this.mContext != null) {
            iWXRenderListener.onRefreshSuccess(this, width, height);
        }
    }

    public void onChangeElement(WXComponent component, boolean isOutOfScreen) {
        if (!isDestroy() && this.mRenderContainer != null && this.mWXPerformance != null && component != null && !component.isIgnoreInteraction && !this.mRenderContainer.hasConsumeEvent()) {
            long lastElementChangeTime = System.currentTimeMillis();
            if (!this.mHasCreateFinish || lastElementChangeTime - this.mWXPerformance.renderTimeOrigin <= 8000) {
                if (component.mIsAddElementToTree) {
                    getWXPerformance().localInteractionViewAddCount++;
                    if (!isOutOfScreen) {
                        getWXPerformance().interactionViewAddLimitCount++;
                    }
                    component.mIsAddElementToTree = false;
                }
                if (!isOutOfScreen) {
                    this.mApmForInstance.arriveInteraction(component);
                }
            }
        }
    }

    public void onRenderError(final String errCode, final String msg) {
        if (this.mRenderListener != null && this.mContext != null) {
            WXLogUtils.e("onRenderError " + errCode + "," + msg);
            runOnUiThread(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass5 */

                public void run() {
                    if (WXSDKInstance.this.mRenderListener != null && WXSDKInstance.this.mContext != null) {
                        WXSDKInstance.this.mRenderListener.onException(WXSDKInstance.this, errCode, msg);
                    }
                }
            });
        }
    }

    public void onJSException(final String errCode, final String function, final String exception) {
        this.hasException = true;
        if (this.mRenderListener != null && this.mContext != null) {
            WXLogUtils.e("onJSException " + errCode + "," + exception);
            runOnUiThread(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass6 */

                public void run() {
                    if (errCode.equals(WXErrorCode.WX_KEY_EXCEPTION_VALIDAPPKEY.getErrorCode())) {
                        if (WXSDKInstance.this.mContext instanceof Activity) {
                            ErrorDialogUtil.checkAppKeyErrorTips((Activity) WXSDKInstance.this.mContext);
                        }
                    } else if (WXSDKInstance.this.mRenderListener != null && WXSDKInstance.this.mContext != null) {
                        WXSDKInstance.this.mRenderListener.onException(WXSDKInstance.this, errCode, function + exception);
                    }
                }
            });
        }
    }

    public final void onLayoutChange(View v, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
        if (left != oldLeft || top != oldTop || right != oldRight || bottom != oldBottom) {
            onLayoutChange(v);
        }
    }

    public void onLayoutChange(View godView) {
    }

    public void firstScreenCreateInstanceTime(long time) {
        if (this.mCreateInstance) {
            this.mWXPerformance.firstScreenJSFExecuteTime = time - this.mRenderStartTime;
            this.mCreateInstance = false;
        }
    }

    public void callJsTime(long time) {
        if (!this.mEnd) {
            this.mWXPerformance.fsCallJsTotalTime += time;
            this.mWXPerformance.fsCallJsTotalNum++;
        }
    }

    public void onComponentCreate(WXComponent component, long createTime) {
        this.mWXPerformance.mActionAddElementCount++;
        WXPerformance wXPerformance = this.mWXPerformance;
        wXPerformance.mActionAddElementSumTime = (int) (((long) wXPerformance.mActionAddElementSumTime) + createTime);
        if (!this.mEnd) {
            WXPerformance wXPerformance2 = this.mWXPerformance;
            wXPerformance2.fsComponentCreateTime = (int) (((long) wXPerformance2.fsComponentCreateTime) + createTime);
            this.mWXPerformance.fsComponentCount++;
        }
        this.mWXPerformance.componentCount++;
        this.mWXPerformance.componentCreateTime += createTime;
    }

    public void callActionAddElementTime(long time) {
        WXPerformance wXPerformance = this.mWXPerformance;
        wXPerformance.mActionAddElementSumTime = (int) (((long) wXPerformance.mActionAddElementSumTime) + time);
    }

    public void onOldFsRenderTimeLogic() {
        if (!this.mEnd) {
            this.mEnd = true;
            if (!(this.mStatisticsListener == null || this.mContext == null)) {
                runOnUiThread(new Runnable() {
                    /* class com.taobao.weex.WXSDKInstance.AnonymousClass7 */

                    public void run() {
                        if (WXSDKInstance.this.mStatisticsListener != null && WXSDKInstance.this.mContext != null) {
                            Trace.beginSection("onFirstScreen");
                            WXSDKInstance.this.mStatisticsListener.onFirstScreen();
                            Trace.endSection();
                        }
                    }
                });
            }
            this.mApmForInstance.arriveFSRenderTime();
            this.mWXPerformance.fsRenderTime = System.currentTimeMillis();
            this.mWXPerformance.screenRenderTime = System.currentTimeMillis() - this.mRenderStartTime;
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public WXSDKInstance getParentInstance() {
        return this.mParentInstance;
    }

    public void setParentInstance(WXSDKInstance mParentInstance2) {
        this.mParentInstance = mParentInstance2;
    }

    private void destroyView(View rootView) {
        try {
            if (rootView instanceof ViewGroup) {
                ViewGroup cViewGroup = (ViewGroup) rootView;
                for (int index = 0; index < cViewGroup.getChildCount(); index++) {
                    destroyView(cViewGroup.getChildAt(index));
                }
                cViewGroup.removeViews(0, ((ViewGroup) rootView).getChildCount());
                WXReflectionUtils.setValue(rootView, "mChildrenCount", 0);
            }
            if (rootView instanceof Destroyable) {
                ((Destroyable) rootView).destroy();
            }
        } catch (Exception e) {
            WXLogUtils.e("WXSDKInstance destroyView Exception: ", e);
        }
    }

    public synchronized void destroy() {
        if (!isDestroy()) {
            if (this.mParentInstance != null) {
                this.mParentInstance = null;
            }
            this.mApmForInstance.onEnd();
            if (this.mRendered) {
                WXSDKManager.getInstance().destroyInstance(this.mInstanceId);
            }
            if (this.mGlobalEventReceiver != null) {
                getContext().unregisterReceiver(this.mGlobalEventReceiver);
                this.mGlobalEventReceiver = null;
            }
            if (this.mRootComp != null) {
                this.mRootComp.destroy();
                this.mRootComp = null;
            }
            if (this.mRenderContainer != null) {
                destroyView(this.mRenderContainer);
            }
            if (this.mGlobalEvents != null) {
                this.mGlobalEvents.clear();
            }
            if (this.mComponentObserver != null) {
                this.mComponentObserver = null;
            }
            if (this.mLayerOverFlowListeners != null) {
                this.mLayerOverFlowListeners.clear();
            }
            getFlatUIContext().destroy();
            this.mFlatGUIContext = null;
            this.mInstanceOnFireEventInterceptorList = null;
            this.mWXScrollListeners = null;
            this.mWXActionbarHandlers = null;
            this.mWXBackPressedHandlers = null;
            this.mRenderContainer = null;
            this.mNestedInstanceInterceptor = null;
            this.mUserTrackAdapter = null;
            this.mScrollView = null;
            this.mContext = null;
            this.mRenderListener = null;
            this.isDestroy = true;
            this.mStatisticsListener = null;
            if (this.responseHeaders != null) {
                this.responseHeaders.clear();
            }
            if (this.templateRef != null) {
                this.templateRef = null;
            }
            if (this.mContentBoxMeasurements != null) {
                this.mContentBoxMeasurements.clear();
            }
            this.mWXPerformance.afterInstanceDestroy(this.mInstanceId);
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass8 */

                public void run() {
                    WXBridgeManager.getInstance().onInstanceClose(WXSDKInstance.this.getInstanceId());
                    WXSDKInstance.this.inactiveAddElementAction.clear();
                }
            });
            WXBridgeManager.getInstance().postDelay(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass9 */

                public void run() {
                    WXSDKManager.getInstance().getAllInstanceMap().remove(WXSDKInstance.this.mInstanceId);
                }
            }, 1000);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean isDestroy() {
        return this.isDestroy;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public String getBundleUrl() {
        return this.mBundleUrl;
    }

    public String getUniPagePath() {
        return this.mUniPagePath;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public View getRootView() {
        WXComponent wXComponent = this.mRootComp;
        if (wXComponent == null) {
            return null;
        }
        return wXComponent.getRealView();
    }

    public View getContainerView() {
        return this.mRenderContainer;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    @Deprecated
    public void setBundleUrl(String url) {
        this.mBundleUrl = url;
        if (WXSDKManager.getInstance().getValidateProcessor() != null) {
            this.mNeedValidate = WXSDKManager.getInstance().getValidateProcessor().needValidate(this.mBundleUrl);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void setUniPagePath(String path) {
        this.mUniPagePath = path;
    }

    public void onRootCreated(WXComponent root) {
        this.mRootComp = root;
        root.mDeepInComponentTree = 1;
        this.mRenderContainer.addView(root.getHostView());
        setSize(this.mRenderContainer.getWidth(), this.mRenderContainer.getHeight());
    }

    public void moveFixedView(View fixedChild) {
        if (this.mRenderContainer != null) {
            ViewGroup parent = (ViewGroup) fixedChild.getParent();
            if (parent == null) {
                this.mRenderContainer.addView(fixedChild);
            } else if (parent != this.mRenderContainer) {
                parent.removeView(fixedChild);
                this.mRenderContainer.addView(fixedChild);
            }
        }
    }

    public void removeFixedView(View fixedChild) {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer != null) {
            wXAbstractRenderContainer.removeView(fixedChild);
        }
    }

    public int getRenderContainerPaddingLeft() {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer != null) {
            return wXAbstractRenderContainer.getPaddingLeft();
        }
        return 0;
    }

    public int getRenderContainerPaddingRight() {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer != null) {
            return wXAbstractRenderContainer.getPaddingRight();
        }
        return 0;
    }

    public int getRenderContainerPaddingTop() {
        WXAbstractRenderContainer wXAbstractRenderContainer = this.mRenderContainer;
        if (wXAbstractRenderContainer != null) {
            return wXAbstractRenderContainer.getPaddingTop();
        }
        return 0;
    }

    public synchronized List<OnWXScrollListener> getWXScrollListeners() {
        return this.mWXScrollListeners;
    }

    public synchronized void registerOnWXScrollListener(OnWXScrollListener wxScrollListener) {
        if (this.mWXScrollListeners == null) {
            this.mWXScrollListeners = new ArrayList();
        }
        this.mWXScrollListeners.add(wxScrollListener);
    }

    public synchronized void registerActionbarHandler(ActionBarHandler actionBarHandler) {
        if (actionBarHandler != null) {
            if (this.mWXActionbarHandlers == null) {
                this.mWXActionbarHandlers = new ArrayList();
            }
            this.mWXActionbarHandlers.add(actionBarHandler);
        }
    }

    public synchronized void unRegisterActionbarHandler(ActionBarHandler actionBarHandler) {
        if (!(this.mWXActionbarHandlers == null || actionBarHandler == null)) {
            this.mWXActionbarHandlers.remove(actionBarHandler);
        }
    }

    public synchronized void registerBackPressedHandler(OnBackPressedHandler backPressedHandler) {
        if (backPressedHandler != null) {
            if (this.mWXBackPressedHandlers == null) {
                this.mWXBackPressedHandlers = new ArrayList();
            }
            this.mWXBackPressedHandlers.add(backPressedHandler);
        }
    }

    public synchronized void unRegisterBackPressedHandler(OnBackPressedHandler backPressedHandler) {
        if (!(this.mWXBackPressedHandlers == null || backPressedHandler == null)) {
            this.mWXBackPressedHandlers.remove(backPressedHandler);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void setSize(int width, int height) {
        if (width > 0) {
            if (((height > 0) && (!this.isDestroy)) && this.mRendered && this.mRenderContainer != null) {
                if (sScreenHeight < 0) {
                    sScreenHeight = WXViewUtils.getScreenHeight(getContext());
                }
                int i = sScreenHeight;
                if (i > 0) {
                    double screenRatio = (((double) height) / ((double) i)) * 100.0d;
                    if (screenRatio > 100.0d) {
                        screenRatio = 100.0d;
                    }
                    getApmForInstance().addStats(WXInstanceApm.KEY_PAGE_STATS_BODY_RATIO, screenRatio);
                }
                ViewGroup.LayoutParams layoutParams = this.mRenderContainer.getLayoutParams();
                if (layoutParams != null) {
                    final float realWidth = (float) width;
                    final float realHeight = (float) height;
                    WXViewUtils.getScreenDensity(this.mContext);
                    if (!(this.mRenderContainer.getWidth() == width && this.mRenderContainer.getHeight() == height)) {
                        layoutParams.width = width;
                        layoutParams.height = height;
                        this.mRenderContainer.setLayoutParams(layoutParams);
                    }
                    if (this.mRootComp != null && layoutParams != null) {
                        final boolean isWidthWrapContent = layoutParams.width == -2;
                        final boolean isHeightWrapContent = layoutParams.height == -2;
                        WXBridgeManager.getInstance().post(new Runnable() {
                            /* class com.taobao.weex.WXSDKInstance.AnonymousClass10 */

                            public void run() {
                                if (WXSDKInstance.this.mOnSizeListener != null) {
                                    WXSDKInstance.this.mOnSizeListener.onSizeChanged(WXSDKInstance.this.getInstanceId(), realWidth, realHeight, isWidthWrapContent, isHeightWrapContent);
                                } else {
                                    WXBridgeManager.getInstance().setDefaultRootSize(WXSDKInstance.this.getInstanceId(), realWidth, realHeight, isWidthWrapContent, isHeightWrapContent);
                                }
                            }
                        });
                    }
                }
            }
        }
    }

    public void setWXInstanceContainerOnSizeListener(IWXInstanceContainerOnSizeListener listener) {
        this.mOnSizeListener = listener;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireGlobalEventCallback(String eventName, Map<String, Object> params) {
        List<String> callbacks = this.mGlobalEvents.get(eventName);
        if (callbacks != null) {
            for (String callback : callbacks) {
                WXSDKManager.getInstance().callback(this.mInstanceId, callback, params, true);
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireEvent(String elementRef, String type, Map<String, Object> data, Map<String, Object> domChanges, List<Object> eventArgs) {
        fireEvent(elementRef, type, data, domChanges, eventArgs, null);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireEvent(String elementRef, String type, Map<String, Object> data, Map<String, Object> domChanges, List<Object> eventArgs, EventResult callback) {
        onInterceptInstanceEvent(getInstanceId(), elementRef, type, data, domChanges);
        WXPerformance wXPerformance = this.mWXPerformance;
        if (wXPerformance != null && wXPerformance.fsCallEventTotalNum < Integer.MAX_VALUE) {
            this.mWXPerformance.fsCallEventTotalNum++;
        }
        this.mApmForInstance.updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_EVENT_NUM, 1.0d);
        WXBridgeManager.getInstance().fireEventOnNode(getInstanceId(), elementRef, type, data, domChanges, eventArgs, callback);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireEvent(String elementRef, String type, Map<String, Object> data, Map<String, Object> domChanges) {
        fireEvent(elementRef, type, data, domChanges, null);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireEvent(String elementRef, String type, Map<String, Object> data) {
        fireEvent(elementRef, type, data, null);
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireEvent(String ref, String type) {
        fireEvent(ref, type, new HashMap());
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void addEventListener(String eventName, String callback) {
        if (!TextUtils.isEmpty(eventName) && !TextUtils.isEmpty(callback)) {
            List<String> callbacks = this.mGlobalEvents.get(eventName);
            if (callbacks == null) {
                callbacks = new ArrayList();
                this.mGlobalEvents.put(eventName, callbacks);
            }
            callbacks.add(callback);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void removeEventListener(String eventName, String callback) {
        List<String> callbacks;
        if (!TextUtils.isEmpty(eventName) && !TextUtils.isEmpty(callback) && (callbacks = this.mGlobalEvents.get(eventName)) != null) {
            callbacks.remove(callback);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void removeEventListener(String eventName) {
        if (!TextUtils.isEmpty(eventName)) {
            this.mGlobalEvents.remove(eventName);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void fireModuleEvent(String eventName, WXModule module, Map<String, Object> params) {
        if (!(TextUtils.isEmpty(eventName) || module == null)) {
            Map<String, Object> event = new HashMap<>();
            event.put("type", eventName);
            event.put("module", module.getModuleName());
            event.put("data", params);
            List<String> callbacks = module.getEventCallbacks(eventName);
            if (callbacks != null) {
                for (String callback : callbacks) {
                    SimpleJSCallback jsCallback = new SimpleJSCallback(this.mInstanceId, callback);
                    if (module.isOnce(callback)) {
                        jsCallback.invoke(event);
                    } else {
                        jsCallback.invokeAndKeepAlive(event);
                    }
                }
            }
        }
    }

    public boolean checkModuleEventRegistered(String eventName, WXModule module) {
        List<String> events;
        if (module == null || (events = module.getEventCallbacks(eventName)) == null || events.size() <= 0) {
            return false;
        }
        return true;
    }

    public WXPerformance getWXPerformance() {
        return this.mWXPerformance;
    }

    public WXInstanceApm getApmForInstance() {
        return this.mApmForInstance;
    }

    public Map<String, Serializable> getUserTrackParams() {
        return this.mUserTrackParams;
    }

    public void addUserTrackParameter(String key, Serializable value) {
        if (this.mUserTrackParams == null) {
            this.mUserTrackParams = new ConcurrentHashMap();
        }
        this.mUserTrackParams.put(key, value);
    }

    public void clearUserTrackParameters() {
        Map<String, Serializable> map = this.mUserTrackParams;
        if (map != null) {
            map.clear();
        }
    }

    public void removeUserTrackParameter(String key) {
        Map<String, Serializable> map = this.mUserTrackParams;
        if (map != null) {
            map.remove(key);
        }
    }

    public int getMaxDeepLayer() {
        return this.mMaxDeepLayer;
    }

    public void setMaxDeepLayer(int maxDeepLayer) {
        this.mMaxDeepLayer = maxDeepLayer;
        this.mApmForInstance.updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_DEEP_VIEW, (double) maxDeepLayer);
    }

    public void setMaxDomDeep(int maxDomDeep) {
        this.mApmForInstance.updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_DEEP_DOM, (double) maxDomDeep);
        WXPerformance wXPerformance = this.mWXPerformance;
        if (wXPerformance != null && wXPerformance.maxDeepVDomLayer <= maxDomDeep) {
            this.mWXPerformance.maxDeepVDomLayer = maxDomDeep;
        }
    }

    public void onHttpStart() {
        if (!this.mEnd) {
            this.mWXPerformance.fsRequestNum++;
        }
    }

    public String getTemplateInfo() {
        String template = getTemplate();
        if (template == null) {
            return " template md5 null ,httpHeader:" + JSONObject.toJSONString(this.responseHeaders);
        } else if (TextUtils.isEmpty(template)) {
            return " template md5  length 0 ,httpHeader" + JSONObject.toJSONString(this.responseHeaders);
        } else {
            try {
                byte[] bts = template.getBytes("UTF-8");
                String sourceMD5 = WXFileUtils.md5(bts);
                String sourceBase64MD5 = WXFileUtils.base64Md5(bts);
                ArrayList<String> sourceMD5List = new ArrayList<>();
                ArrayList<String> sourceBase64MD5List = new ArrayList<>();
                sourceMD5List.add(sourceMD5);
                sourceBase64MD5List.add(sourceBase64MD5);
                this.responseHeaders.put("templateSourceMD5", sourceMD5List);
                this.responseHeaders.put(SOURCE_TEMPLATE_BASE64_MD5, sourceBase64MD5List);
                return " template md5 " + sourceMD5 + " length " + bts.length + " base64 md5 " + sourceBase64MD5 + " response header " + JSONObject.toJSONString(this.responseHeaders);
            } catch (Exception e) {
                return "template md5 getBytes error";
            }
        }
    }

    public boolean isContentMd5Match() {
        Map<String, List<String>> map = this.responseHeaders;
        if (map == null) {
            return true;
        }
        List<String> contentMD5s = map.get("Content-Md5");
        if (contentMD5s == null) {
            contentMD5s = this.responseHeaders.get("content-md5");
        }
        if (contentMD5s == null || contentMD5s.size() <= 0) {
            return true;
        }
        String md5 = contentMD5s.get(0);
        List<String> sourceBase64Md5 = this.responseHeaders.get(SOURCE_TEMPLATE_BASE64_MD5);
        if (sourceBase64Md5 == null) {
            getTemplateInfo();
            sourceBase64Md5 = this.responseHeaders.get(SOURCE_TEMPLATE_BASE64_MD5);
        }
        if (sourceBase64Md5 == null || sourceBase64Md5.size() == 0) {
            return true;
        }
        return md5.equals(sourceBase64Md5.get(0));
    }

    public String getTemplate() {
        WeakReference<String> weakReference = this.templateRef;
        if (weakReference == null) {
            return null;
        }
        return weakReference.get();
    }

    public void setTemplate(String template) {
        this.templateRef = new WeakReference<>(template);
    }

    public void OnVSync() {
        if (WXBridgeManager.getInstance().notifyLayout(getInstanceId())) {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.WXSDKInstance.AnonymousClass11 */

                public void run() {
                    WXBridgeManager.getInstance().forceLayout(WXSDKInstance.this.getInstanceId());
                }
            });
        }
    }

    public void addContentBoxMeasurement(long renderObjectPtr, ContentBoxMeasurement contentBoxMeasurement) {
        this.mContentBoxMeasurements.put(Long.valueOf(renderObjectPtr), contentBoxMeasurement);
    }

    public ContentBoxMeasurement getContentBoxMeasurement(long renderObjectPtr) {
        return this.mContentBoxMeasurements.get(Long.valueOf(renderObjectPtr));
    }

    private void onInterceptInstanceEvent(String instanceId, String elementRef, String type, Map<String, Object> data, Map<String, Object> domChanges) {
        List<InstanceOnFireEventInterceptor> list = this.mInstanceOnFireEventInterceptorList;
        if (list != null) {
            for (InstanceOnFireEventInterceptor instanceOnFireEventInterceptor : list) {
                instanceOnFireEventInterceptor.onInterceptFireEvent(instanceId, elementRef, type, data, domChanges);
            }
        }
    }

    public List<InstanceOnFireEventInterceptor> getInstanceOnFireEventInterceptorList() {
        if (this.mInstanceOnFireEventInterceptorList == null) {
            this.mInstanceOnFireEventInterceptorList = new ArrayList();
        }
        return this.mInstanceOnFireEventInterceptorList;
    }

    public void addInstanceOnFireEventInterceptor(InstanceOnFireEventInterceptor instanceOnFireEventInterceptor) {
        if (instanceOnFireEventInterceptor != null && !getInstanceOnFireEventInterceptorList().contains(instanceOnFireEventInterceptor)) {
            getInstanceOnFireEventInterceptorList().add(instanceOnFireEventInterceptor);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public String getRenderType() {
        return this.mRenderType;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void setRenderType(String renderType) {
        this.mRenderType = renderType;
    }

    private static boolean isDisableSkipFrameworkInDataRender() {
        IWXConfigAdapter adapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (adapter == null) {
            return false;
        }
        return AbsoluteConst.TRUE.equals(adapter.getConfig("wxeagle", "disable_skip_framework_init", AbsoluteConst.FALSE));
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public int getDefaultFontSize() {
        return this.mDefaultFontSize;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void setDefaultFontSize(int size) {
        this.mDefaultFontSize = size;
    }

    public void addFrameViewEventListener(FrameViewEventListener listener) {
        if (!this.frameViewEventListeners.contains(listener)) {
            this.frameViewEventListeners.add(listener);
        }
    }

    public synchronized void removeFrameViewEventListener(FrameViewEventListener listener) {
        if (this.frameViewEventListeners.contains(listener)) {
            this.frameViewEventListeners.remove(listener);
        }
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean isFrameViewShow() {
        return this.isFrameShow;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public synchronized void onShowAnimationEnd() {
        this.isFrameShow = true;
        ArrayList<FrameViewEventListener> temporary = new ArrayList<>();
        temporary.addAll(this.frameViewEventListeners);
        Iterator<FrameViewEventListener> it = temporary.iterator();
        while (it.hasNext()) {
            it.next().onShowAnimationEnd();
        }
        temporary.clear();
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public boolean isImmersive() {
        return this.isImmersive;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public void setImmersive(boolean immersive) {
        this.isImmersive = immersive;
    }

    public void setonSizeChangedRnder(boolean isRnder) {
        this.isOnSizeChangedRender = isRnder;
    }

    public boolean isOnSizeChangedRender() {
        return this.isOnSizeChangedRender;
    }

    @Override // io.dcloud.feature.uniapp.AbsSDKInstance
    public Context getOriginalContext() {
        return this.mOriginalContext;
    }
}
