package com.taobao.weex.adapter;

import android.net.Uri;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import java.util.List;

public class DefaultUriAdapter implements URIAdapter {
    @Override // io.dcloud.feature.uniapp.adapter.AbsURIAdapter
    public Uri rewrite(WXSDKInstance instance, String type, Uri uri) {
        return rewrite(instance.getBundleUrl(), type, uri);
    }

    @Override // io.dcloud.feature.uniapp.adapter.AbsURIAdapter
    public Uri rewrite(String bundleURL, String type, Uri uri) {
        if (TextUtils.isEmpty(bundleURL)) {
            return uri;
        }
        Uri base = Uri.parse(bundleURL);
        Uri.Builder resultBuilder = uri.buildUpon();
        if (!uri.isRelative()) {
            return uri;
        }
        if (uri.getEncodedPath().length() != 0) {
            return buildRelativeURI(resultBuilder, base, uri).build();
        }
        if (!"image".equals(type) || !TextUtils.isEmpty(uri.toString())) {
            return base;
        }
        return uri;
    }

    private Uri.Builder buildRelativeURI(Uri.Builder resultBuilder, Uri base, Uri uri) {
        if (uri.getAuthority() != null) {
            return resultBuilder.scheme(base.getScheme());
        }
        resultBuilder.encodedAuthority(base.getEncodedAuthority()).scheme(base.getScheme()).path(null);
        if (uri.getPath().startsWith("/")) {
            resultBuilder.appendEncodedPath(uri.getEncodedPath().substring(1));
        } else {
            List<String> segments = base.getPathSegments();
            int ignoreLast = 1;
            if (base.getPath().endsWith("/")) {
                ignoreLast = 0;
            }
            int len = segments.size() - ignoreLast;
            for (int i = 0; i < len; i++) {
                resultBuilder.appendEncodedPath(segments.get(i));
            }
            resultBuilder.appendEncodedPath(uri.getEncodedPath());
        }
        return resultBuilder;
    }
}
