package com.taobao.weex.appfram.clipboard;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.utils.WXLogUtils;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.HashMap;
import java.util.Map;

public class WXClipboardModule extends WXModule implements IWXClipboard {
    private static final String DATA = "data";
    private static final String RESULT = "result";
    private static final String RESULT_FAILED = "failed";
    private static final String RESULT_OK = "success";
    private final String CLIP_KEY = "WEEX_CLIP_KEY_MAIN";

    @Override // com.taobao.weex.appfram.clipboard.IWXClipboard
    @JSMethod
    public void setString(String text) {
        if (text != null) {
            ((ClipboardManager) this.mWXSDKInstance.getContext().getSystemService("clipboard")).setPrimaryClip(ClipData.newPlainText("WEEX_CLIP_KEY_MAIN", text));
        }
    }

    @Override // com.taobao.weex.appfram.clipboard.IWXClipboard
    @JSMethod
    public void getString(JSCallback callback) {
        Context context = this.mWXSDKInstance.getContext();
        Map<String, Object> map = new HashMap<>(2);
        ClipData clip = ((ClipboardManager) context.getSystemService("clipboard")).getPrimaryClip();
        CharSequence charSequence = "";
        Object obj = "failed";
        if (clip == null || clip.getItemCount() <= 0) {
            map.put("result", obj);
            map.put("data", charSequence);
        } else {
            CharSequence text = coerceToText(context, clip.getItemAt(0));
            if (text != null) {
                obj = "success";
            }
            map.put("result", obj);
            if (text != null) {
                charSequence = text;
            }
            map.put("data", charSequence);
        }
        if (callback != null) {
            callback.invoke(map);
        }
    }

    private CharSequence coerceToText(Context context, ClipData.Item item) {
        Uri uri;
        CharSequence text = item.getText();
        if (text != null) {
            return text;
        }
        uri = item.getUri();
        if (uri != null) {
            InputStreamReader reader = null;
            FileInputStream stream = null;
            try {
                FileInputStream stream2 = context.getContentResolver().openTypedAssetFileDescriptor(uri, "text/*", null).createInputStream();
                InputStreamReader reader2 = new InputStreamReader(stream2, "UTF-8");
                StringBuilder builder = new StringBuilder(128);
                char[] buffer = new char[8192];
                while (true) {
                    int len = reader2.read(buffer);
                    if (len <= 0) {
                        break;
                    }
                    builder.append(buffer, 0, len);
                }
                String sb = builder.toString();
                try {
                    reader2.close();
                } catch (IOException e) {
                }
                if (stream2 != null) {
                    try {
                        stream2.close();
                    } catch (IOException e2) {
                    }
                }
                return sb;
            } catch (FileNotFoundException e3) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e4) {
                    }
                }
                if (0 != 0) {
                    stream.close();
                }
            } catch (IOException e5) {
                WXLogUtils.w("ClippedData Failure loading text.", e5);
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e6) {
                    }
                }
                if (0 != 0) {
                    try {
                        stream.close();
                    } catch (IOException e7) {
                    }
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        reader.close();
                    } catch (IOException e8) {
                    }
                }
                if (0 != 0) {
                    try {
                        stream.close();
                    } catch (IOException e9) {
                    }
                }
                throw th;
            }
        } else {
            Intent intent = item.getIntent();
            if (intent != null) {
                return intent.toUri(1);
            }
            return null;
        }
        return uri.toString();
    }
}
