package com.taobao.weex.appfram.navigator;

import android.app.ActionBar;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import androidx.appcompat.app.AppCompatActivity;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.utils.WXLogUtils;

public class WXNavigatorModule extends WXModule {
    public static final String CALLBACK_MESSAGE = "message";
    public static final String CALLBACK_RESULT = "result";
    private static final String INSTANCE_ID = "instanceId";
    public static final String MSG_FAILED = "WX_FAILED";
    public static final String MSG_PARAM_ERR = "WX_PARAM_ERR";
    public static final String MSG_SUCCESS = "WX_SUCCESS";
    private static final String TAG = "Navigator";
    private static final String URL = "url";
    private static final String WEEX = "com.taobao.android.intent.category.WEEX";

    @JSMethod(uiThread = true)
    public void open(JSONObject options, JSCallback success, JSCallback failure) {
        if (options != null) {
            String url = options.getString("url");
            JSCallback callback = success;
            JSONObject result = new JSONObject();
            if (!TextUtils.isEmpty(url)) {
                Uri rawUri = Uri.parse(url);
                String scheme = rawUri.getScheme();
                if (TextUtils.isEmpty(scheme) || "http".equalsIgnoreCase(scheme) || "https".equalsIgnoreCase(scheme)) {
                    push(options.toJSONString(), success);
                } else {
                    try {
                        this.mWXSDKInstance.getContext().startActivity(new Intent("android.intent.action.VIEW", rawUri));
                        result.put("result", (Object) MSG_SUCCESS);
                    } catch (Throwable e) {
                        e.printStackTrace();
                        result.put("result", (Object) MSG_FAILED);
                        result.put("message", (Object) "Open page failed.");
                        callback = failure;
                    }
                }
            } else {
                result.put("result", (Object) MSG_PARAM_ERR);
                result.put("message", (Object) "The URL parameter is empty.");
                callback = failure;
            }
            if (callback != null) {
                callback.invoke(result);
            }
        }
    }

    @JSMethod(uiThread = true)
    public void close(JSONObject options, JSCallback success, JSCallback failure) {
        JSCallback callback;
        JSONObject result = new JSONObject();
        if (this.mWXSDKInstance.getContext() instanceof Activity) {
            callback = success;
            ((Activity) this.mWXSDKInstance.getContext()).finish();
        } else {
            result.put("result", (Object) MSG_FAILED);
            result.put("message", (Object) "Close page failed.");
            callback = failure;
        }
        if (callback != null) {
            callback.invoke(result);
        }
    }

    @JSMethod(uiThread = true)
    public void push(String param, JSCallback callback) {
        if (!TextUtils.isEmpty(param)) {
            if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().push(param)) {
                if (this.mWXSDKInstance.getContext() instanceof Activity) {
                    Activity activity = (Activity) this.mWXSDKInstance.getContext();
                    if (WXSDKEngine.getNavigator() != null && WXSDKEngine.getNavigator().push(activity, param)) {
                        if (callback != null) {
                            callback.invoke(MSG_SUCCESS);
                            return;
                        }
                        return;
                    }
                }
                try {
                    String url = JSON.parseObject(param).getString("url");
                    if (!TextUtils.isEmpty(url)) {
                        Uri rawUri = Uri.parse(url);
                        String scheme = rawUri.getScheme();
                        Uri.Builder builder = rawUri.buildUpon();
                        if (TextUtils.isEmpty(scheme)) {
                            builder.scheme("http");
                        }
                        Intent intent = new Intent("android.intent.action.VIEW", builder.build());
                        intent.addCategory(WEEX);
                        intent.putExtra("instanceId", this.mWXSDKInstance.getInstanceId());
                        this.mWXSDKInstance.getContext().startActivity(intent);
                        if (callback != null) {
                            callback.invoke(MSG_SUCCESS);
                        }
                    }
                } catch (Exception e) {
                    WXLogUtils.eTag("Navigator", e);
                    if (callback != null) {
                        callback.invoke(MSG_FAILED);
                    }
                }
            } else if (callback != null) {
                callback.invoke(MSG_SUCCESS);
            }
        } else if (callback != null) {
            callback.invoke(MSG_FAILED);
        }
    }

    @JSMethod(uiThread = true)
    public void pop(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().pop(param)) {
            if (this.mWXSDKInstance.getContext() instanceof Activity) {
                Activity activity = (Activity) this.mWXSDKInstance.getContext();
                if (WXSDKEngine.getNavigator() == null || !WXSDKEngine.getNavigator().pop(activity, param)) {
                    if (callback != null) {
                        callback.invoke(MSG_SUCCESS);
                    }
                    ((Activity) this.mWXSDKInstance.getContext()).finish();
                } else if (callback != null) {
                    callback.invoke(MSG_SUCCESS);
                }
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarRightItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarRightItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarRightItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarRightItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarLeftItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarLeftItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarLeftItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarLeftItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarMoreItem(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarMoreItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void clearNavBarMoreItem(String param, JSCallback callback) {
        if (WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().clearNavBarMoreItem(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod(uiThread = true)
    public void setNavBarTitle(String param, JSCallback callback) {
        if (TextUtils.isEmpty(param) || WXSDKEngine.getActivityNavBarSetter() == null || !WXSDKEngine.getActivityNavBarSetter().setNavBarTitle(param)) {
            if (callback != null) {
                callback.invoke(MSG_FAILED);
            }
        } else if (callback != null) {
            callback.invoke(MSG_SUCCESS);
        }
    }

    @JSMethod
    public void setNavBarHidden(String param, String callback) {
        String message = MSG_FAILED;
        try {
            if (changeVisibilityOfActionBar(this.mWXSDKInstance.getContext(), JSON.parseObject(param).getInteger("hidden").intValue())) {
                message = MSG_SUCCESS;
            }
        } catch (JSONException e) {
            WXLogUtils.e("Navigator", WXLogUtils.getStackTrace(e));
        }
        WXBridgeManager.getInstance().callback(this.mWXSDKInstance.getInstanceId(), callback, message);
    }

    private boolean changeVisibilityOfActionBar(Context context, int visibility) {
        ActionBar actionbar;
        boolean hasAppCompatActivity = false;
        try {
            Class.forName("android.support.v7.app.AppCompatActivity");
            hasAppCompatActivity = true;
        } catch (ClassNotFoundException e) {
            e.printStackTrace();
        }
        if (hasAppCompatActivity && (this.mWXSDKInstance.getContext() instanceof AppCompatActivity)) {
            androidx.appcompat.app.ActionBar actionbar2 = ((AppCompatActivity) this.mWXSDKInstance.getContext()).getSupportActionBar();
            if (actionbar2 == null) {
                return false;
            }
            if (visibility == 0) {
                actionbar2.show();
                return true;
            } else if (visibility != 1) {
                return false;
            } else {
                actionbar2.hide();
                return true;
            }
        } else if (!(this.mWXSDKInstance.getContext() instanceof Activity) || (actionbar = ((Activity) this.mWXSDKInstance.getContext()).getActionBar()) == null) {
            return false;
        } else {
            if (visibility == 0) {
                actionbar.show();
                return true;
            } else if (visibility != 1) {
                return false;
            } else {
                actionbar.hide();
                return true;
            }
        }
    }
}
