package com.taobao.weex.appfram.pickers;

import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.TimePicker;
import com.igexin.push.core.b;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.module.WXModalUIModule;
import com.taobao.weex.utils.WXLogUtils;
import com.xiaomi.mipush.sdk.Constants;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.Map;

public class DatePickerImpl {
    private static final int DEFAULT_END_YEAR = 2100;
    private static final int DEFAULT_START_YEAR = 1900;
    private static SimpleDateFormat dateFormatter;
    private static SimpleDateFormat timeFormatter;

    public interface OnPickListener {
        void onPick(boolean z, String str);
    }

    public static void pickDate(Context context, String value, String max, String min, final OnPickListener listener, Map<String, Object> extras) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(parseDate(value));
        DatePickerDialog dialog = new DatePickerDialog(context, new DatePickerDialog.OnDateSetListener() {
            /* class com.taobao.weex.appfram.pickers.DatePickerImpl.AnonymousClass1 */

            public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth) {
                String realMonthString;
                String realDayString;
                int realMonth = monthOfYear + 1;
                if (realMonth < 10) {
                    realMonthString = "0" + realMonth;
                } else {
                    realMonthString = String.valueOf(realMonth);
                }
                if (dayOfMonth < 10) {
                    realDayString = "0" + dayOfMonth;
                } else {
                    realDayString = String.valueOf(dayOfMonth);
                }
                OnPickListener.this.onPick(true, year + "-" + realMonthString + "-" + realDayString);
            }
        }, calendar.get(1), calendar.get(2), calendar.get(5));
        DatePicker datePicker = dialog.getDatePicker();
        Calendar defaultMinDate = Calendar.getInstance(Locale.getDefault());
        Calendar defaultMaxDate = Calendar.getInstance(Locale.getDefault());
        defaultMinDate.set(1900, 0, 1);
        defaultMaxDate.set(2100, 11, 31);
        if (!TextUtils.isEmpty(min)) {
            if (datePicker.getMaxDate() >= parseDate(min).getTime()) {
                datePicker.setMinDate(parseDate(min).getTime());
            } else {
                datePicker.setMinDate(defaultMinDate.getTimeInMillis());
                datePicker.setMaxDate(defaultMaxDate.getTimeInMillis());
            }
        }
        if (!TextUtils.isEmpty(max)) {
            if (datePicker.getMinDate() <= parseDate(max).getTime()) {
                datePicker.setMaxDate(parseDate(max).getTime());
            } else {
                datePicker.setMinDate(defaultMinDate.getTimeInMillis());
                datePicker.setMaxDate(defaultMaxDate.getTimeInMillis());
            }
        }
        dialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
            /* class com.taobao.weex.appfram.pickers.DatePickerImpl.AnonymousClass2 */

            public void onCancel(DialogInterface dialog) {
                OnPickListener.this.onPick(false, null);
            }
        });
        Object obj = null;
        setButtonText(dialog, -2, String.valueOf(extras != null ? extras.get(WXModalUIModule.CANCEL_TITLE) : null));
        if (extras != null) {
            obj = extras.get("confirmTitle");
        }
        setButtonText(dialog, -1, String.valueOf(obj));
        dialog.show();
    }

    public static void pickTime(Context context, String value, final OnPickListener listener, Map<String, Object> extras) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(parseTime(value));
        TimePickerDialog dialog = new TimePickerDialog(context, new TimePickerDialog.OnTimeSetListener() {
            /* class com.taobao.weex.appfram.pickers.DatePickerImpl.AnonymousClass3 */

            public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
                String h;
                String m;
                if (hourOfDay < 10) {
                    h = "0" + hourOfDay;
                } else {
                    h = String.valueOf(hourOfDay);
                }
                if (minute < 10) {
                    m = "0" + minute;
                } else {
                    m = String.valueOf(minute);
                }
                OnPickListener.this.onPick(true, h + Constants.COLON_SEPARATOR + m);
            }
        }, calendar.get(11), calendar.get(12), false);
        dialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
            /* class com.taobao.weex.appfram.pickers.DatePickerImpl.AnonymousClass4 */

            public void onCancel(DialogInterface dialog) {
                OnPickListener.this.onPick(false, null);
            }
        });
        Object obj = null;
        setButtonText(dialog, -2, String.valueOf(extras != null ? extras.get(WXModalUIModule.CANCEL_TITLE) : null));
        if (extras != null) {
            obj = extras.get("confirmTitle");
        }
        setButtonText(dialog, -1, String.valueOf(obj));
        dialog.show();
    }

    private static Date parseDate(String s) {
        if (dateFormatter == null) {
            dateFormatter = new SimpleDateFormat("yyyy-MM-dd", Locale.getDefault());
        }
        try {
            return dateFormatter.parse(s);
        } catch (ParseException e) {
            WXLogUtils.w("[DatePickerImpl] " + e.toString());
            return new Date();
        }
    }

    private static Date parseTime(String s) {
        if (timeFormatter == null) {
            timeFormatter = new SimpleDateFormat("HH:mm", Locale.getDefault());
        }
        try {
            return timeFormatter.parse(s);
        } catch (ParseException e) {
            WXLogUtils.w("[DatePickerImpl] " + e.toString());
            return new Date();
        }
    }

    private static void setButtonText(final AlertDialog dialog, final int which, final CharSequence text) {
        if (!TextUtils.isEmpty(text) && !b.m.equals(text)) {
            try {
                dialog.getWindow().getDecorView().post(WXThread.secure(new Runnable() {
                    /* class com.taobao.weex.appfram.pickers.DatePickerImpl.AnonymousClass5 */

                    public void run() {
                        Button button = dialog.getButton(which);
                        if (button != null) {
                            button.setAllCaps(false);
                            button.setText(text);
                        }
                    }
                }));
            } catch (Throwable t) {
                t.printStackTrace();
            }
        }
    }
}
