package com.taobao.weex.appfram.pickers;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Checkable;
import android.widget.TextView;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.pickers.DatePickerImpl;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class WXPickersModule extends WXModule {
    private static final String CANCEL = "cancel";
    private static final String DATA = "data";
    private static final String ERROR = "error";
    private static final String KEY_CANCEL_TITLE = "cancelTitle";
    private static final String KEY_CANCEL_TITLE_COLOR = "cancelTitleColor";
    private static final String KEY_CONFIRM_TITLE = "confirmTitle";
    private static final String KEY_CONFIRM_TITLE_COLOR = "confirmTitleColor";
    private static final String KEY_INDEX = "index";
    private static final String KEY_ITEMS = "items";
    private static final String KEY_MAX = "max";
    private static final String KEY_MIN = "min";
    private static final String KEY_SELECTION_COLOR = "selectionColor";
    private static final String KEY_TEXT_COLOR = "textColor";
    private static final String KEY_TITLE = "title";
    private static final String KEY_TITLE_BACKGROUND_COLOR = "titleBackgroundColor";
    private static final String KEY_TITLE_COLOR = "titleColor";
    private static final String KEY_VALUE = "value";
    private static final String RESULT = "result";
    private static final String SUCCESS = "success";
    private int selected;

    @JSMethod
    public void pick(Map<String, Object> options, JSCallback callback) {
        try {
            performSinglePick(safeConvert((List) getOption(options, KEY_ITEMS, new ArrayList())), options, callback);
        } catch (Throwable throwable) {
            throwable.printStackTrace();
        }
    }

    @JSMethod
    public void pickDate(Map<String, Object> options, JSCallback callback) {
        performPickDate(options, callback);
    }

    @JSMethod
    public void pickTime(Map<String, Object> options, JSCallback callback) {
        performPickTime(options, callback);
    }

    private List<String> safeConvert(List src) {
        List<String> result = new ArrayList<>(src.size());
        for (Object obj : src) {
            result.add(String.valueOf(obj));
        }
        return result;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private <T> T getOption(Map<String, Object> options, String key, T defValue) {
        T t = (T) options.get(key);
        if (t == null) {
            return defValue;
        }
        return t;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getColor(Map<String, Object> options, String key, int defValue) {
        Object value = getOption(options, key, null);
        if (value == null) {
            return defValue;
        }
        return WXResourceUtils.getColor(value.toString(), defValue);
    }

    private void performPickTime(Map<String, Object> options, final JSCallback callback) {
        DatePickerImpl.pickTime(this.mWXSDKInstance.getContext(), (String) getOption(options, "value", ""), new DatePickerImpl.OnPickListener() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass1 */

            @Override // com.taobao.weex.appfram.pickers.DatePickerImpl.OnPickListener
            public void onPick(boolean set, String result) {
                if (set) {
                    Map<String, Object> ret = new HashMap<>(2);
                    ret.put("result", "success");
                    ret.put("data", result);
                    callback.invoke(ret);
                    return;
                }
                Map<String, Object> ret2 = new HashMap<>(2);
                ret2.put("result", "cancel");
                ret2.put("data", null);
                callback.invoke(ret2);
            }
        }, options);
    }

    private void performPickDate(Map<String, Object> options, final JSCallback callback) {
        DatePickerImpl.pickDate(this.mWXSDKInstance.getContext(), (String) getOption(options, "value", ""), (String) getOption(options, "max", ""), (String) getOption(options, "min", ""), new DatePickerImpl.OnPickListener() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass2 */

            @Override // com.taobao.weex.appfram.pickers.DatePickerImpl.OnPickListener
            public void onPick(boolean set, String result) {
                if (set) {
                    Map<String, Object> ret = new HashMap<>(2);
                    ret.put("result", "success");
                    ret.put("data", result);
                    callback.invoke(ret);
                    return;
                }
                Map<String, Object> ret2 = new HashMap<>(2);
                ret2.put("result", "cancel");
                ret2.put("data", null);
                callback.invoke(ret2);
            }
        }, options);
    }

    private void performSinglePick(List<String> items, final Map<String, Object> options, final JSCallback callback) {
        this.selected = ((Integer) getOption(options, "index", 0)).intValue();
        final int textColor = getColor(options, KEY_TEXT_COLOR, 0);
        final int selectionColor = getColor(options, KEY_SELECTION_COLOR, 0);
        final ArrayAdapter adapter = new ArrayAdapter<String>(this.mWXSDKInstance.getContext(), 17367055, items) {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass3 */

            public View getView(int position, View convertView, ViewGroup parent) {
                int i;
                View itemView = super.getView(position, convertView, parent);
                if (itemView != null && (itemView instanceof Checkable)) {
                    boolean needSelected = position == WXPickersModule.this.selected;
                    ((Checkable) itemView).setChecked(needSelected);
                    if (needSelected) {
                        itemView.setBackgroundColor(selectionColor);
                    } else {
                        itemView.setBackgroundColor(0);
                    }
                }
                if ((itemView instanceof TextView) && (i = textColor) != 0) {
                    ((TextView) itemView).setTextColor(i);
                }
                return itemView;
            }
        };
        final AlertDialog dialog = new AlertDialog.Builder(this.mWXSDKInstance.getContext()).setAdapter(adapter, null).setPositiveButton(17039370, new DialogInterface.OnClickListener() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass5 */

            public void onClick(DialogInterface dialog, int which) {
                Map<String, Object> ret = new HashMap<>(2);
                ret.put("result", "success");
                ret.put("data", Integer.valueOf(WXPickersModule.this.selected));
                callback.invoke(ret);
            }
        }).setNegativeButton(17039360, new DialogInterface.OnClickListener() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass4 */

            public void onClick(DialogInterface dialog, int which) {
                Map<String, Object> ret = new HashMap<>(2);
                ret.put("result", "cancel");
                ret.put("data", -1);
                callback.invoke(ret);
            }
        }).setCustomTitle(makeTitleView(this.mWXSDKInstance.getContext(), options)).create();
        if (Build.VERSION.SDK_INT >= 21) {
            dialog.create();
        }
        dialog.getListView().setOnItemClickListener(new AdapterView.OnItemClickListener() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass6 */

            @Override // android.widget.AdapterView.OnItemClickListener
            public void onItemClick(AdapterView<?> adapterView, View view, int position, long id) {
                WXPickersModule.this.selected = position;
                adapter.notifyDataSetChanged();
            }
        });
        dialog.getWindow().getDecorView().post(WXThread.secure(new Runnable() {
            /* class com.taobao.weex.appfram.pickers.WXPickersModule.AnonymousClass7 */

            public void run() {
                Button confirm = dialog.getButton(-1);
                Button cancel = dialog.getButton(-2);
                if (confirm != null) {
                    String confirmTitle = (String) WXPickersModule.this.getOption(options, WXPickersModule.KEY_CONFIRM_TITLE, null);
                    int confirmColor = WXPickersModule.this.getColor(options, WXPickersModule.KEY_CONFIRM_TITLE_COLOR, 0);
                    if (confirmTitle != null) {
                        confirm.setText(confirmTitle);
                        confirm.setAllCaps(false);
                    }
                    if (confirmColor != 0) {
                        confirm.setTextColor(confirmColor);
                        confirm.setAllCaps(false);
                    }
                }
                if (cancel != null) {
                    String cancelTitle = (String) WXPickersModule.this.getOption(options, "cancelTitle", null);
                    int cancelColor = WXPickersModule.this.getColor(options, WXPickersModule.KEY_CANCEL_TITLE_COLOR, 0);
                    if (cancelTitle != null) {
                        cancel.setText(cancelTitle);
                    }
                    if (cancelColor != 0) {
                        cancel.setTextColor(cancelColor);
                    }
                }
            }
        }));
        dialog.show();
    }

    private TextView makeTitleView(Context context, Map<String, Object> options) {
        String text = (String) getOption(options, "title", null);
        if (text == null) {
            return null;
        }
        TextView textView = new TextView(context);
        textView.setLayoutParams(new ViewGroup.LayoutParams(-1, -2));
        textView.setTextSize(2, 20.0f);
        int padding = WXViewUtils.dip2px(12.0f);
        textView.setPadding(padding, padding, padding, padding);
        textView.getPaint().setFakeBoldText(true);
        textView.setBackgroundColor(getColor(options, KEY_TITLE_BACKGROUND_COLOR, 0));
        textView.setTextColor(getColor(options, KEY_TITLE_COLOR, -16777216));
        textView.setText(text);
        return textView;
    }
}
