package com.taobao.weex.appfram.storage;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteFullException;
import android.database.sqlite.SQLiteStatement;
import com.taobao.weex.appfram.storage.IWXStorageAdapter;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class DefaultWXStorage implements IWXStorageAdapter {
    private WXSQLiteOpenHelper mDatabaseSupplier;
    private ExecutorService mExecutorService;

    private void execute(Runnable runnable) {
        if (this.mExecutorService == null) {
            this.mExecutorService = Executors.newSingleThreadExecutor();
        }
        if (runnable != null && !this.mExecutorService.isShutdown() && !this.mExecutorService.isTerminated()) {
            this.mExecutorService.execute(WXThread.secure(runnable));
        }
    }

    public DefaultWXStorage(Context context) {
        this.mDatabaseSupplier = new WXSQLiteOpenHelper(context);
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void setItem(final String key, final String value, final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass1 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.setItemResult(DefaultWXStorage.this.performSetItem(key, value, false, true));
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void getItem(final String key, final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass2 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.getItemResult(DefaultWXStorage.this.performGetItem(key));
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void removeItem(final String key, final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass3 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.removeItemResult(DefaultWXStorage.this.performRemoveItem(key));
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void length(final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass4 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.getLengthResult(DefaultWXStorage.this.performGetLength());
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void getAllKeys(final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass5 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.getAllkeysResult(DefaultWXStorage.this.performGetAllKeys());
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void setItemPersistent(final String key, final String value, final IWXStorageAdapter.OnResultReceivedListener listener) {
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass6 */

            public void run() {
                Map<String, Object> data = StorageResultHandler.setItemResult(DefaultWXStorage.this.performSetItem(key, value, true, true));
                IWXStorageAdapter.OnResultReceivedListener onResultReceivedListener = listener;
                if (onResultReceivedListener != null) {
                    onResultReceivedListener.onReceived(data);
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter
    public void close() {
        final ExecutorService needCloseService = this.mExecutorService;
        execute(new Runnable() {
            /* class com.taobao.weex.appfram.storage.DefaultWXStorage.AnonymousClass7 */

            public void run() {
                try {
                    DefaultWXStorage.this.mDatabaseSupplier.closeDatabase();
                    if (needCloseService != null) {
                        needCloseService.shutdown();
                    }
                } catch (Exception e) {
                    WXLogUtils.e("weex_storage", e.getMessage());
                }
            }
        });
        this.mExecutorService = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean performSetItem(String key, String value, boolean isPersistent, boolean allowRetryWhenFull) {
        String str;
        Exception e;
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return false;
        }
        WXLogUtils.d("weex_storage", "set k-v to storage(key:" + key + ",value:" + value + ",isPersistent:" + isPersistent + ",allowRetry:" + allowRetryWhenFull + Operators.BRACKET_END_STR);
        SQLiteStatement statement = null;
        String timeStamp = WXSQLiteOpenHelper.sDateFormatter.format(new Date());
        try {
            statement = database.compileStatement("INSERT OR REPLACE INTO default_wx_storage VALUES (?,?,?,?);");
            statement.clearBindings();
            statement.bindString(1, key);
            statement.bindString(2, value);
            statement.bindString(3, timeStamp);
            str = ",value:";
            try {
                statement.bindLong(4, isPersistent ? 1 : 0);
                statement.execute();
                if (statement != null) {
                    statement.close();
                }
                return true;
            } catch (Exception e2) {
                e = e2;
            }
        } catch (Exception e3) {
            e = e3;
            str = ",value:";
            try {
                WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute setItem :" + e.getMessage());
                if ((e instanceof SQLiteFullException) && allowRetryWhenFull && trimToSize()) {
                    WXLogUtils.d("weex_storage", "retry set k-v to storage(key:" + key + str + value + Operators.BRACKET_END_STR);
                    return performSetItem(key, value, isPersistent, false);
                } else if (statement == null) {
                    return false;
                } else {
                    statement.close();
                    return false;
                }
            } finally {
                if (statement != null) {
                    statement.close();
                }
            }
        }
    }

    private boolean trimToSize() {
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return false;
        }
        List<String> toEvict = new ArrayList<>();
        int num = 0;
        Cursor c = database.query("default_wx_storage", new String[]{"key", "persistent"}, null, null, null, null, "timestamp ASC");
        try {
            int evictSize = c.getCount() / 10;
            while (c.moveToNext()) {
                String key = c.getString(c.getColumnIndex("key"));
                if (!(c.getInt(c.getColumnIndex("persistent")) == 1) && key != null) {
                    num++;
                    toEvict.add(key);
                    if (num == evictSize) {
                        break;
                    }
                }
            }
        } catch (Exception e) {
            WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute trimToSize:" + e.getMessage());
        } catch (Throwable th) {
            c.close();
            throw th;
        }
        c.close();
        if (num <= 0) {
            return false;
        }
        for (String key2 : toEvict) {
            performRemoveItem(key2);
        }
        WXLogUtils.e("weex_storage", "remove " + num + " items by lru");
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String performGetItem(String key) {
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return null;
        }
        Cursor c = database.query("default_wx_storage", new String[]{"value"}, "key=?", new String[]{key}, null, null, null);
        try {
            if (c.moveToNext()) {
                ContentValues values = new ContentValues();
                values.put("timestamp", WXSQLiteOpenHelper.sDateFormatter.format(new Date()));
                int updateResult = this.mDatabaseSupplier.getDatabase().update("default_wx_storage", values, "key= ?", new String[]{key});
                StringBuilder sb = new StringBuilder();
                sb.append("update timestamp ");
                sb.append(updateResult == 1 ? WXImage.SUCCEED : "failed");
                sb.append(" for operation [getItem(key = ");
                sb.append(key);
                sb.append(")]");
                WXLogUtils.d("weex_storage", sb.toString());
                return c.getString(c.getColumnIndex("value"));
            }
            c.close();
            return null;
        } catch (Exception e) {
            WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute getItem:" + e.getMessage());
            return null;
        } finally {
            c.close();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean performRemoveItem(String key) {
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return false;
        }
        try {
            if (database.delete("default_wx_storage", "key=?", new String[]{key}) == 1) {
                return true;
            }
            return false;
        } catch (Exception e) {
            WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute removeItem:" + e.getMessage());
            return false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private long performGetLength() {
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return 0;
        }
        SQLiteStatement statement = null;
        try {
            statement = database.compileStatement("SELECT count(key) FROM default_wx_storage");
            long simpleQueryForLong = statement.simpleQueryForLong();
            if (statement != null) {
                statement.close();
            }
            return simpleQueryForLong;
        } catch (Exception e) {
            WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute getLength:" + e.getMessage());
            if (statement != null) {
                statement.close();
            }
            return 0;
        } catch (Throwable th) {
            if (statement != null) {
                statement.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private List<String> performGetAllKeys() {
        SQLiteDatabase database = this.mDatabaseSupplier.getDatabase();
        if (database == null) {
            return null;
        }
        List<String> result = new ArrayList<>();
        Cursor c = database.query("default_wx_storage", new String[]{"key"}, null, null, null, null, null);
        while (c.moveToNext()) {
            try {
                result.add(c.getString(c.getColumnIndex("key")));
            } catch (Exception e) {
                WXLogUtils.e("weex_storage", "DefaultWXStorage occurred an exception when execute getAllKeys:" + e.getMessage());
                return result;
            } finally {
                c.close();
            }
        }
        return result;
    }
}
