package com.taobao.weex.appfram.storage;

import com.taobao.weex.bridge.JSCallback;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class StorageResultHandler {
    private static final String DATA = "data";
    private static final String RESULT = "result";
    private static final String RESULT_FAILED = "failed";
    private static final String RESULT_FAILED_INVALID_PARAM = "invalid_param";
    private static final String RESULT_FAILED_NO_HANDLER = "no_handler";
    private static final String RESULT_OK = "success";
    private static final String UNDEFINED = "undefined";

    private StorageResultHandler() {
    }

    public static Map<String, Object> getItemResult(String result) {
        Map<String, Object> map = new HashMap<>(4);
        map.put("result", result != null ? "success" : "failed");
        map.put("data", result != null ? result : "undefined");
        return map;
    }

    public static Map<String, Object> setItemResult(boolean result) {
        Map<String, Object> map = new HashMap<>(4);
        map.put("result", result ? "success" : "failed");
        map.put("data", "undefined");
        return map;
    }

    public static Map<String, Object> removeItemResult(boolean result) {
        Map<String, Object> map = new HashMap<>(4);
        map.put("result", result ? "success" : "failed");
        map.put("data", "undefined");
        return map;
    }

    public static Map<String, Object> getLengthResult(long result) {
        Map<String, Object> map = new HashMap<>(4);
        map.put("result", "success");
        map.put("data", Long.valueOf(result));
        return map;
    }

    public static Map<String, Object> getAllkeysResult(List<String> result) {
        if (result == null) {
            result = new ArrayList(1);
        }
        Map<String, Object> map = new HashMap<>(4);
        map.put("result", "success");
        map.put("data", result);
        return map;
    }

    private static void handleResult(JSCallback callback, String result, Object data) {
        if (callback != null) {
            Map<String, Object> retVal = new HashMap<>(4);
            retVal.put("result", result);
            retVal.put("data", data);
            callback.invoke(retVal);
        }
    }

    public static void handleNoHandlerError(JSCallback callback) {
        handleResult(callback, "failed", RESULT_FAILED_NO_HANDLER);
    }

    public static void handleInvalidParam(JSCallback callback) {
        handleResult(callback, "failed", RESULT_FAILED_INVALID_PARAM);
    }
}
