package com.taobao.weex.appfram.storage;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteOpenHelper;
import com.taobao.weex.utils.WXLogUtils;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

public class WXSQLiteOpenHelper extends SQLiteOpenHelper {
    static final String COLUMN_KEY = "key";
    static final String COLUMN_PERSISTENT = "persistent";
    static final String COLUMN_TIMESTAMP = "timestamp";
    static final String COLUMN_VALUE = "value";
    private static final String DATABASE_NAME = "WXStorage";
    private static final int DATABASE_VERSION = 2;
    private static final int SLEEP_TIME_MS = 30;
    private static final String STATEMENT_CREATE_TABLE = "CREATE TABLE IF NOT EXISTS default_wx_storage (key TEXT PRIMARY KEY,value TEXT NOT NULL,timestamp TEXT NOT NULL,persistent INTEGER DEFAULT 0)";
    static final String TABLE_STORAGE = "default_wx_storage";
    static final String TAG_STORAGE = "weex_storage";
    static SimpleDateFormat sDateFormatter = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.getDefault());
    private Context mContext;
    private SQLiteDatabase mDb;
    private long mMaximumDatabaseSize = 52428800;

    public WXSQLiteOpenHelper(Context context) {
        super(context, DATABASE_NAME, (SQLiteDatabase.CursorFactory) null, 2);
        this.mContext = context;
    }

    public SQLiteDatabase getDatabase() {
        ensureDatabase();
        return this.mDb;
    }

    public void onCreate(SQLiteDatabase db) {
        db.execSQL(STATEMENT_CREATE_TABLE);
    }

    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        if (oldVersion == newVersion) {
            return;
        }
        if (newVersion == 2 && oldVersion == 1) {
            WXLogUtils.d(TAG_STORAGE, "storage is updating from version " + oldVersion + " to version " + newVersion);
            boolean updateResult = true;
            try {
                long start = System.currentTimeMillis();
                db.beginTransaction();
                WXLogUtils.d(TAG_STORAGE, "exec sql : " + "ALTER TABLE default_wx_storage ADD COLUMN timestamp TEXT;");
                db.execSQL("ALTER TABLE default_wx_storage ADD COLUMN timestamp TEXT;");
                WXLogUtils.d(TAG_STORAGE, "exec sql : " + "ALTER TABLE default_wx_storage ADD COLUMN persistent INTEGER;");
                db.execSQL("ALTER TABLE default_wx_storage ADD COLUMN persistent INTEGER;");
                String SQL_UPDATE_TABLE = "UPDATE default_wx_storage SET timestamp = '" + sDateFormatter.format(new Date()) + "' , " + COLUMN_PERSISTENT + " = 0";
                WXLogUtils.d(TAG_STORAGE, "exec sql : " + SQL_UPDATE_TABLE);
                db.execSQL(SQL_UPDATE_TABLE);
                db.setTransactionSuccessful();
                WXLogUtils.d(TAG_STORAGE, "storage updated success (" + (System.currentTimeMillis() - start) + "ms)");
            } catch (Exception e) {
                WXLogUtils.d(TAG_STORAGE, "storage updated failed from version " + oldVersion + " to version " + newVersion + "," + e.getMessage());
                updateResult = false;
            } catch (Throwable th) {
                db.endTransaction();
                throw th;
            }
            db.endTransaction();
            if (!updateResult) {
                WXLogUtils.d(TAG_STORAGE, "storage is rollback,all data will be removed");
                deleteDB();
                onCreate(db);
                return;
            }
            return;
        }
        deleteDB();
        onCreate(db);
    }

    /* access modifiers changed from: package-private */
    public synchronized void ensureDatabase() {
        if (this.mDb == null || !this.mDb.isOpen()) {
            int tries = 0;
            while (true) {
                if (tries < 2) {
                    if (tries <= 0) {
                        break;
                    }
                    try {
                        deleteDB();
                        break;
                    } catch (SQLiteException e) {
                        e.printStackTrace();
                        try {
                            Thread.sleep(30);
                        } catch (InterruptedException e2) {
                            Thread.currentThread().interrupt();
                        }
                        tries++;
                    } catch (Throwable e3) {
                        this.mDb = null;
                        WXLogUtils.d(TAG_STORAGE, "ensureDatabase failed, throwable = " + e3.getMessage());
                    }
                } else {
                    break;
                }
            }
            this.mDb = getWritableDatabase();
            if (this.mDb != null) {
                createTableIfNotExists(this.mDb);
                this.mDb.setMaximumSize(this.mMaximumDatabaseSize);
            }
        }
    }

    public synchronized void setMaximumSize(long size) {
        this.mMaximumDatabaseSize = size;
        if (this.mDb != null) {
            this.mDb.setMaximumSize(size);
        }
    }

    private boolean deleteDB() {
        closeDatabase();
        return this.mContext.deleteDatabase(DATABASE_NAME);
    }

    public synchronized void closeDatabase() {
        if (this.mDb != null && this.mDb.isOpen()) {
            this.mDb.close();
            this.mDb = null;
        }
    }

    private void createTableIfNotExists(SQLiteDatabase db) {
        Cursor cursor = null;
        try {
            cursor = db.rawQuery("SELECT DISTINCT tbl_name FROM sqlite_master WHERE tbl_name = 'default_wx_storage'", null);
            if (cursor == null || cursor.getCount() <= 0) {
                db.execSQL(STATEMENT_CREATE_TABLE);
                if (cursor == null) {
                    return;
                }
                cursor.close();
            } else if (cursor != null) {
                cursor.close();
            }
        } catch (Exception e) {
            e.printStackTrace();
            if (0 == 0) {
            }
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }
}
