package com.taobao.weex.appfram.storage;

import android.text.TextUtils;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.storage.IWXStorageAdapter;
import com.taobao.weex.bridge.JSCallback;
import java.util.Map;

public class WXStorageModule extends WXSDKEngine.DestroyableModule implements IWXStorage {
    IWXStorageAdapter mStorageAdapter;

    private IWXStorageAdapter ability() {
        IWXStorageAdapter iWXStorageAdapter = this.mStorageAdapter;
        if (iWXStorageAdapter != null) {
            return iWXStorageAdapter;
        }
        IWXStorageAdapter iWXStorageAdapter2 = WXSDKEngine.getIWXStorageAdapter();
        this.mStorageAdapter = iWXStorageAdapter2;
        return iWXStorageAdapter2;
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void setItem(String key, String value, final JSCallback callback) {
        if (TextUtils.isEmpty(key) || value == null) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.setItem(key, value, new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass1 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void getItem(String key, final JSCallback callback) {
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.getItem(key, new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass2 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void removeItem(String key, final JSCallback callback) {
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.removeItem(key, new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass3 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void length(final JSCallback callback) {
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.length(new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass4 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void getAllKeys(final JSCallback callback) {
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.getAllKeys(new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass5 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.appfram.storage.IWXStorage
    @JSMethod(uiThread = false)
    public void setItemPersistent(String key, String value, final JSCallback callback) {
        if (TextUtils.isEmpty(key) || value == null) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        IWXStorageAdapter adapter = ability();
        if (adapter == null) {
            StorageResultHandler.handleNoHandlerError(callback);
        } else {
            adapter.setItemPersistent(key, value, new IWXStorageAdapter.OnResultReceivedListener() {
                /* class com.taobao.weex.appfram.storage.WXStorageModule.AnonymousClass6 */

                @Override // com.taobao.weex.appfram.storage.IWXStorageAdapter.OnResultReceivedListener
                public void onReceived(Map<String, Object> data) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(data);
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        IWXStorageAdapter adapter = ability();
        if (adapter != null) {
            adapter.close();
        }
    }
}
