package com.taobao.weex.bridge;

import android.util.Log;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.SimpleJSCallback;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import java.lang.reflect.Type;

public class NativeInvokeHelper {
    private String mInstanceId;

    public NativeInvokeHelper(String instanceId) {
        this.mInstanceId = instanceId;
    }

    public Object invoke(final Object target, final Invoker invoker, JSONArray args) throws Exception {
        final Object[] params = prepareArguments(invoker.getParameterTypes(), args);
        if (WXAnalyzerDataTransfer.isInteractionLogOpen() && (invoker instanceof MethodInvoker)) {
            int i = 0;
            while (true) {
                if (i >= params.length) {
                    break;
                } else if (params[i] instanceof SimpleJSCallback) {
                    final String callBackId = ((SimpleJSCallback) params[i]).getCallbackId();
                    Log.d(WXAnalyzerDataTransfer.INTERACTION_TAG, "[client][callNativeModuleStart]," + this.mInstanceId + "," + ((MethodInvoker) invoker).mMethod.getDeclaringClass() + "," + ((MethodInvoker) invoker).mMethod.getName() + "," + callBackId);
                    ((SimpleJSCallback) params[i]).setInvokerCallback(new SimpleJSCallback.InvokerCallback() {
                        /* class com.taobao.weex.bridge.NativeInvokeHelper.AnonymousClass1 */

                        @Override // com.taobao.weex.bridge.SimpleJSCallback.InvokerCallback
                        public void onInvokeSuccess() {
                            Log.d(WXAnalyzerDataTransfer.INTERACTION_TAG, "[client][callNativeModuleEnd]," + NativeInvokeHelper.this.mInstanceId + "," + ((MethodInvoker) invoker).mMethod.getDeclaringClass() + "," + ((MethodInvoker) invoker).mMethod.getName() + "," + callBackId);
                        }
                    });
                    break;
                } else {
                    i++;
                }
            }
        }
        if (!invoker.isRunOnUIThread()) {
            return invoker.invoke(target, params);
        }
        WXSDKManager.getInstance().postOnUiThread(new Runnable() {
            /* class com.taobao.weex.bridge.NativeInvokeHelper.AnonymousClass2 */

            public void run() {
                if (invoker != null) {
                    try {
                        WXSDKInstance targetInstance = WXSDKManager.getInstance().getSDKInstance(NativeInvokeHelper.this.mInstanceId);
                        if (targetInstance == null) {
                            return;
                        }
                        if (!targetInstance.isDestroy()) {
                            invoker.invoke(target, params);
                        }
                    } catch (Exception e) {
                        WXLogUtils.e("NativeInvokeHelper", target + " Invoker " + invoker.toString() + " exception:" + e);
                    }
                }
            }
        }, 0);
        return null;
    }

    /* access modifiers changed from: protected */
    public Object[] prepareArguments(Type[] paramClazzs, JSONArray args) throws Exception {
        Object[] params = new Object[paramClazzs.length];
        for (int i = 0; i < paramClazzs.length; i++) {
            Type paramClazz = paramClazzs[i];
            if (i < args.size()) {
                Object value = args.get(i);
                if (paramClazz == JSONObject.class) {
                    if ((value instanceof JSONObject) || value == null) {
                        params[i] = value;
                    } else if (value instanceof String) {
                        params[i] = JSON.parseObject(value.toString());
                    }
                } else if (JSCallback.class != paramClazz && UniJSCallback.class != paramClazz) {
                    params[i] = WXReflectionUtils.parseArgument(paramClazz, value);
                } else if (value instanceof String) {
                    params[i] = new SimpleJSCallback(this.mInstanceId, (String) value);
                } else {
                    throw new Exception("Parameter type not match.");
                }
            } else if (!paramClazz.getClass().isPrimitive()) {
                params[i] = null;
            } else {
                throw new Exception("[prepareArguments] method argument list not match.");
            }
        }
        return params;
    }
}
