package com.taobao.weex.bridge;

import android.net.Uri;
import android.text.TextUtils;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXHttpListener;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.http.WXHttpUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.util.HashMap;
import java.util.Locale;

public class RequestHandler {
    /* access modifiers changed from: package-private */
    public native void nativeInvokeOnFailed(long j);

    /* access modifiers changed from: package-private */
    public native void nativeInvokeOnSuccess(long j, String str, String str2);

    public static RequestHandler create() {
        return new RequestHandler();
    }

    public void send(String instanceId, String url, long nativeCallback) {
        if (!TextUtils.isEmpty(instanceId) && !TextUtils.isEmpty(url) && nativeCallback != 0 && WXSDKManager.getInstance().getAllInstanceMap().containsKey(instanceId)) {
            WXSDKManager manager = WXSDKManager.getInstance();
            WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (instance != null) {
                IWXHttpAdapter adapter = WXSDKManager.getInstance().getIWXHttpAdapter();
                WXRequest wxRequest = new WXRequest();
                wxRequest.url = manager.getURIAdapter().rewrite(instance, AbsURIAdapter.BUNDLE, Uri.parse(url)).toString();
                if (wxRequest.paramMap == null) {
                    wxRequest.paramMap = new HashMap();
                }
                wxRequest.paramMap.put(WXHttpUtil.KEY_USER_AGENT, WXHttpUtil.assembleUserAgent(instance.getContext(), WXEnvironment.getConfig()));
                wxRequest.paramMap.put("isBundleRequest", AbsoluteConst.TRUE);
                WXLogUtils.i("Eagle", String.format(Locale.ENGLISH, "Weex eagle is going to download script from %s", url));
                adapter.sendRequest(wxRequest, new OnHttpListenerInner(instance, nativeCallback, url));
            }
        }
    }

    public void getBundleType(String instanceId, final String content, final long nativeCallback) {
        WXBridgeManager.BundType bundleType = WXBridgeManager.getInstance().getBundleType("", content);
        final String bundleTypeStr = bundleType == null ? "Others" : bundleType.toString();
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if ("Others".equalsIgnoreCase(bundleTypeStr) && instance != null) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE;
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "RequestHandler.onSuccess", "eagle ->" + WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE.getErrorMsg(), null);
        }
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.taobao.weex.bridge.RequestHandler.AnonymousClass1 */

            public void run() {
                if (WXBridgeManager.getInstance().isJSFrameworkInit()) {
                    RequestHandler.this.nativeInvokeOnSuccess(nativeCallback, content, bundleTypeStr);
                } else {
                    RequestHandler.this.nativeInvokeOnFailed(nativeCallback);
                }
            }
        });
    }

    class OnHttpListenerInner extends WXHttpListener {
        private long sNativeCallback;

        OnHttpListenerInner(WXSDKInstance instance, long nativeCallback, String bundlUrl) {
            super(instance, bundlUrl);
            this.sNativeCallback = nativeCallback;
        }

        @Override // com.taobao.weex.WXHttpListener
        public void onSuccess(WXResponse response) {
            final String script = new String(response.originalData);
            WXBridgeManager.BundType bundleType = WXBridgeManager.getInstance().getBundleType("", script);
            final String bundleTypeStr = bundleType == null ? "Others" : bundleType.toString();
            if ("Others".equalsIgnoreCase(bundleTypeStr) && getInstance() != null) {
                String instanceId = getInstance().getInstanceId();
                WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE;
                WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "RequestHandler.onSuccess", "eagle ->" + WXErrorCode.WX_KEY_EXCEPTION_NO_BUNDLE_TYPE.getErrorMsg(), null);
            }
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.bridge.RequestHandler.OnHttpListenerInner.AnonymousClass1 */

                public void run() {
                    if (WXBridgeManager.getInstance().isJSFrameworkInit()) {
                        RequestHandler.this.nativeInvokeOnSuccess(OnHttpListenerInner.this.sNativeCallback, script, bundleTypeStr);
                    } else {
                        RequestHandler.this.nativeInvokeOnFailed(OnHttpListenerInner.this.sNativeCallback);
                    }
                }
            });
        }

        @Override // com.taobao.weex.WXHttpListener
        public void onFail(WXResponse response) {
            RequestHandler.this.nativeInvokeOnFailed(this.sNativeCallback);
        }
    }
}
