package com.taobao.weex.bridge;

import android.text.TextUtils;
import android.util.Log;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.IWXBridge;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXJsonUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXWsonJSONSwitch;
import com.taobao.weex.utils.tools.TimeCalculator;
import io.dcloud.feature.internal.sdk.SDK;
import java.io.Serializable;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;

public class WXBridge implements IWXBridge {
    public static final boolean MULTIPROCESS = true;
    public static final String TAG = "WXBridge";

    private native void nativeBindMeasurementToRenderObject(long j);

    private native String nativeDecrypt(String str, String str2, String str3, String str4);

    private native String nativeEncrypt(String str, String str2, String str3, String str4);

    private native int nativeExecJS(String str, String str2, String str3, WXJSObject[] wXJSObjectArr);

    private native int nativeExecJSService(String str);

    private native void nativeForceLayout(String str);

    private native int nativeInitFramework(String str, WXParams wXParams);

    private native int nativeInitFrameworkEnv(String str, WXParams wXParams, String str2, boolean z);

    private native void nativeMarkDirty(String str, String str2, boolean z);

    private native boolean nativeNotifyLayout(String str);

    private native void nativeOnInstanceClose(String str);

    private native String nativePreGetClientKey(String str, String str2, String str3);

    private native void nativeRefreshInstance(String str, String str2, String str3, WXJSObject[] wXJSObjectArr);

    private native void nativeRegisterCoreEnv(String str, String str2);

    private native void nativeReloadPageLayout(String str);

    private native void nativeRemoveInstanceRenderType(String str);

    private native void nativeResetWXBridge(Object obj, String str);

    private native void nativeSetDefaultHeightAndWidthIntoRootDom(String str, float f, float f2, boolean z, boolean z2);

    private native void nativeSetDeviceDisplay(String str, float f, float f2, float f3);

    private native void nativeSetDeviceDisplayOfPage(String str, float f, float f2);

    private native void nativeSetFlexDirectionDef(String str);

    private native void nativeSetInstanceRenderType(String str, String str2);

    private native void nativeSetLogType(float f, float f2);

    private native void nativeSetMargin(String str, String str2, int i, float f);

    private native void nativeSetPadding(String str, String str2, int i, float f);

    private native void nativeSetPageArgument(String str, String str2, String str3);

    private native void nativeSetPosition(String str, String str2, int i, float f);

    private native void nativeSetRenderContainerWrapContent(boolean z, String str);

    private native void nativeSetStyleHeight(String str, String str2, float f, boolean z);

    private native void nativeSetStyleWidth(String str, String str2, float f, boolean z);

    private native void nativeSetViewPortWidth(String str, float f);

    private native void nativeTakeHeapSnapshot(String str);

    private native void nativeUpdateInitFrameworkParams(String str, String str2, String str3);

    private native boolean nativeVerifyClientKeyPayload(String str, String str2, String str3);

    public native int nativeCreateInstanceContext(String str, String str2, String str3, WXJSObject[] wXJSObjectArr);

    public native int nativeDestoryInstance(String str, String str2, String str3, WXJSObject[] wXJSObjectArr);

    public native String nativeDumpIpcPageQueueInfo();

    public native String nativeExecJSOnInstance(String str, String str2, int i);

    public native void nativeExecJSWithCallback(String str, String str2, String str3, WXJSObject[] wXJSObjectArr, long j);

    public native byte[] nativeExecJSWithResult(String str, String str2, String str3, WXJSObject[] wXJSObjectArr);

    public native void nativeFireEventOnDataRenderNode(String str, String str2, String str3, String str4, String str5);

    public native long[] nativeGetFirstScreenRenderTime(String str);

    public native long[] nativeGetRenderFinishTime(String str);

    public native void nativeInvokeCallbackOnDataRender(String str, String str2, String str3, boolean z);

    public native void nativeOnInteractionTimeUpdate(String str);

    public native void nativeRegisterComponentOnDataRenderNode(String str);

    public native void nativeRegisterModuleOnDataRenderNode(String str);

    public native void nativeUpdateGlobalConfig(String str);

    @Override // com.taobao.weex.common.IWXBridge
    public void updateInitFrameworkParams(String key, String value, String desc) {
        WXStateRecord.getInstance().recordAction("", "updateInitFrameworkParams:");
        nativeUpdateInitFrameworkParams(key, value, desc);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setLogType(float type, boolean isPerf) {
        Log.e("WeexCore", "setLog" + WXEnvironment.sLogLevel.getValue() + "isPerf : " + isPerf);
        nativeSetLogType(type, isPerf ? 1.0f : 0.0f);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int initFramework(String framework, WXParams params) {
        return nativeInitFramework(framework, params);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int initFrameworkEnv(String framework, WXParams params, String cacheDir, boolean pieSupport) {
        WXStateRecord.getInstance().recordAction("", "nativeInitFrameworkEnv:");
        return nativeInitFrameworkEnv(framework, params, cacheDir, pieSupport);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void refreshInstance(String instanceId, String namespace, String function, WXJSObject[] args) {
        WXStateRecord instance = WXStateRecord.getInstance();
        instance.recordAction(instanceId, "refreshInstance:" + namespace + "," + function);
        nativeRefreshInstance(instanceId, namespace, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int execJS(String instanceId, String namespace, String function, WXJSObject[] args) {
        WXStateRecord instance = WXStateRecord.getInstance();
        instance.recordAction(instanceId, "execJS:" + namespace + "," + function);
        return nativeExecJS(instanceId, namespace, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void execJSWithCallback(String instanceId, String namespace, String function, WXJSObject[] args, ResultCallback callback) {
        WXStateRecord instance = WXStateRecord.getInstance();
        instance.recordAction(instanceId, "execJSWithCallback:" + namespace + "," + function);
        if (callback == null) {
            execJS(instanceId, namespace, function, args);
        }
        nativeExecJSWithCallback(instanceId, namespace, function, args, ResultCallbackManager.generateCallbackId(callback));
    }

    public void onNativePerformanceDataUpdate(String instanceId, Map<String, String> map) {
        WXSDKInstance instance;
        if (!TextUtils.isEmpty(instanceId) && map != null && map.size() >= 1 && (instance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId)) != null && instance.getApmForInstance() != null) {
            instance.getApmForInstance().updateNativePerformanceData(map);
        }
    }

    public void onReceivedResult(long callbackId, byte[] result) {
        WXStateRecord instance = WXStateRecord.getInstance();
        instance.recordAction("onReceivedResult", SDK.UNIMP_EVENT_CALLBACKID + callbackId);
        ResultCallback callback = ResultCallbackManager.removeCallbackById(callbackId);
        if (callback != null) {
            callback.onReceiveResult(result);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int execJSService(String javascript) {
        WXStateRecord.getInstance().recordAction("execJSService", "execJSService:");
        return nativeExecJSService(javascript);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void takeHeapSnapshot(String filename) {
        nativeTakeHeapSnapshot(filename);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int createInstanceContext(String instanceId, String name, String function, WXJSObject[] args) {
        Log.e(TimeCalculator.TIMELINE_TAG, "createInstance :" + System.currentTimeMillis());
        WXStateRecord.getInstance().recordAction(instanceId, "createInstanceContext:");
        return nativeCreateInstanceContext(instanceId, name, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int destoryInstance(String instanceId, String name, String function, WXJSObject[] args) {
        WXStateRecord.getInstance().recordAction(instanceId, "destoryInstance:");
        return nativeDestoryInstance(instanceId, name, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public String execJSOnInstance(String instanceId, String script, int type) {
        WXStateRecord instance = WXStateRecord.getInstance();
        instance.recordAction(instanceId, "execJSOnInstance:" + type);
        return nativeExecJSOnInstance(instanceId, script, type);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callNative(String instanceId, byte[] tasks, String callback) {
        if (!"HeartBeat".equals(callback)) {
            return callNative(instanceId, JSON.parseArray(new String(tasks)), callback);
        }
        Log.e("HeartBeat instanceId", instanceId);
        WXSDKInstance sdkInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sdkInstance == null) {
            return 1;
        }
        sdkInstance.createInstanceFuncHeartBeat();
        return 1;
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callNative(String instanceId, String tasks, String callback) {
        try {
            return callNative(instanceId, JSONArray.parseArray(tasks), callback);
        } catch (Exception e) {
            WXLogUtils.e(TAG, "callNative throw exception: " + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    private int callNative(String instanceId, JSONArray tasks, String callback) {
        long start = System.currentTimeMillis();
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (instance != null) {
            instance.firstScreenCreateInstanceTime(start);
        }
        int errorCode = 1;
        try {
            errorCode = WXBridgeManager.getInstance().callNative(instanceId, tasks, callback);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "callNative throw exception:" + WXLogUtils.getStackTrace(e));
        }
        if (WXEnvironment.isApkDebugable() && errorCode == -1) {
            WXLogUtils.w("destroyInstance :" + instanceId + " JSF must stop callNative");
        }
        return errorCode;
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportJSException(String instanceId, String func, String exception) {
        WXBridgeManager.getInstance().reportJSException(instanceId, func, exception);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public Object callVueExecSync(String instanceId, String name, String value) {
        WXSDKInstance sdkInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sdkInstance == null) {
            return new WXJSObject(null);
        }
        if (sdkInstance != null && sdkInstance.isDestroy()) {
            return new WXJSObject(null);
        }
        Object object = WXSDKManager.getInstance().getVueBridgeAdapter().execSync(sdkInstance, name, value);
        if (object == null) {
            return new WXJSObject(null);
        }
        return new WXJSObject(3, WXJsonUtils.fromObjectToJSONString(object));
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callVueExec(String instanceId, final String name, final String value) {
        final WXSDKInstance sdkInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sdkInstance == null) {
            return;
        }
        if (sdkInstance == null || !sdkInstance.isDestroy()) {
            WXSDKManager.getInstance().postOnUiThread(new Runnable() {
                /* class com.taobao.weex.bridge.WXBridge.AnonymousClass1 */

                public void run() {
                    WXSDKManager.getInstance().getVueBridgeAdapter().exec(sdkInstance, name, value);
                }
            }, 0);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public Object callNativeModule(String instanceId, String module, String method, byte[] arguments, byte[] options) {
        Exception e;
        JSONArray argArray;
        JSONObject optionsObj;
        WXSDKInstance sdkInstance;
        JSONArray argArray2;
        try {
            WXStateRecord instance = WXStateRecord.getInstance();
            StringBuilder sb = new StringBuilder();
            sb.append("callNativeModule:");
            try {
                sb.append(module);
                sb.append(Operators.DOT_STR);
            } catch (Exception e2) {
                e = e2;
                WXLogUtils.e(TAG, e);
                return new WXJSObject(null);
            }
            try {
                sb.append(method);
                instance.recordAction(instanceId, sb.toString());
                long start = WXUtils.getFixUnixTime();
                WXSDKInstance instance2 = WXSDKManager.getInstance().getSDKInstance(instanceId);
                if (arguments == null) {
                    argArray = null;
                } else if (instance2 == null || !(instance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || instance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
                    argArray = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                } else {
                    try {
                        argArray2 = (JSONArray) JSON.parse(new String(arguments, "UTF-8"));
                    } catch (Exception e3) {
                        argArray2 = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                    }
                    argArray = argArray2;
                }
                if (options != null) {
                    optionsObj = (JSONObject) WXWsonJSONSwitch.parseWsonOrJSON(options);
                } else {
                    if (!(argArray == null || (sdkInstance = WXSDKManager.getInstance().getSDKInstance(instanceId)) == null || !WXBridgeManager.BundType.Rax.equals(sdkInstance.bundleType))) {
                        Object weex_options__ = null;
                        Iterator<Object> it = argArray.iterator();
                        while (it.hasNext()) {
                            Object object = it.next();
                            if ((object instanceof JSONObject) && ((JSONObject) object).containsKey("__weex_options__")) {
                                weex_options__ = ((JSONObject) object).get("__weex_options__");
                            }
                        }
                        if (weex_options__ instanceof JSONObject) {
                            optionsObj = (JSONObject) weex_options__;
                        }
                    }
                    optionsObj = null;
                }
                Object object2 = WXBridgeManager.getInstance().callNativeModule(instanceId, module, method, argArray, optionsObj);
                if (instance2 != null) {
                    instance2.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_NATIVE_NUM, 1.0d);
                    instance2.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_NATIVE_TIME, (double) (WXUtils.getFixUnixTime() - start));
                }
                if (instance2 == null || (instance2.getRenderStrategy() != WXRenderStrategy.DATA_RENDER && instance2.getRenderStrategy() != WXRenderStrategy.DATA_RENDER_BINARY)) {
                    return WXWsonJSONSwitch.toWsonOrJsonWXJSObject(object2);
                }
                if (object2 == null) {
                    try {
                        return new WXJSObject(null);
                    } catch (Exception e4) {
                        return WXWsonJSONSwitch.toWsonOrJsonWXJSObject(object2);
                    }
                } else if (object2.getClass() == WXJSObject.class) {
                    return (WXJSObject) object2;
                } else {
                    return new WXJSObject(3, WXJsonUtils.fromObjectToJSONString(object2));
                }
            } catch (Exception e5) {
                e = e5;
                WXLogUtils.e(TAG, e);
                return new WXJSObject(null);
            }
        } catch (Exception e6) {
            e = e6;
            WXLogUtils.e(TAG, e);
            return new WXJSObject(null);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callNativeComponent(String instanceId, String ref, String method, byte[] arguments, byte[] optionsData) {
        JSONArray argArray;
        JSONArray argArray2;
        WXStateRecord.getInstance().recordAction(instanceId, "callNativeComponent:" + method);
        try {
            WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (arguments == null) {
                argArray = null;
            } else if (instance == null || !(instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || instance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
                argArray = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
            } else {
                try {
                    argArray2 = (JSONArray) JSON.parse(new String(arguments, "UTF-8"));
                } catch (Exception e) {
                    argArray2 = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                }
                argArray = argArray2;
            }
            WXBridgeManager.getInstance().callNativeComponent(instanceId, ref, method, argArray, WXWsonJSONSwitch.parseWsonOrJSON(optionsData));
        } catch (Exception e2) {
            WXLogUtils.e(TAG, e2);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setTimeoutNative(String callbackId, String time) {
        WXBridgeManager.getInstance().setTimeout(callbackId, time);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setJSFrmVersion(String version) {
        if (version != null) {
            WXEnvironment.JS_LIB_SDK_VERSION = version;
        }
        WXStateRecord.getInstance().onJSFMInit();
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void resetWXBridge(boolean remoteDebug) {
        nativeResetWXBridge(this, getClass().getName().replace(Operators.DOT, '/'));
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateFinish(String instanceId, byte[] tasks, String callback) {
        try {
            return WXBridgeManager.getInstance().callUpdateFinish(instanceId, callback);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callCreateBody throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRefreshFinish(String instanceId, byte[] tasks, String callback) {
        try {
            return WXBridgeManager.getInstance().callRefreshFinish(instanceId, callback);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportServerCrash(String instanceId, String crashFile) {
        WXLogUtils.e(TAG, "reportServerCrash instanceId:" + instanceId + " crashFile: " + crashFile);
        try {
            WXBridgeManager.getInstance().callReportCrashReloadPage(instanceId, crashFile);
        } catch (Throwable e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "reloadPageNative throw exception:" + WXLogUtils.getStackTrace(e));
            }
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callCreateBody(String instanceId, String componentType, String ref, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders) {
        try {
            return WXBridgeManager.getInstance().callCreateBody(instanceId, componentType, ref, styles, attributes, events, margins, paddings, borders);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callCreateBody throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddElement(String instanceId, String componentType, String ref, int index, String parentRef, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders, boolean willLayout) {
        try {
            return WXBridgeManager.getInstance().callAddElement(instanceId, componentType, ref, index, parentRef, styles, attributes, events, margins, paddings, borders, willLayout);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            e.printStackTrace();
            WXLogUtils.e(TAG, "callAddElement throw error:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveElement(String instanceId, String ref) {
        try {
            return WXBridgeManager.getInstance().callRemoveElement(instanceId, ref);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callRemoveElement throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callMoveElement(String instanceId, String ref, String parentref, int index) {
        try {
            return WXBridgeManager.getInstance().callMoveElement(instanceId, ref, parentref, index);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callMoveElement throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddEvent(String instanceId, String ref, String event) {
        try {
            return WXBridgeManager.getInstance().callAddEvent(instanceId, ref, event);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "callAddEvent throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callBacthStart(String instanceId) {
        try {
            WXBridgeManager.getInstance().callBacthStart(instanceId);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "cal\n    return errorCode;\n  }lAddEvent throw exception:" + WXLogUtils.getStackTrace(e));
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callBacthEnd(String instanceId) {
        try {
            WXBridgeManager.getInstance().callBacthEnd(instanceId);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "cal\n    return errorCode;\n  }lAddEvent throw exception:" + WXLogUtils.getStackTrace(e));
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveEvent(String instanceId, String ref, String event) {
        try {
            return WXBridgeManager.getInstance().callRemoveEvent(instanceId, ref, event);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callRemoveEvent throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateStyle(String instanceId, String ref, HashMap<String, Object> styles, HashMap<String, String> paddings, HashMap<String, String> margins, HashMap<String, String> borders) {
        if (styles != null) {
            try {
                if (styles.isEmpty() && paddings != null && paddings.isEmpty() && margins != null && margins.isEmpty() && borders != null && borders.isEmpty()) {
                    return 1;
                }
            } catch (Throwable e) {
                if (!WXEnvironment.isApkDebugable()) {
                    return 1;
                }
                WXLogUtils.e(TAG, "callUpdateStyle throw exception:" + WXLogUtils.getStackTrace(e));
                return 1;
            }
        }
        return WXBridgeManager.getInstance().callUpdateStyle(instanceId, ref, styles, paddings, margins, borders);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateAttrs(String instanceId, String ref, HashMap<String, String> attrs) {
        try {
            return WXBridgeManager.getInstance().callUpdateAttrs(instanceId, ref, attrs);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callUpdateAttr throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddChildToRichtext(String instanceId, String nodeType, String ref, String parentRef, String richTextRef, HashMap<String, String> styles, HashMap<String, String> attrs) {
        try {
            return WXBridgeManager.getInstance().callAddChildToRichtext(instanceId, nodeType, ref, parentRef, richTextRef, styles, attrs);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callAddChildToRichtext throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveChildFromRichtext(String instanceId, String ref, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callRemoveChildFromRichtext(instanceId, ref, parentRef, richTextRef);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callRemoveChildFromRichtext throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateRichtextStyle(String instanceId, String ref, HashMap<String, String> styles, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callUpdateRichtextStyle(instanceId, ref, styles, parentRef, richTextRef);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callUpdateRichtextStyle throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateRichtextChildAttr(String instanceId, String ref, HashMap<String, String> attrs, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callUpdateRichtextChildAttr(instanceId, ref, attrs, parentRef, richTextRef);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callUpdateRichtextChildAttr throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callLayout(String instanceId, String ref, int top, int bottom, int left, int right, int height, int width, boolean isRTL, int index) {
        try {
            return WXBridgeManager.getInstance().callLayout(instanceId, ref, top, bottom, left, right, height, width, isRTL, index);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callLayout throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callCreateFinish(String instanceId) {
        try {
            return WXBridgeManager.getInstance().callCreateFinish(instanceId);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRenderSuccess(String instanceId) {
        try {
            return WXBridgeManager.getInstance().callRenderSuccess(instanceId);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAppendTreeCreateFinish(String instanceId, String ref) {
        try {
            return WXBridgeManager.getInstance().callAppendTreeCreateFinish(instanceId, ref);
        } catch (Throwable e) {
            WXLogUtils.e(TAG, "callAppendTreeCreateFinish throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callHasTransitionPros(String instanceId, String ref, HashMap<String, String> styles) {
        try {
            return WXBridgeManager.getInstance().callHasTransitionPros(instanceId, ref, styles);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 1;
            }
            WXLogUtils.e(TAG, "callHasTransitionPros throw exception:" + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public ContentBoxMeasurement getMeasurementFunc(String instanceId, long renderObjectPtr) {
        try {
            return WXBridgeManager.getInstance().getMeasurementFunc(instanceId, renderObjectPtr);
        } catch (Throwable e) {
            if (!WXEnvironment.isApkDebugable()) {
                return null;
            }
            WXLogUtils.e(TAG, "getMeasurementFunc throw exception:" + WXLogUtils.getStackTrace(e));
            return null;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void bindMeasurementToRenderObject(long ptr) {
        nativeBindMeasurementToRenderObject(ptr);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setRenderContainerWrapContent(boolean wrap, String instanceId) {
        nativeSetRenderContainerWrapContent(wrap, instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public long[] getFirstScreenRenderTime(String instanceId) {
        return nativeGetFirstScreenRenderTime(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public long[] getRenderFinishTime(String instanceId) {
        return nativeGetRenderFinishTime(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDefaultHeightAndWidthIntoRootDom(String instanceId, float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
        nativeSetDefaultHeightAndWidthIntoRootDom(instanceId, defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void onInstanceClose(String instanceId) {
        nativeOnInstanceClose(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void forceLayout(String instanceId) {
        nativeForceLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public boolean notifyLayout(String instanceId) {
        return nativeNotifyLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleWidth(String instanceId, String ref, float value, boolean update) {
        nativeSetStyleWidth(instanceId, ref, value, update);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setMargin(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetMargin(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPadding(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetPadding(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPosition(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetPosition(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void markDirty(String instanceId, String ref, boolean dirty) {
        nativeMarkDirty(instanceId, ref, dirty);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDeviceDisplay(String instanceId, float width, float height, float scale) {
        nativeSetDeviceDisplay(instanceId, width, height, scale);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleHeight(String instanceId, String ref, float value, boolean update) {
        nativeSetStyleHeight(instanceId, ref, value, update);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleWidth(String instanceId, String ref, float value) {
        nativeSetStyleWidth(instanceId, ref, value, false);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleHeight(String instanceId, String ref, float value) {
        nativeSetStyleHeight(instanceId, ref, value, false);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setInstanceRenderType(String instanceId, String renderType) {
        if (!TextUtils.isEmpty(renderType)) {
            nativeSetInstanceRenderType(instanceId, renderType);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setViewPortWidth(String instanceId, float viewPortWidth) {
        nativeSetViewPortWidth(instanceId, viewPortWidth);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setFlexDirectionDef(String def) {
        nativeSetFlexDirectionDef(def);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void removeInstanceRenderType(String instanceId) {
        nativeRemoveInstanceRenderType(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPageArgument(String instanceId, String key, String value) {
        nativeSetPageArgument(instanceId, key, value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void registerCoreEnv(String key, String value) {
        nativeRegisterCoreEnv(key, value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportNativeInitStatus(String statusCode, String errorMsg) {
        if (WXErrorCode.WX_JS_FRAMEWORK_INIT_SINGLE_PROCESS_SUCCESS.getErrorCode().equals(statusCode) || WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED.getErrorCode().equals(statusCode)) {
            IWXUserTrackAdapter userTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
            if (userTrackAdapter != null) {
                Map<String, Serializable> params = new HashMap<>(3);
                params.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, statusCode);
                params.put(IWXUserTrackAdapter.MONITOR_ARG, "InitFrameworkNativeError");
                params.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, errorMsg);
                WXLogUtils.e("reportNativeInitStatus is running and errorCode is " + statusCode + " And errorMsg is " + errorMsg);
                userTrackAdapter.commit(null, null, IWXUserTrackAdapter.INIT_FRAMEWORK, null, params);
            }
        } else if (WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL.getErrorCode().equals(statusCode)) {
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL, "WeexProxy::initFromParam()", WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL.getErrorMsg() + ": " + errorMsg, null);
        } else {
            WXErrorCode[] values = WXErrorCode.values();
            for (WXErrorCode e : values) {
                if (e.getErrorType().equals(WXErrorCode.ErrorType.NATIVE_ERROR) && e.getErrorCode().equals(statusCode)) {
                    WXExceptionUtils.commitCriticalExceptionRT(null, e, IWXUserTrackAdapter.INIT_FRAMEWORK, errorMsg, null);
                    return;
                }
            }
        }
    }

    public void fireEventOnDataRenderNode(String instanceId, String ref, String type, String data, String domChanges) {
        nativeFireEventOnDataRenderNode(instanceId, ref, type, data, domChanges);
    }

    public void invokeCallbackOnDataRender(String instanceId, String callbackId, String data, boolean keepAlive) {
        nativeInvokeCallbackOnDataRender(instanceId, callbackId, data, keepAlive);
    }

    public void registerModuleOnDataRenderNode(String data) {
        nativeRegisterModuleOnDataRenderNode(data);
    }

    public void registerComponentOnDataRenderNode(String data) {
        nativeRegisterComponentOnDataRenderNode(data);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reloadPageLayout(String instanceId) {
        nativeReloadPageLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDeviceDisplayOfPage(String instanceId, float width, float height) {
        nativeSetDeviceDisplayOfPage(instanceId, width, height);
    }

    public String encryptGetClientKeyPayload(String appId, String data, String appKey) {
        return nativePreGetClientKey(appId, data, appKey);
    }

    public String encrypt(String appId, String data, String appKey, String clientKeyData) {
        return nativeEncrypt(appId, data, appKey, clientKeyData);
    }

    public String decrypt(String appId, String data, String appKey, String clientKeyData) {
        return nativeDecrypt(appId, data, appKey, clientKeyData);
    }

    public boolean verifyClientKeyPayload(String appId, String appKey, String clientKeyData) {
        return nativeVerifyClientKeyPayload(appId, appKey, clientKeyData);
    }
}
