package com.taobao.weex.bridge;

import android.content.Intent;
import android.text.TextUtils;
import android.view.Menu;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.coremedia.iso.boxes.MetaBox;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.common.WXException;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.config.ConfigModuleFactory;
import com.taobao.weex.ui.module.WXDomModule;
import com.taobao.weex.ui.module.WXTimerModule;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.cache.RegisterCache;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

public class WXModuleManager {
    private static ArrayList<String> mBlackModuleList;
    private static Map<String, WXDomModule> sDomModuleMap = new HashMap();
    private static Map<String, WXModule> sGlobalModuleMap = new HashMap();
    private static Map<String, Map<String, WXModule>> sInstanceModuleMap = new ConcurrentHashMap();
    private static volatile ConcurrentMap<String, ModuleFactoryImpl> sModuleFactoryMap = new ConcurrentHashMap();

    public static boolean registerModule(Map<String, RegisterCache.ModuleCache> moduleCacheMap) {
        if (moduleCacheMap.isEmpty()) {
            return true;
        }
        final Iterator<Map.Entry<String, RegisterCache.ModuleCache>> iterator = moduleCacheMap.entrySet().iterator();
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.taobao.weex.bridge.WXModuleManager.AnonymousClass1 */

            public void run() {
                Map<String, Object> modules = new HashMap<>();
                while (iterator.hasNext()) {
                    RegisterCache.ModuleCache value = ((Map.Entry) iterator.next()).getValue();
                    String moduleName = value.name;
                    if (TextUtils.equals(moduleName, WXDomModule.WXDOM)) {
                        WXLogUtils.e("Cannot registered module with name 'dom'.");
                    } else {
                        if (WXModuleManager.sModuleFactoryMap != null && WXModuleManager.sModuleFactoryMap.containsKey(moduleName)) {
                            WXLogUtils.w("WXComponentRegistry Duplicate the Module name: " + moduleName);
                        }
                        ModuleFactory factory = value.factory;
                        try {
                            WXModuleManager.registerNativeModule(moduleName, factory);
                        } catch (WXException e) {
                            WXLogUtils.e("registerNativeModule" + e);
                        }
                        if (value.global) {
                            try {
                                WXModule wxModule = factory.buildInstance();
                                wxModule.setModuleName(moduleName);
                                WXModuleManager.sGlobalModuleMap.put(moduleName, wxModule);
                            } catch (Exception e2) {
                                WXLogUtils.e(moduleName + " class must have a default constructor without params. ", e2);
                            }
                        }
                        try {
                            WXModuleManager.sModuleFactoryMap.put(moduleName, new ModuleFactoryImpl(factory));
                        } catch (Throwable th) {
                        }
                        modules.put(moduleName, factory.getMethods());
                    }
                }
                WXSDKManager.getInstance().registerModules(modules);
            }
        });
        return true;
    }

    public static boolean registerModule(final String moduleName, final ModuleFactory factory, final boolean global) throws WXException {
        if (moduleName == null || factory == null) {
            return false;
        }
        if (TextUtils.equals(moduleName, WXDomModule.WXDOM)) {
            WXLogUtils.e("Cannot registered module with name 'dom'.");
            return false;
        } else if (RegisterCache.getInstance().cacheModule(moduleName, factory, global)) {
            return true;
        } else {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.bridge.WXModuleManager.AnonymousClass2 */

                public void run() {
                    if (WXModuleManager.sModuleFactoryMap != null && WXModuleManager.sModuleFactoryMap.containsKey(moduleName)) {
                        WXLogUtils.w("WXComponentRegistry Duplicate the Module name: " + moduleName);
                    }
                    try {
                        WXModuleManager.registerNativeModule(moduleName, factory);
                    } catch (WXException e) {
                        WXLogUtils.e("registerNativeModule" + e);
                    }
                    if (global) {
                        try {
                            WXModule wxModule = factory.buildInstance();
                            wxModule.setModuleName(moduleName);
                            WXModuleManager.sGlobalModuleMap.put(moduleName, wxModule);
                        } catch (Exception e2) {
                            WXLogUtils.e(moduleName + " class must have a default constructor without params. ", e2);
                        }
                    }
                    WXModuleManager.registerJSModule(moduleName, factory);
                    try {
                        WXModuleManager.sModuleFactoryMap.put(moduleName, new ModuleFactoryImpl(factory));
                    } catch (Throwable th) {
                    }
                }
            });
            return true;
        }
    }

    static boolean registerNativeModule(String moduleName, ModuleFactory factory) throws WXException {
        if (factory == null) {
            return false;
        }
        try {
            if (sModuleFactoryMap.containsKey(moduleName)) {
                return true;
            }
            sModuleFactoryMap.put(moduleName, new ModuleFactoryImpl(factory));
            return true;
        } catch (ArrayStoreException e) {
            e.printStackTrace();
            WXLogUtils.e("[WXModuleManager] registerNativeModule Error moduleName:" + moduleName + " Error:" + e.toString());
            return true;
        }
    }

    static boolean registerJSModule(String moduleName, ModuleFactory factory) {
        Map<String, Object> modules = new HashMap<>();
        modules.put(moduleName, factory.getMethods());
        WXSDKManager.getInstance().registerModules(modules);
        return true;
    }

    static Object callModuleMethod(String instanceId, String moduleStr, String methodStr, JSONArray args) {
        Exception e;
        Exception e2;
        ModuleFactory factory = sModuleFactoryMap.get(moduleStr).mFactory;
        if (factory == null) {
            WXLogUtils.e("[WXModuleManager] module factory not found.");
            return null;
        }
        WXModule wxModule = findModule(instanceId, moduleStr, factory);
        if (wxModule == null) {
            return null;
        }
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        wxModule.mWXSDKInstance = instance;
        wxModule.mUniSDKInstance = instance;
        Invoker invoker = factory.getMethodInvoker(methodStr);
        if (instance != null) {
            try {
                IWXUserTrackAdapter userTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
                if (userTrackAdapter != null) {
                    HashMap<String, Serializable> data = new HashMap<>();
                    data.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, "101");
                    data.put(IWXUserTrackAdapter.MONITOR_ARG, moduleStr + Operators.DOT_STR + methodStr);
                    data.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, instance.getBundleUrl());
                    userTrackAdapter.commit(instance.getContext(), null, IWXUserTrackAdapter.INVOKE_MODULE, null, data);
                }
                try {
                    Object dispatchCallModuleMethod = dispatchCallModuleMethod(instance, wxModule, args, invoker);
                    if ((wxModule instanceof WXDomModule) || (wxModule instanceof WXTimerModule)) {
                        wxModule.mWXSDKInstance = null;
                        wxModule.mUniSDKInstance = null;
                    }
                    return dispatchCallModuleMethod;
                } catch (Exception e3) {
                    e2 = e3;
                    try {
                        WXLogUtils.e("callModuleMethod >>> invoke module:" + moduleStr + ", method:" + methodStr + " failed. ", e2);
                        if ((wxModule instanceof WXDomModule) || (wxModule instanceof WXTimerModule)) {
                            wxModule.mWXSDKInstance = null;
                            wxModule.mUniSDKInstance = null;
                        }
                        return null;
                    } catch (Throwable th) {
                        e = th;
                        if ((wxModule instanceof WXDomModule) || (wxModule instanceof WXTimerModule)) {
                            wxModule.mWXSDKInstance = null;
                            wxModule.mUniSDKInstance = null;
                        }
                        throw e;
                    }
                }
            } catch (Exception e4) {
                e2 = e4;
                WXLogUtils.e("callModuleMethod >>> invoke module:" + moduleStr + ", method:" + methodStr + " failed. ", e2);
                wxModule.mWXSDKInstance = null;
                wxModule.mUniSDKInstance = null;
                return null;
            } catch (Throwable th2) {
                e = th2;
                wxModule.mWXSDKInstance = null;
                wxModule.mUniSDKInstance = null;
                throw e;
            }
        } else {
            WXLogUtils.e("callModuleMethod >>> instance is null");
            if ((wxModule instanceof WXDomModule) || (wxModule instanceof WXTimerModule)) {
                wxModule.mWXSDKInstance = null;
                wxModule.mUniSDKInstance = null;
            }
            return null;
        }
    }

    private static Object dispatchCallModuleMethod(WXSDKInstance instance, WXModule wxModule, JSONArray args, Invoker invoker) throws Exception {
        if (!instance.isPreRenderMode()) {
            return instance.getNativeInvokeHelper().invoke(wxModule, invoker, args);
        }
        if (invoker.isRunOnUIThread()) {
            return null;
        }
        return instance.getNativeInvokeHelper().invoke(wxModule, invoker, args);
    }

    public static boolean hasModule(String module) {
        return sGlobalModuleMap.containsKey(module) || sModuleFactoryMap.containsKey(module);
    }

    private static WXModule findModule(String instanceId, String moduleStr, ModuleFactory factory) {
        WXModule wxModule = sGlobalModuleMap.get(moduleStr);
        if (wxModule == null) {
            Map<String, WXModule> moduleMap = sInstanceModuleMap.get(instanceId);
            if (moduleMap == null) {
                moduleMap = new ConcurrentHashMap();
                sInstanceModuleMap.put(instanceId, moduleMap);
            }
            wxModule = moduleMap.get(moduleStr);
            if (wxModule == null) {
                try {
                    if (factory instanceof ConfigModuleFactory) {
                        wxModule = ((ConfigModuleFactory) factory).buildInstance(WXSDKManager.getInstance().getSDKInstance(instanceId));
                    } else {
                        wxModule = factory.buildInstance();
                    }
                    wxModule.setModuleName(moduleStr);
                    moduleMap.put(moduleStr, wxModule);
                } catch (Exception e) {
                    WXLogUtils.e(moduleStr + " module build instace failed.", e);
                    return null;
                }
            }
        }
        return wxModule;
    }

    public static void onActivityCreate(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityCreate();
                } else {
                    WXLogUtils.w("onActivityCreate can not find the " + key + " module");
                }
            }
        }
    }

    public static void onActivityStart(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityStart();
                } else {
                    WXLogUtils.w("onActivityStart can not find the " + key + " module");
                }
            }
        }
    }

    public static void onActivityPause(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityPause();
                } else {
                    WXLogUtils.w("onActivityPause can not find the " + key + " module");
                }
            }
        }
    }

    public static void onActivityResume(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityResume();
                } else {
                    WXLogUtils.w("onActivityResume can not find the " + key + " module");
                }
            }
        }
    }

    public static void onActivityStop(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityStop();
                } else {
                    WXLogUtils.w("onActivityStop can not find the " + key + " module");
                }
            }
        }
    }

    public static void onActivityDestroy(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityDestroy();
                } else {
                    WXLogUtils.w("onActivityDestroy can not find the " + key + " module");
                }
            }
        }
    }

    public static boolean onActivityBack(String instanceId) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules == null) {
            return false;
        }
        for (String key : modules.keySet()) {
            WXModule module = modules.get(key);
            if (module != null) {
                return module.onActivityBack();
            }
            WXLogUtils.w("onActivityCreate can not find the " + key + " module");
        }
        return false;
    }

    public static void onActivityResult(String instanceId, int requestCode, int resultCode, Intent data) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onActivityResult(requestCode, resultCode, data);
                } else {
                    WXLogUtils.w("onActivityResult can not find the " + key + " module");
                }
            }
        }
    }

    public static boolean onCreateOptionsMenu(String instanceId, Menu menu) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules == null) {
            return false;
        }
        for (String key : modules.keySet()) {
            WXModule module = modules.get(key);
            if (module != null) {
                module.onCreateOptionsMenu(menu);
            } else {
                WXLogUtils.w("onActivityResult can not find the " + key + " module");
            }
        }
        return false;
    }

    public static void onRequestPermissionsResult(String instanceId, int requestCode, String[] permissions, int[] grantResults) {
        Map<String, WXModule> modules = sInstanceModuleMap.get(instanceId);
        if (modules != null) {
            for (String key : modules.keySet()) {
                WXModule module = modules.get(key);
                if (module != null) {
                    module.onRequestPermissionsResult(requestCode, permissions, grantResults);
                } else {
                    WXLogUtils.w("onActivityResult can not find the " + key + " module");
                }
            }
        }
    }

    public static void destroyInstanceModules(String instanceId) {
        sDomModuleMap.remove(instanceId);
        Map<String, WXModule> moduleMap = sInstanceModuleMap.remove(instanceId);
        if (moduleMap != null && moduleMap.size() >= 1) {
            for (Map.Entry<String, WXModule> entry : moduleMap.entrySet()) {
                WXModule module = entry.getValue();
                if (module instanceof Destroyable) {
                    ((Destroyable) module).destroy();
                }
            }
        }
    }

    public static void createDomModule(WXSDKInstance instance) {
        if (instance != null) {
            sDomModuleMap.put(instance.getInstanceId(), new WXDomModule(instance));
        }
    }

    public static void destoryDomModule(String instanceID) {
        sDomModuleMap.remove(instanceID);
    }

    public static WXDomModule getDomModule(String instanceId) {
        return sDomModuleMap.get(instanceId);
    }

    public static void reload() {
        if (sModuleFactoryMap != null && sModuleFactoryMap.size() > 0) {
            for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
                try {
                    registerJSModule(entry.getKey(), entry.getValue().mFactory);
                } catch (Throwable th) {
                }
            }
        }
    }

    public static void registerWhenCreateInstance() {
        if (sModuleFactoryMap != null && sModuleFactoryMap.size() > 0) {
            for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
                try {
                    if (!entry.getValue().hasRigster) {
                        registerJSModule(entry.getKey(), entry.getValue().mFactory);
                    }
                } catch (Throwable th) {
                }
            }
        }
    }

    public static void resetAllModuleState() {
        if (sModuleFactoryMap != null && sModuleFactoryMap.size() > 0) {
            for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
                entry.getValue().hasRigster = false;
            }
        }
    }

    public static void resetModuleState(String module, boolean state) {
        if (sModuleFactoryMap != null && sModuleFactoryMap.size() > 0) {
            for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
                try {
                    if (entry.getKey() != null && entry.getKey().equals(module)) {
                        entry.getValue().hasRigster = state;
                    }
                } catch (Throwable th) {
                }
            }
        }
    }

    public static JSONObject getRegisterJsModules() {
        JSONObject data = null;
        if (sModuleFactoryMap != null && sModuleFactoryMap.size() > 0) {
            data = new JSONObject();
            for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
                try {
                    if (!getBlackList().contains(entry.getKey())) {
                        if (entry.getValue().mFactory != null) {
                            data.put(entry.getKey(), (Object) modulesToJSONArray(entry.getValue().mFactory.getMethods(), entry.getValue().mFactory));
                        }
                    }
                } catch (Throwable th) {
                }
            }
        }
        return data;
    }

    private static ArrayList<String> getBlackList() {
        if (mBlackModuleList == null) {
            ArrayList<String> arrayList = new ArrayList<>();
            mBlackModuleList = arrayList;
            arrayList.add("webview");
            mBlackModuleList.add("animation");
            mBlackModuleList.add("binding");
            mBlackModuleList.add("bindingx");
            mBlackModuleList.add("instanceWrap");
            mBlackModuleList.add(MetaBox.TYPE);
            mBlackModuleList.add("navigator");
            mBlackModuleList.add("expressionBinding");
        }
        return mBlackModuleList;
    }

    public static JSONArray modulesToJSONArray(String[] json, ModuleFactory factory) {
        String str;
        JSONArray jsonArray = null;
        if (json != null && json.length > 0) {
            for (int i = 0; i < json.length; i++) {
                if (jsonArray == null) {
                    jsonArray = new JSONArray();
                }
                if (!json[i].equals("addEventListener") && !json[i].equals("removeAllEventListeners")) {
                    boolean isSync = !factory.getMethodInvoker(json[i]).isRunOnUIThread();
                    StringBuilder sb = new StringBuilder();
                    sb.append(json[i]);
                    if (isSync) {
                        str = ":sync";
                    } else {
                        str = ":async";
                    }
                    sb.append(str);
                    jsonArray.add(sb.toString());
                }
            }
        }
        return jsonArray;
    }
}
