package com.taobao.weex.bridge;

import android.text.TextUtils;
import com.taobao.weex.common.WXJSService;
import io.dcloud.common.util.StringUtil;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class WXServiceManager {
    private static volatile ConcurrentHashMap<String, WXJSService> sInstanceJSServiceMap = new ConcurrentHashMap<>();

    public static boolean registerService(String name, String serviceScript, Map<String, Object> options) {
        if (TextUtils.isEmpty(name) || TextUtils.isEmpty(serviceScript)) {
            return false;
        }
        String param2 = "serviceName: \"" + name + "\"";
        for (String key : options.keySet()) {
            Object value = options.get(key);
            param2 = value instanceof String ? param2 + ", '" + key + "': '" + value + "'" : param2 + ", '" + key + "': " + value;
        }
        String serviceJs = StringUtil.format(";(function(service, options){ ;%s; })({ %s }, { %s });", serviceScript, "register: global.registerService, unregister: global.unregisterService", param2);
        WXJSService service = new WXJSService();
        service.setName(name);
        service.setScript(serviceScript);
        service.setOptions(options);
        sInstanceJSServiceMap.put(name, service);
        WXBridgeManager.getInstance().execJSService(serviceJs);
        return true;
    }

    public static boolean unRegisterService(String name) {
        if (TextUtils.isEmpty(name)) {
            return false;
        }
        sInstanceJSServiceMap.remove(name);
        WXBridgeManager.getInstance().execJSService(StringUtil.format("global.unregisterService( \"%s\" );", name));
        return true;
    }

    public static void execAllCacheJsService() {
        for (String serviceName : sInstanceJSServiceMap.keySet()) {
            WXJSService service = sInstanceJSServiceMap.get(serviceName);
            registerService(service.getName(), service.getScript(), service.getOptions());
        }
    }

    public static WXJSService getService(String serviceName) {
        if (sInstanceJSServiceMap != null) {
            return sInstanceJSServiceMap.get(serviceName);
        }
        return null;
    }

    public static void reload() {
        if (sInstanceJSServiceMap != null && sInstanceJSServiceMap.size() > 0) {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.bridge.WXServiceManager.AnonymousClass1 */

                public void run() {
                    for (Map.Entry<String, WXJSService> entry : WXServiceManager.sInstanceJSServiceMap.entrySet()) {
                        WXJSService service = entry.getValue();
                        WXServiceManager.registerService(service.getName(), service.getScript(), service.getOptions());
                    }
                }
            });
        }
    }
}
