package com.taobao.weex.common;

import com.taobao.weex.WXEnvironment;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.bridge.MethodInvoker;
import com.taobao.weex.bridge.ModuleFactory;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.common.UniModuleAnno;
import java.lang.annotation.Annotation;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

public class TypeModuleFactory<T extends WXModule> implements ModuleFactory<T> {
    public static final String TAG = "TypeModuleFactory";
    Class<T> mClazz;
    Map<String, Invoker> mMethodMap;

    public TypeModuleFactory(Class<T> clz) {
        this.mClazz = clz;
    }

    private void generateMethodMap() {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("TypeModuleFactory", "extractMethodNames:" + this.mClazz.getSimpleName());
        }
        HashMap<String, Invoker> methodMap = new HashMap<>();
        try {
            Method[] methods = this.mClazz.getMethods();
            for (Method method : methods) {
                Annotation[] declaredAnnotations = method.getDeclaredAnnotations();
                int length = declaredAnnotations.length;
                int i = 0;
                while (true) {
                    if (i >= length) {
                        break;
                    }
                    Annotation anno = declaredAnnotations[i];
                    if (anno != null) {
                        if (anno instanceof JSMethod) {
                            JSMethod methodAnnotation = (JSMethod) anno;
                            methodMap.put("_".equals(methodAnnotation.alias()) ? method.getName() : methodAnnotation.alias(), new MethodInvoker(method, methodAnnotation.uiThread()));
                        } else if (anno instanceof WXModuleAnno) {
                            methodMap.put(method.getName(), new MethodInvoker(method, ((WXModuleAnno) anno).runOnUIThread()));
                            break;
                        } else if (anno instanceof UniJSMethod) {
                            UniJSMethod methodAnnotation2 = (UniJSMethod) anno;
                            methodMap.put("_".equals(methodAnnotation2.alias()) ? method.getName() : methodAnnotation2.alias(), new MethodInvoker(method, methodAnnotation2.uiThread()));
                        } else if (anno instanceof UniModuleAnno) {
                            methodMap.put(method.getName(), new MethodInvoker(method, ((UniModuleAnno) anno).runOnUIThread()));
                            break;
                        }
                    }
                    i++;
                }
            }
        } catch (Throwable e) {
            WXLogUtils.e("[WXModuleManager] extractMethodNames:", e);
        }
        this.mMethodMap = methodMap;
    }

    @Override // com.taobao.weex.bridge.ModuleFactory
    public T buildInstance() throws IllegalAccessException, InstantiationException {
        return this.mClazz.newInstance();
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public String[] getMethods() {
        if (this.mMethodMap == null) {
            generateMethodMap();
        }
        Set<String> keys = this.mMethodMap.keySet();
        return (String[]) keys.toArray(new String[keys.size()]);
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public Invoker getMethodInvoker(String name) {
        if (this.mMethodMap == null) {
            generateMethodMap();
        }
        return this.mMethodMap.get(name);
    }
}
