package com.taobao.weex.dom.binding;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.el.parse.Parser;
import com.taobao.weex.el.parse.Token;
import com.taobao.weex.utils.WXLogUtils;

public class ELUtils {
    public static final String BINDING = "@binding";
    public static final String COMPONENT_PROPS = "@componentProps";
    public static final String[] EXCLUDES_BINDING = {"clickEventParams"};
    public static final String IS_COMPONENT_ROOT = "@isComponentRoot";

    public static boolean isBinding(Object value) {
        if (value instanceof JSONObject) {
            if (((JSONObject) value).containsKey(BINDING)) {
                return true;
            }
        } else if (value instanceof JSONArray) {
            JSONArray array = (JSONArray) value;
            for (int i = 0; i < array.size(); i++) {
                if (isBinding(array.get(i))) {
                    return true;
                }
            }
        } else if (!(value instanceof String) || ((String) value).indexOf(BINDING) < 0) {
            return false;
        } else {
            return true;
        }
        return false;
    }

    public static Object bindingBlock(Object value) {
        if (value instanceof JSONObject) {
            JSONObject object = (JSONObject) value;
            if (object.containsKey(BINDING)) {
                Object binding = object.get(BINDING);
                if (!(binding instanceof Token)) {
                    object.put(BINDING, (Object) Parser.parse(binding.toString()));
                }
            }
            for (Object propsKey : object.keySet()) {
                if ((object.get(propsKey) instanceof JSONObject) && ((JSONObject) object.get(propsKey)).containsKey(BINDING)) {
                    JSONObject propsValue = (JSONObject) object.get(propsKey);
                    Object binding2 = propsValue.get(BINDING);
                    if (!(binding2 instanceof Token)) {
                        propsValue.put(BINDING, (Object) Parser.parse(binding2.toString()));
                    }
                }
            }
        } else if (value instanceof JSONArray) {
            JSONArray array = (JSONArray) value;
            for (int i = 0; i < array.size(); i++) {
                bindingBlock(array.get(i));
            }
        } else if (value instanceof String) {
            String json = value.toString();
            if (json.startsWith(Operators.BLOCK_START_STR)) {
                return bindingBlock(JSON.parseObject(json));
            }
            if (json.startsWith(Operators.ARRAY_START_STR)) {
                return bindingBlock(JSON.parseArray(json));
            }
        }
        return value;
    }

    public static Object vforBlock(Object vfor) {
        if (vfor instanceof JSONObject) {
            if (((JSONObject) vfor).containsKey(WXStatement.WX_FOR_LIST)) {
                Object list = ((JSONObject) vfor).get(WXStatement.WX_FOR_LIST);
                if (!(list instanceof Token)) {
                    ((JSONObject) vfor).put(WXStatement.WX_FOR_LIST, (Object) Parser.parse(list.toString()));
                }
            }
        } else if (vfor instanceof String) {
            return vforBlock(JSONObject.parseObject(vfor.toString()));
        } else {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("weex", "weex vfor is illegal " + vfor);
            }
        }
        return vfor;
    }
}
