package com.taobao.weex.el.parse;

import com.igexin.push.core.b;
import com.taobao.weex.common.Constants;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.reflect.Array;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Stack;

public class Operators {
    public static final String AND = "&&";
    public static final String AND_NOT = "!";
    public static final char ARRAY_END = ']';
    public static final String ARRAY_END_STR = "]";
    public static final char ARRAY_SEPRATOR = ',';
    public static final String ARRAY_SEPRATOR_STR = ",";
    public static final char ARRAY_START = '[';
    public static final String ARRAY_START_STR = "[";
    public static final char BLOCK_END = '}';
    public static final String BLOCK_END_STR = "}";
    public static final char BLOCK_START = '{';
    public static final String BLOCK_START_STR = "{";
    public static final char BRACKET_END = ')';
    public static final String BRACKET_END_STR = ")";
    public static final char BRACKET_START = '(';
    public static final String BRACKET_START_STR = "(";
    public static final char CONDITION_IF = '?';
    public static final char CONDITION_IF_MIDDLE = ':';
    public static final String CONDITION_IF_STRING = "?";
    public static final String DIV = "/";
    public static final char DOLLAR = '$';
    public static final String DOLLAR_STR = "$";
    public static final char DOT = '.';
    public static final String DOT_STR = ".";
    public static final String EQUAL = "===";
    public static final String EQUAL2 = "==";
    public static final String G = ">";
    public static final String GE = ">=";
    public static final Map<String, Object> KEYWORDS;
    public static final String L = "<";
    public static final String LE = "<=";
    public static final String MOD = "%";
    public static final String MUL = "*";
    public static final String NOT_EQUAL = "!==";
    public static final String NOT_EQUAL2 = "!=";
    public static Map<String, Integer> OPERATORS_PRIORITY = null;
    public static final String OR = "||";
    public static final String PLUS = "+";
    public static final char QUOTE = '\"';
    public static final char SINGLE_QUOTE = '\'';
    public static final char SPACE = ' ';
    public static final String SPACE_STR = " ";
    public static final String SUB = "-";

    public static Object dot(Token left, Token right, Object context) {
        Object leftValue;
        Object value;
        if (left == null || right == null || (leftValue = left.execute(context)) == null) {
            return null;
        }
        if (right.getType() != 0) {
            Object identifter = right.execute(context);
            if (identifter instanceof Double) {
                identifter = Integer.valueOf(((Double) identifter).intValue());
            }
            value = el(leftValue, identifter == null ? "" : identifter.toString().trim());
        } else {
            value = right.execute(leftValue);
        }
        if (value != null) {
            return value;
        }
        return specialKey(leftValue, right.getToken());
    }

    public static Object el(Object context, String key) {
        if (context == null) {
            return null;
        }
        if (context instanceof ArrayStack) {
            ArrayStack stack = (ArrayStack) context;
            for (int index = stack.size() - 1; index >= 0; index--) {
                Object value = stack.get(index);
                if (value instanceof Map) {
                    Map map = (Map) value;
                    if (map.containsKey(key)) {
                        return map.get(key);
                    }
                }
            }
        }
        if (context instanceof Stack) {
            Stack stack2 = (Stack) context;
            for (int index2 = stack2.size() - 1; index2 >= 0; index2--) {
                Object value2 = stack2.get(index2);
                if (value2 instanceof Map) {
                    Map map2 = (Map) value2;
                    if (map2.containsKey(key)) {
                        return map2.get(key);
                    }
                }
            }
        }
        if (context instanceof Map) {
            return ((Map) context).get(key);
        }
        if (context instanceof List) {
            try {
                return ((List) context).get(Integer.parseInt(key));
            } catch (Exception e) {
            }
        }
        if (context.getClass().isArray()) {
            try {
                return Array.get(context, Integer.parseInt(key));
            } catch (Exception e2) {
            }
        }
        return null;
    }

    public static Object specialKey(Object leftValue, String key) {
        if (!"length".equals(key)) {
            return null;
        }
        if (leftValue instanceof CharSequence) {
            return Integer.valueOf(((CharSequence) leftValue).length());
        }
        if (leftValue instanceof Map) {
            return Integer.valueOf(((Map) leftValue).size());
        }
        if (leftValue instanceof Map) {
            return Integer.valueOf(((Map) leftValue).size());
        }
        if (leftValue instanceof List) {
            return Integer.valueOf(((List) leftValue).size());
        }
        if (leftValue.getClass().isArray()) {
            return Integer.valueOf(Array.getLength(leftValue));
        }
        return null;
    }

    public static Object plus(Token left, Token right, Object context) {
        Object leftValue = null;
        Object rightValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        if (right != null) {
            rightValue = right.execute(context);
        }
        String str = "";
        if ((leftValue instanceof CharSequence) || (rightValue instanceof CharSequence)) {
            if (leftValue == null) {
                return rightValue;
            }
            StringBuilder sb = new StringBuilder();
            sb.append(leftValue.toString());
            if (rightValue != null) {
                str = rightValue.toString();
            }
            sb.append(str);
            return sb.toString();
        } else if ((leftValue instanceof Number) || (rightValue instanceof Number)) {
            return Double.valueOf(getNumber(leftValue) + getNumber(rightValue));
        } else {
            if (leftValue == null && rightValue == null) {
                return null;
            }
            if (leftValue == null) {
                return rightValue.toString();
            }
            StringBuilder sb2 = new StringBuilder();
            sb2.append(leftValue.toString());
            if (rightValue != null) {
                str = rightValue.toString();
            }
            sb2.append(str);
            return sb2.toString();
        }
    }

    public static Object sub(Token left, Token right, Object context) {
        Object leftValue = null;
        Object rightValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        if (right != null) {
            rightValue = right.execute(context);
        }
        return Double.valueOf(getNumber(leftValue) - getNumber(rightValue));
    }

    public static Object div(Token left, Token right, Object context) {
        Object leftValue = null;
        Object rightValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        if (right != null) {
            rightValue = right.execute(context);
        }
        return Double.valueOf(getNumber(leftValue) / getNumber(rightValue));
    }

    public static Object mul(Token left, Token right, Object context) {
        Object leftValue = null;
        Object rightValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        if (right != null) {
            rightValue = right.execute(context);
        }
        return Double.valueOf(getNumber(leftValue) * getNumber(rightValue));
    }

    public static Object mod(Token left, Token right, Object context) {
        Object leftValue = null;
        Object rightValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        if (right != null) {
            rightValue = right.execute(context);
        }
        return Double.valueOf(getNumber(leftValue) % getNumber(rightValue));
    }

    public static Object condition(Token selfs, Token first, Token second, Object context) {
        boolean value = false;
        if (selfs != null) {
            value = isTrue(selfs.execute(context));
        }
        if (value) {
            if (first != null) {
                return first.execute(context);
            }
            return null;
        } else if (second != null) {
            return second.execute(context);
        } else {
            return null;
        }
    }

    public static boolean tokenTrue(Token selfs, Object context) {
        if (selfs == null) {
            return false;
        }
        return isTrue(selfs.execute(context));
    }

    public static double tokenNumber(Token self, Object context) {
        if (self == null) {
            return 0.0d;
        }
        return getNumber(self.execute(context));
    }

    public static boolean isEquals(Token left, Token right, Object context) {
        if (left == null && right == null) {
            return true;
        }
        Object leftValue = null;
        if (left != null) {
            leftValue = left.execute(context);
        }
        Object rightValue = null;
        if (right != null) {
            rightValue = right.execute(context);
        }
        if (leftValue == null) {
            if (rightValue == null) {
                return true;
            }
            if (!(rightValue instanceof CharSequence) || !isEmpty(rightValue.toString())) {
                return false;
            }
            return true;
        } else if (rightValue == null) {
            if (isEmpty(leftValue.toString())) {
                return true;
            }
            return false;
        } else if (leftValue instanceof Number) {
            if (rightValue instanceof Number) {
                if (((Number) leftValue).doubleValue() == ((Number) rightValue).doubleValue()) {
                    return true;
                }
                return false;
            } else if (((Number) leftValue).doubleValue() == getNumber(rightValue)) {
                return true;
            } else {
                return false;
            }
        } else if (rightValue instanceof Number) {
            if (getNumber(leftValue) == ((Number) rightValue).doubleValue()) {
                return true;
            }
            return false;
        } else if ((leftValue instanceof CharSequence) || (rightValue instanceof CharSequence)) {
            return leftValue.toString().trim().equals(rightValue.toString().trim());
        } else {
            return leftValue.equals(rightValue);
        }
    }

    public static boolean isTrue(Object value) {
        if (value == null) {
            return false;
        }
        if (!(value instanceof Number)) {
            String bool = value.toString().trim();
            if (AbsoluteConst.FALSE.equals(bool) || Constants.Name.UNDEFINED.equals(bool) || b.m.equals(bool) || isEmpty(bool)) {
                return false;
            }
            return true;
        } else if (((Number) value).doubleValue() != 0.0d) {
            return true;
        } else {
            return false;
        }
    }

    public static boolean isEmpty(String value) {
        if (value == null) {
            return true;
        }
        for (int i = 0; i < value.length(); i++) {
            if (value.charAt(i) != ' ') {
                return false;
            }
        }
        return true;
    }

    public static double getNumber(Object value) {
        if (value == null) {
            return 0.0d;
        }
        if (value instanceof Number) {
            return ((Number) value).doubleValue();
        }
        try {
            return Double.parseDouble(value.toString());
        } catch (Exception e) {
            return 0.0d;
        }
    }

    public static boolean isOpEnd(String op) {
        return isOpEnd(op.charAt(0));
    }

    public static boolean isOpEnd(char op) {
        if (op == ')' || op == ']' || op == ' ' || op == ',') {
            return true;
        }
        return false;
    }

    public static boolean isDot(String opStr) {
        char op = opStr.charAt(0);
        if (op == '.' || op == '[') {
            return true;
        }
        return false;
    }

    static {
        HashMap hashMap = new HashMap();
        OPERATORS_PRIORITY = hashMap;
        hashMap.put("}", 0);
        OPERATORS_PRIORITY.put(BRACKET_END_STR, 0);
        OPERATORS_PRIORITY.put(SPACE_STR, 0);
        OPERATORS_PRIORITY.put(",", 0);
        OPERATORS_PRIORITY.put(ARRAY_END_STR, 0);
        OPERATORS_PRIORITY.put(OR, 1);
        OPERATORS_PRIORITY.put(AND, 1);
        OPERATORS_PRIORITY.put(EQUAL, 2);
        OPERATORS_PRIORITY.put(EQUAL2, 2);
        OPERATORS_PRIORITY.put(NOT_EQUAL, 2);
        OPERATORS_PRIORITY.put(NOT_EQUAL2, 2);
        OPERATORS_PRIORITY.put(G, 7);
        OPERATORS_PRIORITY.put(GE, 7);
        OPERATORS_PRIORITY.put(L, 7);
        OPERATORS_PRIORITY.put(LE, 8);
        OPERATORS_PRIORITY.put(PLUS, 9);
        OPERATORS_PRIORITY.put("-", 9);
        OPERATORS_PRIORITY.put("*", 10);
        OPERATORS_PRIORITY.put("/", 10);
        OPERATORS_PRIORITY.put("%", 10);
        OPERATORS_PRIORITY.put(AND_NOT, 11);
        OPERATORS_PRIORITY.put(DOT_STR, 15);
        OPERATORS_PRIORITY.put(ARRAY_START_STR, 16);
        OPERATORS_PRIORITY.put(BRACKET_START_STR, 17);
        OPERATORS_PRIORITY.put(BLOCK_START_STR, 17);
        HashMap hashMap2 = new HashMap();
        KEYWORDS = hashMap2;
        hashMap2.put(b.m, null);
        KEYWORDS.put(AbsoluteConst.TRUE, Boolean.TRUE);
        KEYWORDS.put(AbsoluteConst.FALSE, Boolean.FALSE);
        KEYWORDS.put(Constants.Name.UNDEFINED, null);
    }
}
