package com.taobao.weex.http;

import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.common.WXRequest;
import java.util.HashMap;
import java.util.Map;

/* access modifiers changed from: package-private */
public class Options {
    private String body;
    private Map<String, String> headers;
    private String inputType;
    private boolean isFirstIpv4;
    private String method;
    private boolean sslVerify;
    private int timeout;
    private JSONObject tlsConfig;
    private Type type;
    private String url;

    public enum Type {
        json,
        text,
        jsonp,
        base64
    }

    private Options(String method2, String url2, Map<String, String> headers2, String body2, Type type2, int timeout2) {
        this.type = Type.text;
        this.timeout = WXRequest.DEFAULT_TIMEOUT_MS;
        this.sslVerify = false;
        this.isFirstIpv4 = false;
        this.method = method2;
        this.url = url2;
        this.headers = headers2;
        this.body = body2;
        this.type = type2;
        this.timeout = timeout2 == 0 ? WXRequest.DEFAULT_TIMEOUT_MS : timeout2;
    }

    private Options(String method2, String url2, Map<String, String> headers2, String body2, Type type2, int timeout2, boolean sslVerify2, boolean sFirstIpv4) {
        this.type = Type.text;
        this.timeout = WXRequest.DEFAULT_TIMEOUT_MS;
        this.sslVerify = false;
        this.isFirstIpv4 = false;
        this.method = method2;
        this.url = url2;
        this.headers = headers2;
        this.body = body2;
        this.type = type2;
        this.timeout = timeout2 == 0 ? WXRequest.DEFAULT_TIMEOUT_MS : timeout2;
        this.sslVerify = sslVerify2;
        this.isFirstIpv4 = sFirstIpv4;
    }

    public String getMethod() {
        return this.method;
    }

    public String getUrl() {
        return this.url;
    }

    public Map<String, String> getHeaders() {
        return this.headers;
    }

    public String getBody() {
        return this.body;
    }

    public Type getType() {
        return this.type;
    }

    public int getTimeout() {
        return this.timeout;
    }

    public boolean getSslVerify() {
        return this.sslVerify;
    }

    public boolean isFirstIpv4() {
        return this.isFirstIpv4;
    }

    public JSONObject getTlsConfig() {
        return this.tlsConfig;
    }

    public void setTlsConfig(JSONObject tlsConfig2) {
        this.tlsConfig = tlsConfig2;
    }

    public String getInputType() {
        return this.inputType;
    }

    public void setInputType(String inputType2) {
        this.inputType = inputType2;
    }

    public static class Builder {
        private JSONObject androidTLSConfig;
        private String body;
        private Map<String, String> headers = new HashMap();
        private String inputType;
        private boolean isFirstIpv4;
        private String method;
        private boolean sslVerify;
        private int timeout;
        private Type type;
        private String url;

        public Builder setAndroidTlsConfig(JSONObject config) {
            this.androidTLSConfig = config;
            return this;
        }

        public Builder setMethod(String method2) {
            this.method = method2;
            return this;
        }

        public Builder setUrl(String url2) {
            this.url = url2;
            return this;
        }

        public Builder putHeader(String key, String value) {
            this.headers.put(key, value);
            return this;
        }

        public Builder setBody(String body2) {
            this.body = body2;
            return this;
        }

        public Builder setSslVerify(boolean sslVerify2) {
            this.sslVerify = sslVerify2;
            return this;
        }

        public Builder setFirstIpv4(boolean firstIpv4) {
            this.isFirstIpv4 = firstIpv4;
            return this;
        }

        public Builder setType(String type2) {
            if (Type.json.name().equals(type2)) {
                this.type = Type.json;
            } else if (Type.jsonp.name().equals(type2)) {
                this.type = Type.jsonp;
            } else if (Type.base64.name().equals(type2)) {
                this.type = Type.base64;
            } else {
                this.type = Type.text;
            }
            return this;
        }

        public Builder setType(Type type2) {
            this.type = type2;
            return this;
        }

        public Builder setInputTypes(String type2) {
            this.inputType = type2;
            return this;
        }

        public Builder setTimeout(int timeout2) {
            this.timeout = timeout2;
            return this;
        }

        public Options createOptions() {
            Options newOption = new Options(this.method, this.url, this.headers, this.body, this.type, this.timeout, this.sslVerify, this.isFirstIpv4);
            newOption.setInputType(this.inputType);
            newOption.setTlsConfig(this.androidTLSConfig);
            return newOption;
        }
    }
}
