package com.taobao.weex.http;

import android.net.Uri;
import android.text.TextUtils;
import android.util.Base64;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alipay.sdk.m.l.c;
import com.igexin.push.core.b;
import com.igexin.push.f.r;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.http.Options;
import com.taobao.weex.utils.WXLogUtils;
import com.tencent.connect.common.Constants;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.net.NetWork;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class WXStreamModule extends WXModule {
    static final Pattern CHARSET_PATTERN = Pattern.compile("charset=([a-z0-9-]+)");
    public static final String STATUS = "status";
    public static final String STATUS_TEXT = "statusText";
    public static HashMap<String, CertDTO> certMap = new HashMap<>();
    final IWXHttpAdapter mAdapter;

    /* access modifiers changed from: private */
    public interface ResponseCallback {
        void onResponse(WXResponse wXResponse, Map<String, String> map);
    }

    public WXStreamModule() {
        this(null);
    }

    public WXStreamModule(IWXHttpAdapter adapter) {
        this.mAdapter = adapter;
    }

    @JSMethod(uiThread = false)
    @Deprecated
    public void sendHttp(JSONObject paramsObj, final String callback) {
        String method = paramsObj.getString("method");
        String url = paramsObj.getString("url");
        JSONObject headers = paramsObj.getJSONObject("header");
        String body = paramsObj.getString("body");
        int timeout = paramsObj.getIntValue("timeout");
        boolean sslVerify = paramsObj.getBooleanValue("sslVerify");
        boolean firstIpv4 = paramsObj.getBooleanValue("firstIpv4");
        JSONObject androidTLSConfig = paramsObj.getJSONObject("tls");
        if (method != null) {
            method = method.toUpperCase();
        }
        Options.Builder builder = new Options.Builder();
        String str = Constants.HTTP_GET;
        if (str.equals(method) || Constants.HTTP_POST.equals(method) || "PUT".equals(method) || "DELETE".equals(method) || "HEAD".equals(method) || "PATCH".equals(method)) {
            str = method;
        }
        Options.Builder builder2 = builder.setMethod(str).setUrl(url).setBody(body).setTimeout(timeout).setSslVerify(sslVerify).setAndroidTlsConfig(androidTLSConfig).setFirstIpv4(firstIpv4);
        extractHeaders(headers, builder2);
        final Options options = builder2.createOptions();
        sendRequest(builder2.createOptions(), new ResponseCallback() {
            /* class com.taobao.weex.http.WXStreamModule.AnonymousClass1 */

            @Override // com.taobao.weex.http.WXStreamModule.ResponseCallback
            public void onResponse(WXResponse response, Map<String, String> headers) {
                String str;
                if (callback != null && WXStreamModule.this.mWXSDKInstance != null) {
                    WXBridgeManager instance = WXBridgeManager.getInstance();
                    String instanceId = WXStreamModule.this.mWXSDKInstance.getInstanceId();
                    String str2 = callback;
                    if (response == null || response.originalData == null) {
                        str = "{}";
                    } else {
                        str = WXStreamModule.readAsString(response.originalData, headers != null ? WXStreamModule.getHeader(headers, NetWork.CONTENT_TYPE) : "", options.getType());
                    }
                    instance.callback(instanceId, str2, str);
                }
            }
        }, null, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
    }

    @JSMethod(uiThread = false)
    public void fetch(JSONObject optionsObj, JSCallback callback, JSCallback progressCallback) {
        fetch(optionsObj, callback, progressCallback, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
    }

    @JSMethod(uiThread = false)
    public void fetchWithArrayBuffer(JSONObject arrayBufferObj, JSONObject optionsObj, JSCallback callback, JSCallback progressCallback) {
        if (arrayBufferObj != null) {
            String typeParam = arrayBufferObj.getString("@type");
            if (!TextUtils.isEmpty(typeParam) && "binary".equalsIgnoreCase(typeParam)) {
                String base64Param = arrayBufferObj.getString("base64");
                if (!TextUtils.isEmpty(base64Param)) {
                    optionsObj.put("inputType", "base64");
                    optionsObj.put("body", (Object) base64Param);
                    fetch(optionsObj, callback, progressCallback, this.mWXSDKInstance.getInstanceId(), this.mWXSDKInstance.getBundleUrl());
                } else if (callback != null) {
                    Map<String, Object> resp = new HashMap<>();
                    resp.put(b.y, false);
                    resp.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
                    callback.invoke(resp);
                }
            } else if (callback != null) {
                Map<String, Object> resp2 = new HashMap<>();
                resp2.put(b.y, false);
                resp2.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
                callback.invoke(resp2);
            }
        } else if (callback != null) {
            Map<String, Object> resp3 = new HashMap<>();
            resp3.put(b.y, false);
            resp3.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
            callback.invoke(resp3);
        }
    }

    @JSMethod(uiThread = false)
    public void configMTLS(JSONArray certArray, JSCallback callback) {
        if (callback != null) {
            if (certArray == null || certArray.isEmpty()) {
                callback.invoke(CertJSResponse.obtainFail(-1, DOMException.MSG_PARAMETER_ERROR));
                return;
            }
            certMap.clear();
            for (int index = 0; index < certArray.size(); index++) {
                JSONObject perCertObject = certArray.getJSONObject(index);
                if (perCertObject.containsKey(c.f)) {
                    CertDTO perCert = new CertDTO();
                    String hostKey = perCertObject.getString(c.f);
                    perCert.host = hostKey;
                    perCert.client = perCertObject.getString("client");
                    perCert.clientPassword = perCertObject.getString("clientPassword");
                    perCert.server = (String[]) perCertObject.getJSONArray("server").toArray(new String[0]);
                    certMap.put(hostKey, perCert);
                }
            }
            callback.invoke(CertJSResponse.obtainSuccess());
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0098  */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x009e  */
    public void fetch(JSONObject optionsObj, final JSCallback callback, JSCallback progressCallback, String instanceId, String bundleURL) {
        String localUrl;
        String method;
        if (!(optionsObj == null || optionsObj.getString("url") == null)) {
            String method2 = optionsObj.getString("method");
            String url = optionsObj.getString("url");
            JSONObject headers = optionsObj.getJSONObject("headers");
            String body = optionsObj.getString("body");
            String type = optionsObj.getString("type");
            String inputType = optionsObj.getString("inputType");
            int timeout = optionsObj.getIntValue("timeout");
            JSONObject androidTLSConfig = optionsObj.getJSONObject("tls");
            boolean sslVerify = optionsObj.getBooleanValue("sslVerify");
            boolean isFirstIPV4 = optionsObj.getBooleanValue("firstIpv4");
            WXSDKInstance wxsdkInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (!(wxsdkInstance == null || wxsdkInstance.getStreamNetworkHandler() == null)) {
                localUrl = wxsdkInstance.getStreamNetworkHandler().fetchLocal(url);
                if (!TextUtils.isEmpty(localUrl)) {
                    if (method2 == null) {
                        method = method2.toUpperCase();
                    } else {
                        method = method2;
                    }
                    Options.Builder builder = new Options.Builder().setMethod((!Constants.HTTP_GET.equals(method) || Constants.HTTP_POST.equals(method) || "PUT".equals(method) || "DELETE".equals(method) || "HEAD".equals(method) || "PATCH".equals(method)) ? method : Constants.HTTP_GET).setUrl(localUrl).setBody(body).setType(type).setInputTypes(inputType).setTimeout(timeout).setSslVerify(sslVerify).setAndroidTlsConfig(androidTLSConfig).setFirstIpv4(isFirstIPV4);
                    extractHeaders(headers, builder);
                    final Options options = builder.createOptions();
                    sendRequest(options, new ResponseCallback() {
                        /* class com.taobao.weex.http.WXStreamModule.AnonymousClass2 */

                        @Override // com.taobao.weex.http.WXStreamModule.ResponseCallback
                        public void onResponse(WXResponse response, Map<String, String> headers) {
                            if (callback != null) {
                                Map<String, Object> resp = new HashMap<>();
                                if (response == null || "-1".equals(response.statusCode)) {
                                    resp.put("status", -1);
                                    resp.put(WXStreamModule.STATUS_TEXT, Status.ERR_CONNECT_FAILED);
                                    if (response != null) {
                                        resp.put("errorMsg", response.errorMsg);
                                    } else {
                                        resp.put("errorMsg", "response 为空");
                                    }
                                } else {
                                    int code = Integer.parseInt(response.statusCode);
                                    resp.put("status", Integer.valueOf(code));
                                    resp.put(b.y, Boolean.valueOf(code >= 200 && code <= 299));
                                    if (response.originalData == null) {
                                        resp.put("data", response.errorMsg);
                                    } else {
                                        try {
                                            resp.put("data", WXStreamModule.this.parseData(WXStreamModule.readAsString(response.originalData, headers != null ? WXStreamModule.getHeader(headers, NetWork.CONTENT_TYPE) : "", options.getType()), options.getType()));
                                        } catch (JSONException exception) {
                                            WXLogUtils.e("", exception);
                                            resp.put(b.y, false);
                                            resp.put("data", "{'err':'Data parse failed!'}");
                                        }
                                    }
                                    resp.put(WXStreamModule.STATUS_TEXT, Status.getStatusText(response.statusCode));
                                }
                                resp.put("headers", headers);
                                callback.invoke(resp);
                            }
                        }
                    }, progressCallback, instanceId, bundleURL);
                }
            }
            localUrl = url;
            if (method2 == null) {
            }
            Options.Builder builder2 = new Options.Builder().setMethod((!Constants.HTTP_GET.equals(method) || Constants.HTTP_POST.equals(method) || "PUT".equals(method) || "DELETE".equals(method) || "HEAD".equals(method) || "PATCH".equals(method)) ? method : Constants.HTTP_GET).setUrl(localUrl).setBody(body).setType(type).setInputTypes(inputType).setTimeout(timeout).setSslVerify(sslVerify).setAndroidTlsConfig(androidTLSConfig).setFirstIpv4(isFirstIPV4);
            extractHeaders(headers, builder2);
            final Options options2 = builder2.createOptions();
            sendRequest(options2, new ResponseCallback() {
                /* class com.taobao.weex.http.WXStreamModule.AnonymousClass2 */

                @Override // com.taobao.weex.http.WXStreamModule.ResponseCallback
                public void onResponse(WXResponse response, Map<String, String> headers) {
                    if (callback != null) {
                        Map<String, Object> resp = new HashMap<>();
                        if (response == null || "-1".equals(response.statusCode)) {
                            resp.put("status", -1);
                            resp.put(WXStreamModule.STATUS_TEXT, Status.ERR_CONNECT_FAILED);
                            if (response != null) {
                                resp.put("errorMsg", response.errorMsg);
                            } else {
                                resp.put("errorMsg", "response 为空");
                            }
                        } else {
                            int code = Integer.parseInt(response.statusCode);
                            resp.put("status", Integer.valueOf(code));
                            resp.put(b.y, Boolean.valueOf(code >= 200 && code <= 299));
                            if (response.originalData == null) {
                                resp.put("data", response.errorMsg);
                            } else {
                                try {
                                    resp.put("data", WXStreamModule.this.parseData(WXStreamModule.readAsString(response.originalData, headers != null ? WXStreamModule.getHeader(headers, NetWork.CONTENT_TYPE) : "", options2.getType()), options2.getType()));
                                } catch (JSONException exception) {
                                    WXLogUtils.e("", exception);
                                    resp.put(b.y, false);
                                    resp.put("data", "{'err':'Data parse failed!'}");
                                }
                            }
                            resp.put(WXStreamModule.STATUS_TEXT, Status.getStatusText(response.statusCode));
                        }
                        resp.put("headers", headers);
                        callback.invoke(resp);
                    }
                }
            }, progressCallback, instanceId, bundleURL);
        } else if (callback != null) {
            Map<String, Object> resp = new HashMap<>();
            resp.put(b.y, false);
            resp.put(STATUS_TEXT, Status.ERR_INVALID_REQUEST);
            callback.invoke(resp);
        }
    }

    /* access modifiers changed from: package-private */
    public Object parseData(String data, Options.Type type) throws JSONException {
        if (type == Options.Type.json) {
            return JSONObject.parse(data);
        }
        if (type != Options.Type.jsonp) {
            return data;
        }
        if (data == null || data.isEmpty()) {
            return new JSONObject();
        }
        int b = data.indexOf(Operators.BRACKET_START_STR) + 1;
        int e = data.lastIndexOf(Operators.BRACKET_END_STR);
        if (b == 0 || b >= e || e <= 0) {
            return new JSONObject();
        }
        return JSONObject.parse(data.substring(b, e));
    }

    static String getHeader(Map<String, String> headers, String key) {
        if (headers == null || key == null) {
            return null;
        }
        if (headers.containsKey(key)) {
            return headers.get(key);
        }
        return headers.get(key.toLowerCase(Locale.ENGLISH));
    }

    static String readAsString(byte[] data, String cType, Options.Type type) {
        String charset = r.b;
        if (cType != null) {
            Matcher matcher = CHARSET_PATTERN.matcher(cType.toLowerCase(Locale.ENGLISH));
            if (matcher.find()) {
                charset = matcher.group(1);
            }
        }
        try {
            if (type == Options.Type.base64) {
                return Base64.encodeToString(data, 2);
            }
            return new String(data, charset);
        } catch (Exception e) {
            WXLogUtils.e("", e);
            return new String(data);
        }
    }

    private void extractHeaders(JSONObject headers, Options.Builder builder) {
        String UA = WXHttpUtil.assembleUserAgent(WXEnvironment.getApplication(), WXEnvironment.getConfig());
        if (headers != null) {
            for (String key : headers.keySet()) {
                if (key.equals(WXHttpUtil.KEY_USER_AGENT)) {
                    UA = headers.getString(key);
                } else {
                    builder.putHeader(key, headers.getString(key));
                }
            }
        }
        builder.putHeader(WXHttpUtil.KEY_USER_AGENT, UA);
    }

    private void sendRequest(Options options, ResponseCallback callback, JSCallback progressCallback, String instanceId, String bundleURL) {
        WXRequest wxRequest = new WXRequest();
        wxRequest.method = options.getMethod();
        wxRequest.url = WXSDKManager.getInstance().getURIAdapter().rewrite(bundleURL, "request", Uri.parse(options.getUrl())).toString();
        wxRequest.body = options.getBody();
        wxRequest.timeoutMs = options.getTimeout();
        wxRequest.instanceId = instanceId;
        wxRequest.sslVerify = options.getSslVerify();
        wxRequest.isFirstIpv4 = options.isFirstIpv4();
        wxRequest.tls = options.getTlsConfig();
        if ("BASE64".equalsIgnoreCase(options.getInputType())) {
            wxRequest.inputType = "BASE64";
        } else {
            wxRequest.inputType = "";
        }
        if (options.getHeaders() != null) {
            if (wxRequest.paramMap == null) {
                wxRequest.paramMap = options.getHeaders();
            } else {
                wxRequest.paramMap.putAll(options.getHeaders());
            }
        }
        IWXHttpAdapter adapter = this.mAdapter;
        if (adapter == null) {
            adapter = WXSDKManager.getInstance().getIWXHttpAdapter();
        }
        if (adapter != null) {
            adapter.sendRequest(wxRequest, new StreamHttpListener(callback, progressCallback));
        } else {
            WXLogUtils.e("WXStreamModule", "No HttpAdapter found,request failed.");
        }
    }

    /* access modifiers changed from: private */
    public static class StreamHttpListener implements IWXHttpAdapter.OnHttpListener {
        private ResponseCallback mCallback;
        private JSCallback mProgressCallback;
        private Map<String, String> mRespHeaders;
        private Map<String, Object> mResponse;

        private StreamHttpListener(ResponseCallback callback, JSCallback progressCallback) {
            this.mResponse = new HashMap();
            this.mCallback = callback;
            this.mProgressCallback = progressCallback;
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpStart() {
            if (this.mProgressCallback != null) {
                this.mResponse.put("readyState", 1);
                this.mResponse.put("length", 0);
                this.mProgressCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpUploadProgress(int uploadProgress) {
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHeadersReceived(int statusCode, Map<String, List<String>> headers) {
            this.mResponse.put("readyState", 2);
            this.mResponse.put("status", Integer.valueOf(statusCode));
            Map<String, String> simpleHeaders = new HashMap<>();
            if (headers != null) {
                for (Map.Entry<String, List<String>> entry : headers.entrySet()) {
                    if (entry.getValue().size() != 0) {
                        String str = "_";
                        if (entry.getValue().size() == 1) {
                            if (entry.getKey() != null) {
                                str = entry.getKey();
                            }
                            simpleHeaders.put(str, entry.getValue().get(0));
                        } else {
                            if (entry.getKey() != null) {
                                str = entry.getKey();
                            }
                            simpleHeaders.put(str, entry.getValue().toString());
                        }
                    }
                }
            }
            this.mResponse.put("headers", simpleHeaders);
            this.mRespHeaders = simpleHeaders;
            JSCallback jSCallback = this.mProgressCallback;
            if (jSCallback != null) {
                jSCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpResponseProgress(int loadedLength) {
            this.mResponse.put("length", Integer.valueOf(loadedLength));
            JSCallback jSCallback = this.mProgressCallback;
            if (jSCallback != null) {
                jSCallback.invokeAndKeepAlive(new HashMap(this.mResponse));
            }
        }

        @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
        public void onHttpFinish(WXResponse response) {
            ResponseCallback responseCallback = this.mCallback;
            if (responseCallback != null) {
                responseCallback.onResponse(response, this.mRespHeaders);
            }
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("WXStreamModule", (response == null || response.originalData == null) ? "response data is NUll!" : new String(response.originalData));
            }
        }
    }
}
