package com.taobao.weex.layout.measurefunc;

import android.graphics.Canvas;
import android.os.Build;
import android.os.Looper;
import android.text.Editable;
import android.text.Layout;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.text.SpannedString;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.style.AlignmentSpan;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.TextDecorationSpan;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXCustomStyleSpan;
import com.taobao.weex.dom.WXLineHeightSpan;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.layout.MeasureMode;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXTextDecoration;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;

public class TextContentBoxMeasurement extends ContentBoxMeasurement {
    private static final Canvas DUMMY_CANVAS = new Canvas();
    private static final String ELLIPSIS = "…";
    private AtomicReference<Layout> atomicReference = new AtomicReference<>();
    private boolean hasBeenMeasured = false;
    private Layout layout;
    protected Layout.Alignment mAlignment;
    protected int mColor;
    protected String mFontFamily = null;
    protected int mFontSize = -1;
    protected int mFontStyle = -1;
    protected int mFontWeight = -1;
    protected boolean mIsColorSet = false;
    protected int mLineHeight = -1;
    private int mNumberOfLines = -1;
    private String mText = null;
    protected WXTextDecoration mTextDecoration = WXTextDecoration.NONE;
    protected TextPaint mTextPaint;
    private float previousWidth = Float.NaN;
    private Spanned spanned;
    private TextUtils.TruncateAt textOverflow;

    public TextContentBoxMeasurement(WXComponent component) {
        super(component);
    }

    class SetSpanOperation {
        protected final int end;
        protected final int flag;
        protected final int start;
        protected final Object what;

        SetSpanOperation(TextContentBoxMeasurement this$02, int start2, int end2, Object what2) {
            this(start2, end2, what2, 17);
        }

        SetSpanOperation(int start2, int end2, Object what2, int flag2) {
            this.start = start2;
            this.end = end2;
            this.what = what2;
            this.flag = flag2;
        }

        public void execute(Spannable sb) {
            sb.setSpan(this.what, this.start, this.end, this.flag);
        }
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void layoutBefore() {
        this.mTextPaint = new TextPaint(1);
        this.hasBeenMeasured = false;
        updateStyleAndText();
        this.spanned = createSpanned(this.mText);
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
        float measureWidth = width;
        float measureHeight = height;
        boolean z = true;
        this.hasBeenMeasured = true;
        TextPaint textPaint = this.mTextPaint;
        if (widthMeasureMode != MeasureMode.EXACTLY) {
            z = false;
        }
        float textWidth = getTextWidth(textPaint, width, z);
        if (textWidth <= 0.0f || this.spanned == null) {
            if (widthMeasureMode == MeasureMode.UNSPECIFIED) {
                measureWidth = 0.0f;
            }
            if (heightMeasureMode == MeasureMode.UNSPECIFIED) {
                measureHeight = 0.0f;
            }
        } else {
            Layout createLayout = createLayout(textWidth, null);
            this.layout = createLayout;
            this.previousWidth = (float) createLayout.getWidth();
            if (Float.isNaN(width)) {
                measureWidth = (float) this.layout.getWidth();
            } else {
                measureWidth = Math.min((float) this.layout.getWidth(), measureWidth);
            }
            if (Float.isNaN(height)) {
                measureHeight = (float) this.layout.getHeight();
            }
        }
        this.mMeasureWidth = measureWidth;
        this.mMeasureHeight = measureHeight;
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void layoutAfter(float computedWidth, float computedHeight) {
        if (this.mComponent != null) {
            if (!this.hasBeenMeasured) {
                updateStyleAndText();
                recalculateLayout(computedWidth);
            } else if (!(this.layout == null || WXDomUtils.getContentWidth(this.mComponent.getPadding(), this.mComponent.getBorder(), computedWidth) == this.previousWidth)) {
                recalculateLayout(computedWidth);
            }
            this.hasBeenMeasured = false;
            Layout layout2 = this.layout;
            if (layout2 != null && !layout2.equals(this.atomicReference.get()) && Build.VERSION.SDK_INT >= 19 && Thread.currentThread() != Looper.getMainLooper().getThread()) {
                warmUpTextLayoutCache(this.layout);
            }
            swap();
            WXSDKManager.getInstance().getWXRenderManager().postOnUiThread(new Runnable() {
                /* class com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement.AnonymousClass1 */

                public void run() {
                    if (TextContentBoxMeasurement.this.mComponent != null) {
                        TextContentBoxMeasurement.this.mComponent.updateExtra(TextContentBoxMeasurement.this.atomicReference.get());
                    }
                }
            }, this.mComponent.getInstanceId());
        }
    }

    private void updateStyleAndText() {
        updateStyleImp(this.mComponent.getStyles());
        this.mText = WXAttr.getValue(this.mComponent.getAttrs());
    }

    public void forceRelayout() {
        layoutBefore();
        measure(this.previousWidth, Float.NaN, MeasureMode.EXACTLY, MeasureMode.UNSPECIFIED);
        layoutAfter(this.previousWidth, Float.NaN);
    }

    private void updateStyleImp(Map<String, Object> style) {
        if (style != null) {
            if (style.containsKey(Constants.Name.LINES)) {
                int lines = WXStyle.getLines(style);
                this.mNumberOfLines = lines > 0 ? lines : -1;
            }
            if (style.containsKey(Constants.Name.FONT_SIZE)) {
                this.mFontSize = WXStyle.getFontSize(style, this.mComponent.getInstance().getDefaultFontSize(), this.mComponent.getViewPortWidthForFloat());
            }
            if (style.containsKey(Constants.Name.FONT_WEIGHT)) {
                this.mFontWeight = WXStyle.getFontWeight(style);
            }
            if (style.containsKey(Constants.Name.FONT_STYLE)) {
                this.mFontStyle = WXStyle.getFontStyle(style);
            }
            if (style.containsKey("color")) {
                int color = WXResourceUtils.getColor(WXStyle.getTextColor(style));
                this.mColor = color;
                this.mIsColorSet = color != Integer.MIN_VALUE;
            }
            if (style.containsKey(Constants.Name.TEXT_DECORATION)) {
                this.mTextDecoration = WXStyle.getTextDecoration(style);
            }
            if (style.containsKey(Constants.Name.FONT_FAMILY)) {
                this.mFontFamily = WXStyle.getFontFamily(style);
            }
            this.mAlignment = WXStyle.getTextAlignment(style, this.mComponent.isLayoutRTL());
            this.textOverflow = WXStyle.getTextOverflow(style);
            int lineHeight = WXStyle.getLineHeight(style, this.mComponent.getViewPortWidthForFloat());
            if (lineHeight != -1) {
                this.mLineHeight = lineHeight;
            }
        }
    }

    /* access modifiers changed from: protected */
    public Spanned createSpanned(String text) {
        if (TextUtils.isEmpty(text)) {
            return new SpannableString("");
        }
        SpannableString spannable = new SpannableString(text);
        updateSpannable(spannable, 17);
        return spannable;
    }

    /* access modifiers changed from: protected */
    public void updateSpannable(Spannable spannable, int spanFlag) {
        int end = spannable.length();
        int i = this.mFontSize;
        if (i == -1) {
            this.mTextPaint.setTextSize((float) this.mComponent.getInstance().getDefaultFontSize());
        } else {
            this.mTextPaint.setTextSize((float) i);
        }
        int i2 = this.mLineHeight;
        if (i2 != -1) {
            setSpan(spannable, new WXLineHeightSpan(i2), 0, end, spanFlag);
        }
        setSpan(spannable, new AlignmentSpan.Standard(this.mAlignment), 0, end, spanFlag);
        if (!(this.mFontStyle == -1 && this.mFontWeight == -1 && this.mFontFamily == null)) {
            setSpan(spannable, new WXCustomStyleSpan(this.mFontStyle, this.mFontWeight, this.mFontFamily), 0, end, spanFlag);
        }
        if (this.mIsColorSet) {
            this.mTextPaint.setColor(this.mColor);
        }
        if (this.mTextDecoration == WXTextDecoration.UNDERLINE || this.mTextDecoration == WXTextDecoration.LINETHROUGH) {
            setSpan(spannable, new TextDecorationSpan(this.mTextDecoration), 0, end, spanFlag);
        }
    }

    /* access modifiers changed from: protected */
    public void setSpan(Spannable spannable, Object what, int start, int end, int spanFlag) {
        spannable.setSpan(what, start, end, spanFlag);
    }

    /* JADX INFO: Multiple debug info for r0v2 float: [D('textWidth' float), D('desiredWidth' float)] */
    private float getTextWidth(TextPaint textPaint, float outerWidth, boolean forceToDesired) {
        if (this.mText == null) {
            if (forceToDesired) {
                return outerWidth;
            }
            return 0.0f;
        } else if (forceToDesired) {
            return outerWidth;
        } else {
            float desiredWidth = Layout.getDesiredWidth(this.spanned, textPaint);
            return (WXUtils.isUndefined(outerWidth) || desiredWidth < outerWidth) ? desiredWidth : outerWidth;
        }
    }

    private Layout createLayout(float textWidth, Layout previousLayout) {
        Layout layout2;
        SpannableStringBuilder builder;
        if (this.previousWidth != textWidth || previousLayout == null) {
            layout2 = new StaticLayout(this.spanned, this.mTextPaint, (int) Math.ceil((double) textWidth), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
        } else {
            layout2 = previousLayout;
        }
        int i = this.mNumberOfLines;
        if (i != -1 && i > 0 && i < layout2.getLineCount()) {
            int i2 = this.mNumberOfLines;
            if (i2 > 1) {
                int lastLineStart = layout2.getLineStart(i2 - 1);
                int lastLineEnd = layout2.getLineEnd(this.mNumberOfLines - 1);
                if (lastLineStart < lastLineEnd) {
                    if (lastLineStart > 0) {
                        builder = new SpannableStringBuilder(this.spanned.subSequence(0, lastLineStart));
                    } else {
                        builder = new SpannableStringBuilder();
                    }
                    builder.append((CharSequence) truncate(new SpannableStringBuilder(this.spanned.subSequence(lastLineStart, lastLineEnd)), this.mTextPaint, (int) Math.ceil((double) textWidth), this.textOverflow));
                    adjustSpansRange(this.spanned, builder);
                    this.spanned = builder;
                    return new StaticLayout(this.spanned, this.mTextPaint, (int) Math.ceil((double) textWidth), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
                }
            } else {
                int ceilTextWidth = (int) Math.ceil((double) textWidth);
                Spanned spanned2 = this.spanned;
                return StaticLayout.Builder.obtain(spanned2, 0, spanned2.length(), this.mTextPaint, ceilTextWidth).setMaxLines(1).setEllipsize(TextUtils.TruncateAt.END).setEllipsizedWidth(ceilTextWidth).build();
            }
        }
        return layout2;
    }

    private Spanned truncate(Editable source, TextPaint paint, int desired, TextUtils.TruncateAt truncateAt) {
        Spanned ret = new SpannedString("");
        if (TextUtils.isEmpty(source) || source.length() <= 0) {
            return ret;
        }
        if (truncateAt != null) {
            source.append(ELLIPSIS);
            Object[] spans = source.getSpans(0, source.length(), Object.class);
            for (Object span : spans) {
                int start = source.getSpanStart(span);
                int end = source.getSpanEnd(span);
                if (start == 0 && end == source.length() - 1) {
                    source.removeSpan(span);
                    source.setSpan(span, 0, source.length(), source.getSpanFlags(span));
                }
            }
        }
        while (source.length() > 1) {
            int startOffset = source.length() - 1;
            int startOffset2 = truncateAt != null ? startOffset - 1 : startOffset;
            source.delete(startOffset2, startOffset2 + 1);
            if (new StaticLayout(source, paint, desired, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false).getLineCount() <= 1) {
                return source;
            }
        }
        return ret;
    }

    private void adjustSpansRange(Spanned beforeTruncate, Spannable afterTruncate) {
        Object[] spans = beforeTruncate.getSpans(0, beforeTruncate.length(), Object.class);
        for (Object span : spans) {
            int start = beforeTruncate.getSpanStart(span);
            int end = beforeTruncate.getSpanEnd(span);
            if (start == 0 && end == beforeTruncate.length()) {
                afterTruncate.removeSpan(span);
                afterTruncate.setSpan(span, 0, afterTruncate.length(), beforeTruncate.getSpanFlags(span));
            }
        }
    }

    private void recalculateLayout(float computedWidth) {
        float contentWidth = WXDomUtils.getContentWidth(this.mComponent.getPadding(), this.mComponent.getBorder(), computedWidth);
        if (contentWidth > 0.0f) {
            Spanned createSpanned = createSpanned(this.mText);
            this.spanned = createSpanned;
            if (createSpanned != null) {
                Layout createLayout = createLayout(contentWidth, this.layout);
                this.layout = createLayout;
                this.previousWidth = (float) createLayout.getWidth();
                return;
            }
            this.previousWidth = 0.0f;
        }
    }

    private boolean warmUpTextLayoutCache(Layout layout2) {
        try {
            layout2.draw(DUMMY_CANVAS);
            return true;
        } catch (Exception e) {
            WXLogUtils.eTag("TextWarmUp", e);
            return false;
        }
    }

    private void swap() {
        Layout layout2 = this.layout;
        if (layout2 != null) {
            this.atomicReference.set(layout2);
            this.layout = null;
        }
        this.hasBeenMeasured = false;
    }
}
