package com.taobao.weex.performance;

import android.util.Log;
import com.amap.api.maps.model.MyLocationStyle;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXJSExceptionInfo;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.utils.WXUtils;
import java.util.List;
import org.json.JSONObject;

public class WXAnalyzerDataTransfer {
    private static final String GROUP = "WXAnalyzer";
    public static final String INTERACTION_TAG = "wxInteractionAnalyzer";
    private static final String MODULE_ERROR = "WXError";
    private static final String MODULE_WX_APM = "wxapm";
    public static boolean isOpenPerformance = false;
    private static boolean sOpenInteractionLog;

    public static void transferPerformance(String instanceId, String type, String key, Object value) {
        WXSDKInstance instance;
        if (isOpenPerformance) {
            if (sOpenInteractionLog && "stage".equals(type)) {
                Log.d(INTERACTION_TAG, "[client][stage]" + instanceId + "," + key + "," + value);
            }
            List<IWXAnalyzer> transferList = WXSDKManager.getInstance().getWXAnalyzerList();
            if (transferList != null && transferList.size() != 0 && (instance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId)) != null) {
                try {
                    String data = new JSONObject().put(key, value).toString();
                    for (IWXAnalyzer item : transferList) {
                        item.transfer(MODULE_WX_APM, instance.getInstanceId(), type, data);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static void transferInteractionInfo(WXComponent targetComponent) {
        List<IWXAnalyzer> transferList;
        if (isOpenPerformance && (transferList = WXSDKManager.getInstance().getWXAnalyzerList()) != null && transferList.size() != 0) {
            try {
                String data = new JSONObject().put("renderOriginDiffTime", WXUtils.getFixUnixTime() - targetComponent.getInstance().getWXPerformance().renderUnixTimeOrigin).put("type", targetComponent.getComponentType()).put("ref", targetComponent.getRef()).put("style", targetComponent.getStyles()).put(TemplateDom.KEY_ATTRS, targetComponent.getAttrs()).toString();
                for (IWXAnalyzer transfer : transferList) {
                    transfer.transfer(MODULE_WX_APM, targetComponent.getInstanceId(), "wxinteraction", data);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public static void transferError(WXJSExceptionInfo exceptionInfo, String instanceId) {
        List<IWXAnalyzer> transferList;
        WXSDKInstance instance;
        if (!(!WXEnvironment.isApkDebugable() || (transferList = WXSDKManager.getInstance().getWXAnalyzerList()) == null || transferList.size() == 0 || (instance = WXSDKManager.getInstance().getSDKInstance(instanceId)) == null)) {
            WXErrorCode errorCode = exceptionInfo.getErrCode();
            String data = "";
            try {
                data = new JSONObject().put("instanceId", instanceId).put("url", instance.getBundleUrl()).put(MyLocationStyle.ERROR_CODE, errorCode.getErrorCode()).put("errorMsg", errorCode.getErrorMsg()).put("errorGroup", errorCode.getErrorGroup()).toString();
            } catch (Exception e) {
                e.printStackTrace();
            }
            for (IWXAnalyzer transfer : transferList) {
                transfer.transfer(GROUP, MODULE_ERROR, errorCode.getErrorType().toString(), data);
            }
        }
    }

    public static void switchInteractionLog(boolean isOpen) {
        if (sOpenInteractionLog != isOpen && WXEnvironment.JsFrameworkInit) {
            sOpenInteractionLog = isOpen;
            WXBridgeManager.getInstance().registerCoreEnv("switchInteractionLog", String.valueOf(isOpen));
        }
    }

    public static boolean isInteractionLogOpen() {
        return sOpenInteractionLog;
    }
}
