package com.taobao.weex.performance;

import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentLinkedQueue;

public class WXStateRecord {
    private long jsThreadTime;
    private Runnable jsThreadWatchTask;
    private RecordList<Info> mActionHistory;
    private RecordList<Info> mExceptionHistory;
    private RecordList<Info> mIPCExceptionHistory;
    private RecordList<Info> mJsThradWatchHistory;
    private RecordList<Info> mJscCrashHistory;
    private RecordList<Info> mJscReloadHistory;
    private RecordList<Info> mJsfmInitHistory;

    /* access modifiers changed from: private */
    public static class SingleTonHolder {
        private static final WXStateRecord S_INSTANCE = new WXStateRecord();

        private SingleTonHolder() {
        }
    }

    public static WXStateRecord getInstance() {
        return SingleTonHolder.S_INSTANCE;
    }

    private WXStateRecord() {
        this.jsThreadTime = -1;
        this.jsThreadWatchTask = new Runnable() {
            /* class com.taobao.weex.performance.WXStateRecord.AnonymousClass1 */

            public void run() {
                if (WXStateRecord.this.jsThreadTime == -1) {
                    WXStateRecord.this.jsThreadTime = WXUtils.getFixUnixTime();
                }
                long diff = WXUtils.getFixUnixTime() - WXStateRecord.this.jsThreadTime;
                WXStateRecord wXStateRecord = WXStateRecord.this;
                wXStateRecord.recordJsThreadWatch("diff:" + diff);
                WXStateRecord.this.jsThreadTime = WXUtils.getFixUnixTime();
                WXBridgeManager.getInstance().postDelay(WXStateRecord.this.jsThreadWatchTask, 500);
            }
        };
        this.mExceptionHistory = new RecordList<>(10);
        this.mActionHistory = new RecordList<>(20);
        this.mJsfmInitHistory = new RecordList<>(10);
        this.mJscCrashHistory = new RecordList<>(10);
        this.mJscReloadHistory = new RecordList<>(10);
        this.mJsThradWatchHistory = new RecordList<>(20);
        this.mIPCExceptionHistory = new RecordList<>(20);
    }

    public void recordException(String instanceId, String exception) {
        recordCommon(this.mExceptionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, exception.length() > 200 ? exception.substring(0, 200) : exception));
    }

    public void recordAction(String instanceId, String action) {
        recordCommon(this.mActionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, action));
    }

    public void recordIPCException(String instanceId, String exception) {
        recordCommon(this.mIPCExceptionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, exception.length() > 200 ? exception.substring(0, 200) : exception));
    }

    public void onJSFMInit() {
        recoreJsfmInitHistory("setJsfmVersion");
    }

    public void recoreJsfmInitHistory(String msg) {
        recordCommon(this.mJsfmInitHistory, new Info(WXUtils.getFixUnixTime(), "JSFM", msg));
    }

    public void recordJsThreadWatch(String msg) {
        recordCommon(this.mJsThradWatchHistory, new Info(WXUtils.getFixUnixTime(), "jsWatch", msg));
    }

    public void onJSEngineReload(String instanceId) {
        recordCommon(this.mJscReloadHistory, new Info(WXUtils.getFixUnixTime(), instanceId, "onJSEngineReload"));
    }

    public void onJSCCrash(String instanceId) {
        recordCommon(this.mJscCrashHistory, new Info(WXUtils.getFixUnixTime(), instanceId, "onJSCCrash"));
    }

    private void recordCommon(RecordList<Info> list, Info info) {
        if (list != null && info != null) {
            try {
                list.add(info);
                if (!list.isEmpty() && list.size() > ((RecordList) list).maxSize) {
                    list.poll();
                }
            } catch (Throwable e) {
                e.getStackTrace();
            }
        }
    }

    public Map<String, String> getStateInfo() {
        Map<String, String> stateInfo = new HashMap<>(5);
        stateInfo.put("reInitCount", String.valueOf(WXBridgeManager.reInitCount));
        List<Info> reportTimeLineInfo = new ArrayList<>(this.mExceptionHistory.size() + this.mActionHistory.size() + this.mJsfmInitHistory.size() + this.mJscCrashHistory.size() + this.mJscReloadHistory.size() + this.mJsThradWatchHistory.size());
        reportTimeLineInfo.addAll(this.mExceptionHistory);
        reportTimeLineInfo.addAll(this.mActionHistory);
        reportTimeLineInfo.addAll(this.mJsfmInitHistory);
        reportTimeLineInfo.addAll(this.mJscCrashHistory);
        reportTimeLineInfo.addAll(this.mJscReloadHistory);
        reportTimeLineInfo.addAll(this.mJsThradWatchHistory);
        reportTimeLineInfo.addAll(this.mIPCExceptionHistory);
        Collections.sort(reportTimeLineInfo);
        stateInfo.put("stateInfoList", reportTimeLineInfo.toString());
        IWXConfigAdapter adapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (adapter != null && AbsoluteConst.TRUE.equalsIgnoreCase(adapter.getConfig("wxapm", "dumpIpcPageInfo", AbsoluteConst.TRUE))) {
            stateInfo.put("pageQueueInfo", WXBridgeManager.getInstance().dumpIpcPageInfo());
        }
        return stateInfo;
    }

    /* access modifiers changed from: private */
    public static class RecordList<E> extends ConcurrentLinkedQueue<E> {
        private int maxSize;

        public RecordList(int maxSize2) {
            this.maxSize = maxSize2;
        }
    }

    /* access modifiers changed from: private */
    public static class Info implements Comparable<Info> {
        private String instanceId;
        private String msg;
        private long time;

        public Info(long time2, String instance, String msg2) {
            this.time = time2;
            this.instanceId = instance;
            this.msg = msg2;
        }

        public String toString() {
            return Operators.ARRAY_START + this.instanceId + Operators.ARRAY_SEPRATOR + this.time + Operators.ARRAY_SEPRATOR + this.msg + "]->";
        }

        public int compareTo(Info next) {
            long j = this.time;
            long j2 = next.time;
            if (j == j2) {
                return 0;
            }
            return j > j2 ? 1 : -1;
        }
    }

    public void startJSThreadWatchDog() {
        WXBridgeManager.getInstance().post(this.jsThreadWatchTask);
    }
}
