package com.taobao.weex.performance;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import com.alipay.sdk.m.u.i;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.common.Constants;
import org.json.JSONObject;

public class WhiteScreenUtils {
    public static boolean doWhiteScreenCheck() {
        IWXConfigAdapter configAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (configAdapter == null) {
            return false;
        }
        double randomValue = Math.random() * 100.0d;
        double max = 100.0d;
        try {
            max = Double.valueOf(configAdapter.getConfig("wxapm", "new_ws_sampling", "100")).doubleValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (randomValue < max) {
            return true;
        }
        return false;
    }

    public static boolean isWhiteScreen(WXSDKInstance instance) {
        if (instance == null) {
            return false;
        }
        View v = instance.getContainerView();
        if ((v instanceof ViewGroup) && !isInWhiteList(instance)) {
            return !hasLeafViewOrSizeIgnore(v, 3);
        }
        return false;
    }

    private static boolean isInWhiteList(WXSDKInstance instance) {
        IWXConfigAdapter configAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (configAdapter == null) {
            return false;
        }
        String whiteList = configAdapter.getConfig("wxapm", "ws_white_list", null);
        if (TextUtils.isEmpty(whiteList)) {
            return false;
        }
        try {
            String[] urlList = whiteList.split(i.b);
            for (String whiteUrl : urlList) {
                if (instance.getBundleUrl() != null && instance.getBundleUrl().contains(whiteUrl)) {
                    return true;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    private static boolean hasLeafViewOrSizeIgnore(View v, int checkDeep) {
        if (!(v instanceof ViewGroup)) {
            return true;
        }
        if (checkDeep > 0) {
            if (v.getHeight() < 10 || v.getWidth() < 10) {
                return true;
            }
            checkDeep--;
        }
        ViewGroup group = (ViewGroup) v;
        for (int i = 0; i < group.getChildCount(); i++) {
            if (hasLeafViewOrSizeIgnore(group.getChildAt(i), checkDeep)) {
                return true;
            }
        }
        return false;
    }

    public static String takeViewTreeSnapShot(WXSDKInstance instance) {
        if (instance == null) {
            return "nullInstance";
        }
        JSONObject root = geViewDetailTreeMsg(instance.getContainerView());
        if (root != null) {
            return root.toString();
        }
        return "";
    }

    private static JSONObject geViewDetailTreeMsg(View view) {
        if (view == null) {
            return null;
        }
        JSONObject node = new JSONObject();
        try {
            node.put("width", view.getWidth());
            node.put("height", view.getHeight());
            int[] location = {-1, -1};
            view.getLocationOnScreen(location);
            node.put(Constants.Name.X, location[0]);
            node.put(Constants.Name.Y, location[1]);
            if (view instanceof ViewGroup) {
                node.put("type", view.getClass().getSimpleName());
                ViewGroup group = (ViewGroup) view;
                for (int i = 0; i < group.getChildCount(); i++) {
                    node.put("child_" + i, geViewDetailTreeMsg(group.getChildAt(i)));
                }
            } else {
                node.put("type", view.getClass().getSimpleName());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return node;
    }
}
