package com.taobao.weex.tracing;

import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class Stopwatch {
    private static final ThreadLocal<Stopwatch> sThreadLocal = new ThreadLocal<>();
    private List<ProcessEvent> splits = new ArrayList();
    private long startMillis;
    private long startNanos;

    public static class ProcessEvent {
        public double duration;
        public String fname;
        public long startMillis;
    }

    private static void prepare() {
        if (sThreadLocal.get() == null) {
            sThreadLocal.set(new Stopwatch());
        }
    }

    public static void tick() {
        if (WXTracing.isAvailable()) {
            try {
                prepare();
                if (sThreadLocal.get().startNanos != 0) {
                    WXLogUtils.w("Stopwatch", "Stopwatch is not reset");
                }
                sThreadLocal.get().startNanos = System.nanoTime();
                sThreadLocal.get().startMillis = System.currentTimeMillis();
            } catch (Throwable t) {
                t.printStackTrace();
            }
        }
    }

    public static void split(String fname) {
        if (WXTracing.isAvailable()) {
            try {
                ProcessEvent event = new ProcessEvent();
                long start = sThreadLocal.get().startMillis;
                double millis = tackAndTick();
                event.fname = fname;
                event.duration = millis;
                event.startMillis = start;
                sThreadLocal.get().splits.add(event);
            } catch (Throwable throwable) {
                throwable.printStackTrace();
            }
        }
    }

    public static List<ProcessEvent> getProcessEvents() {
        if (!WXTracing.isAvailable()) {
            return Collections.emptyList();
        }
        tack();
        List<ProcessEvent> existedEvents = sThreadLocal.get().splits;
        sThreadLocal.get().splits = new ArrayList();
        return existedEvents;
    }

    public static double tack() {
        if (!WXTracing.isAvailable()) {
            return -1.0d;
        }
        try {
            long startNanos2 = sThreadLocal.get().startNanos;
            if (startNanos2 == 0) {
                WXLogUtils.w("Stopwatch", "Should call Stopwatch.tick() before Stopwatch.tack() called");
            }
            sThreadLocal.get().startNanos = 0;
            return nanosToMillis(System.nanoTime() - startNanos2);
        } catch (Throwable throwable) {
            throwable.printStackTrace();
            return -1.0d;
        }
    }

    public static long lastTickStamp() {
        if (!WXTracing.isAvailable()) {
            return -1;
        }
        try {
            return sThreadLocal.get().startMillis;
        } catch (Throwable t) {
            t.printStackTrace();
            return -1;
        }
    }

    public static double tackAndTick() {
        double ms = tack();
        tick();
        return ms;
    }

    public static double nanosToMillis(long nanos) {
        return ((double) nanos) / 1000000.0d;
    }

    public static double millisUntilNow(long startNanos2) {
        return nanosToMillis(System.nanoTime() - startNanos2);
    }
}
