package com.taobao.weex.ui;

import android.text.TextUtils;
import android.view.View;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.dom.RenderContext;
import com.taobao.weex.ui.component.DCWXScroller;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXComponent;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.CopyOnWriteArrayList;

/* access modifiers changed from: package-private */
public class RenderContextImpl implements RenderContext {
    private Map<String, WXComponent> mIdComponent = new ConcurrentHashMap();
    private Map<String, WXComponent> mRegistry = new ConcurrentHashMap();
    private List<DCWXScroller> mScrollers = new CopyOnWriteArrayList();
    private WXSDKInstance mWXSDKInstance;

    public RenderContextImpl(WXSDKInstance instance) {
        this.mWXSDKInstance = instance;
    }

    public void destroy() {
        this.mWXSDKInstance = null;
        try {
            this.mRegistry.clear();
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public WXSDKInstance getWXSDKInstance() {
        return this.mWXSDKInstance;
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXSDKInstance getInstance() {
        return this.mWXSDKInstance;
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXComponent getComponent(String ref) {
        return this.mRegistry.get(ref);
    }

    public WXComponent getComponentById(String id) {
        return this.mIdComponent.get(id);
    }

    public void registerComponent(String ref, WXComponent comp) {
        if (comp instanceof DCWXScroller) {
            this.mScrollers.add((DCWXScroller) comp);
        }
        if (comp.getAttrs().containsKey("id")) {
            String id = (String) comp.getAttrs().get("id");
            if (!TextUtils.isEmpty(id)) {
                this.mIdComponent.put(id, comp);
            }
        }
        this.mRegistry.put(ref, comp);
    }

    @Override // com.taobao.weex.dom.RenderContext
    public WXComponent unregisterComponent(String ref) {
        return this.mRegistry.remove(ref);
    }

    public void setAllScrollerScrollable(boolean scrollable, String ref) {
        if (this.mScrollers.size() > 0) {
            Scrollable scrollView = getComponent(ref).getParentScroller();
            while (scrollView != null) {
                if (scrollView instanceof DCWXScroller) {
                    DCWXScroller scroller = (DCWXScroller) scrollView;
                    View view = scroller.getInnerView();
                    if (view instanceof DCWXScrollView) {
                        ((DCWXScrollView) view).setScrollable(scrollable);
                    }
                    scrollView = scroller.getParentScroller();
                } else {
                    scrollView = ((WXComponent) scrollView).getParentScroller();
                }
            }
        }
    }

    public int getComponentCount() {
        return this.mRegistry.size();
    }
}
