package com.taobao.weex.ui;

import android.util.Log;
import android.util.Pair;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.bridge.MethodInvoker;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.ui.action.AbsComponentData;
import io.dcloud.feature.uniapp.ui.component.AbsVContainer;
import io.dcloud.feature.uniapp.ui.component.UniComponent;
import io.dcloud.feature.uniapp.ui.component.UniComponentProp;
import io.dcloud.feature.uniapp.ui.component.UniVContainer;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

public class SimpleComponentHolder implements IFComponentHolder {
    public static final String TAG = "SimpleComponentHolder";
    private final Class<? extends WXComponent> mClz;
    private ComponentCreator mCreator;
    private Map<String, Invoker> mMethodInvokers;
    private Map<String, Invoker> mPropertyInvokers;

    public static class ClazzComponentCreator implements ComponentCreator {
        private Constructor<? extends WXComponent> mAbsConstructor;
        private final Class<? extends WXComponent> mCompClz;
        private Constructor<? extends WXComponent> mConstructor;

        public ClazzComponentCreator(Class<? extends WXComponent> c) {
            this.mCompClz = c;
        }

        private Constructor<? extends WXComponent> getComponentConstructor(Boolean isAbs) {
            Class componentData;
            Class container;
            Class instance;
            Class<? extends WXComponent> c = this.mCompClz;
            if (isAbs.booleanValue()) {
                instance = UniSDKInstance.class;
                container = AbsVContainer.class;
                componentData = AbsComponentData.class;
            } else {
                instance = WXSDKInstance.class;
                container = WXVContainer.class;
                componentData = BasicComponentData.class;
            }
            try {
                return c.getConstructor(instance, container, componentData);
            } catch (NoSuchMethodException e) {
                WXLogUtils.d("ClazzComponentCreator", "Use deprecated component constructor");
                try {
                    return c.getConstructor(instance, container, Boolean.TYPE, componentData);
                } catch (NoSuchMethodException e2) {
                    try {
                        return c.getConstructor(instance, container, String.class, Boolean.TYPE, componentData);
                    } catch (NoSuchMethodException e3) {
                        Log.e("shutao", "        " + c.getSuperclass().getSimpleName());
                        throw new WXRuntimeException("Can't find constructor of component.");
                    }
                }
            }
        }

        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            Constructor<? extends WXComponent> constructor;
            boolean isAbs = UniVContainer.class.isAssignableFrom(this.mCompClz) || UniComponent.class.isAssignableFrom(this.mCompClz);
            if (isAbs) {
                if (this.mAbsConstructor == null) {
                    this.mAbsConstructor = getComponentConstructor(Boolean.valueOf(isAbs));
                }
                constructor = this.mAbsConstructor;
            } else {
                if (this.mConstructor == null) {
                    this.mConstructor = getComponentConstructor(Boolean.valueOf(isAbs));
                }
                constructor = this.mConstructor;
            }
            int parameters = constructor.getParameterTypes().length;
            if (parameters == 3) {
                return (WXComponent) constructor.newInstance(instance, parent, basicComponentData);
            } else if (parameters == 4) {
                return (WXComponent) constructor.newInstance(instance, parent, false, basicComponentData);
            } else {
                return (WXComponent) constructor.newInstance(instance, parent, instance.getInstanceId(), Boolean.valueOf(parent.isLazy()));
            }
        }
    }

    public SimpleComponentHolder(Class<? extends WXComponent> clz) {
        this(clz, new ClazzComponentCreator(clz));
    }

    public SimpleComponentHolder(Class<? extends WXComponent> clz, ComponentCreator customCreator) {
        this.mClz = clz;
        this.mCreator = customCreator;
    }

    @Override // io.dcloud.feature.uniapp.ui.AbsIComponentHolder
    public void loadIfNonLazy() {
        Annotation[] annotations = this.mClz.getDeclaredAnnotations();
        for (Annotation annotation : annotations) {
            if (annotation instanceof Component) {
                if (!((Component) annotation).lazyload() && this.mMethodInvokers == null) {
                    generate();
                    return;
                } else {
                    return;
                }
            }
        }
    }

    private synchronized void generate() {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("SimpleComponentHolder", "Generate Component:" + this.mClz.getSimpleName());
        }
        Pair<Map<String, Invoker>, Map<String, Invoker>> methodPair = getMethods(this.mClz);
        this.mPropertyInvokers = (Map) methodPair.first;
        this.mMethodInvokers = (Map) methodPair.second;
    }

    public static Pair<Map<String, Invoker>, Map<String, Invoker>> getMethods(Class clz) {
        Map<String, Invoker> methods = new HashMap<>();
        Map<String, Invoker> mInvokers = new HashMap<>();
        try {
            Method[] methods2 = clz.getMethods();
            for (Method method : methods2) {
                try {
                    Annotation[] annotations = method.getDeclaredAnnotations();
                    int i = 0;
                    int annotationsCount = annotations.length;
                    while (true) {
                        if (i >= annotationsCount) {
                            break;
                        }
                        Annotation anno = annotations[i];
                        if (anno != null) {
                            if (anno instanceof WXComponentProp) {
                                methods.put(((WXComponentProp) anno).name(), new MethodInvoker(method, true));
                                break;
                            } else if (anno instanceof JSMethod) {
                                JSMethod methodAnno = (JSMethod) anno;
                                String name = methodAnno.alias();
                                if ("_".equals(name)) {
                                    name = method.getName();
                                }
                                mInvokers.put(name, new MethodInvoker(method, methodAnno.uiThread()));
                            } else if (anno instanceof UniComponentProp) {
                                methods.put(((UniComponentProp) anno).name(), new MethodInvoker(method, true));
                                break;
                            } else if (anno instanceof UniJSMethod) {
                                UniJSMethod methodAnno2 = (UniJSMethod) anno;
                                String name2 = methodAnno2.alias();
                                if ("_".equals(name2)) {
                                    name2 = method.getName();
                                }
                                mInvokers.put(name2, new MethodInvoker(method, methodAnno2.uiThread()));
                            }
                        }
                        i++;
                    }
                } catch (ArrayIndexOutOfBoundsException | IncompatibleClassChangeError e) {
                }
            }
        } catch (IndexOutOfBoundsException e2) {
            e2.printStackTrace();
        } catch (Exception e3) {
            WXLogUtils.e("SimpleComponentHolder", e3);
        }
        return new Pair<>(methods, mInvokers);
    }

    @Override // com.taobao.weex.ui.ComponentCreator
    public synchronized WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
        WXComponent component;
        component = this.mCreator.createInstance(instance, parent, basicComponentData);
        component.bindHolder(this);
        return component;
    }

    @Override // io.dcloud.feature.uniapp.ui.AbsIComponentHolder
    public synchronized Invoker getPropertyInvoker(String name) {
        if (this.mPropertyInvokers == null) {
            generate();
        }
        return this.mPropertyInvokers.get(name);
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public Invoker getMethodInvoker(String name) {
        if (this.mMethodInvokers == null) {
            generate();
        }
        return this.mMethodInvokers.get(name);
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public synchronized String[] getMethods() {
        Set<String> keys;
        if (this.mMethodInvokers == null) {
            generate();
        }
        keys = this.mMethodInvokers.keySet();
        try {
        } catch (Throwable th) {
            if (this.mClz != null) {
                String name = this.mClz.getName();
                WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_INVOKE_REGISTER_COMPONENT, WXBridgeManager.METHOD_REGISTER_COMPONENTS, name + ": gen methods failed", null);
            }
            return new String[1];
        }
        return (String[]) keys.toArray(new String[keys.size()]);
    }
}
