package com.taobao.weex.ui;

import android.text.TextUtils;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXException;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.cache.RegisterCache;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class WXComponentRegistry {
    private static ArrayList<Map<String, Object>> sComponentInfos = new ArrayList<>();
    private static Map<String, IFComponentHolder> sTypeComponentMap = new ConcurrentHashMap();

    public static synchronized boolean registerComponent(Map<String, RegisterCache.ComponentCache> componentCacheMap) {
        synchronized (WXComponentRegistry.class) {
            if (componentCacheMap.isEmpty()) {
                return true;
            }
            final Iterator<Map.Entry<String, RegisterCache.ComponentCache>> iterator = componentCacheMap.entrySet().iterator();
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.ui.WXComponentRegistry.AnonymousClass1 */

                public void run() {
                    ArrayList<Map<String, Object>> coms = new ArrayList<>();
                    while (iterator.hasNext()) {
                        try {
                            RegisterCache.ComponentCache value = ((Map.Entry) iterator.next()).getValue();
                            Map<String, Object> registerInfo = value.componentInfo;
                            if (registerInfo == null) {
                                registerInfo = new HashMap();
                            }
                            registerInfo.put("type", value.type);
                            registerInfo.put("methods", value.holder.getMethods());
                            WXComponentRegistry.registerNativeComponent(value.type, value.holder);
                            WXComponentRegistry.sComponentInfos.add(registerInfo);
                            coms.add(registerInfo);
                        } catch (WXException e) {
                            e.printStackTrace();
                        }
                    }
                    WXSDKManager.getInstance().registerComponents(coms);
                }
            });
            return true;
        }
    }

    public static synchronized boolean registerComponent(final String type, final IFComponentHolder holder, final Map<String, Object> componentInfo) throws WXException {
        synchronized (WXComponentRegistry.class) {
            if (holder != null) {
                if (!TextUtils.isEmpty(type)) {
                    if (RegisterCache.getInstance().cacheComponent(type, holder, componentInfo)) {
                        return true;
                    }
                    WXBridgeManager.getInstance().post(new Runnable() {
                        /* class com.taobao.weex.ui.WXComponentRegistry.AnonymousClass2 */

                        public void run() {
                            try {
                                Map<String, Object> registerInfo = componentInfo;
                                if (registerInfo == null) {
                                    registerInfo = new HashMap<>();
                                }
                                registerInfo.put("type", type);
                                registerInfo.put("methods", holder.getMethods());
                                WXComponentRegistry.registerNativeComponent(type, holder);
                                WXComponentRegistry.registerJSComponent(registerInfo);
                                WXComponentRegistry.sComponentInfos.add(registerInfo);
                            } catch (WXException e) {
                                WXLogUtils.e("register component error:", e);
                            }
                        }
                    });
                    return true;
                }
            }
            return false;
        }
    }

    /* access modifiers changed from: private */
    public static boolean registerNativeComponent(String type, IFComponentHolder holder) throws WXException {
        try {
            holder.loadIfNonLazy();
            sTypeComponentMap.put(type, holder);
            return true;
        } catch (ArrayStoreException e) {
            e.printStackTrace();
            return true;
        }
    }

    /* access modifiers changed from: private */
    public static boolean registerJSComponent(Map<String, Object> componentInfo) throws WXException {
        ArrayList<Map<String, Object>> coms = new ArrayList<>();
        coms.add(componentInfo);
        WXSDKManager.getInstance().registerComponents(coms);
        return true;
    }

    public static IFComponentHolder getComponent(String type) {
        return sTypeComponentMap.get(type);
    }

    public static void reload() {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.taobao.weex.ui.WXComponentRegistry.AnonymousClass3 */

            public void run() {
                try {
                    Iterator it = WXComponentRegistry.sComponentInfos.iterator();
                    while (it.hasNext()) {
                        WXComponentRegistry.registerJSComponent((Map) it.next());
                    }
                } catch (WXException e) {
                    WXLogUtils.e("", e);
                }
            }
        });
    }
}
