package com.taobao.weex.ui;

import android.opengl.GLES10;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.RenderContext;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.action.BasicGraphicAction;
import com.taobao.weex.ui.action.GraphicActionBatchAction;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import javax.microedition.khronos.egl.EGL10;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.egl.EGLContext;
import javax.microedition.khronos.egl.EGLDisplay;
import javax.microedition.khronos.egl.EGLSurface;

public class WXRenderManager {
    private static int mOpenGLRenderLimitValue = 0;
    private static int nativeBatchTimes = 0;
    private static final String sKeyAction = "Action";
    private final int MAX_DROP_FRAME_NATIVE_BATCH = 2000;
    private ArrayList<Map<String, Object>> mBatchActions = new ArrayList<>();
    private String mCurrentBatchInstanceId = null;
    private volatile ConcurrentHashMap<String, RenderContextImpl> mRenderContext = new ConcurrentHashMap<>();
    private WXRenderHandler mWXRenderHandler = new WXRenderHandler();

    public RenderContext getRenderContext(String instanceId) {
        return this.mRenderContext.get(instanceId);
    }

    public WXComponent getWXComponent(String instanceId, String ref) {
        RenderContext stmt;
        if (instanceId == null || TextUtils.isEmpty(ref) || (stmt = getRenderContext(instanceId)) == null) {
            return null;
        }
        return stmt.getComponent(ref);
    }

    public WXComponent getWXComponentById(String instanceId, String ref) {
        RenderContextImpl stmt;
        if (instanceId == null || TextUtils.isEmpty(ref) || (stmt = this.mRenderContext.get(instanceId)) == null) {
            return null;
        }
        return stmt.getComponentById(ref);
    }

    public void setScrollable(String instanceId, boolean scrollable, String ref) {
        if (instanceId != null) {
            this.mRenderContext.get(instanceId).setAllScrollerScrollable(scrollable, ref);
        }
    }

    public WXSDKInstance getWXSDKInstance(String instanceId) {
        RenderContextImpl statement = this.mRenderContext.get(instanceId);
        if (statement == null) {
            return null;
        }
        return statement.getWXSDKInstance();
    }

    public static int getOpenGLRenderLimitValue() {
        if (mOpenGLRenderLimitValue == 0) {
            int maxsize = 0;
            try {
                EGL10 egl = (EGL10) EGLContext.getEGL();
                EGLDisplay dpy = egl.eglGetDisplay(EGL10.EGL_DEFAULT_DISPLAY);
                egl.eglInitialize(dpy, new int[2]);
                EGLConfig[] configs = new EGLConfig[1];
                int[] numConfig = new int[1];
                egl.eglChooseConfig(dpy, new int[]{12351, 12430, 12329, 0, 12339, 1, 12344}, configs, 1, numConfig);
                if (numConfig[0] == 0) {
                    maxsize = -1;
                    egl.eglTerminate(dpy);
                } else {
                    EGLConfig config = configs[0];
                    EGLSurface surf = egl.eglCreatePbufferSurface(dpy, config, new int[]{12375, 64, 12374, 64, 12344});
                    EGLContext ctx = egl.eglCreateContext(dpy, config, EGL10.EGL_NO_CONTEXT, new int[]{12440, 1, 12344});
                    egl.eglMakeCurrent(dpy, surf, surf, ctx);
                    int[] maxSize = new int[1];
                    GLES10.glGetIntegerv(3379, maxSize, 0);
                    egl.eglMakeCurrent(dpy, EGL10.EGL_NO_SURFACE, EGL10.EGL_NO_SURFACE, EGL10.EGL_NO_CONTEXT);
                    egl.eglDestroySurface(dpy, surf);
                    egl.eglDestroyContext(dpy, ctx);
                    egl.eglTerminate(dpy);
                    maxsize = maxSize[0];
                }
            } catch (Exception e) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
            }
            mOpenGLRenderLimitValue = maxsize;
        }
        return mOpenGLRenderLimitValue;
    }

    public void postOnUiThread(Runnable runnable, long delayMillis) {
        this.mWXRenderHandler.postDelayed(WXThread.secure(runnable), delayMillis);
    }

    public void postOnUiThread(Runnable runnable, String instanceId) {
        this.mWXRenderHandler.post(instanceId, WXThread.secure(runnable));
    }

    public void postOnUiThread(Runnable runnable) {
        this.mWXRenderHandler.post(WXThread.secure(runnable));
    }

    public void removeTask(Runnable runnable) {
        this.mWXRenderHandler.removeCallbacks(runnable);
    }

    public void removeRenderStatement(String instanceId) {
        if (WXUtils.isUiThread()) {
            RenderContextImpl statement = this.mRenderContext.remove(instanceId);
            if (statement != null) {
                statement.destroy();
            }
            if (instanceId == null) {
                this.mWXRenderHandler.removeCallbacksAndMessages(null);
            } else {
                this.mWXRenderHandler.removeMessages(instanceId.hashCode());
            }
        } else {
            throw new WXRuntimeException("[WXRenderManager] removeRenderStatement can only be called in main thread");
        }
    }

    private void postAllStashedGraphicAction(String instanceId, BasicGraphicAction action) {
        RenderContextImpl renderContext = this.mRenderContext.get(instanceId);
        ArrayList<Map<String, Object>> tmpList = null;
        if (renderContext != null) {
            tmpList = new ArrayList<>(this.mBatchActions);
        }
        this.mBatchActions.clear();
        this.mCurrentBatchInstanceId = null;
        nativeBatchTimes = 0;
        if (renderContext != null) {
            ArrayList<BasicGraphicAction> actions = new ArrayList<>(tmpList.size());
            for (int i = 0; i < tmpList.size(); i++) {
                Object mustBeAction = tmpList.get(i).get(sKeyAction);
                if (mustBeAction instanceof BasicGraphicAction) {
                    BasicGraphicAction tmpAction = (BasicGraphicAction) mustBeAction;
                    if (!(tmpAction.mActionType == 1 || tmpAction.mActionType == 2)) {
                        actions.add(tmpAction);
                    }
                }
            }
            postGraphicAction(instanceId, new GraphicActionBatchAction(action.getWXSDKIntance(), action.getRef(), actions));
        }
    }

    public void postGraphicAction(String instanceId, BasicGraphicAction action) {
        if (this.mRenderContext.get(instanceId) != null) {
            String str = this.mCurrentBatchInstanceId;
            if (str != null && instanceId != null && !str.equals(instanceId) && this.mBatchActions.size() > 0) {
                ArrayList<Map<String, Object>> arrayList = this.mBatchActions;
                Object mustBeAction = arrayList.get(arrayList.size() - 1).get(sKeyAction);
                if (mustBeAction instanceof BasicGraphicAction) {
                    postAllStashedGraphicAction(this.mCurrentBatchInstanceId, (BasicGraphicAction) mustBeAction);
                }
            }
            if (action.mActionType == 2) {
                postAllStashedGraphicAction(instanceId, action);
                return;
            }
            if (action.mActionType == 1 || this.mBatchActions.size() > 0) {
                int i = nativeBatchTimes + 1;
                nativeBatchTimes = i;
                if (i > 2000) {
                    postAllStashedGraphicAction(instanceId, action);
                } else {
                    HashMap<String, Object> item = new HashMap<>(1);
                    action.mIsRunByBatch = true;
                    item.put(sKeyAction, action);
                    this.mBatchActions.add(item);
                    this.mCurrentBatchInstanceId = instanceId;
                    return;
                }
            }
            this.mWXRenderHandler.post(instanceId, action);
        }
    }

    public void registerInstance(WXSDKInstance instance) {
        if (instance.getInstanceId() == null) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_RENDER_ERR_INSTANCE_ID_NULL;
            WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, "registerInstance", WXErrorCode.WX_RENDER_ERR_INSTANCE_ID_NULL.getErrorMsg() + "instanceId is null", null);
            return;
        }
        this.mRenderContext.put(instance.getInstanceId(), new RenderContextImpl(instance));
    }

    public List<WXSDKInstance> getAllInstances() {
        ArrayList<WXSDKInstance> instances = null;
        if (this.mRenderContext != null && !this.mRenderContext.isEmpty()) {
            instances = new ArrayList<>();
            for (Map.Entry<String, RenderContextImpl> entry : this.mRenderContext.entrySet()) {
                RenderContextImpl renderStatement = entry.getValue();
                if (renderStatement != null) {
                    instances.add(renderStatement.getWXSDKInstance());
                }
            }
        }
        return instances;
    }

    public void registerComponent(String instanceId, String ref, WXComponent comp) {
        RenderContextImpl statement = this.mRenderContext.get(instanceId);
        if (statement != null) {
            statement.registerComponent(ref, comp);
            if (statement.getInstance() != null) {
                statement.getInstance().getApmForInstance().updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_COMPONENT_NUM, (double) statement.getComponentCount());
            }
        }
    }

    public WXComponent unregisterComponent(String instanceId, String ref) {
        RenderContextImpl statement = this.mRenderContext.get(instanceId);
        if (statement == null) {
            return null;
        }
        if (statement.getInstance() != null) {
            statement.getInstance().getApmForInstance().updateMaxStats(WXInstanceApm.KEY_PAGE_STATS_MAX_COMPONENT_NUM, (double) statement.getComponentCount());
        }
        return statement.unregisterComponent(ref);
    }
}
