package com.taobao.weex.ui.action;

import android.text.TextUtils;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.font.FontAdapter;
import com.taobao.weex.utils.FontDO;
import com.taobao.weex.utils.TypefaceUtil;

public class ActionAddRule implements IExecutable {
    private final JSONObject mData;
    private final String mPageId;
    private final String mType;

    public ActionAddRule(String pageId, String type, JSONObject data) {
        this.mPageId = pageId;
        this.mType = type;
        this.mData = data;
    }

    @Override // com.taobao.weex.ui.action.IExecutable
    public void executeAction() {
        FontDO fontDO;
        WXSDKInstance instance = WXSDKManager.getInstance().getWXRenderManager().getWXSDKInstance(this.mPageId);
        if (instance != null && !instance.isDestroy() && Constants.Name.FONT_FACE.equals(this.mType) && (fontDO = parseFontDO(this.mData, instance)) != null && !TextUtils.isEmpty(fontDO.getFontFamilyName())) {
            notifyAddFontRule(instance, fontDO);
            FontDO cacheFontDO = TypefaceUtil.getFontDO(fontDO.getFontFamilyName());
            if (cacheFontDO == null || !TextUtils.equals(cacheFontDO.getUrl(), fontDO.getUrl())) {
                TypefaceUtil.putFontDO(fontDO);
                TypefaceUtil.loadTypeface(fontDO, true);
                return;
            }
            TypefaceUtil.loadTypeface(cacheFontDO, true);
        }
    }

    private FontDO parseFontDO(JSONObject jsonObject, WXSDKInstance instance) {
        if (jsonObject == null) {
            return null;
        }
        return new FontDO(jsonObject.getString(Constants.Name.FONT_FAMILY), jsonObject.getString("src"), instance);
    }

    private void notifyAddFontRule(WXSDKInstance instance, FontDO fontDO) {
        FontAdapter fontAdapter = WXSDKManager.getInstance().getFontAdapter();
        if (fontAdapter != null) {
            fontAdapter.onAddFontRule(instance.getInstanceId(), fontDO.getFontFamilyName(), fontDO.getUrl());
        }
    }
}
