package com.taobao.weex.ui.action;

import android.graphics.Rect;
import android.text.TextUtils;
import android.view.View;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.SimpleJSCallback;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.HashMap;
import java.util.Map;

public class ActionGetComponentRect extends BasicGraphicAction {
    private final String mCallback;

    public ActionGetComponentRect(WXSDKInstance instance, String ref, String callback) {
        super(instance, ref);
        this.mCallback = callback;
    }

    @Override // com.taobao.weex.ui.action.IExecutable
    public void executeAction() {
        WXSDKInstance instance = getWXSDKIntance();
        if (instance != null && !instance.isDestroy()) {
            JSCallback jsCallback = new SimpleJSCallback(instance.getInstanceId(), this.mCallback);
            if (TextUtils.isEmpty(getRef())) {
                Map<String, Object> options = new HashMap<>();
                options.put("result", false);
                options.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, "Illegal parameter");
                jsCallback.invoke(options);
            } else if ("viewport".equalsIgnoreCase(getRef())) {
                callbackViewport(instance, jsCallback);
            } else {
                WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), getRef());
                if (component != null) {
                    Map<String, Object> options2 = new HashMap<>();
                    if (component != null) {
                        float viewPort = instance.getInstanceViewPortWidthWithFloat();
                        Map<String, Float> size = new HashMap<>();
                        Rect sizes = component.getComponentSize();
                        size.put("width", Float.valueOf(getWebPxValue(sizes.width(), viewPort)));
                        size.put("height", Float.valueOf(getWebPxValue(sizes.height(), viewPort)));
                        size.put("bottom", Float.valueOf(getWebPxValue(sizes.bottom, viewPort)));
                        size.put("left", Float.valueOf(getWebPxValue(sizes.left, viewPort)));
                        size.put("right", Float.valueOf(getWebPxValue(sizes.right, viewPort)));
                        size.put("top", Float.valueOf(getWebPxValue(sizes.top, viewPort)));
                        options2.put(AbsoluteConst.JSON_KEY_SIZE, size);
                        options2.put("result", true);
                    } else {
                        options2.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, "Component does not exist");
                    }
                    jsCallback.invoke(options2);
                }
            }
        }
    }

    private void callbackViewport(WXSDKInstance instance, JSCallback jsCallback) {
        View container = instance.getContainerView();
        if (container != null) {
            Map<String, Object> options = new HashMap<>();
            Map<String, Float> sizes = new HashMap<>();
            instance.getContainerView().getLocationOnScreen(new int[2]);
            float viewport = instance.getInstanceViewPortWidthWithFloat();
            sizes.put("left", Float.valueOf(0.0f));
            sizes.put("top", Float.valueOf(0.0f));
            sizes.put("right", Float.valueOf(getWebPxValue(container.getWidth(), viewport)));
            sizes.put("bottom", Float.valueOf(getWebPxValue(container.getHeight(), viewport)));
            sizes.put("width", Float.valueOf(getWebPxValue(container.getWidth(), viewport)));
            sizes.put("height", Float.valueOf(getWebPxValue(container.getHeight(), viewport)));
            options.put(AbsoluteConst.JSON_KEY_SIZE, sizes);
            options.put("result", true);
            jsCallback.invoke(options);
            return;
        }
        Map<String, Object> options2 = new HashMap<>();
        options2.put("result", false);
        options2.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, "Component does not exist");
        jsCallback.invoke(options2);
    }

    private float getWebPxValue(int value, float viewport) {
        return WXViewUtils.getWebPxByWidth((float) value, viewport);
    }
}
