package com.taobao.weex.ui.action;

import android.text.TextUtils;
import android.util.Log;
import androidx.collection.ArrayMap;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.dom.transition.WXTransition;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.performance.WXStateRecord;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.Arrays;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

public class GraphicActionAddElement extends GraphicActionAbstractAddElement {
    private WXComponent child;
    private boolean isLayoutRTL;
    private GraphicPosition layoutPosition;
    private GraphicSize layoutSize;
    private WXVContainer parent;

    public GraphicActionAddElement(WXSDKInstance instance, String ref, String componentType, String parentRef, int index, Map<String, String> style, Map<String, String> attributes, Set<String> events, float[] margins, float[] paddings, float[] borders) {
        super(instance, ref);
        ClassCastException e;
        WXComponent parent2;
        this.mComponentType = componentType;
        this.mParentRef = parentRef;
        this.mIndex = index;
        this.mStyle = style;
        this.mAttributes = attributes;
        this.mEvents = events;
        this.mPaddings = paddings;
        this.mMargins = margins;
        this.mBorders = borders;
        if (instance.getContext() != null) {
            if (WXAnalyzerDataTransfer.isInteractionLogOpen()) {
                Log.d(WXAnalyzerDataTransfer.INTERACTION_TAG, "[client][addelementStart]" + instance.getInstanceId() + "," + componentType + "," + ref);
            }
            try {
                this.parent = (WXVContainer) WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), this.mParentRef);
                long start = WXUtils.getFixUnixTime();
                try {
                    WXComponent createComponent = createComponent(instance, this.parent, new BasicComponentData(ref, this.mComponentType, this.mParentRef));
                    this.child = createComponent;
                    createComponent.setTransition(WXTransition.fromMap(createComponent.getStyles(), this.child));
                    instance.getApmForInstance().componentCreateTime += WXUtils.getFixUnixTime() - start;
                    if (this.parent != null && this.parent.isIgnoreInteraction) {
                        this.child.isIgnoreInteraction = true;
                    }
                    if (!this.child.isIgnoreInteraction) {
                        Object flag = this.child.getAttrs() != null ? this.child.getAttrs().get("ignoreInteraction") : null;
                        if (!AbsoluteConst.FALSE.equals(flag)) {
                            if (!"0".equals(flag)) {
                                if ("1".equals(flag) || AbsoluteConst.TRUE.equals(flag) || this.child.isFixed()) {
                                    this.child.isIgnoreInteraction = true;
                                }
                            }
                        }
                        this.child.isIgnoreInteraction = false;
                    }
                    WXStateRecord.getInstance().recordAction(instance.getInstanceId(), "addElement");
                } catch (ClassCastException e2) {
                    e = e2;
                    Map<String, String> ext = new ArrayMap<>();
                    parent2 = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), this.mParentRef);
                    if (this.mStyle != null && !this.mStyle.isEmpty()) {
                        ext.put("child.style", this.mStyle.toString());
                    }
                    if (!(parent2 == null || parent2.getStyles() == null || parent2.getStyles().isEmpty())) {
                        ext.put("parent.style", parent2.getStyles().toString());
                    }
                    if (this.mAttributes != null && !this.mAttributes.isEmpty()) {
                        ext.put("child.attr", this.mAttributes.toString());
                    }
                    if (!(parent2 == null || parent2.getAttrs() == null || parent2.getAttrs().isEmpty())) {
                        ext.put("parent.attr", parent2.getAttrs().toString());
                    }
                    if (this.mEvents != null && !this.mEvents.isEmpty()) {
                        ext.put("child.event", this.mEvents.toString());
                    }
                    if (!(parent2 == null || parent2.getEvents() == null || parent2.getEvents().isEmpty())) {
                        ext.put("parent.event", parent2.getEvents().toString());
                    }
                    if (this.mMargins != null && this.mMargins.length > 0) {
                        ext.put("child.margin", Arrays.toString(this.mMargins));
                    }
                    if (!(parent2 == null || parent2.getMargin() == null)) {
                        ext.put("parent.margin", parent2.getMargin().toString());
                    }
                    if (this.mPaddings != null && this.mPaddings.length > 0) {
                        ext.put("child.padding", Arrays.toString(this.mPaddings));
                    }
                    if (!(parent2 == null || parent2.getPadding() == null)) {
                        ext.put("parent.padding", parent2.getPadding().toString());
                    }
                    if (this.mBorders != null && this.mBorders.length > 0) {
                        ext.put("child.border", Arrays.toString(this.mBorders));
                    }
                    if (!(parent2 == null || parent2.getBorder() == null)) {
                        ext.put("parent.border", parent2.getBorder().toString());
                    }
                    WXExceptionUtils.commitCriticalExceptionRT(instance.getInstanceId(), WXErrorCode.WX_RENDER_ERR_CONTAINER_TYPE, "GraphicActionAddElement", String.format(Locale.ENGLISH, "You are trying to add a %s to a %2$s, which is illegal as %2$s is not a container", componentType, WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), this.mParentRef).getComponentType()), ext);
                }
            } catch (ClassCastException e3) {
                e = e3;
                Map<String, String> ext2 = new ArrayMap<>();
                parent2 = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), this.mParentRef);
                ext2.put("child.style", this.mStyle.toString());
                ext2.put("parent.style", parent2.getStyles().toString());
                ext2.put("child.attr", this.mAttributes.toString());
                ext2.put("parent.attr", parent2.getAttrs().toString());
                ext2.put("child.event", this.mEvents.toString());
                ext2.put("parent.event", parent2.getEvents().toString());
                ext2.put("child.margin", Arrays.toString(this.mMargins));
                ext2.put("parent.margin", parent2.getMargin().toString());
                ext2.put("child.padding", Arrays.toString(this.mPaddings));
                ext2.put("parent.padding", parent2.getPadding().toString());
                ext2.put("child.border", Arrays.toString(this.mBorders));
                ext2.put("parent.border", parent2.getBorder().toString());
                WXExceptionUtils.commitCriticalExceptionRT(instance.getInstanceId(), WXErrorCode.WX_RENDER_ERR_CONTAINER_TYPE, "GraphicActionAddElement", String.format(Locale.ENGLISH, "You are trying to add a %s to a %2$s, which is illegal as %2$s is not a container", componentType, WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), this.mParentRef).getComponentType()), ext2);
            }
        }
    }

    public void setRTL(boolean isRTL) {
        this.isLayoutRTL = isRTL;
    }

    public void setSize(GraphicSize graphicSize) {
        this.layoutSize = graphicSize;
    }

    public void setPosition(GraphicPosition position) {
        this.layoutPosition = position;
    }

    public void setIndex(int index) {
        this.mIndex = index;
    }

    @Override // com.taobao.weex.ui.action.IExecutable, com.taobao.weex.ui.action.GraphicActionAbstractAddElement
    public void executeAction() {
        super.executeAction();
        try {
            if (!TextUtils.equals(this.mComponentType, "video") && !TextUtils.equals(this.mComponentType, "videoplus")) {
                this.child.mIsAddElementToTree = true;
            }
            long start = WXUtils.getFixUnixTime();
            this.parent.addChild(this.child, this.mIndex);
            this.parent.createChildViewAt(this.mIndex);
            this.child.setIsLayoutRTL(this.isLayoutRTL);
            if (!(this.layoutPosition == null || this.layoutSize == null)) {
                this.child.setDemission(this.layoutSize, this.layoutPosition);
            }
            this.child.applyLayoutAndEvent(this.child);
            this.child.bindData(this.child);
            long diff = WXUtils.getFixUnixTime() - start;
            if (getWXSDKIntance() != null) {
                getWXSDKIntance().getApmForInstance().viewCreateTime += diff;
            }
        } catch (Exception e) {
            WXLogUtils.e("add component failed.", e);
        }
    }
}
