package com.taobao.weex.ui.action;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ArgbEvaluator;
import android.animation.ObjectAnimator;
import android.animation.PropertyValuesHolder;
import android.graphics.drawable.ColorDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.Pair;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.AccelerateDecelerateInterpolator;
import android.view.animation.AccelerateInterpolator;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import android.view.animation.LinearInterpolator;
import androidx.core.view.animation.PathInterpolatorCompat;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.animation.BackgroundColorProperty;
import com.taobao.weex.ui.animation.HeightProperty;
import com.taobao.weex.ui.animation.WXAnimationBean;
import com.taobao.weex.ui.animation.WXAnimationModule;
import com.taobao.weex.ui.animation.WidthProperty;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.SingleFunctionParser;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.HashMap;
import java.util.List;

public class GraphicActionAnimation extends BasicGraphicAction {
    private static final String TAG = "GraphicActionAnimation";
    private final String callback;
    private WXAnimationBean mAnimationBean;
    private final boolean styleNeedInit;

    public GraphicActionAnimation(WXSDKInstance instance, String ref, WXAnimationBean animationBean) {
        super(instance, ref);
        this.styleNeedInit = false;
        this.callback = null;
        this.mAnimationBean = animationBean;
    }

    public GraphicActionAnimation(WXSDKInstance instance, String ref, String animation, String callBack) {
        super(instance, ref);
        this.styleNeedInit = true;
        this.callback = callBack;
        if (!TextUtils.isEmpty(animation)) {
            this.mAnimationBean = (WXAnimationBean) JSONObject.parseObject(animation, WXAnimationBean.class);
        }
    }

    public GraphicActionAnimation(WXSDKInstance instance, String ref, WXAnimationBean animationBean, String callBack) {
        super(instance, ref);
        this.styleNeedInit = false;
        this.mAnimationBean = animationBean;
        this.callback = callBack;
    }

    @Override // com.taobao.weex.ui.action.IExecutable
    public void executeAction() {
        WXSDKInstance instance;
        if (this.mAnimationBean != null) {
            WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(getPageId(), getRef());
            if ((component != null || (TemplateDom.isVirtualDomRef(getRef()) && (component = TemplateDom.findVirtualComponentByVRef(getPageId(), getRef())) != null)) && (instance = WXSDKManager.getInstance().getWXRenderManager().getWXSDKInstance(getPageId())) != null && this.mAnimationBean.styles != null) {
                if (this.styleNeedInit) {
                    String transformOrigin = (String) component.getStyles().get(Constants.Name.TRANSFORM_ORIGIN);
                    if (TextUtils.isEmpty(this.mAnimationBean.styles.transformOrigin)) {
                        this.mAnimationBean.styles.transformOrigin = transformOrigin;
                    }
                    this.mAnimationBean.styles.init(this.mAnimationBean.styles.transformOrigin, this.mAnimationBean.styles.transform, (int) component.getLayoutWidth(), (int) component.getLayoutHeight(), instance.getInstanceViewPortWidthWithFloat(), instance);
                }
                startAnimation(instance, component);
            }
        }
    }

    private void startAnimation(WXSDKInstance instance, WXComponent component) {
        if (component != null) {
            WXAnimationBean wXAnimationBean = this.mAnimationBean;
            if (wXAnimationBean != null) {
                component.setNeedLayoutOnAnimation(wXAnimationBean.needLayout);
            }
            if (component.getHostView() == null) {
                component.postAnimation(new WXAnimationModule.AnimationHolder(this.mAnimationBean, this.callback));
                return;
            }
            try {
                Animator animator = createAnimator(component.getHostView(), instance.getInstanceViewPortWidthWithFloat());
                if (animator != null) {
                    Animator.AnimatorListener animatorCallback = createAnimatorListener(instance, this.callback);
                    if (Build.VERSION.SDK_INT < 18 && component.isLayerTypeEnabled()) {
                        component.getHostView().setLayerType(2, null);
                    }
                    Interpolator interpolator = createTimeInterpolator();
                    if (animatorCallback != null) {
                        animator.addListener(animatorCallback);
                    }
                    if (interpolator != null) {
                        animator.setInterpolator(interpolator);
                    }
                    component.getHostView().setCameraDistance(this.mAnimationBean.styles.getCameraDistance());
                    animator.setDuration(this.mAnimationBean.duration);
                    animator.start();
                }
            } catch (RuntimeException e) {
                WXLogUtils.e(TAG, WXLogUtils.getStackTrace(e));
            }
        }
    }

    private ObjectAnimator createAnimator(View target, float viewPortWidth) {
        WXAnimationBean.Style style;
        if (target == null || (style = this.mAnimationBean.styles) == null) {
            return null;
        }
        List<PropertyValuesHolder> holders = style.getHolders();
        if (!TextUtils.isEmpty(style.backgroundColor)) {
            BorderDrawable borderDrawable = WXViewUtils.getBorderDrawable(target);
            if (borderDrawable != null) {
                holders.add(PropertyValuesHolder.ofObject(new BackgroundColorProperty(), new ArgbEvaluator(), Integer.valueOf(borderDrawable.getColor()), Integer.valueOf(WXResourceUtils.getColor(style.backgroundColor))));
            } else if (target.getBackground() instanceof ColorDrawable) {
                holders.add(PropertyValuesHolder.ofObject(new BackgroundColorProperty(), new ArgbEvaluator(), Integer.valueOf(((ColorDrawable) target.getBackground()).getColor()), Integer.valueOf(WXResourceUtils.getColor(style.backgroundColor))));
            }
        }
        if (target.getLayoutParams() != null && (!TextUtils.isEmpty(style.width) || !TextUtils.isEmpty(style.height))) {
            ViewGroup.LayoutParams layoutParams = target.getLayoutParams();
            if (!TextUtils.isEmpty(style.width)) {
                holders.add(PropertyValuesHolder.ofInt(new WidthProperty(), layoutParams.width, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(style.width), viewPortWidth)));
            }
            if (!TextUtils.isEmpty(style.height)) {
                holders.add(PropertyValuesHolder.ofInt(new HeightProperty(), layoutParams.height, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(style.height), viewPortWidth)));
            }
        }
        if (style.getPivot() != null) {
            Pair<Float, Float> pair = style.getPivot();
            target.setPivotX(((Float) pair.first).floatValue());
            target.setPivotY(((Float) pair.second).floatValue());
        }
        ObjectAnimator animator = ObjectAnimator.ofPropertyValuesHolder(target, (PropertyValuesHolder[]) holders.toArray(new PropertyValuesHolder[holders.size()]));
        animator.setStartDelay(this.mAnimationBean.delay);
        return animator;
    }

    private Animator.AnimatorListener createAnimatorListener(final WXSDKInstance instance, final String callBack) {
        if (!TextUtils.isEmpty(callBack)) {
            return new AnimatorListenerAdapter() {
                /* class com.taobao.weex.ui.action.GraphicActionAnimation.AnonymousClass1 */

                public void onAnimationEnd(Animator animation) {
                    WXSDKInstance wXSDKInstance = instance;
                    if (wXSDKInstance == null || wXSDKInstance.isDestroy()) {
                        WXLogUtils.e("RenderContextImpl-onAnimationEnd WXSDKInstance == null NPE or instance is destroyed");
                    } else {
                        WXSDKManager.getInstance().callback(instance.getInstanceId(), callBack, new HashMap());
                    }
                }
            };
        }
        return null;
    }

    private Interpolator createTimeInterpolator() {
        String interpolator = this.mAnimationBean.timingFunction;
        if (TextUtils.isEmpty(interpolator)) {
            return null;
        }
        char c = 65535;
        switch (interpolator.hashCode()) {
            case -1965120668:
                if (interpolator.equals("ease-in")) {
                    c = 0;
                    break;
                }
                break;
            case -1102672091:
                if (interpolator.equals("linear")) {
                    c = 3;
                    break;
                }
                break;
            case -789192465:
                if (interpolator.equals("ease-out")) {
                    c = 1;
                    break;
                }
                break;
            case -361990811:
                if (interpolator.equals("ease-in-out")) {
                    c = 2;
                    break;
                }
                break;
        }
        if (c == 0) {
            return new AccelerateInterpolator();
        }
        if (c == 1) {
            return new DecelerateInterpolator();
        }
        if (c == 2) {
            return new AccelerateDecelerateInterpolator();
        }
        if (c == 3) {
            return new LinearInterpolator();
        }
        try {
            List<Float> params = new SingleFunctionParser<>(this.mAnimationBean.timingFunction, new SingleFunctionParser.FlatMapper<Float>() {
                /* class com.taobao.weex.ui.action.GraphicActionAnimation.AnonymousClass2 */

                @Override // com.taobao.weex.utils.SingleFunctionParser.FlatMapper
                public Float map(String raw) {
                    return Float.valueOf(Float.parseFloat(raw));
                }
            }).parse("cubic-bezier");
            if (params == null || params.size() != 4) {
                return null;
            }
            return PathInterpolatorCompat.create(params.get(0).floatValue(), params.get(1).floatValue(), params.get(2).floatValue(), params.get(3).floatValue());
        } catch (RuntimeException e) {
            return null;
        }
    }
}
