package com.taobao.weex.ui.animation;

import android.animation.PropertyValuesHolder;
import android.text.TextUtils;
import android.util.Pair;
import android.util.Property;
import android.view.View;
import androidx.collection.ArrayMap;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.utils.FunctionParser;
import com.taobao.weex.utils.WXDataStructureUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

public class TransformParser {
    public static final String BACKGROUND_COLOR = "backgroundColor";
    public static final String BOTTOM = "bottom";
    public static final String CENTER = "center";
    private static final String DEG = "deg";
    private static final String FULL = "100%";
    private static final String HALF = "50%";
    public static final String HEIGHT = "height";
    public static final String LEFT = "left";
    private static final String PX = "px";
    public static final String RIGHT = "right";
    public static final String TOP = "top";
    public static final String WIDTH = "width";
    public static final String WX_ROTATE = "rotate";
    public static final String WX_ROTATE_X = "rotateX";
    public static final String WX_ROTATE_Y = "rotateY";
    public static final String WX_ROTATE_Z = "rotateZ";
    public static final String WX_SCALE = "scale";
    public static final String WX_SCALE_X = "scaleX";
    public static final String WX_SCALE_Y = "scaleY";
    public static final String WX_TRANSLATE = "translate";
    public static final String WX_TRANSLATE_X = "translateX";
    public static final String WX_TRANSLATE_Y = "translateY";
    private static final String ZERO = "0%";
    public static Map<String, List<Property<View, Float>>> wxToAndroidMap;

    static {
        ArrayMap arrayMap = new ArrayMap();
        wxToAndroidMap = arrayMap;
        arrayMap.put("translate", Arrays.asList(View.TRANSLATION_X, View.TRANSLATION_Y));
        wxToAndroidMap.put("translateX", Collections.singletonList(View.TRANSLATION_X));
        wxToAndroidMap.put("translateY", Collections.singletonList(View.TRANSLATION_Y));
        wxToAndroidMap.put("rotate", Collections.singletonList(View.ROTATION));
        wxToAndroidMap.put(WX_ROTATE_Z, Collections.singletonList(View.ROTATION));
        wxToAndroidMap.put("rotateX", Collections.singletonList(View.ROTATION_X));
        wxToAndroidMap.put("rotateY", Collections.singletonList(View.ROTATION_Y));
        wxToAndroidMap.put("scale", Arrays.asList(View.SCALE_X, View.SCALE_Y));
        wxToAndroidMap.put("scaleX", Collections.singletonList(View.SCALE_X));
        wxToAndroidMap.put("scaleY", Collections.singletonList(View.SCALE_Y));
        wxToAndroidMap.put(Constants.Name.PERSPECTIVE, Collections.singletonList(CameraDistanceProperty.getInstance()));
        wxToAndroidMap = Collections.unmodifiableMap(wxToAndroidMap);
    }

    public static PropertyValuesHolder[] toHolders(Map<Property<View, Float>, Float> transformMap) {
        PropertyValuesHolder[] holders = new PropertyValuesHolder[transformMap.size()];
        int i = 0;
        for (Map.Entry<Property<View, Float>, Float> entry : transformMap.entrySet()) {
            holders[i] = PropertyValuesHolder.ofFloat(entry.getKey(), entry.getValue().floatValue());
            i++;
        }
        return holders;
    }

    public static Map<Property<View, Float>, Float> parseTransForm(String instanceId, String rawTransform, final int width, final int height, final float viewportW) {
        try {
            if (!TextUtils.isEmpty(rawTransform)) {
                return new FunctionParser<>(rawTransform, new FunctionParser.Mapper<Property<View, Float>, Float>() {
                    /* class com.taobao.weex.ui.animation.TransformParser.AnonymousClass1 */

                    @Override // com.taobao.weex.utils.FunctionParser.Mapper
                    public Map<Property<View, Float>, Float> map(String functionName, List<String> raw) {
                        if (raw == null || raw.isEmpty() || !TransformParser.wxToAndroidMap.containsKey(functionName)) {
                            return new HashMap();
                        }
                        return convertParam(width, height, viewportW, TransformParser.wxToAndroidMap.get(functionName), raw);
                    }

                    private Map<Property<View, Float>, Float> convertParam(int width, int height, float viewportW, List<Property<View, Float>> propertyList, List<String> rawValue) {
                        Map<Property<View, Float>, Float> result = WXDataStructureUtil.newHashMapWithExpectedSize(propertyList.size());
                        List<Float> convertedList = new ArrayList<>(propertyList.size());
                        if (propertyList.contains(View.ROTATION) || propertyList.contains(View.ROTATION_X) || propertyList.contains(View.ROTATION_Y)) {
                            convertedList.addAll(parseRotationZ(rawValue));
                        } else if (propertyList.contains(View.TRANSLATION_X) || propertyList.contains(View.TRANSLATION_Y)) {
                            convertedList.addAll(parseTranslation(propertyList, width, height, rawValue, viewportW));
                        } else if (propertyList.contains(View.SCALE_X) || propertyList.contains(View.SCALE_Y)) {
                            convertedList.addAll(parseScale(propertyList.size(), rawValue));
                        } else if (propertyList.contains(CameraDistanceProperty.getInstance())) {
                            convertedList.add(parseCameraDistance(rawValue));
                        }
                        if (propertyList.size() == convertedList.size()) {
                            for (int i = 0; i < propertyList.size(); i++) {
                                result.put(propertyList.get(i), convertedList.get(i));
                            }
                        }
                        return result;
                    }

                    private List<Float> parseScale(int size, List<String> rawValue) {
                        List<Float> convertedList = new ArrayList<>(rawValue.size() * 2);
                        List<Float> rawFloat = new ArrayList<>(rawValue.size());
                        for (String item : rawValue) {
                            rawFloat.add(Float.valueOf(WXUtils.fastGetFloat(item)));
                        }
                        convertedList.addAll(rawFloat);
                        if (size != 1 && rawValue.size() == 1) {
                            convertedList.addAll(rawFloat);
                        }
                        return convertedList;
                    }

                    private List<Float> parseRotationZ(List<String> rawValue) {
                        List<Float> convertedList = new ArrayList<>(1);
                        for (String raw : rawValue) {
                            int suffix = raw.lastIndexOf(TransformParser.DEG);
                            if (suffix != -1) {
                                convertedList.add(Float.valueOf(WXUtils.fastGetFloat(raw.substring(0, suffix))));
                            } else {
                                convertedList.add(Float.valueOf((float) Math.toDegrees((double) WXUtils.fastGetFloat(raw))));
                            }
                        }
                        return convertedList;
                    }

                    private List<Float> parseTranslation(List<Property<View, Float>> propertyList, int width, int height, List<String> rawValue, float viewportW) {
                        List<Float> convertedList = new ArrayList<>(2);
                        String first = rawValue.get(0);
                        if (propertyList.size() == 1) {
                            parseSingleTranslation(propertyList, width, height, convertedList, first, viewportW);
                        } else {
                            parseDoubleTranslation(width, height, rawValue, convertedList, first, viewportW);
                        }
                        return convertedList;
                    }

                    private void parseSingleTranslation(List<Property<View, Float>> propertyList, int width, int height, List<Float> convertedList, String first, float viewportW) {
                        if (propertyList.contains(View.TRANSLATION_X)) {
                            convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, width, viewportW)));
                        } else if (propertyList.contains(View.TRANSLATION_Y)) {
                            convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, height, viewportW)));
                        }
                    }

                    private void parseDoubleTranslation(int width, int height, List<String> rawValue, List<Float> convertedList, String first, float viewportW) {
                        String second;
                        if (rawValue.size() == 1) {
                            second = first;
                        } else {
                            second = rawValue.get(1);
                        }
                        convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, width, viewportW)));
                        convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(second, height, viewportW)));
                    }

                    private Float parseCameraDistance(List<String> rawValue) {
                        float ret = Float.MAX_VALUE;
                        if (rawValue.size() == 1) {
                            float value = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(rawValue.get(0)), viewportW);
                            float scale = WXEnvironment.getApplication().getResources().getDisplayMetrics().density;
                            if (!Float.isNaN(value) && value > 0.0f) {
                                ret = value * scale;
                            }
                        }
                        return Float.valueOf(ret);
                    }
                }).parse();
            }
        } catch (Exception e) {
            WXLogUtils.e("TransformParser", e);
            WXErrorCode wXErrorCode = WXErrorCode.WX_RENDER_ERR_TRANSITION;
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "parse animation transition", WXErrorCode.WX_RENDER_ERR_TRANSITION.getErrorMsg() + "parse transition error: " + e.getMessage(), null);
        }
        return new LinkedHashMap();
    }

    private static Pair<Float, Float> parsePivot(String transformOrigin, int width, int height, float viewportW) {
        int firstSpace;
        if (TextUtils.isEmpty(transformOrigin) || (firstSpace = transformOrigin.indexOf(32)) == -1) {
            return null;
        }
        int i = firstSpace;
        while (i < transformOrigin.length() && transformOrigin.charAt(i) == ' ') {
            i++;
        }
        if (i >= transformOrigin.length() || transformOrigin.charAt(i) == ' ') {
            return null;
        }
        List<String> list = new ArrayList<>(2);
        list.add(transformOrigin.substring(0, firstSpace).trim());
        list.add(transformOrigin.substring(i, transformOrigin.length()).trim());
        return parsePivot(list, width, height, viewportW);
    }

    private static Pair<Float, Float> parsePivot(List<String> list, int width, int height, float viewportW) {
        return new Pair<>(Float.valueOf(parsePivotX(list.get(0), width, viewportW)), Float.valueOf(parsePivotY(list.get(1), height, viewportW)));
    }

    private static float parsePivotX(String x, int width, float viewportW) {
        String value = x;
        if ("left".equals(x)) {
            value = ZERO;
        } else if ("right".equals(x)) {
            value = FULL;
        } else if ("center".equals(x)) {
            value = HALF;
        }
        return parsePercentOrPx(value, width, viewportW);
    }

    private static float parsePivotY(String y, int height, float viewportW) {
        String value = y;
        if ("top".equals(y)) {
            value = ZERO;
        } else if ("bottom".equals(y)) {
            value = FULL;
        } else if ("center".equals(y)) {
            value = HALF;
        }
        return parsePercentOrPx(value, height, viewportW);
    }

    /* access modifiers changed from: private */
    public static float parsePercentOrPx(String raw, int unit, float viewportW) {
        int suffix = raw.lastIndexOf(37);
        if (suffix != -1) {
            return parsePercent(raw.substring(0, suffix), unit, 1);
        }
        int suffix2 = raw.lastIndexOf(PX);
        if (suffix2 != -1) {
            return WXViewUtils.getRealPxByWidth(WXUtils.fastGetFloat(raw.substring(0, suffix2), 1.0f), viewportW);
        }
        return WXViewUtils.getRealPxByWidth(WXUtils.fastGetFloat(raw, 1.0f), viewportW);
    }

    private static float parsePercent(String percent, int unit, int precision) {
        return (WXUtils.fastGetFloat(percent, (float) precision) / 100.0f) * ((float) unit);
    }
}
