package com.taobao.weex.ui.component;

import android.animation.ObjectAnimator;
import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import androidx.core.view.ViewCompat;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.view.IWXScroller;
import com.taobao.weex.ui.view.WXBaseRefreshLayout;
import com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.DensityUtils;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.weex_scroller.helper.DCScrollStartEndHelper;
import io.dcloud.feature.weex_scroller.view.DCBounceScrollerView;
import io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import io.dcloud.feature.weex_scroller.view.WXStickyHelper;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;

@Component(lazyload = false)
public class DCWXScroller extends WXBaseScroller implements DCWXScrollView.WXScrollViewListener, Scrollable {
    public static final String DIRECTION = "direction";
    private static final int SWIPE_MIN_DISTANCE = 5;
    private static final int SWIPE_THRESHOLD_VELOCITY = 300;
    private boolean canScroll2Top;
    Map<String, WXComponent> childens;
    private Handler handler;
    private boolean isAnimation;
    private boolean isScrollable;
    private AtomicBoolean isViewLayoutFinished;
    private int mActiveFeature;
    private Map<String, AppearanceHelper> mAppearanceComponents;
    private int mChildrenLayoutOffset;
    private int mContentHeight;
    private int mContentWidth;
    private boolean mForceLoadmoreNextTime;
    private GestureDetector mGestureDetector;
    private boolean mHasAddScrollEvent;
    private boolean mIsHostAttachedToWindow;
    private Point mLastReport;
    private int mOffsetAccuracy;
    private View.OnAttachStateChangeListener mOnAttachStateChangeListener;
    protected int mOrientation;
    private FrameLayout mRealView;
    private List<WXComponent> mRefreshs;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private FrameLayout mScrollerView;
    private Map<String, Map<String, WXComponent>> mStickyMap;
    private boolean pageEnable;
    private int pageSize;
    private WXStickyHelper stickyHelper;

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            instance.setUseScroller(true);
            return new DCWXScroller(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public DCWXScroller(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public DCWXScroller(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mOrientation = 1;
        this.mRefreshs = new ArrayList();
        this.mChildrenLayoutOffset = 0;
        this.mForceLoadmoreNextTime = false;
        this.mOffsetAccuracy = 10;
        this.mLastReport = new Point(-1, -1);
        this.mHasAddScrollEvent = false;
        this.mActiveFeature = 0;
        this.pageSize = 0;
        this.pageEnable = false;
        this.mIsHostAttachedToWindow = false;
        this.isAnimation = false;
        this.canScroll2Top = false;
        this.mAppearanceComponents = new HashMap();
        this.mStickyMap = new HashMap();
        this.mContentHeight = 0;
        this.mContentWidth = 0;
        this.handler = new Handler(Looper.getMainLooper());
        this.isScrollable = true;
        this.childens = new HashMap();
        this.isViewLayoutFinished = new AtomicBoolean(false);
        this.stickyHelper = new WXStickyHelper(this);
        instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_SCROLLER_NUM, 1.0d);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return this.mScrollerView;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        super.createViewImpl();
        for (int i = 0; i < this.mRefreshs.size(); i++) {
            WXComponent component = this.mRefreshs.get(i);
            component.createViewImpl();
            checkRefreshOrLoading(component);
        }
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public ViewGroup getInnerView() {
        if (getHostView() == null) {
            return null;
        }
        if (getHostView() instanceof DCBounceScrollerView) {
            return (ViewGroup) ((DCBounceScrollerView) getHostView()).getInnerView();
        }
        return (ViewGroup) getHostView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (DCScrollStartEndHelper.isScrollEvent(type) && getInnerView() != null && !this.mHasAddScrollEvent) {
            this.mHasAddScrollEvent = true;
            if (getInnerView() instanceof DCWXScrollView) {
                ((DCWXScrollView) getInnerView()).addScrollViewListener(new DCWXScrollView.WXScrollViewListener() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass1 */

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                    public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
                        DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                        if (DCWXScroller.this.getEvents().contains("scroll") && DCWXScroller.this.shouldReport(x, y)) {
                            DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                        }
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                    public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                        HashMap hashMap = new HashMap(1);
                        hashMap.put("direction", "bottom");
                        Map<String, Object> detail = new HashMap<>(1);
                        detail.put("detail", hashMap);
                        DCWXScroller.this.fireEvent("scrolltolower", detail);
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                    public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                        HashMap hashMap = new HashMap(1);
                        hashMap.put("direction", "top");
                        Map<String, Object> detail = new HashMap<>(1);
                        detail.put("detail", hashMap);
                        DCWXScroller.this.fireEvent("scrolltoupper", detail);
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                    public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                        DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                        if (DCWXScroller.this.getEvents().contains("scroll")) {
                            DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, 0, 0);
                        }
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                    public void onScroll(DCWXScrollView scrollView, int x, int y) {
                    }
                });
            } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
                ((DCWXHorizontalScrollView) getInnerView()).addScrollViewListener(new DCWXHorizontalScrollView.ScrollViewListener() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass2 */

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                    public void onScrollChanged(DCWXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                        DCWXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                        if (DCWXScroller.this.getEvents().contains("scroll") && DCWXScroller.this.shouldReport(x, y)) {
                            DCWXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                        }
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                    public void onScrolltoTop() {
                        HashMap hashMap = new HashMap(1);
                        hashMap.put("direction", "top");
                        Map<String, Object> detail = new HashMap<>(1);
                        detail.put("detail", hashMap);
                        DCWXScroller.this.fireEvent("scrolltoupper", detail);
                    }

                    @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                    public void onScrollToBottom() {
                        HashMap hashMap = new HashMap(1);
                        hashMap.put("direction", "bottom");
                        Map<String, Object> detail = new HashMap<>(1);
                        detail.put("detail", hashMap);
                        DCWXScroller.this.fireEvent("scrolltolower", detail);
                    }
                });
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireScrollEvent(Rect contentFrame, int x, int y, int oldx, int oldy) {
        fireEvent("scroll", getScrollEvent(x, y, oldx, oldy));
    }

    public Map<String, Object> getScrollEvent(int x, int y, int oldx, int oldy) {
        Rect contentFrame = new Rect();
        int scrollLeft = 0;
        int scrollTop = 0;
        if (getInnerView() instanceof DCWXScrollView) {
            contentFrame = ((DCWXScrollView) getInnerView()).getContentFrame();
            scrollTop = getInnerView().getScrollY();
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            contentFrame = ((DCWXHorizontalScrollView) getInnerView()).getContentFrame();
            scrollLeft = getInnerView().getScrollX();
        }
        Map<String, Object> event = new HashMap<>(2);
        Map<String, Object> contentSize = new HashMap<>(6);
        new HashMap(2);
        float viewport = getInstance().getInstanceViewPortWidthWithFloat();
        contentSize.put("scrollWidth", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.width(), viewport)));
        contentSize.put("scrollHeight", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.height(), viewport)));
        contentSize.put(Constants.Name.SCROLL_LEFT, Float.valueOf(WXViewUtils.getWebPxByWidth((float) scrollLeft, viewport)));
        contentSize.put(Constants.Name.SCROLL_TOP, Float.valueOf(WXViewUtils.getWebPxByWidth((float) scrollTop, viewport)));
        contentSize.put("deltaX", Float.valueOf(WXViewUtils.getWebPxByWidth((float) oldx, viewport)));
        contentSize.put("deltaY", Float.valueOf(WXViewUtils.getWebPxByWidth((float) oldy, viewport)));
        event.put("detail", contentSize);
        return event;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Object> getScrollEvent(int x, int y) {
        Rect contentFrame = new Rect();
        if (getInnerView() instanceof DCWXScrollView) {
            contentFrame = ((DCWXScrollView) getInnerView()).getContentFrame();
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            contentFrame = ((DCWXHorizontalScrollView) getInnerView()).getContentFrame();
        }
        Map<String, Object> event = new HashMap<>(2);
        Map<String, Object> contentSize = new HashMap<>(2);
        Map<String, Object> contentOffset = new HashMap<>(2);
        float viewport = getInstance().getInstanceViewPortWidthWithFloat();
        contentSize.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.width(), viewport)));
        contentSize.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.height(), viewport)));
        contentOffset.put(Constants.Name.X, Float.valueOf(WXViewUtils.getWebPxByWidth((float) x, viewport)));
        contentOffset.put(Constants.Name.Y, Float.valueOf(WXViewUtils.getWebPxByWidth((float) y, viewport)));
        event.put(Constants.Name.CONTENT_SIZE, contentSize);
        event.put(Constants.Name.CONTENT_OFFSET, contentOffset);
        return event;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean shouldReport(int x, int y) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation == 0 && Math.abs(x - this.mLastReport.x) >= this.mOffsetAccuracy) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation != 1 || Math.abs(y - this.mLastReport.y) < this.mOffsetAccuracy) {
            return false;
        } else {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
        FrameLayout frameLayout;
        if (child != null && (frameLayout = this.mRealView) != null && !(child instanceof WXBaseRefreshLayout)) {
            int index2 = index >= frameLayout.getChildCount() ? -1 : index;
            if (child.getParent() != null) {
                ((ViewGroup) child.getParent()).removeView(child);
            }
            if (index2 == -1) {
                this.mRealView.addView(child);
            } else {
                this.mRealView.addView(child, index2);
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        int listSize;
        if (this.mChildrenLayoutOffset == 0 && (listSize = this.mRefreshs.size()) > 0) {
            for (int i = 0; i < listSize; i++) {
                this.mChildrenLayoutOffset += this.mRefreshs.get(i).getLayoutTopOffsetForSibling();
            }
        }
        return this.mChildrenLayoutOffset;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        if (child.getAttrs().containsKey("id")) {
            this.childens.put(child.getAttrs().get("id").toString(), child);
        }
        if ((child instanceof WXBaseRefresh) && checkRefreshOrLoading(child)) {
            this.mRefreshs.add(child);
        }
        super.addChild(child, index);
    }

    private boolean checkRefreshOrLoading(final WXComponent child) {
        boolean result = false;
        if ((child instanceof WXRefresh) && getHostView() != null) {
            ((BaseBounceView) getHostView()).setOnRefreshListener((WXRefresh) child);
            this.handler.postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass3 */

                public void run() {
                    ((BaseBounceView) DCWXScroller.this.getHostView()).setHeaderView(child);
                }
            }), 100);
            result = true;
        }
        if (!(child instanceof WXLoading) || getHostView() == null) {
            return result;
        }
        ((BaseBounceView) getHostView()).setOnLoadingListener((WXLoading) child);
        this.handler.postDelayed(WXThread.secure(new Runnable() {
            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass4 */

            public void run() {
                ((BaseBounceView) DCWXScroller.this.getHostView()).setFooterView(child);
            }
        }), 100);
        return true;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destory) {
        super.remove(child, destory);
        if (child instanceof WXLoading) {
            ((BaseBounceView) getHostView()).removeFooterView(child);
        } else if (child instanceof WXRefresh) {
            ((BaseBounceView) getHostView()).removeHeaderView(child);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (getInnerView() != null && (getInnerView() instanceof IWXScroller)) {
            ((IWXScroller) getInnerView()).destroy();
        }
        Map<String, AppearanceHelper> map = this.mAppearanceComponents;
        if (map != null) {
            map.clear();
        }
        Map<String, Map<String, WXComponent>> map2 = this.mStickyMap;
        if (map2 != null) {
            map2.clear();
        }
        if (!(this.mOnAttachStateChangeListener == null || getInnerView() == null)) {
            getInnerView().removeOnAttachStateChangeListener(this.mOnAttachStateChangeListener);
        }
        super.destroy();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        if (Build.VERSION.SDK_INT >= 17) {
            lp.setMargins(left, top, right, bottom);
            lp.setMarginStart(left);
            lp.setMarginEnd(right);
        } else if (lp instanceof FrameLayout.LayoutParams) {
            FrameLayout.LayoutParams lp_frameLayout = (FrameLayout.LayoutParams) lp;
            if (isLayoutRTL()) {
                lp_frameLayout.gravity = 53;
                lp.setMargins(right, top, left, bottom);
                return;
            }
            lp_frameLayout.gravity = 51;
            lp.setMargins(left, top, right, bottom);
        } else {
            lp.setMargins(left, top, right, bottom);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        if (!TextUtils.isEmpty(component.getComponentType()) && !TextUtils.isEmpty(component.getRef()) && component.getLayoutPosition() != null && component.getLayoutSize() != null) {
            if (component.getHostView() != null) {
                ViewCompat.setLayoutDirection(component.getHostView(), component.isLayoutRTL() ? 1 : 0);
            }
            super.setLayout(component);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        WXComponent.MeasureOutput measureOutput = new WXComponent.MeasureOutput();
        int i = -1;
        if (this.mOrientation == 0) {
            int screenW = WXViewUtils.getScreenWidth(WXEnvironment.sApplication);
            int weexW = WXViewUtils.getWeexWidth(getInstanceId());
            if (width <= (weexW >= screenW ? screenW : weexW)) {
                i = width;
            }
            measureOutput.width = i;
            measureOutput.height = height;
        } else {
            int screenH = WXViewUtils.getScreenHeight(WXEnvironment.sApplication);
            int weexH = WXViewUtils.getWeexHeight(getInstanceId());
            if (height <= (weexH >= screenH ? screenH : weexH)) {
                i = height;
            }
            measureOutput.height = i;
            measureOutput.width = width;
        }
        return measureOutput;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r4v4, resolved type: io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView */
    /* JADX WARN: Multi-variable type inference failed */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public ViewGroup initComponentHostView(Context context) {
        String scroll;
        ViewGroup host;
        boolean scrollable = true;
        boolean scrollX = false;
        boolean scrollY = false;
        if (getAttrs().isEmpty()) {
            scroll = "vertical";
        } else {
            if (getAttrs().containsKey("scrollX")) {
                scrollX = Boolean.parseBoolean(getAttrs().get("scrollX").toString());
            }
            if (getAttrs().containsKey("scrollY")) {
                scrollY = Boolean.parseBoolean(getAttrs().get("scrollY").toString());
            }
            if (scrollY) {
                scrollable = !getAttrs().get("scrollY").equals(AbsoluteConst.FALSE);
                scroll = "vertical";
            } else if (scrollX) {
                scrollable = !getAttrs().get("scrollX").equals(AbsoluteConst.FALSE);
                scroll = Constants.Value.HORIZONTAL;
            } else if (getAttrs().containsKey(Constants.Name.SCROLL_DIRECTION)) {
                scroll = getAttrs().getScrollDirection();
            } else {
                scroll = "vertical";
            }
            Object o = getAttrs().get(Constants.Name.PAGE_ENABLED);
            this.pageEnable = o != null && Boolean.parseBoolean(o.toString());
            Object pageSize2 = getAttrs().get(Constants.Name.PAGE_SIZE);
            if (pageSize2 != null) {
                float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(pageSize2), getInstance().getInstanceViewPortWidth());
                if (realPxByWidth != 0.0f) {
                    this.pageSize = (int) realPxByWidth;
                }
            }
        }
        if (Constants.Value.HORIZONTAL.equals(scroll)) {
            this.mOrientation = 0;
            final DCWXHorizontalScrollView scrollView = new DCWXHorizontalScrollView(context);
            scrollView.setWAScroller(this);
            scrollView.setScrollable(scrollable);
            this.mRealView = new FrameLayout(context);
            scrollView.setScrollViewListener(new DCWXHorizontalScrollView.ScrollViewListener() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass5 */

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollChanged(DCWXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                    if (DCWXScroller.this.getInstance() != null) {
                        DCWXScroller.this.procAppear(x, y, oldx, oldy);
                        DCWXScroller.this.onLoadMore(scrollView, x, y);
                    }
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrolltoTop() {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXHorizontalScrollView.ScrollViewListener
                public void onScrollToBottom() {
                }
            });
            scrollView.addView(this.mRealView, new FrameLayout.LayoutParams(-1, -1));
            scrollView.setHorizontalScrollBarEnabled(true);
            this.mScrollerView = scrollView;
            scrollView.setScrollBarSize(DensityUtils.dip2px(getInstance().getContext(), 4.0f));
            final View.OnLayoutChangeListener listener = new View.OnLayoutChangeListener() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass6 */

                public void onLayoutChange(final View view, int left, int top, int right, int bottom, int oldLeft, int oldTop, int oldRight, int oldBottom) {
                    scrollView.post(new Runnable() {
                        /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass6.AnonymousClass1 */

                        public void run() {
                            if (DCWXScroller.this.isLayoutRTL()) {
                                scrollView.scrollTo(view.getMeasuredWidth(), this.getScrollY());
                                return;
                            }
                            scrollView.scrollTo(0, this.getScrollY());
                        }
                    });
                    if (DCWXScroller.this.mRealView != null) {
                        DCWXScroller.this.mRealView.removeOnLayoutChangeListener(this);
                    }
                }
            };
            this.mRealView.addOnAttachStateChangeListener(new View.OnAttachStateChangeListener() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass7 */

                public void onViewAttachedToWindow(View view) {
                    view.addOnLayoutChangeListener(listener);
                }

                public void onViewDetachedFromWindow(View view) {
                    view.removeOnLayoutChangeListener(listener);
                }
            });
            host = scrollView;
            if (this.pageEnable) {
                this.mGestureDetector = new GestureDetector(new MyGestureDetector(scrollView));
                scrollView.setOnTouchListener(new View.OnTouchListener() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass8 */

                    public boolean onTouch(View v, MotionEvent event) {
                        if (DCWXScroller.this.pageSize == 0) {
                            DCWXScroller.this.pageSize = v.getMeasuredWidth();
                        }
                        if (DCWXScroller.this.mGestureDetector.onTouchEvent(event)) {
                            return true;
                        }
                        if (event.getAction() != 1 && event.getAction() != 3) {
                            return false;
                        }
                        int scrollX = DCWXScroller.this.getScrollX();
                        int featureWidth = DCWXScroller.this.pageSize;
                        DCWXScroller.this.mActiveFeature = ((featureWidth / 2) + scrollX) / featureWidth;
                        scrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * featureWidth, 0);
                        return true;
                    }
                });
                host = scrollView;
            }
        } else {
            this.mOrientation = 1;
            DCBounceScrollerView scrollerView = new DCBounceScrollerView(context, this.mOrientation, this);
            this.mRealView = new FrameLayout(context);
            DCWXScrollView innerView = (DCWXScrollView) scrollerView.getInnerView();
            innerView.addScrollViewListener(this);
            if (scrollX || scrollY) {
                innerView.setScrollable(scrollable);
            } else {
                innerView.setScrollable(false);
            }
            innerView.addView(this.mRealView, new FrameLayout.LayoutParams(-1, -1));
            innerView.setVerticalScrollBarEnabled(true);
            this.mScrollerView = innerView;
            innerView.setNestedScrollingEnabled(WXUtils.getBoolean(getAttrs().get(Constants.Name.NEST_SCROLLING_ENABLED), true).booleanValue());
            innerView.addScrollViewListener(new DCWXScrollView.WXScrollViewListener() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass9 */

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                    if (DCWXScroller.this.getInstance() != null) {
                        List<OnWXScrollListener> listeners = DCWXScroller.this.getInstance().getWXScrollListeners();
                        if (listeners != null && listeners.size() > 0) {
                            for (OnWXScrollListener listener : listeners) {
                                if (listener != null) {
                                    listener.onScrollStateChanged(scrollView, x, y, 0);
                                }
                            }
                        }
                        DCWXScroller.this.getScrollStartEndHelper().onScrollStateChanged(0);
                    }
                }

                @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                public void onScroll(DCWXScrollView scrollView, int x, int y) {
                    List<OnWXScrollListener> listeners;
                    if (!(DCWXScroller.this.getInstance() == null || (listeners = DCWXScroller.this.getInstance().getWXScrollListeners()) == null || listeners.size() <= 0)) {
                        for (OnWXScrollListener listener : listeners) {
                            if (listener != null) {
                                if (!(listener instanceof ICheckBindingScroller)) {
                                    listener.onScrolled(scrollView, x, y);
                                } else if (((ICheckBindingScroller) listener).isNeedScroller(DCWXScroller.this.getRef(), null)) {
                                    listener.onScrolled(scrollView, x, y);
                                }
                            }
                        }
                    }
                }
            });
            host = scrollerView;
        }
        host.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass10 */

            public void onGlobalLayout() {
                DCWXScroller.this.procAppear(0, 0, 0, 0);
                View view = DCWXScroller.this.getHostView();
                if (view != null && DCWXScroller.this.getInstance() != null) {
                    if (Build.VERSION.SDK_INT >= 16) {
                        view.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                    } else {
                        view.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                    }
                }
            }
        });
        View.OnAttachStateChangeListener r5 = new View.OnAttachStateChangeListener() {
            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass11 */

            public void onViewAttachedToWindow(View v) {
                DCWXScroller.this.mIsHostAttachedToWindow = true;
                DCWXScroller dCWXScroller = DCWXScroller.this;
                dCWXScroller.procAppear(dCWXScroller.getScrollX(), DCWXScroller.this.getScrollY(), DCWXScroller.this.getScrollX(), DCWXScroller.this.getScrollY());
            }

            public void onViewDetachedFromWindow(View v) {
                DCWXScroller.this.mIsHostAttachedToWindow = false;
                DCWXScroller.this.dispatchDisappearEvent();
            }
        };
        this.mOnAttachStateChangeListener = r5;
        host.addOnAttachStateChangeListener(r5);
        return host;
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getScrollY() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getScrollX() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollX();
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getOrientation() {
        return this.mOrientation;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Map<String, WXComponent>> getStickMap() {
        return this.mStickyMap;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -101546095:
                if (key.equals("scrollWithAnimation")) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 1926689579:
                if (key.equals("scrollX")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1926689580:
                if (key.equals("scrollY")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            Boolean result = WXUtils.getBoolean(param, null);
            if (result != null) {
                setShowScrollbar(result.booleanValue());
            }
            return true;
        } else if (c == 1) {
            setScrollable(WXUtils.getBoolean(param, true).booleanValue());
            return true;
        } else if (c == 2 || c == 3) {
            setScrollable(!String.valueOf(param).equals(AbsoluteConst.FALSE));
            return true;
        } else if (c != 4) {
            if (c == 5) {
                setScrollWithAnimation(WXUtils.getBoolean(param, false).booleanValue());
            }
            return super.setProperty(key, param);
        } else {
            setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
            return true;
        }
    }

    @WXComponentProp(name = "scrollIntoView")
    public void setScrollIntoView(final String ref) {
        if (!this.isViewLayoutFinished.get()) {
            getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass12 */

                public void onGlobalLayout() {
                    if (DCWXScroller.this.getInstance() != null) {
                        WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(DCWXScroller.this.getInstanceId(), ref);
                        if (component != null) {
                            DCWXScroller.this.scrollTo(component, JSONObject.parseObject("{'animated':false}"));
                        }
                        DCWXScroller.this.isViewLayoutFinished.set(true);
                        DCWXScroller.this.handler.postDelayed(new Runnable() {
                            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass12.AnonymousClass1 */

                            public void run() {
                                DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                            }
                        }, 100);
                    }
                }
            });
            return;
        }
        WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(getInstanceId(), ref);
        if (component != null) {
            scrollTo(component, JSONObject.parseObject(StringUtil.format("{'animated':%b}", Boolean.valueOf(this.isAnimation))));
        }
    }

    @JSMethod
    public void scrollTo(int top) {
        float realPx = WXViewUtils.getRealPxByWidth((float) top, getInstance().getInstanceViewPortWidth());
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, (int) realPx);
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPx, 0);
        }
    }

    @JSMethod
    public void scrollTo(String op, JSCallback callback) {
        float realPx = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(JSON.parseObject(op).getString(Constants.Name.SCROLL_TOP)), getInstance().getInstanceViewPortWidth());
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, (int) realPx);
        } else if (getInnerView() instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPx, 0);
        }
        if (callback != null) {
            Map<String, Object> params = new HashMap<>();
            params.put("type", WXImage.SUCCEED);
            callback.invoke(params);
        }
    }

    private WXComponent getViewById(String id) {
        if (this.childens.containsKey(id)) {
            return this.childens.get(id);
        }
        for (WXComponent child : this.childens.values()) {
            if (child.getAttrs().containsKey("id") && child.getAttrs().get("id").equals(id)) {
                return child;
            }
        }
        return null;
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getInnerView() != null) {
            if (this.mOrientation == 1) {
                getInnerView().setVerticalScrollBarEnabled(show);
            } else {
                getInnerView().setHorizontalScrollBarEnabled(show);
            }
        }
    }

    @WXComponentProp(name = "scrollWithAnimation")
    public void setScrollWithAnimation(boolean isAnimation2) {
        this.isAnimation = isAnimation2;
    }

    @WXComponentProp(name = "upperThreshold")
    public void setUpperHeight(int height) {
        View host = getInnerView();
        float realPx = WXViewUtils.getRealPxByWidth((float) height, getInstance().getInstanceViewPortWidth());
        if (host instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) host).setUpperLength(realPx);
        } else if (host instanceof DCWXScrollView) {
            ((DCWXScrollView) host).setUpperLength(realPx);
        }
    }

    @WXComponentProp(name = "enable-back-to-top")
    public void isEnableBackToTop(boolean toTop) {
        this.canScroll2Top = toTop;
    }

    @JSMethod
    public void scrollToTop() {
        if ((getInnerView() instanceof DCWXScrollView) && this.canScroll2Top) {
            ((DCWXScrollView) getInnerView()).smoothScrollTo(0, 0);
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        if (getInnerView() instanceof DCWXScrollView) {
            final float realPy = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidth());
            if (!this.isViewLayoutFinished.get()) {
                getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass13 */

                    public void onGlobalLayout() {
                        DCWXScroller.this.getInnerView().scrollTo(0, (int) realPy);
                        DCWXScroller.this.isViewLayoutFinished.set(true);
                        DCWXScroller.this.handler.postDelayed(new Runnable() {
                            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass13.AnonymousClass1 */

                            public void run() {
                                DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                            }
                        }, 100);
                    }
                });
                return;
            }
            if (this.isAnimation) {
                if (getInnerView() instanceof DCWXScrollView) {
                    ((DCWXScrollView) getInnerView()).stopScroll();
                }
                ObjectAnimator.ofInt(getInnerView(), "scrollY", getInnerView().getScrollY(), (int) realPy).setDuration(200L).start();
            } else {
                getInnerView().post(new Runnable() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass14 */

                    public void run() {
                        DCWXScroller.this.getInnerView().scrollTo(0, (int) realPy);
                    }
                });
            }
            this.isViewLayoutFinished.set(true);
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        if (getInnerView() instanceof DCWXHorizontalScrollView) {
            final float realPx = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidth());
            if (!this.isViewLayoutFinished.get()) {
                getInnerView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
                    /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass15 */

                    public void onGlobalLayout() {
                        ObjectAnimator.ofInt(DCWXScroller.this.getInnerView(), "scrollX", DCWXScroller.this.getInnerView().getScrollX(), (int) realPx).setDuration(1L).start();
                        DCWXScroller.this.isViewLayoutFinished.set(true);
                        DCWXScroller.this.handler.postDelayed(new Runnable() {
                            /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass15.AnonymousClass1 */

                            public void run() {
                                DCWXScroller.this.getInnerView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                            }
                        }, 100);
                    }
                });
                return;
            }
            if (this.isAnimation) {
                if (getInnerView() instanceof DCWXHorizontalScrollView) {
                    ((DCWXHorizontalScrollView) getInnerView()).stopScroll();
                }
                ObjectAnimator.ofInt(getInnerView(), "scrollX", getInnerView().getScrollX(), (int) realPx).setDuration(200L).start();
            } else {
                ((DCWXHorizontalScrollView) getInnerView()).smoothScrollTo((int) realPx, 0);
            }
            this.isViewLayoutFinished.set(true);
        }
    }

    @WXComponentProp(name = "lowerThreshold")
    public void setLowwerHeight(int height) {
        View host = getInnerView();
        float realPx = WXViewUtils.getRealPxByWidth((float) height, getInstance().getInstanceViewPortWidth());
        if (host instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) host).setLowwerLength(realPx);
        } else if (host instanceof DCWXScrollView) {
            ((DCWXScrollView) host).setLowwerLength(realPx);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onFinishLayout() {
        super.onFinishLayout();
    }

    public void setScrollable(boolean scrollable) {
        this.isScrollable = scrollable;
        View hostView = getInnerView();
        if (hostView instanceof DCWXHorizontalScrollView) {
            ((DCWXHorizontalScrollView) hostView).setScrollable(scrollable);
        } else if (hostView instanceof DCWXScrollView) {
            ((DCWXScrollView) hostView).setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth((float) accuracy, getInstance().getInstanceViewPortWidth());
    }

    @WXComponentProp(name = "decelerationRate")
    public void setDecelerationRate(float rate) {
        if (getInnerView() instanceof DCWXScrollView) {
            ((DCWXScrollView) getInnerView()).setRate(rate);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public boolean isScrollable() {
        return this.isScrollable;
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindStickStyle(WXComponent component) {
        this.stickyHelper.bindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindStickStyle(WXComponent component) {
        this.stickyHelper.unbindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindAppearEvent(WXComponent component) {
        setWatch(0, component, true);
    }

    private void setWatch(int event, WXComponent component, boolean isWatch) {
        AppearanceHelper item = this.mAppearanceComponents.get(component.getRef());
        if (item == null) {
            item = new AppearanceHelper(component);
            this.mAppearanceComponents.put(component.getRef(), item);
        }
        item.setWatchEvent(event, isWatch);
        procAppear(0, 0, 0, 0);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindDisappearEvent(WXComponent component) {
        setWatch(1, component, true);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindAppearEvent(WXComponent component) {
        setWatch(0, component, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindDisappearEvent(WXComponent component) {
        setWatch(1, component, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int viewXInScroller;
        float offsetFloat = 0.0f;
        boolean smooth = true;
        if (options != null) {
            String offset = options.get("offset") == null ? "0" : options.get("offset").toString();
            smooth = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (offset != null) {
                try {
                    offsetFloat = WXViewUtils.getRealPxByWidth(Float.parseFloat(offset), getInstance().getInstanceViewPortWidth());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
        }
        if (this.pageEnable) {
            this.mActiveFeature = this.mChildren.indexOf(component);
        }
        int viewYInScroller = component.getAbsoluteY() - getAbsoluteY();
        if (isLayoutRTL()) {
            if (getInnerView().getChildCount() > 0) {
                viewXInScroller = (getInnerView().getChildAt(0).getWidth() - (component.getAbsoluteX() - getAbsoluteX())) - getInnerView().getMeasuredWidth();
            } else {
                viewXInScroller = component.getAbsoluteX() - getAbsoluteX();
            }
            offsetFloat = -offsetFloat;
        } else {
            viewXInScroller = component.getAbsoluteX() - getAbsoluteX();
        }
        scrollBy((viewXInScroller - getScrollX()) + ((int) offsetFloat), (viewYInScroller - getScrollY()) + ((int) offsetFloat), smooth);
    }

    public void scrollBy(int x, int y) {
        scrollBy(x, y, false);
    }

    public void scrollBy(final int x, final int y, final boolean smooth) {
        if (getInnerView() != null) {
            getInnerView().postDelayed(new Runnable() {
                /* class com.taobao.weex.ui.component.DCWXScroller.AnonymousClass16 */

                public void run() {
                    if (DCWXScroller.this.mOrientation == 1) {
                        if (smooth) {
                            ((DCWXScrollView) DCWXScroller.this.getInnerView()).smoothScrollBy(0, y);
                        } else {
                            ((DCWXScrollView) DCWXScroller.this.getInnerView()).scrollBy(0, y);
                        }
                    } else if (smooth) {
                        ((DCWXHorizontalScrollView) DCWXScroller.this.getInnerView()).smoothScrollBy(x, 0);
                    } else {
                        ((DCWXHorizontalScrollView) DCWXScroller.this.getInnerView()).scrollBy(x, 0);
                    }
                    DCWXScroller.this.getInnerView().invalidate();
                }
            }, 16);
        }
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollChanged(DCWXScrollView scrollView, int x, int y, int oldx, int oldy) {
        procAppear(x, y, oldx, oldy);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        if (containsEvent(Constants.Event.APPEAR) || containsEvent(Constants.Event.DISAPPEAR)) {
            Map<String, Object> params = new HashMap<>();
            params.put("direction", direction);
            fireEvent(wxEventType, params);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void procAppear(int x, int y, int oldx, int oldy) {
        String direction;
        int result;
        if (this.mIsHostAttachedToWindow) {
            int moveY = y - oldy;
            int moveX = x - oldx;
            if (moveY > 0) {
                direction = "up";
            } else {
                direction = moveY < 0 ? "down" : null;
            }
            if (this.mOrientation == 0 && moveX != 0) {
                direction = moveX > 0 ? "right" : "left";
            }
            for (Map.Entry<String, AppearanceHelper> item : this.mAppearanceComponents.entrySet()) {
                AppearanceHelper helper = item.getValue();
                if (helper.isWatch() && (result = helper.setAppearStatus(checkItemVisibleInScroller(helper.getAwareChild()))) != 0) {
                    helper.getAwareChild().notifyAppearStateChange(result == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, direction);
                }
            }
        }
    }

    private boolean checkItemVisibleInScroller(WXComponent component) {
        boolean visible = false;
        while (component != null && !(component instanceof DCWXScroller)) {
            if (component.getParent() instanceof DCWXScroller) {
                boolean z = true;
                if (this.mOrientation == 0) {
                    int offsetLeft = ((int) component.getLayoutPosition().getLeft()) - getScrollX();
                    if (((float) offsetLeft) <= 0.0f - component.getLayoutWidth() || ((float) offsetLeft) >= getLayoutWidth()) {
                        z = false;
                    }
                    visible = z;
                } else {
                    int offsetTop = ((int) component.getLayoutPosition().getTop()) - getScrollY();
                    if (((float) offsetTop) <= 0.0f - component.getLayoutHeight() || ((float) offsetTop) >= getLayoutHeight()) {
                        z = false;
                    }
                    visible = z;
                }
            }
            component = component.getParent();
        }
        return visible;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchDisappearEvent() {
        int result;
        for (Map.Entry<String, AppearanceHelper> item : this.mAppearanceComponents.entrySet()) {
            AppearanceHelper helper = item.getValue();
            if (helper.isWatch() && (result = helper.setAppearStatus(false)) != 0) {
                helper.getAwareChild().notifyAppearStateChange(result == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, "");
            }
        }
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
    }

    @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
    public void onScroll(DCWXScrollView scrollView, int x, int y) {
        onLoadMore(scrollView, x, y);
    }

    /* access modifiers changed from: protected */
    public void onLoadMore(FrameLayout scrollView, int x, int y) {
        try {
            String offset = getAttrs().getLoadMoreOffset();
            if (!TextUtils.isEmpty(offset)) {
                int offsetInt = (int) WXViewUtils.getRealPxByWidth(Float.parseFloat(offset), getInstance().getInstanceViewPortWidth());
                if (scrollView instanceof DCWXHorizontalScrollView) {
                    int contentWidth = scrollView.getChildAt(0).getWidth();
                    if ((contentWidth - x) - scrollView.getWidth() >= offsetInt) {
                        return;
                    }
                    if (this.mContentWidth != contentWidth || this.mForceLoadmoreNextTime) {
                        fireEvent(Constants.Event.LOADMORE);
                        this.mContentWidth = contentWidth;
                        this.mForceLoadmoreNextTime = false;
                        return;
                    }
                    return;
                }
                int contentH = scrollView.getChildAt(0).getHeight();
                int offScreenY = (contentH - y) - scrollView.getHeight();
                if (offScreenY < offsetInt) {
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d("[WXScroller-onScroll] offScreenY :" + offScreenY);
                    }
                    if (this.mContentHeight != contentH || this.mForceLoadmoreNextTime) {
                        fireEvent(Constants.Event.LOADMORE);
                        this.mContentHeight = contentH;
                        this.mForceLoadmoreNextTime = false;
                    }
                }
            }
        } catch (Exception e) {
            WXLogUtils.d("[DCWXScroller-onScroll] ", e);
        }
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    /* access modifiers changed from: package-private */
    public class MyGestureDetector extends GestureDetector.SimpleOnGestureListener {
        private final DCWXHorizontalScrollView scrollView;

        public DCWXHorizontalScrollView getScrollView() {
            return this.scrollView;
        }

        MyGestureDetector(DCWXHorizontalScrollView horizontalScrollView) {
            this.scrollView = horizontalScrollView;
        }

        public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
            int mItems = DCWXScroller.this.mChildren.size();
            try {
                if (e1.getX() - e2.getX() <= 5.0f || Math.abs(velocityX) <= 300.0f) {
                    if (e2.getX() - e1.getX() > 5.0f && Math.abs(velocityX) > 300.0f) {
                        int featureWidth = DCWXScroller.this.pageSize;
                        DCWXScroller.this.mActiveFeature = DCWXScroller.this.mActiveFeature > 0 ? DCWXScroller.this.mActiveFeature - 1 : 0;
                        this.scrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * featureWidth, 0);
                        return true;
                    }
                    return false;
                }
                int featureWidth2 = DCWXScroller.this.pageSize;
                DCWXScroller.this.mActiveFeature = DCWXScroller.this.mActiveFeature < mItems + -1 ? DCWXScroller.this.mActiveFeature + 1 : mItems - 1;
                this.scrollView.smoothScrollTo(DCWXScroller.this.mActiveFeature * featureWidth2, 0);
                return true;
            } catch (Exception e) {
                WXLogUtils.e("There was an error processing the Fling event:" + e.getMessage());
            }
        }
    }
}
