package com.taobao.weex.ui.component;

import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.WXEditText;
import com.taobao.weex.utils.WXUtils;

public class Textarea extends AbstractEditComponent {
    public static final int DEFAULT_ROWS = 2;
    private int mNumberOfLines = 2;

    public Textarea(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    public void onHostViewInitialized(WXEditText host) {
        host.setAllowDisableMovement(false);
        super.onHostViewInitialized(host);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    public void appleStyleAfterCreated(WXEditText editText) {
        super.appleStyleAfterCreated(editText);
        String rowsStr = (String) getStyles().get(Constants.Name.ROWS);
        int rows = 2;
        try {
            if (!TextUtils.isEmpty(rowsStr)) {
                rows = Integer.parseInt(rowsStr);
            }
        } catch (NumberFormatException e) {
            e.printStackTrace();
        }
        editText.setLines(rows);
        editText.setMinLines(rows);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    public int getVerticalGravity() {
        return 48;
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent, com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        if (((key.hashCode() == 3506649 && key.equals(Constants.Name.ROWS)) ? (char) 0 : 65535) != 0) {
            return super.setProperty(key, param);
        }
        Integer rows = WXUtils.getInteger(param, null);
        if (rows == null) {
            return true;
        }
        setRows(rows.intValue());
        return true;
    }

    @WXComponentProp(name = Constants.Name.ROWS)
    public void setRows(int rows) {
        WXEditText text = (WXEditText) getHostView();
        if (text != null && rows > 0) {
            text.setLines(rows);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    public float getMeasureHeight() {
        return getMeasuredLineHeight() * ((float) this.mNumberOfLines);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    public void updateStyleAndAttrs() {
        super.updateStyleAndAttrs();
        Object raw = getAttrs().get(Constants.Name.ROWS);
        if (raw != null) {
            if (raw instanceof String) {
                try {
                    int lines = Integer.parseInt((String) raw);
                    if (lines > 0) {
                        this.mNumberOfLines = lines;
                    }
                } catch (NumberFormatException e) {
                    e.printStackTrace();
                }
            } else if (raw instanceof Integer) {
                this.mNumberOfLines = ((Integer) raw).intValue();
            }
        }
    }
}
