package com.taobao.weex.ui.component;

import android.animation.Animator;
import android.animation.AnimatorSet;
import android.animation.ObjectAnimator;
import android.animation.StateListAnimator;
import android.content.Context;
import android.content.Intent;
import android.content.res.ColorStateList;
import android.graphics.Canvas;
import android.graphics.Outline;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.graphics.drawable.RippleDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.Pair;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.widget.FrameLayout;
import androidx.core.view.AccessibilityDelegateCompat;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.interpolator.view.animation.FastOutLinearInInterpolator;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.JSONLexer;
import com.taobao.weex.ComponentObserver;
import com.taobao.weex.IWXActivityStateListener;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXAccessibilityRoleAdapter;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.IWXObject;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXPerformance;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.dom.transition.WXTransition;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.tracing.Stopwatch;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.WXRenderManager;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.action.GraphicActionAnimation;
import com.taobao.weex.ui.action.GraphicActionUpdateStyle;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.animation.WXAnimationBean;
import com.taobao.weex.ui.component.basic.WXBasicComponent;
import com.taobao.weex.ui.component.binding.Statements;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.component.list.template.jni.NativeRenderObjectUtils;
import com.taobao.weex.ui.component.pesudo.OnActivePseudoListner;
import com.taobao.weex.ui.component.pesudo.PesudoStatus;
import com.taobao.weex.ui.component.pesudo.TouchActivePseudoListener;
import com.taobao.weex.ui.flat.FlatComponent;
import com.taobao.weex.ui.flat.FlatGUIContext;
import com.taobao.weex.ui.flat.widget.AndroidViewWidget;
import com.taobao.weex.ui.flat.widget.Widget;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXDataStructureUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.uniapp.dom.AbsCSSShorthand;
import io.dcloud.feature.uniapp.ui.AbsAnimationHolder;
import io.dcloud.feature.uniapp.ui.action.UniMethodData;
import io.dcloud.feature.uniapp.ui.component.AbsBasicComponent;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowData;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowLayer;
import io.dcloud.feature.uniapp.ui.shadow.UniNormalBoxShadowDrawable;
import io.dcloud.feature.uniapp.utils.UniBoxShadowUtil;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.weex.ViewHover;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;

public abstract class WXComponent<T extends View> extends WXBasicComponent<T> implements IWXObject, IWXActivityStateListener, OnActivePseudoListner {
    public static final String PROP_FIXED_SIZE = "fixedSize";
    public static final String PROP_FS_MATCH_PARENT = "m";
    public static final String PROP_FS_WRAP_CONTENT = "w";
    public static final String ROOT = "_root";
    public static final int STATE_ALL_FINISH = 2;
    public static final int STATE_DOM_FINISH = 0;
    public static final int STATE_UI_FINISH = 1;
    public static final String TYPE = "type";
    public static final int TYPE_COMMON = 0;
    public static final int TYPE_VIRTUAL = 1;
    private int[] EMPTY_STATE_SET;
    private int[] ENABLED_STATE_SET;
    private int[] FOCUSED_ENABLED_STATE_SET;
    private long PRESSED_ANIM_DELAY;
    private long PRESSED_ANIM_DURATION;
    private int[] PRESSED_ENABLED_STATE_SET;
    private ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> animations;
    protected ContentBoxMeasurement contentBoxMeasurement;
    public int interactionAbsoluteX;
    public int interactionAbsoluteY;
    public boolean isIgnoreInteraction;
    private boolean isLastLayoutDirectionRTL;
    private boolean isPreventGesture;
    private boolean isUsing;
    private int mAbsoluteX;
    private int mAbsoluteY;
    private AbsAnimationHolder mAnimationHolder;
    private Set<String> mAppendEvents;
    private BorderDrawable mBackgroundDrawable;
    private UniBoxShadowData mBoxShadowData;
    private UniNormalBoxShadowDrawable mBoxShadowDrawable;
    private WXComponent<T>.OnClickListenerImp mClickEventListener;
    private Context mContext;
    public int mDeepInComponentTree;
    private float mElevation;
    private int mFixedProp;
    private List<OnFocusChangeListener> mFocusChangeListeners;
    protected WXGesture mGesture;
    private Set<String> mGestureType;
    private boolean mHasAddFocusListener;
    private IFComponentHolder mHolder;
    T mHost;
    private List<OnClickListener> mHostClickListeners;
    private ViewHover mHover;
    private UniInsetBoxShadowLayer mInsetBoxShadowDrawable;
    private WXSDKInstance mInstance;
    public boolean mIsAddElementToTree;
    private boolean mIsDestroyed;
    private boolean mIsDisabled;
    private String mLastBoxShadowId;
    private boolean mLazy;
    private boolean mNeedLayoutOnAnimation;
    private volatile WXVContainer mParent;
    private ConcurrentLinkedQueue<UniMethodData> mPendingComponetMethodQueue;
    private PesudoStatus mPesudoStatus;
    private int mPreRealHeight;
    private int mPreRealLeft;
    private int mPreRealRight;
    private int mPreRealTop;
    private int mPreRealWidth;
    private GraphicSize mPseudoResetGraphicSize;
    private Drawable mRippleBackground;
    private int mStickyOffset;
    public WXTracing.TraceInfo mTraceInfo;
    private WXTransition mTransition;
    private int mType;
    private String mViewTreeKey;
    private boolean waste;

    public static class MeasureOutput {
        public int height;
        public int width;
    }

    public interface OnClickListener {
        void onHostViewClick();
    }

    public interface OnFocusChangeListener {
        void onFocusChange(boolean z);
    }

    @Target({ElementType.PARAMETER})
    @Retention(RetentionPolicy.SOURCE)
    public @interface RenderState {
    }

    @Deprecated
    public WXComponent(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    @Deprecated
    public WXComponent(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        this(instance, parent, 0, basicComponentData);
    }

    public WXComponent(WXSDKInstance instance, WXVContainer parent, int type, BasicComponentData basicComponentData) {
        super(basicComponentData);
        this.mFixedProp = 0;
        this.mAbsoluteY = 0;
        this.mAbsoluteX = 0;
        this.isLastLayoutDirectionRTL = false;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealTop = 0;
        this.mStickyOffset = 0;
        this.isUsing = false;
        this.mIsDestroyed = false;
        this.mIsDisabled = false;
        this.mType = 0;
        this.mNeedLayoutOnAnimation = false;
        this.mDeepInComponentTree = 0;
        this.mIsAddElementToTree = false;
        this.interactionAbsoluteX = 0;
        this.interactionAbsoluteY = 0;
        this.mHasAddFocusListener = false;
        this.mTraceInfo = new WXTracing.TraceInfo();
        this.waste = false;
        this.isIgnoreInteraction = false;
        this.mPendingComponetMethodQueue = new ConcurrentLinkedQueue<>();
        this.PRESSED_ANIM_DURATION = 100;
        this.PRESSED_ANIM_DELAY = 100;
        this.ENABLED_STATE_SET = new int[]{16842910};
        this.EMPTY_STATE_SET = new int[0];
        this.PRESSED_ENABLED_STATE_SET = new int[]{16842919, 16842910};
        this.FOCUSED_ENABLED_STATE_SET = new int[]{16842908, 16842910};
        this.mElevation = 0.0f;
        this.mLazy = false;
        this.isPreventGesture = false;
        this.mInstance = instance;
        this.mContext = instance.getContext();
        this.mParent = parent;
        this.mType = type;
        if (instance != null) {
            setViewPortWidth(instance.getInstanceViewPortWidthWithFloat());
        }
        onCreate();
        ComponentObserver observer = getInstance().getComponentObserver();
        if (observer != null) {
            observer.onCreate(this);
        }
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public final void bindComponent(AbsBasicComponent component) {
        super.bindComponent(component);
        if (getInstance() != null) {
            setViewPortWidth(getInstance().getInstanceViewPortWidthWithFloat());
        }
        WXComponent ct = (WXComponent) component;
        this.mParent = ct.getParent();
        this.mType = ct.getType();
    }

    /* access modifiers changed from: protected */
    public void setContentBoxMeasurement(ContentBoxMeasurement contentBoxMeasurement2) {
        this.contentBoxMeasurement = contentBoxMeasurement2;
        this.mInstance.addContentBoxMeasurement(getRenderObjectPtr(), contentBoxMeasurement2);
        WXBridgeManager.getInstance().bindMeasurementToRenderObject(getRenderObjectPtr());
    }

    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        lp.setMargins(left, top, right, bottom);
        if (lp instanceof FrameLayout.LayoutParams) {
            ((FrameLayout.LayoutParams) lp).gravity = 51;
        }
    }

    public void updateStyles(WXComponent component) {
        if (component != null) {
            updateProperties(component.getStyles());
            applyBorder(component);
        }
    }

    public void updateStyles(Map<String, Object> styles) {
        if (styles != null) {
            updateProperties(styles);
            applyBorder(this);
        }
    }

    public void updateAttrs(AbsBasicComponent component) {
        if (component != null) {
            updateProperties(component.getAttrs());
        }
    }

    public void updateAttrs(Map<String, Object> attrs) {
        if (attrs != null) {
            updateProperties(attrs);
        }
    }

    private void applyBorder(AbsBasicComponent component) {
        AbsCSSShorthand border = component.getBorder();
        float left = border.get(CSSShorthand.EDGE.LEFT);
        float top = border.get(CSSShorthand.EDGE.TOP);
        float right = border.get(CSSShorthand.EDGE.RIGHT);
        float bottom = border.get(CSSShorthand.EDGE.BOTTOM);
        if (this.mHost != null) {
            setBorderWidth(Constants.Name.BORDER_LEFT_WIDTH, left);
            setBorderWidth(Constants.Name.BORDER_TOP_WIDTH, top);
            setBorderWidth(Constants.Name.BORDER_RIGHT_WIDTH, right);
            setBorderWidth(Constants.Name.BORDER_BOTTOM_WIDTH, bottom);
        }
    }

    public void setPadding(AbsCSSShorthand padding, AbsCSSShorthand border) {
        int left = (int) (padding.get(CSSShorthand.EDGE.LEFT) + border.get(CSSShorthand.EDGE.LEFT));
        int top = (int) (padding.get(CSSShorthand.EDGE.TOP) + border.get(CSSShorthand.EDGE.TOP));
        int right = (int) (padding.get(CSSShorthand.EDGE.RIGHT) + border.get(CSSShorthand.EDGE.RIGHT));
        int bottom = (int) (padding.get(CSSShorthand.EDGE.BOTTOM) + border.get(CSSShorthand.EDGE.BOTTOM));
        if ((this instanceof FlatComponent) && !((FlatComponent) this).promoteToView(true)) {
            ((FlatComponent) this).getOrCreateFlatWidget().setContentBox(left, top, right, bottom);
        } else if (this.mHost != null) {
            UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
            if (uniBoxShadowData != null) {
                if (uniBoxShadowData.getNormalLeft() > 0) {
                    int offset = this.mBoxShadowData.getNormalLeft() / 2;
                    left += offset;
                    right += offset;
                }
                if (this.mBoxShadowData.getNormalTop() > 0) {
                    int offset2 = this.mBoxShadowData.getNormalTop() / 2;
                    top += offset2;
                    bottom += offset2;
                }
            }
            this.mHost.setPadding(left, top, right, bottom);
        }
    }

    public void applyComponentEvents() {
        applyEvents();
    }

    private void applyEvents() {
        if (getEvents() != null && !getEvents().isEmpty()) {
            WXEvent event = getEvents();
            int size = event.size();
            int i = 0;
            while (i < size && i < event.size()) {
                addEvent((String) event.get(i));
                i++;
            }
            setActiveTouchListener();
        }
    }

    public void addEvent(String type) {
        if (this.mAppendEvents == null) {
            this.mAppendEvents = new HashSet();
        }
        if (!TextUtils.isEmpty(type) && !this.mAppendEvents.contains(type)) {
            View view = getRealView();
            if (type.equals(Constants.Event.LAYEROVERFLOW)) {
                addLayerOverFlowListener(getRef());
            }
            if (type.equals(Constants.Event.CLICK)) {
                if (view != null) {
                    if (this.mClickEventListener == null) {
                        this.mClickEventListener = new OnClickListenerImp();
                    }
                    addClickListener(this.mClickEventListener);
                } else {
                    return;
                }
            } else if (type.equals(Constants.Event.FOCUS) || type.equals(Constants.Event.BLUR)) {
                if (!this.mHasAddFocusListener) {
                    this.mHasAddFocusListener = true;
                    addFocusChangeListener(new OnFocusChangeListener() {
                        /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass1 */

                        @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
                        public void onFocusChange(boolean hasFocus) {
                            Map<String, Object> params = new HashMap<>();
                            params.put("timeStamp", Long.valueOf(System.currentTimeMillis()));
                            WXComponent.this.fireEvent(hasFocus ? Constants.Event.FOCUS : Constants.Event.BLUR, params);
                        }
                    });
                }
            } else if (!needGestureDetector(type)) {
                Scrollable scroller = getParentScroller();
                if (scroller != null) {
                    if (type.equals(Constants.Event.APPEAR)) {
                        scroller.bindAppearEvent(this);
                    } else if (type.equals(Constants.Event.DISAPPEAR)) {
                        scroller.bindDisappearEvent(this);
                    }
                } else {
                    return;
                }
            } else if (view != null) {
                if (view instanceof WXGestureObservable) {
                    if (this.mGesture == null) {
                        this.mGesture = new WXGesture(this, this.mContext);
                        this.mGesture.setPreventMoveEvent(WXUtils.getBoolean(getAttrs().get(Constants.Name.PREVENT_MOVE_EVENT), false).booleanValue());
                    }
                    if (this.mGestureType == null) {
                        this.mGestureType = new HashSet();
                    }
                    if (!ViewHover.VIEW_HOVER_EVENT.equals(type)) {
                        this.mGestureType.add(type);
                    }
                    ((WXGestureObservable) view).registerGestureListener(this.mGesture);
                } else {
                    WXLogUtils.e(view.getClass().getSimpleName() + " don't implement WXGestureObservable, so no gesture is supported.");
                }
            } else {
                return;
            }
            this.mAppendEvents.add(type);
        }
    }

    public void interceptFocusAndBlurEvent() {
        this.mHasAddFocusListener = true;
    }

    /* access modifiers changed from: protected */
    public void onCreate() {
    }

    public void bindHolder(IFComponentHolder holder) {
        this.mHolder = holder;
    }

    public WXSDKInstance getInstance() {
        return this.mInstance;
    }

    public Context getContext() {
        return this.mContext;
    }

    /* access modifiers changed from: protected */
    public final WXComponent findComponent(String ref) {
        if (this.mInstance == null || ref == null) {
            return null;
        }
        return WXSDKManager.getInstance().getWXRenderManager().getWXComponent(this.mInstance.getInstanceId(), ref);
    }

    public String getAttrByKey(String key) {
        return "default";
    }

    public void postAnimation(AbsAnimationHolder holder) {
        this.mAnimationHolder = holder;
    }

    public boolean isFlatUIEnabled() {
        return this.mParent != null && this.mParent.isFlatUIEnabled();
    }

    /* access modifiers changed from: private */
    public class OnClickListenerImp implements OnClickListener {
        private OnClickListenerImp() {
        }

        @Override // com.taobao.weex.ui.component.WXComponent.OnClickListener
        public void onHostViewClick() {
            Map<String, Object> param = WXDataStructureUtil.newHashMapWithExpectedSize(1);
            Map<String, Object> position = WXDataStructureUtil.newHashMapWithExpectedSize(4);
            int[] location = new int[2];
            WXComponent.this.mHost.getLocationOnScreen(location);
            position.put(Constants.Name.X, Float.valueOf(WXViewUtils.getWebPxByWidth((float) location[0], WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            position.put(Constants.Name.Y, Float.valueOf(WXViewUtils.getWebPxByWidth((float) location[1], WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            position.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth(WXComponent.this.getLayoutWidth(), WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            position.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth(WXComponent.this.getLayoutHeight(), WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            param.put("position", position);
            WXComponent.this.fireEvent(Constants.Event.CLICK, param);
        }
    }

    public String getInstanceId() {
        return this.mInstance.getInstanceId();
    }

    public Rect getComponentSize() {
        Rect size = new Rect();
        if (!(this.mHost == null || this.mInstance.getContainerView() == null)) {
            int[] location = new int[2];
            int[] anchor = new int[2];
            this.mHost.getLocationOnScreen(location);
            this.mInstance.getContainerView().getLocationOnScreen(anchor);
            int left = location[0] - anchor[0];
            int top = (location[1] - this.mStickyOffset) - anchor[1];
            size.set(left, top, left + ((int) getLayoutWidth()), top + ((int) getLayoutHeight()));
        }
        return size;
    }

    public final void invoke(String method, JSONArray args) {
        if (getHostView() == null || getRealView() == null) {
            this.mPendingComponetMethodQueue.offer(new UniMethodData(method, args));
            return;
        }
        Invoker invoker = this.mHolder.getMethodInvoker(method);
        if (invoker != null) {
            try {
                getInstance().getNativeInvokeHelper().invoke(this, invoker, args);
            } catch (Exception e) {
                WXLogUtils.e("[WXComponent] updateProperties :class:" + getClass() + "method:" + invoker.toString() + " function " + WXLogUtils.getStackTrace(e));
            }
        } else {
            onInvokeUnknownMethod(method, args);
        }
    }

    /* access modifiers changed from: protected */
    public void onInvokeUnknownMethod(String method, JSONArray args) {
    }

    public final void fireEvent(String type) {
        fireEvent(type, null);
    }

    public final void fireEvent(String type, Map<String, Object> params) {
        if (WXUtils.getBoolean(getAttrs().get("fireEventSyn"), false).booleanValue()) {
            fireEventWait(type, params);
        } else {
            fireEvent(type, params, null, null);
        }
    }

    public final EventResult fireEventWait(String type, Map<String, Object> params) {
        final CountDownLatch waitLatch = new CountDownLatch(1);
        EventResult callback = new EventResult() {
            /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass2 */

            @Override // com.taobao.weex.bridge.EventResult
            public void onCallback(Object result) {
                super.onCallback(result);
                waitLatch.countDown();
            }
        };
        try {
            fireEvent(type, params, null, callback);
            waitLatch.await(50, TimeUnit.MILLISECONDS);
            return callback;
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("fireEventWait", e);
            }
            return callback;
        }
    }

    /* access modifiers changed from: protected */
    public final void fireEvent(String type, Map<String, Object> params, Map<String, Object> domChanges) {
        fireEvent(type, params, domChanges, null);
    }

    private final void fireEvent(String type, Map<String, Object> params, Map<String, Object> domChanges, EventResult callback) {
        String componentId;
        if (this.mInstance != null) {
            List<Object> eventArgsValues = null;
            if (!(getEvents() == null || getEvents().getEventBindingArgsValues() == null)) {
                eventArgsValues = getEvents().getEventBindingArgsValues().get(type);
            }
            if (!(params == null || (componentId = Statements.getComponentId(this)) == null)) {
                params.put("componentId", componentId);
            }
            this.mInstance.fireEvent(getRef(), type, params, domChanges, eventArgsValues, callback);
        }
    }

    public Object findTypeParent(AbsBasicComponent component, Class type) {
        if (component.getClass() == type) {
            return component;
        }
        WXComponent ct = (WXComponent) component;
        if (ct.getParent() == null) {
            return null;
        }
        findTypeParent(ct.getParent(), type);
        return null;
    }

    public boolean isLazy() {
        if (this.mLazy) {
            return true;
        }
        if (this.mParent == null || !this.mParent.isLazy()) {
            return false;
        }
        return true;
    }

    /* access modifiers changed from: protected */
    public final void addFocusChangeListener(OnFocusChangeListener l) {
        View view;
        if (l != null && (view = getRealView()) != null) {
            if (this.mFocusChangeListeners == null) {
                this.mFocusChangeListeners = new ArrayList();
                view.setFocusable(true);
                view.setOnFocusChangeListener(new View.OnFocusChangeListener() {
                    /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass3 */

                    public void onFocusChange(View v, boolean hasFocus) {
                        for (OnFocusChangeListener listener : WXComponent.this.mFocusChangeListeners) {
                            if (listener != null) {
                                listener.onFocusChange(hasFocus);
                            }
                        }
                    }
                });
            }
            this.mFocusChangeListeners.add(l);
        }
    }

    /* access modifiers changed from: protected */
    public boolean ismHasFocusChangeListener(OnFocusChangeListener l) {
        List<OnFocusChangeListener> list = this.mFocusChangeListeners;
        if (list != null) {
            return list.contains(l);
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public final void addClickListener(OnClickListener l) {
        View view;
        if (l != null && (view = getRealView()) != null) {
            if (this.mHostClickListeners == null) {
                this.mHostClickListeners = new ArrayList();
            }
            if (!view.hasOnClickListeners()) {
                view.setClickable(true);
                view.setOnClickListener(new View.OnClickListener() {
                    /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass4 */

                    public void onClick(View v) {
                        if (WXComponent.this.mGesture == null || !WXComponent.this.mGesture.isTouchEventConsumedByAdvancedGesture()) {
                            for (OnClickListener listener : WXComponent.this.mHostClickListeners) {
                                if (listener != null) {
                                    listener.onHostViewClick();
                                }
                            }
                        }
                    }
                });
            }
            this.mHostClickListeners.add(l);
        }
    }

    /* access modifiers changed from: protected */
    public final void removeClickListener(OnClickListener l) {
        this.mHostClickListeners.remove(l);
    }

    public void bindData(WXComponent component) {
        bindComponentData(component);
    }

    /* access modifiers changed from: protected */
    public void bindComponentData(AbsBasicComponent component) {
        if (!isLazy()) {
            if (component == null) {
                component = this;
            }
            WXComponent ct = (WXComponent) component;
            bindComponent(ct);
            updateStyles(ct);
            updateAttrs(component);
            updateExtra(component.getExtra());
        }
    }

    public void applyLayoutAndEvent(AbsBasicComponent component) {
        if (!isLazy()) {
            if (component == null) {
                component = this;
            }
            WXComponent ct = (WXComponent) component;
            bindComponent(ct);
            setSafeLayout(ct);
            setPadding(component.getPadding(), component.getBorder());
            applyEvents();
        }
    }

    public void setDemission(GraphicSize size, GraphicPosition position) {
        setLayoutPosition(position);
        setLayoutSize(size);
    }

    public void updateDemission(float top, float bottom, float left, float right, float height, float width) {
        getLayoutPosition().update(top, bottom, left, right);
        getLayoutSize().update(width, height);
    }

    public void applyLayoutOnly() {
        if (!isLazy()) {
            setSafeLayout(this);
            setPadding(getPadding(), getBorder());
        }
    }

    public void refreshData(WXComponent component) {
    }

    @Deprecated
    public void updateProperties(Map<String, Object> props) {
        if (props == null) {
            return;
        }
        if ((this.mHost != null || isVirtualComponent()) && getInstance() != null) {
            for (Map.Entry<String, Object> entry : props.entrySet()) {
                String key = entry.getKey();
                Object param = entry.getValue();
                String value = WXUtils.getString(param, null);
                if (key == null) {
                    WXExceptionUtils.commitCriticalExceptionRT(getInstanceId(), WXErrorCode.WX_RENDER_ERR_NULL_KEY, "updateProperties", WXErrorCode.WX_RENDER_ERR_NULL_KEY.getErrorMsg(), null);
                } else {
                    if (TextUtils.isEmpty(value)) {
                        param = convertEmptyProperty(key, value);
                    }
                    if (setProperty(key, param)) {
                        continue;
                    } else if (this.mHolder != null && getInstance() != null) {
                        Invoker invoker = this.mHolder.getPropertyInvoker(key);
                        if (invoker != null) {
                            try {
                                Type[] paramClazzs = invoker.getParameterTypes();
                                if (paramClazzs.length != 1) {
                                    WXLogUtils.e("[WXComponent] setX method only one parameter：" + invoker);
                                    return;
                                }
                                invoker.invoke(this, WXReflectionUtils.parseArgument(paramClazzs[0], param));
                            } catch (Exception e) {
                                WXLogUtils.e("[WXComponent] updateProperties :class:" + getClass() + "method:" + invoker.toString() + " function " + WXLogUtils.getStackTrace(e));
                            }
                        } else {
                            continue;
                        }
                    } else {
                        return;
                    }
                }
            }
            readyToRender();
            if ((this instanceof FlatComponent) && this.mBackgroundDrawable != null) {
                FlatComponent flatComponent = (FlatComponent) this;
                if (!(flatComponent.promoteToView(true) || (flatComponent.getOrCreateFlatWidget() instanceof AndroidViewWidget))) {
                    flatComponent.getOrCreateFlatWidget().setBackgroundAndBorder(this.mBackgroundDrawable);
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public boolean setProperty(String key, Object param) {
        if (key == null || getInstance() == null) {
            return true;
        }
        char c = 65535;
        switch (key.hashCode()) {
            case -1989576717:
                if (key.equals(Constants.Name.BORDER_RIGHT_COLOR)) {
                    c = 18;
                    break;
                }
                break;
            case -1974639039:
                if (key.equals(Constants.Name.BORDER_RIGHT_STYLE)) {
                    c = '\f';
                    break;
                }
                break;
            case -1971292586:
                if (key.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                    c = '1';
                    break;
                }
                break;
            case -1501175880:
                if (key.equals(Constants.Name.PADDING_LEFT)) {
                    c = Operators.ARRAY_SEPRATOR;
                    break;
                }
                break;
            case -1470826662:
                if (key.equals(Constants.Name.BORDER_TOP_COLOR)) {
                    c = 17;
                    break;
                }
                break;
            case -1455888984:
                if (key.equals(Constants.Name.BORDER_TOP_STYLE)) {
                    c = 15;
                    break;
                }
                break;
            case -1452542531:
                if (key.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                    c = '0';
                    break;
                }
                break;
            case -1383228885:
                if (key.equals("bottom")) {
                    c = '7';
                    break;
                }
                break;
            case -1375815020:
                if (key.equals(Constants.Name.MIN_WIDTH)) {
                    c = JSONLexer.EOI;
                    break;
                }
                break;
            case -1308858324:
                if (key.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                    c = 19;
                    break;
                }
                break;
            case -1293920646:
                if (key.equals(Constants.Name.BORDER_BOTTOM_STYLE)) {
                    c = '\r';
                    break;
                }
                break;
            case -1290574193:
                if (key.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                    c = '2';
                    break;
                }
                break;
            case -1267206133:
                if (key.equals("opacity")) {
                    c = 5;
                    break;
                }
                break;
            case -1228066334:
                if (key.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                    c = 7;
                    break;
                }
                break;
            case -1221029593:
                if (key.equals("height")) {
                    c = 28;
                    break;
                }
                break;
            case -1111969773:
                if (key.equals(Constants.Name.ARIA_HIDDEN)) {
                    c = 24;
                    break;
                }
                break;
            case -1081309778:
                if (key.equals("margin")) {
                    c = WXUtils.PERCENT;
                    break;
                }
                break;
            case -1063257157:
                if (key.equals(Constants.Name.ALIGN_ITEMS)) {
                    c = 31;
                    break;
                }
                break;
            case -1044792121:
                if (key.equals(Constants.Name.MARGIN_TOP)) {
                    c = '&';
                    break;
                }
                break;
            case -975171706:
                if (key.equals(Constants.Name.FLEX_DIRECTION)) {
                    c = Operators.QUOTE;
                    break;
                }
                break;
            case -906066005:
                if (key.equals(Constants.Name.MAX_HEIGHT)) {
                    c = 30;
                    break;
                }
                break;
            case -863700117:
                if (key.equals(Constants.Name.ARIA_LABEL)) {
                    c = 23;
                    break;
                }
                break;
            case -806339567:
                if (key.equals("padding")) {
                    c = '*';
                    break;
                }
                break;
            case -289173127:
                if (key.equals(Constants.Name.MARGIN_BOTTOM)) {
                    c = Operators.BRACKET_END;
                    break;
                }
                break;
            case -242276144:
                if (key.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                    c = 20;
                    break;
                }
                break;
            case -227338466:
                if (key.equals(Constants.Name.BORDER_LEFT_STYLE)) {
                    c = 14;
                    break;
                }
                break;
            case -223992013:
                if (key.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                    c = '3';
                    break;
                }
                break;
            case -133587431:
                if (key.equals(Constants.Name.MIN_HEIGHT)) {
                    c = 29;
                    break;
                }
                break;
            case 115029:
                if (key.equals("top")) {
                    c = '5';
                    break;
                }
                break;
            case 3145721:
                if (key.equals(Constants.Name.FLEX)) {
                    c = '!';
                    break;
                }
                break;
            case 3317767:
                if (key.equals("left")) {
                    c = '4';
                    break;
                }
                break;
            case 3506294:
                if (key.equals(Constants.Name.ROLE)) {
                    c = '9';
                    break;
                }
                break;
            case 90130308:
                if (key.equals(Constants.Name.PADDING_TOP)) {
                    c = '+';
                    break;
                }
                break;
            case 108511772:
                if (key.equals("right")) {
                    c = '6';
                    break;
                }
                break;
            case 113126854:
                if (key.equals("width")) {
                    c = 25;
                    break;
                }
                break;
            case 202355100:
                if (key.equals(Constants.Name.PADDING_BOTTOM)) {
                    c = Operators.DOT;
                    break;
                }
                break;
            case 270940796:
                if (key.equals(Constants.Name.DISABLED)) {
                    c = 1;
                    break;
                }
                break;
            case 333432965:
                if (key.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                    c = '\b';
                    break;
                }
                break;
            case 400381634:
                if (key.equals(Constants.Name.MAX_WIDTH)) {
                    c = 27;
                    break;
                }
                break;
            case 581268560:
                if (key.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                    c = '\n';
                    break;
                }
                break;
            case 588239831:
                if (key.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                    c = '\t';
                    break;
                }
                break;
            case 713848971:
                if (key.equals(Constants.Name.PADDING_RIGHT)) {
                    c = '-';
                    break;
                }
                break;
            case 717381201:
                if (key.equals(Constants.Name.PREVENT_MOVE_EVENT)) {
                    c = 0;
                    break;
                }
                break;
            case 722830999:
                if (key.equals(Constants.Name.BORDER_COLOR)) {
                    c = 16;
                    break;
                }
                break;
            case 737768677:
                if (key.equals(Constants.Name.BORDER_STYLE)) {
                    c = 11;
                    break;
                }
                break;
            case 741115130:
                if (key.equals(Constants.Name.BORDER_WIDTH)) {
                    c = '/';
                    break;
                }
                break;
            case 743055051:
                if (key.equals(Constants.Name.BOX_SHADOW)) {
                    c = '8';
                    break;
                }
                break;
            case 747463061:
                if (key.equals(PROP_FIXED_SIZE)) {
                    c = 22;
                    break;
                }
                break;
            case 747804969:
                if (key.equals("position")) {
                    c = 2;
                    break;
                }
                break;
            case 975087886:
                if (key.equals(Constants.Name.MARGIN_RIGHT)) {
                    c = Operators.BRACKET_START;
                    break;
                }
                break;
            case 1287124693:
                if (key.equals("backgroundColor")) {
                    c = 3;
                    break;
                }
                break;
            case 1292595405:
                if (key.equals(Constants.Name.BACKGROUND_IMAGE)) {
                    c = 4;
                    break;
                }
                break;
            case 1349188574:
                if (key.equals(Constants.Name.BORDER_RADIUS)) {
                    c = 6;
                    break;
                }
                break;
            case 1744216035:
                if (key.equals(Constants.Name.FLEX_WRAP)) {
                    c = Operators.DOLLAR;
                    break;
                }
                break;
            case 1767100401:
                if (key.equals(Constants.Name.ALIGN_SELF)) {
                    c = ' ';
                    break;
                }
                break;
            case 1860657097:
                if (key.equals(Constants.Name.JUSTIFY_CONTENT)) {
                    c = '#';
                    break;
                }
                break;
            case 1941332754:
                if (key.equals(Constants.Name.VISIBILITY)) {
                    c = 21;
                    break;
                }
                break;
            case 1970934485:
                if (key.equals(Constants.Name.MARGIN_LEFT)) {
                    c = Operators.SINGLE_QUOTE;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                WXGesture wXGesture = this.mGesture;
                if (wXGesture != null) {
                    wXGesture.setPreventMoveEvent(WXUtils.getBoolean(param, false).booleanValue());
                }
                return true;
            case 1:
                Boolean disabled = WXUtils.getBoolean(param, null);
                if (disabled != null) {
                    setDisabled(disabled.booleanValue());
                    setPseudoClassStatus(Constants.PSEUDO.DISABLED, disabled.booleanValue());
                }
                return true;
            case 2:
                String position = WXUtils.getString(param, null);
                if (position != null) {
                    setSticky(position);
                }
                return true;
            case 3:
                String bgColor = WXUtils.getString(param, null);
                if (bgColor != null) {
                    setBackgroundColor(bgColor);
                }
                return true;
            case 4:
                String bgImage = WXUtils.getString(param, null);
                if (!(bgImage == null || this.mHost == null)) {
                    setBackgroundImage(bgImage);
                }
                return true;
            case 5:
                Float opacity = WXUtils.getFloat(param, Float.valueOf(1.0f));
                if (opacity != null) {
                    setOpacity(opacity.floatValue());
                }
                return true;
            case 6:
            case 7:
            case '\b':
            case '\t':
            case '\n':
                Float radius = WXUtils.getFloat(param, null);
                if (radius != null) {
                    setBorderRadius(key, radius.floatValue());
                }
                return true;
            case 11:
            case '\f':
            case '\r':
            case 14:
            case 15:
                String border_style = WXUtils.getString(param, null);
                if (border_style != null) {
                    setBorderStyle(key, border_style);
                }
                return true;
            case 16:
            case 17:
            case 18:
            case 19:
            case 20:
                String border_color = WXUtils.getString(param, null);
                if (border_color != null) {
                    setBorderColor(key, border_color);
                }
                return true;
            case 21:
                String visibility = WXUtils.getString(param, null);
                if (visibility != null) {
                    setVisibility(visibility);
                }
                return true;
            case 22:
                setFixedSize(WXUtils.getString(param, PROP_FS_MATCH_PARENT));
                return true;
            case 23:
                setAriaLabel(WXUtils.getString(param, ""));
                return true;
            case 24:
                setAriaHidden(WXUtils.getBoolean(param, false).booleanValue());
                return true;
            case 25:
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case ' ':
            case '!':
            case '\"':
            case '#':
            case '$':
            case '%':
            case '&':
            case '\'':
            case '(':
            case ')':
            case '*':
            case '+':
            case ',':
            case '-':
            case '.':
            case '/':
            case '0':
            case '1':
            case '2':
            case '3':
            case '4':
            case '5':
            case '6':
            case '7':
                return true;
            case '8':
                try {
                    getHostView();
                } catch (Throwable t) {
                    t.printStackTrace();
                }
                return true;
            case '9':
                setRole(WXUtils.getString(param, ""));
                return true;
            default:
                return false;
        }
    }

    @WXComponentProp(name = Constants.Name.ELEVATION)
    public void setElevation(String str) {
        initElevation(str);
    }

    /* access modifiers changed from: protected */
    public void initElevation(String str) {
        if (!TextUtils.isEmpty(str) && Build.VERSION.SDK_INT > 20) {
            this.mElevation = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(str, Float.valueOf(0.0f)).floatValue(), this.mInstance.getInstanceViewPortWidthWithFloat());
            if (this.mBoxShadowData != null) {
                clearBoxShadow();
            }
            if (Build.VERSION.SDK_INT == 21) {
                getHostView().setElevation(this.mElevation);
                return;
            }
            StateListAnimator stateListAnimator = new StateListAnimator();
            AnimatorSet set = new AnimatorSet();
            set.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
            set.setInterpolator(new FastOutLinearInInterpolator());
            stateListAnimator.addState(this.PRESSED_ENABLED_STATE_SET, set);
            AnimatorSet set2 = new AnimatorSet();
            set2.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
            set2.setInterpolator(new FastOutLinearInInterpolator());
            stateListAnimator.addState(this.FOCUSED_ENABLED_STATE_SET, set2);
            AnimatorSet set3 = new AnimatorSet();
            List<Animator> animators = new ArrayList<>();
            animators.add(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L));
            if (Build.VERSION.SDK_INT >= 22 && Build.VERSION.SDK_INT <= 24) {
                animators.add(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, getHostView().getTranslationZ()).setDuration(this.PRESSED_ANIM_DELAY));
            }
            animators.add(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
            set3.playSequentially((Animator[]) animators.toArray(new ObjectAnimator[0]));
            set3.setInterpolator(new FastOutLinearInInterpolator());
            stateListAnimator.addState(this.ENABLED_STATE_SET, set3);
            AnimatorSet set4 = new AnimatorSet();
            set4.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, 0.0f).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(0L));
            set4.setInterpolator(new FastOutLinearInInterpolator());
            stateListAnimator.addState(this.EMPTY_STATE_SET, set4);
            getHostView().setStateListAnimator(stateListAnimator);
        }
    }

    /* access modifiers changed from: protected */
    public BorderDrawable getOrCreateBorder() {
        if (this.mBackgroundDrawable == null) {
            this.mBackgroundDrawable = new BorderDrawable();
            T t = this.mHost;
            if (t != null) {
                WXViewUtils.setBackGround(t, null, this);
                if (this.mRippleBackground == null) {
                    if (this.mBoxShadowDrawable != null) {
                        WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mBoxShadowDrawable, this.mBackgroundDrawable}), this);
                    } else if (this.mInsetBoxShadowDrawable != null) {
                        WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mBackgroundDrawable, this.mInsetBoxShadowDrawable}), this);
                    } else {
                        WXViewUtils.setBackGround(this.mHost, this.mBackgroundDrawable, this);
                    }
                } else if (this.mBoxShadowDrawable != null) {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBoxShadowDrawable, this.mBackgroundDrawable}), this);
                } else if (this.mInsetBoxShadowDrawable != null) {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable}), this);
                } else {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable}), this);
                }
            }
        }
        return this.mBackgroundDrawable;
    }

    public void setSafeLayout(WXComponent component) {
        if (!TextUtils.isEmpty(component.getComponentType()) && !TextUtils.isEmpty(component.getRef()) && component.getLayoutPosition() != null && component.getLayoutSize() != null) {
            setLayout(component);
        }
    }

    public void setLayout(WXComponent component) {
        int realLeft;
        int realTop;
        setLayoutSize(component.getLayoutSize());
        setLayoutPosition(component.getLayoutPosition());
        setPaddings(component.getPadding());
        setMargins(component.getMargin());
        setBorders(component.getBorder());
        boolean isRTL = component.isLayoutRTL();
        setIsLayoutRTL(isRTL);
        if (isRTL != component.isLastLayoutDirectionRTL) {
            component.isLastLayoutDirectionRTL = isRTL;
            layoutDirectionDidChanged(isRTL);
        }
        try {
            if (!(getLayoutSize().getWidth() == 0.0f || getLayoutSize().getHeight() == 0.0f)) {
                parseAnimation();
            }
        } catch (Exception e) {
        }
        int siblingOffset = 0;
        boolean nullParent = this.mParent == null;
        if (!nullParent) {
            siblingOffset = this.mParent.getChildrenLayoutTopOffset();
        }
        CSSShorthand parentPadding = nullParent ? new CSSShorthand() : this.mParent.getPadding();
        CSSShorthand parentBorder = nullParent ? new CSSShorthand() : this.mParent.getBorder();
        int realWidth = (int) getLayoutSize().getWidth();
        int realHeight = (int) getLayoutSize().getHeight();
        if (isFixed()) {
            realLeft = (int) (getLayoutPosition().getLeft() - ((float) getInstance().getRenderContainerPaddingLeft()));
            realTop = ((int) (getLayoutPosition().getTop() - ((float) getInstance().getRenderContainerPaddingTop()))) + siblingOffset;
        } else {
            realLeft = (int) ((getLayoutPosition().getLeft() - parentPadding.get(CSSShorthand.EDGE.LEFT)) - parentBorder.get(CSSShorthand.EDGE.LEFT));
            realTop = ((int) ((getLayoutPosition().getTop() - parentPadding.get(CSSShorthand.EDGE.TOP)) - parentBorder.get(CSSShorthand.EDGE.TOP))) + siblingOffset;
        }
        int realRight = (int) getMargin().get(CSSShorthand.EDGE.RIGHT);
        int realBottom = (int) getMargin().get(CSSShorthand.EDGE.BOTTOM);
        Point rawOffset = new Point((int) getLayoutPosition().getLeft(), (int) getLayoutPosition().getTop());
        if (this.mPreRealWidth != realWidth || this.mPreRealHeight != realHeight || this.mPreRealLeft != realLeft || this.mPreRealRight != realRight || this.mPreRealTop != realTop) {
            if ((this instanceof WXCell) && realHeight >= WXPerformance.VIEW_LIMIT_HEIGHT && realWidth >= WXPerformance.VIEW_LIMIT_WIDTH) {
                this.mInstance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_CELL_EXCEED_NUM, 1.0d);
                this.mInstance.getWXPerformance().cellExceedNum++;
            }
            this.mAbsoluteY = (int) (nullParent ? 0.0f : ((float) this.mParent.getAbsoluteY()) + getCSSLayoutTop());
            this.mAbsoluteX = (int) (nullParent ? 0.0f : ((float) this.mParent.getAbsoluteX()) + getCSSLayoutLeft());
            T t = this.mHost;
            if (t != null) {
                if (!(t instanceof ViewGroup) && this.mAbsoluteY + realHeight > this.mInstance.getWeexHeight() + 1) {
                    if (!this.mInstance.mEnd) {
                        this.mInstance.onOldFsRenderTimeLogic();
                    }
                    if (!this.mInstance.isNewFsEnd) {
                        this.mInstance.isNewFsEnd = true;
                        this.mInstance.getApmForInstance().arriveNewFsRenderTime();
                    }
                }
                MeasureOutput measureOutput = measure(realWidth, realHeight);
                setComponentLayoutParams(measureOutput.width, measureOutput.height, realLeft, realTop, realRight, realBottom, rawOffset);
            }
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    private void setComponentLayoutParams(int realWidth, int realHeight, int realLeft, int realTop, int realRight, int realBottom, Point rawOffset) {
        int top;
        int left;
        int height;
        int width;
        Widget widget;
        if (getInstance() == null) {
            return;
        }
        if (!getInstance().isDestroy()) {
            updateBoxShadow(realWidth, realHeight, false);
            UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
            if (uniBoxShadowData == null || uniBoxShadowData.getNormalShadows().size() <= 0) {
                width = realWidth;
                height = realHeight;
                left = realLeft;
                top = realTop;
            } else {
                int width2 = this.mBoxShadowData.getNormalMaxWidth();
                int height2 = this.mBoxShadowData.getNormalMaxHeight();
                width = width2;
                height = height2;
                left = realLeft - (this.mBoxShadowData.getNormalLeft() / 2);
                top = realTop - (this.mBoxShadowData.getNormalTop() / 2);
            }
            FlatGUIContext UIImp = getInstance().getFlatUIContext();
            if (UIImp != null) {
                if (UIImp.getFlatComponentAncestor(this) != null) {
                    if (!(this instanceof FlatComponent) || ((FlatComponent) this).promoteToView(true)) {
                        widget = UIImp.getAndroidViewWidget(this);
                    } else {
                        widget = ((FlatComponent) this).getOrCreateFlatWidget();
                    }
                    setWidgetParams(widget, UIImp, rawOffset, width, height, left, realRight, top, realBottom);
                    return;
                }
            }
            if (this.mHost != null) {
                if (isFixed()) {
                    setFixedHostLayoutParams(this.mHost, width, height, left, realRight, top, realBottom);
                } else {
                    setHostLayoutParams(this.mHost, width, height, left, realRight, top, realBottom);
                }
                recordInteraction(realWidth, realHeight);
                this.mPreRealWidth = realWidth;
                this.mPreRealHeight = realHeight;
                this.mPreRealLeft = realLeft;
                this.mPreRealRight = realRight;
                this.mPreRealTop = realTop;
                onFinishLayout();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void layoutDirectionDidChanged(boolean isRTL) {
    }

    private void recordInteraction(int realWidth, int realHeight) {
        if (this.mIsAddElementToTree) {
            boolean z = false;
            this.mIsAddElementToTree = false;
            if (this.mParent == null) {
                this.interactionAbsoluteX = 0;
                this.interactionAbsoluteY = 0;
            } else {
                float cssTop = getCSSLayoutTop();
                float cssLeft = getCSSLayoutLeft();
                this.interactionAbsoluteX = (int) (isFixed() ? cssLeft : ((float) this.mParent.interactionAbsoluteX) + cssLeft);
                this.interactionAbsoluteY = (int) (isFixed() ? cssTop : ((float) this.mParent.interactionAbsoluteY) + cssTop);
            }
            if (getInstance().getApmForInstance().instanceRect == null) {
                getInstance().getApmForInstance().instanceRect = new Rect();
            }
            Rect instanceRect = getInstance().getApmForInstance().instanceRect;
            instanceRect.set(0, 0, this.mInstance.getWeexWidth(), this.mInstance.getWeexHeight());
            boolean inScreen = instanceRect.contains(this.interactionAbsoluteX, this.interactionAbsoluteY) || instanceRect.contains(this.interactionAbsoluteX + realWidth, this.interactionAbsoluteY) || instanceRect.contains(this.interactionAbsoluteX, this.interactionAbsoluteY + realHeight) || instanceRect.contains(this.interactionAbsoluteX + realWidth, this.interactionAbsoluteY + realHeight);
            WXSDKInstance wXSDKInstance = this.mInstance;
            if (!inScreen) {
                z = true;
            }
            wXSDKInstance.onChangeElement(this, z);
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r19v0, resolved type: com.taobao.weex.ui.component.WXComponent<T extends android.view.View> */
    /* JADX WARN: Multi-variable type inference failed */
    private void setWidgetParams(Widget widget, FlatGUIContext UIImp, Point rawoffset, int width, int height, int left, int right, int top, int bottom) {
        int bottom2;
        int top2;
        int right2;
        int left2;
        int height2;
        int width2;
        int i;
        int i2;
        Point childOffset = new Point();
        if (this.mParent != null) {
            if (!(this.mParent instanceof FlatComponent) || UIImp.getFlatComponentAncestor(this.mParent) == null || UIImp.getAndroidViewWidget(this.mParent) != null) {
                i2 = left;
                i = top;
                childOffset.set(i2, i);
            } else {
                childOffset.set(rawoffset.x, rawoffset.y);
                i2 = left;
                i = top;
            }
            if ((this.mParent instanceof FlatComponent) && UIImp.getFlatComponentAncestor(this.mParent) != null && UIImp.getAndroidViewWidget(this.mParent) == null) {
                Point parentLayoutOffset = ((FlatComponent) this.mParent).getOrCreateFlatWidget().getLocInFlatContainer();
                childOffset.offset(parentLayoutOffset.x, parentLayoutOffset.y);
            }
            ViewGroup.LayoutParams lp = this.mParent.getChildLayoutParams(this, this.mHost, width, height, left, right, top, bottom);
            if (lp instanceof ViewGroup.MarginLayoutParams) {
                int width3 = lp.width;
                int height3 = lp.height;
                int left3 = ((ViewGroup.MarginLayoutParams) lp).leftMargin;
                int right3 = ((ViewGroup.MarginLayoutParams) lp).rightMargin;
                width2 = width3;
                height2 = height3;
                left2 = left3;
                right2 = right3;
                top2 = ((ViewGroup.MarginLayoutParams) lp).topMargin;
                bottom2 = ((ViewGroup.MarginLayoutParams) lp).bottomMargin;
                widget.setLayout(width2, height2, left2, right2, top2, bottom2, childOffset);
                if ((widget instanceof AndroidViewWidget) && ((AndroidViewWidget) widget).getView() != null) {
                    setHostLayoutParams(((AndroidViewWidget) widget).getView(), width2, height2, childOffset.x, right2, childOffset.y, bottom2);
                    return;
                }
            }
        } else {
            i2 = left;
            i = top;
        }
        width2 = width;
        right2 = right;
        bottom2 = bottom;
        top2 = i;
        left2 = i2;
        height2 = height;
        widget.setLayout(width2, height2, left2, right2, top2, bottom2, childOffset);
        if (widget instanceof AndroidViewWidget) {
        }
    }

    public int getLayoutTopOffsetForSibling() {
        return 0;
    }

    /* access modifiers changed from: protected */
    public void setHostLayoutParams(T host, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.LayoutParams lp;
        if (this.mParent == null) {
            FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(width, height);
            setMarginsSupportRTL(params, left, top, right, bottom);
            lp = params;
        } else {
            lp = this.mParent.getChildLayoutParams(this, host, width, height, left, right, top, bottom);
        }
        if (lp != null) {
            host.setLayoutParams(lp);
        }
    }

    private void setFixedHostLayoutParams(T host, int width, int height, int left, int right, int top, int bottom) {
        FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(-2, -2);
        params.width = width;
        params.height = height;
        setMarginsSupportRTL(params, left, top, right, bottom);
        host.setLayoutParams(params);
        this.mInstance.moveFixedView(host);
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("Weex_Fixed_Style", "WXComponent:setLayout :" + left + Operators.SPACE_STR + top + Operators.SPACE_STR + width + Operators.SPACE_STR + height);
            StringBuilder sb = new StringBuilder();
            sb.append("WXComponent:setLayout Left:");
            sb.append(getStyles().getLeft());
            sb.append(Operators.SPACE_STR);
            sb.append((int) getStyles().getTop());
            WXLogUtils.d("Weex_Fixed_Style", sb.toString());
        }
    }

    /* access modifiers changed from: protected */
    public void updateBoxShadow(int width, int height, boolean isRender) {
        UniBoxShadowData boxShadowData;
        int i;
        UniInsetBoxShadowLayer insetBoxShadowDrawable;
        UniBoxShadowData boxShadowData2;
        UniNormalBoxShadowDrawable normalBoxShadowDrawable;
        LayerDrawable layerDrawable;
        int realTop;
        int realLeft;
        if (!UniBoxShadowUtil.isBoxShadowEnabled() || this.mElevation > 0.0f || getStyles().get(Constants.Name.ELEVATION) != null || getAttrs().get(Constants.Name.ELEVATION) != null) {
            WXLogUtils.w("BoxShadow", "box-shadow disabled");
            if (this.mBoxShadowData != null) {
                clearBoxShadow();
            }
        } else if (getStyles() != null) {
            Object boxShadow = getStyles().get(Constants.Name.BOX_SHADOW);
            Object shadowQuality = getAttrs().get(Constants.Name.SHADOW_QUALITY);
            if (boxShadow != null) {
                if (width <= 0) {
                    return;
                }
                if (height > 0) {
                    float quality = WXUtils.getFloat(shadowQuality, Float.valueOf(0.5f)).floatValue();
                    float viewPort = getInstance().getInstanceViewPortWidthWithFloat();
                    float[] radii = {0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
                    WXStyle style = getStyles();
                    if (style != null) {
                        float tl = WXUtils.getFloat(style.get(Constants.Name.BORDER_TOP_LEFT_RADIUS), Float.valueOf(0.0f)).floatValue();
                        radii[0] = WXViewUtils.getRealSubPxByWidth(tl, viewPort);
                        radii[1] = WXViewUtils.getRealSubPxByWidth(tl, viewPort);
                        float tr = WXUtils.getFloat(style.get(Constants.Name.BORDER_TOP_RIGHT_RADIUS), Float.valueOf(0.0f)).floatValue();
                        radii[2] = WXViewUtils.getRealSubPxByWidth(tr, viewPort);
                        radii[3] = WXViewUtils.getRealSubPxByWidth(tr, viewPort);
                        float br = WXUtils.getFloat(style.get(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS), Float.valueOf(0.0f)).floatValue();
                        radii[4] = WXViewUtils.getRealSubPxByWidth(br, viewPort);
                        radii[5] = WXViewUtils.getRealSubPxByWidth(br, viewPort);
                        float bl = WXUtils.getFloat(style.get(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS), Float.valueOf(0.0f)).floatValue();
                        radii[6] = WXViewUtils.getRealSubPxByWidth(bl, viewPort);
                        radii[7] = WXViewUtils.getRealSubPxByWidth(bl, viewPort);
                        if (style.containsKey(Constants.Name.BORDER_RADIUS)) {
                            float radius = WXUtils.getFloat(style.get(Constants.Name.BORDER_RADIUS), Float.valueOf(0.0f)).floatValue();
                            for (int i2 = 0; i2 < radii.length; i2++) {
                                radii[i2] = WXViewUtils.getRealSubPxByWidth(radius, viewPort);
                            }
                        }
                    }
                    UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
                    if ((uniBoxShadowData == null || !uniBoxShadowData.equalsUniBoxShadowData(boxShadow.toString(), width, height, radii)) && (boxShadowData = UniBoxShadowUtil.parseBoxShadow(width, height, boxShadow.toString(), radii, viewPort, quality)) != null) {
                        this.mBoxShadowData = boxShadowData;
                        UniNormalBoxShadowDrawable normalBoxShadowDrawable2 = UniBoxShadowUtil.getNormalBoxShadowDrawable(boxShadowData, getContext().getResources());
                        UniInsetBoxShadowLayer insetBoxShadowDrawable2 = UniBoxShadowUtil.getInsetBoxShadowDrawable(boxShadowData);
                        if (!(normalBoxShadowDrawable2 == null && insetBoxShadowDrawable2 == null)) {
                            if (normalBoxShadowDrawable2 == null || boxShadowData == null || !isRender || this.mHost == null) {
                                normalBoxShadowDrawable = normalBoxShadowDrawable2;
                                i = 1;
                                insetBoxShadowDrawable = insetBoxShadowDrawable2;
                                boxShadowData2 = boxShadowData;
                            } else {
                                int realWidth = boxShadowData.getNormalMaxWidth();
                                int realHeight = boxShadowData.getNormalMaxHeight();
                                boolean nullParent = this.mParent == null;
                                CSSShorthand parentPadding = nullParent ? new CSSShorthand() : this.mParent.getPadding();
                                CSSShorthand parentBorder = nullParent ? new CSSShorthand() : this.mParent.getBorder();
                                int siblingOffset = nullParent ? 0 : this.mParent.getChildrenLayoutTopOffset();
                                if (isFixed()) {
                                    realLeft = (int) (getLayoutPosition().getLeft() - ((float) getInstance().getRenderContainerPaddingLeft()));
                                    realTop = ((int) (getLayoutPosition().getTop() - ((float) getInstance().getRenderContainerPaddingTop()))) + siblingOffset;
                                } else {
                                    realLeft = (int) ((getLayoutPosition().getLeft() - parentPadding.get(CSSShorthand.EDGE.LEFT)) - parentBorder.get(CSSShorthand.EDGE.LEFT));
                                    realTop = ((int) ((getLayoutPosition().getTop() - parentPadding.get(CSSShorthand.EDGE.TOP)) - parentBorder.get(CSSShorthand.EDGE.TOP))) + siblingOffset;
                                }
                                int realRight = (int) getMargin().get(CSSShorthand.EDGE.RIGHT);
                                int realBottom = (int) getMargin().get(CSSShorthand.EDGE.BOTTOM);
                                int realLeft2 = realLeft - (boxShadowData.getNormalLeft() / 2);
                                int realTop2 = realTop - (boxShadowData.getNormalTop() / 2);
                                if (isFixed()) {
                                    normalBoxShadowDrawable = normalBoxShadowDrawable2;
                                    boxShadowData2 = boxShadowData;
                                    i = 1;
                                    insetBoxShadowDrawable = insetBoxShadowDrawable2;
                                    setFixedHostLayoutParams(this.mHost, realWidth, realHeight, realLeft2, realRight, realTop2, realBottom);
                                } else {
                                    normalBoxShadowDrawable = normalBoxShadowDrawable2;
                                    i = 1;
                                    insetBoxShadowDrawable = insetBoxShadowDrawable2;
                                    boxShadowData2 = boxShadowData;
                                    setHostLayoutParams(this.mHost, realWidth, realHeight, realLeft2, realRight, realTop2, realBottom);
                                }
                                setPadding(getPadding(), getBorder());
                            }
                            if (this.mBackgroundDrawable != null) {
                                clearBoxShadow();
                                if (this.mRippleBackground == null) {
                                    if (normalBoxShadowDrawable != null) {
                                        Drawable[] drawableArr = new Drawable[2];
                                        drawableArr[0] = normalBoxShadowDrawable;
                                        drawableArr[i] = this.mBackgroundDrawable;
                                        layerDrawable = new LayerDrawable(drawableArr);
                                    } else if (insetBoxShadowDrawable != null) {
                                        Drawable[] drawableArr2 = new Drawable[2];
                                        drawableArr2[0] = this.mBackgroundDrawable;
                                        drawableArr2[i] = insetBoxShadowDrawable;
                                        layerDrawable = new LayerDrawable(drawableArr2);
                                    } else {
                                        Drawable[] drawableArr3 = new Drawable[i];
                                        drawableArr3[0] = this.mBackgroundDrawable;
                                        layerDrawable = new LayerDrawable(drawableArr3);
                                    }
                                } else if (normalBoxShadowDrawable != null) {
                                    Drawable[] drawableArr4 = new Drawable[3];
                                    drawableArr4[0] = this.mRippleBackground;
                                    drawableArr4[i] = normalBoxShadowDrawable;
                                    drawableArr4[2] = this.mBackgroundDrawable;
                                    layerDrawable = new LayerDrawable(drawableArr4);
                                } else if (insetBoxShadowDrawable != null) {
                                    Drawable[] drawableArr5 = new Drawable[3];
                                    drawableArr5[0] = this.mRippleBackground;
                                    drawableArr5[i] = this.mBackgroundDrawable;
                                    drawableArr5[2] = insetBoxShadowDrawable;
                                    layerDrawable = new LayerDrawable(drawableArr5);
                                } else {
                                    Drawable[] drawableArr6 = new Drawable[2];
                                    drawableArr6[0] = this.mRippleBackground;
                                    drawableArr6[i] = this.mBackgroundDrawable;
                                    layerDrawable = new LayerDrawable(drawableArr6);
                                }
                                WXViewUtils.setBackGround(getHostView(), layerDrawable, this);
                                this.mBoxShadowData = boxShadowData2;
                                this.mBoxShadowDrawable = normalBoxShadowDrawable;
                                this.mInsetBoxShadowDrawable = insetBoxShadowDrawable;
                                this.mBackgroundDrawable.updateBoxShadowData(boxShadowData2);
                                return;
                            }
                            clearBoxShadow();
                            this.mBoxShadowData = boxShadowData2;
                            this.mBoxShadowDrawable = normalBoxShadowDrawable;
                            this.mInsetBoxShadowDrawable = insetBoxShadowDrawable;
                            getOrCreateBorder().updateBoxShadowData(boxShadowData2);
                        }
                    }
                }
            }
        } else {
            WXLogUtils.w("Can not resolve styles");
        }
    }

    /* access modifiers changed from: protected */
    public void clearBoxShadow() {
        if (!UniBoxShadowUtil.isBoxShadowEnabled()) {
            WXLogUtils.w("BoxShadow", "box-shadow disabled");
            return;
        }
        BorderDrawable borderDrawable = this.mBackgroundDrawable;
        if (borderDrawable != null) {
            borderDrawable.updateBoxShadowData(null);
        }
        if (!(getHostView() == null || this.mBackgroundDrawable == null || !(getHostView().getBackground() instanceof LayerDrawable))) {
            if (this.mRippleBackground == null) {
                WXViewUtils.setBackGround(getHostView(), new LayerDrawable(new Drawable[]{this.mBackgroundDrawable}), this);
            } else {
                WXViewUtils.setBackGround(getHostView(), new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable}), this);
            }
        }
        if (this.mBoxShadowData != null) {
            this.mBoxShadowData = null;
        }
        UniNormalBoxShadowDrawable uniNormalBoxShadowDrawable = this.mBoxShadowDrawable;
        if (uniNormalBoxShadowDrawable != null) {
            if (uniNormalBoxShadowDrawable.getBitmap() != null) {
                this.mBoxShadowDrawable.getBitmap().recycle();
            }
            this.mBoxShadowDrawable = null;
        }
        if (this.mInsetBoxShadowDrawable != null) {
            this.mInsetBoxShadowDrawable = null;
        }
    }

    /* access modifiers changed from: protected */
    public void onFinishLayout() {
        Object param = getStyles() != null ? getStyles().get(Constants.Name.BACKGROUND_IMAGE) : null;
        if (param != null) {
            setBackgroundImage(param.toString());
        }
    }

    /* access modifiers changed from: protected */
    public MeasureOutput measure(int width, int height) {
        MeasureOutput measureOutput = new MeasureOutput();
        int i = this.mFixedProp;
        if (i != 0) {
            measureOutput.width = i;
            measureOutput.height = this.mFixedProp;
        } else {
            measureOutput.width = width;
            measureOutput.height = height;
        }
        return measureOutput;
    }

    /* access modifiers changed from: protected */
    public void setAriaHidden(boolean isHidden) {
        View host = getHostView();
        if (host != null && Build.VERSION.SDK_INT >= 16) {
            host.setImportantForAccessibility(isHidden ? 2 : 1);
        }
    }

    /* access modifiers changed from: protected */
    public void setAriaLabel(String label) {
        View host = getHostView();
        if (host != null) {
            host.setContentDescription(label);
        }
    }

    /* access modifiers changed from: protected */
    public void setRole(String roleKey) {
        View host = getHostView();
        final String role = roleKey;
        if (host != null && !TextUtils.isEmpty(roleKey)) {
            IWXAccessibilityRoleAdapter roleAdapter = WXSDKManager.getInstance().getAccessibilityRoleAdapter();
            if (roleAdapter != null) {
                role = roleAdapter.getRole(roleKey);
            }
            ViewCompat.setAccessibilityDelegate(host, new AccessibilityDelegateCompat() {
                /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass5 */

                @Override // androidx.core.view.AccessibilityDelegateCompat
                public void onInitializeAccessibilityNodeInfo(View host, AccessibilityNodeInfoCompat info) {
                    try {
                        super.onInitializeAccessibilityNodeInfo(host, info);
                        info.setRoleDescription(role);
                    } catch (Throwable th) {
                        WXLogUtils.e("SetRole failed!");
                    }
                }
            });
        }
    }

    private void setFixedSize(String fixedSize) {
        ViewGroup.LayoutParams layoutParams;
        if (PROP_FS_MATCH_PARENT.equals(fixedSize)) {
            this.mFixedProp = -1;
        } else if (PROP_FS_WRAP_CONTENT.equals(fixedSize)) {
            this.mFixedProp = -2;
        } else {
            this.mFixedProp = 0;
            return;
        }
        T t = this.mHost;
        if (t != null && (layoutParams = t.getLayoutParams()) != null) {
            layoutParams.height = this.mFixedProp;
            layoutParams.width = this.mFixedProp;
            this.mHost.setLayoutParams(layoutParams);
        }
    }

    /* access modifiers changed from: protected */
    public void appendEventToDOM(String type) {
    }

    public View getRealView() {
        return this.mHost;
    }

    private boolean needGestureDetector(String type) {
        if (this.mHost != null) {
            for (WXGestureType gesture : WXGestureType.LowLevelGesture.values()) {
                if (type.equals(gesture.toString())) {
                    return true;
                }
            }
            for (WXGestureType gesture2 : WXGestureType.HighLevelGesture.values()) {
                if (type.equals(gesture2.toString())) {
                    return true;
                }
            }
        }
        return WXGesture.isStopPropagation(type) || type.equals(ViewHover.VIEW_HOVER_EVENT) || isPreventGesture();
    }

    public Scrollable getParentScroller() {
        WXComponent component = this;
        while (true) {
            WXVContainer container = component.getParent();
            if (container == null) {
                return null;
            }
            if (container instanceof Scrollable) {
                return (Scrollable) container;
            }
            if (container.getRef().equals(ROOT)) {
                return null;
            }
            component = container;
        }
    }

    public Scrollable getFirstScroller() {
        if (this instanceof Scrollable) {
            return (Scrollable) this;
        }
        return null;
    }

    public WXVContainer getParent() {
        return this.mParent;
    }

    public final void createView() {
        if (!isLazy()) {
            createViewImpl();
        }
    }

    /* access modifiers changed from: protected */
    public void createViewImpl() {
        Context context = this.mContext;
        if (context != null) {
            T initComponentHostView = initComponentHostView(context);
            this.mHost = initComponentHostView;
            if (initComponentHostView == null && !isVirtualComponent()) {
                initView();
            }
            T t = this.mHost;
            if (t != null) {
                if (t.getId() == -1) {
                    this.mHost.setId(WXViewUtils.generateViewId());
                }
                ComponentObserver observer = getInstance().getComponentObserver();
                if (observer != null) {
                    observer.onViewCreated(this, this.mHost);
                }
                invokePendingComponetMethod();
            }
            onHostViewInitialized(this.mHost);
            return;
        }
        WXLogUtils.e("createViewImpl", "Context is null");
    }

    private final void invokePendingComponetMethod() {
        if (this.mPendingComponetMethodQueue.size() > 0) {
            WXBridgeManager.getInstance().post(new Runnable() {
                /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass6 */

                public void run() {
                    while (!WXComponent.this.mPendingComponetMethodQueue.isEmpty()) {
                        UniMethodData data = (UniMethodData) WXComponent.this.mPendingComponetMethodQueue.poll();
                        if (data != null) {
                            WXComponent.this.invoke(data.getMethod(), data.getArgs());
                        }
                    }
                }
            });
        }
    }

    /* access modifiers changed from: protected */
    @Deprecated
    public void initView() {
        Context context = this.mContext;
        if (context != null) {
            T initComponentHostView = initComponentHostView(context);
            this.mHost = initComponentHostView;
            if (initComponentHostView != null) {
                invokePendingComponetMethod();
            }
        }
    }

    /* access modifiers changed from: protected */
    public T initComponentHostView(Context context) {
        return null;
    }

    /* access modifiers changed from: protected */
    public void onHostViewInitialized(T t) {
        AbsAnimationHolder absAnimationHolder = this.mAnimationHolder;
        if (absAnimationHolder != null) {
            absAnimationHolder.execute(this.mInstance, this);
        }
        setActiveTouchListener();
    }

    public T getHostView() {
        return this.mHost;
    }

    @Deprecated
    public View getView() {
        return this.mHost;
    }

    public int getAbsoluteY() {
        return this.mAbsoluteY;
    }

    public int getAbsoluteX() {
        return this.mAbsoluteX;
    }

    public void removeEvent(String type) {
        if (!TextUtils.isEmpty(type)) {
            if (type.equals(Constants.Event.LAYEROVERFLOW)) {
                removeLayerOverFlowListener(getRef());
            }
            if (getEvents() != null) {
                getEvents().remove(type);
            }
            Set<String> set = this.mAppendEvents;
            if (set != null) {
                set.remove(type);
            }
            Set<String> set2 = this.mGestureType;
            if (set2 != null) {
                set2.remove(type);
            }
            removeEventFromView(type);
        }
    }

    /* access modifiers changed from: protected */
    public void removeEventFromView(String type) {
        if (!(!type.equals(Constants.Event.CLICK) || getRealView() == null || this.mHostClickListeners == null)) {
            if (this.mClickEventListener == null) {
                this.mClickEventListener = new OnClickListenerImp();
            }
            this.mHostClickListeners.remove(this.mClickEventListener);
            if (this.mHostClickListeners.size() < 1) {
                getRealView().setOnClickListener(null);
                getRealView().setClickable(false);
            }
        }
        Scrollable scroller = getParentScroller();
        if (type.equals(Constants.Event.APPEAR) && scroller != null) {
            scroller.unbindAppearEvent(this);
        }
        if (type.equals(Constants.Event.DISAPPEAR) && scroller != null) {
            scroller.unbindDisappearEvent(this);
        }
    }

    public void removeAllEvent() {
        if (getEvents().size() >= 1) {
            WXEvent events = getEvents();
            int size = events.size();
            int i = 0;
            while (i < size && i < events.size()) {
                String event = (String) events.get(i);
                if (event != null) {
                    removeEventFromView(event);
                }
                i++;
            }
            Set<String> set = this.mAppendEvents;
            if (set != null) {
                set.clear();
            }
            Set<String> set2 = this.mGestureType;
            if (set2 != null) {
                set2.clear();
            }
            this.mGesture = null;
            if (getRealView() != null && (getRealView() instanceof WXGestureObservable)) {
                ((WXGestureObservable) getRealView()).registerGestureListener(null);
            }
            T t = this.mHost;
            if (t != null) {
                t.setOnFocusChangeListener(null);
                List<OnClickListener> list = this.mHostClickListeners;
                if (list != null && list.size() > 0) {
                    this.mHostClickListeners.clear();
                    this.mHost.setOnClickListener(null);
                }
            }
        }
    }

    public final void removeStickyStyle() {
        Scrollable scroller;
        if (isSticky() && (scroller = getParentScroller()) != null) {
            scroller.unbindStickStyle(this);
        }
    }

    public boolean isSticky() {
        return getStyles().isSticky();
    }

    public boolean isFixed() {
        return getStyles().isFixed();
    }

    public void setDisabled(boolean disabled) {
        this.mIsDisabled = disabled;
        T t = this.mHost;
        if (t != null) {
            t.setEnabled(!disabled);
        }
    }

    public boolean isDisabled() {
        return this.mIsDisabled;
    }

    public void setSticky(String sticky) {
        Scrollable waScroller;
        if (!TextUtils.isEmpty(sticky) && sticky.equals("sticky") && (waScroller = getParentScroller()) != null) {
            waScroller.bindStickStyle(this);
        }
    }

    public void setBackgroundColor(String color) {
        LayerDrawable layerDrawable;
        if (!TextUtils.isEmpty(color)) {
            int colorInt = WXResourceUtils.getColor(color);
            if (isRippleEnabled() && Build.VERSION.SDK_INT >= 21) {
                Drawable prepareBackgroundRipple = prepareBackgroundRipple();
                this.mRippleBackground = prepareBackgroundRipple;
                if (prepareBackgroundRipple != null) {
                    if (this.mBackgroundDrawable == null) {
                        WXViewUtils.setBackGround(this.mHost, prepareBackgroundRipple, this);
                        return;
                    }
                    if (this.mBoxShadowDrawable != null) {
                        layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBoxShadowDrawable, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable});
                    } else if (this.mInsetBoxShadowDrawable != null) {
                        layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable});
                    } else {
                        layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable});
                    }
                    WXViewUtils.setBackGround(this.mHost, layerDrawable, this);
                    return;
                }
            }
            if (colorInt != 0 || this.mBackgroundDrawable != null) {
                getOrCreateBorder().setColor(colorInt);
            }
        }
    }

    private Drawable prepareBackgroundRipple() {
        Object bg;
        try {
            if (!(getStyles() == null || getStyles().getPesudoResetStyles() == null)) {
                Map<String, Object> resetStyles = getStyles().getPesudoResetStyles();
                Object bgColor = resetStyles.get("backgroundColor");
                int colorInt = 0;
                if ((bgColor != null && (colorInt = WXResourceUtils.getColor(bgColor.toString(), 0)) == 0) || (bg = resetStyles.get("backgroundColor:active")) == null) {
                    return null;
                }
                int rippleColor = WXResourceUtils.getColor(bg.toString(), colorInt);
                if (Build.VERSION.SDK_INT >= 21) {
                    return new RippleDrawable(new ColorStateList(new int[][]{new int[0]}, new int[]{rippleColor}), new ColorDrawable(colorInt), null) {
                        /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass7 */

                        public void draw(Canvas canvas) {
                            if (WXComponent.this.mBackgroundDrawable != null) {
                                canvas.clipPath(WXComponent.this.mBackgroundDrawable.getContentPath(new RectF(0.0f, 0.0f, (float) canvas.getWidth(), (float) canvas.getHeight())));
                            }
                            super.draw(canvas);
                        }
                    };
                }
            }
        } catch (Throwable t) {
            WXLogUtils.w("Exception on create ripple: ", t);
        }
        return null;
    }

    public void setBackgroundImage(String bgImage) {
        if ("".equals(bgImage.trim())) {
            getOrCreateBorder().setImage(null);
            return;
        }
        getOrCreateBorder().setImage(WXResourceUtils.getShader(bgImage, getLayoutSize().getWidth(), getLayoutSize().getHeight()));
    }

    private boolean shouldCancelHardwareAccelerate() {
        IWXConfigAdapter adapter = WXSDKManager.getInstance().getWxConfigAdapter();
        boolean cancel_hardware_accelerate = true;
        if (adapter != null) {
            try {
                cancel_hardware_accelerate = Boolean.parseBoolean(adapter.getConfig("android_weex_test_gpu", "cancel_hardware_accelerate", AbsoluteConst.TRUE));
            } catch (Exception e) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
            }
            WXLogUtils.i("cancel_hardware_accelerate : " + cancel_hardware_accelerate);
        }
        return cancel_hardware_accelerate;
    }

    public void setOpacity(float opacity) {
        if (opacity >= 0.0f && opacity <= 1.0f && this.mHost.getAlpha() != opacity) {
            int limit = WXRenderManager.getOpenGLRenderLimitValue();
            if (isLayerTypeEnabled()) {
                this.mHost.setLayerType(2, null);
            }
            if (isLayerTypeEnabled() && shouldCancelHardwareAccelerate() && limit > 0 && (getLayoutHeight() > ((float) limit) || getLayoutWidth() > ((float) limit))) {
                this.mHost.setLayerType(0, null);
            }
            this.mHost.setAlpha(opacity);
        }
    }

    public void setBorderRadius(String key, float borderRadius) {
        if (borderRadius >= 0.0f) {
            char c = 65535;
            switch (key.hashCode()) {
                case -1228066334:
                    if (key.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                        c = 1;
                        break;
                    }
                    break;
                case 333432965:
                    if (key.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                        c = 2;
                        break;
                    }
                    break;
                case 581268560:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                        c = 4;
                        break;
                    }
                    break;
                case 588239831:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                        c = 3;
                        break;
                    }
                    break;
                case 1349188574:
                    if (key.equals(Constants.Name.BORDER_RADIUS)) {
                        c = 0;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.ALL, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
            } else if (c == 1) {
                getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
            } else if (c == 2) {
                getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
            } else if (c == 3) {
                getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
            } else if (c == 4) {
                getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
            }
        }
    }

    private void initOutlineProvider(final float radius) {
        if (useFeature() && (getHostView() instanceof BaseFrameLayout)) {
            getHostView().setOutlineProvider(new ViewOutlineProvider() {
                /* class com.taobao.weex.ui.component.WXComponent.AnonymousClass8 */

                public void getOutline(View view, Outline outline) {
                    if (!WXComponent.this.getInstance().isDestroy()) {
                        int w = view.getWidth();
                        int h = view.getHeight();
                        if (w != 0 && h != 0 && WXComponent.this.getOrCreateBorder().isRounded()) {
                            Rect f = new Rect(0, 0, w, h);
                            float factor = ((float) w) / (radius * 2.0f);
                            if (Float.isNaN(factor) || factor >= 1.0f) {
                                outline.setRoundRect(f, radius);
                            } else {
                                outline.setRoundRect(f, radius * factor);
                            }
                        }
                    }
                }
            });
            getHostView().setClipToOutline(true);
        }
    }

    public boolean useFeature() {
        return Build.VERSION.SDK_INT >= 24;
    }

    public void setBorderWidth(String key, float borderWidth) {
        if (borderWidth >= 0.0f) {
            char c = 65535;
            switch (key.hashCode()) {
                case -1971292586:
                    if (key.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                        c = 2;
                        break;
                    }
                    break;
                case -1452542531:
                    if (key.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1290574193:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                        c = 3;
                        break;
                    }
                    break;
                case -223992013:
                    if (key.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                        c = 4;
                        break;
                    }
                    break;
                case 741115130:
                    if (key.equals(Constants.Name.BORDER_WIDTH)) {
                        c = 0;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.ALL, borderWidth);
            } else if (c == 1) {
                getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.TOP, borderWidth);
            } else if (c == 2) {
                getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.RIGHT, borderWidth);
            } else if (c == 3) {
                getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.BOTTOM, borderWidth);
            } else if (c == 4) {
                getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.LEFT, borderWidth);
            }
        }
    }

    public void setBorderStyle(String key, String borderStyle) {
        if (!TextUtils.isEmpty(borderStyle)) {
            char c = 65535;
            switch (key.hashCode()) {
                case -1974639039:
                    if (key.equals(Constants.Name.BORDER_RIGHT_STYLE)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1455888984:
                    if (key.equals(Constants.Name.BORDER_TOP_STYLE)) {
                        c = 4;
                        break;
                    }
                    break;
                case -1293920646:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_STYLE)) {
                        c = 2;
                        break;
                    }
                    break;
                case -227338466:
                    if (key.equals(Constants.Name.BORDER_LEFT_STYLE)) {
                        c = 3;
                        break;
                    }
                    break;
                case 737768677:
                    if (key.equals(Constants.Name.BORDER_STYLE)) {
                        c = 0;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.ALL, borderStyle);
            } else if (c == 1) {
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.RIGHT, borderStyle);
            } else if (c == 2) {
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.BOTTOM, borderStyle);
            } else if (c == 3) {
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.LEFT, borderStyle);
            } else if (c == 4) {
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.TOP, borderStyle);
            }
        }
    }

    public void setBorderColor(String key, String borderColor) {
        int colorInt;
        if (!TextUtils.isEmpty(borderColor) && (colorInt = WXResourceUtils.getColor(borderColor)) != Integer.MIN_VALUE) {
            char c = 65535;
            switch (key.hashCode()) {
                case -1989576717:
                    if (key.equals(Constants.Name.BORDER_RIGHT_COLOR)) {
                        c = 2;
                        break;
                    }
                    break;
                case -1470826662:
                    if (key.equals(Constants.Name.BORDER_TOP_COLOR)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1308858324:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                        c = 3;
                        break;
                    }
                    break;
                case -242276144:
                    if (key.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                        c = 4;
                        break;
                    }
                    break;
                case 722830999:
                    if (key.equals(Constants.Name.BORDER_COLOR)) {
                        c = 0;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.ALL, colorInt);
            } else if (c == 1) {
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.TOP, colorInt);
            } else if (c == 2) {
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.RIGHT, colorInt);
            } else if (c == 3) {
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.BOTTOM, colorInt);
            } else if (c == 4) {
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.LEFT, colorInt);
            }
        }
    }

    public String getVisibility() {
        try {
            return (String) getStyles().get(Constants.Name.VISIBILITY);
        } catch (Exception e) {
            return "visible";
        }
    }

    public void setVisibility(String visibility) {
        View view = getRealView();
        if (view == null) {
            return;
        }
        if (TextUtils.equals(visibility, "visible")) {
            view.setVisibility(0);
        } else if (TextUtils.equals(visibility, "hidden")) {
            view.setVisibility(8);
        }
    }

    private void updateElevation() {
        float elevation = getAttrs().getElevation(getInstance().getInstanceViewPortWidthWithFloat());
        if (!Float.isNaN(elevation)) {
            ViewCompat.setElevation(getHostView(), elevation);
        }
    }

    @Deprecated
    public void registerActivityStateListener() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityCreate() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStart() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityPause() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStop() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityDestroy() {
        ConcurrentLinkedQueue<UniMethodData> concurrentLinkedQueue = this.mPendingComponetMethodQueue;
        if (concurrentLinkedQueue != null) {
            concurrentLinkedQueue.clear();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public boolean onActivityBack() {
        return false;
    }

    public void onActivityResult(int requestCode, int resultCode, Intent data) {
    }

    public boolean onCreateOptionsMenu(Menu menu) {
        return false;
    }

    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
    }

    public void recycled() {
        if (!isFixed()) {
        }
    }

    public void destroy() {
        View view;
        if (getInstance() != null) {
            clearBoxShadow();
            ComponentObserver observer = getInstance().getComponentObserver();
            if (observer != null) {
                observer.onPreDestory(this);
            }
            if (!WXEnvironment.isApkDebugable() || WXUtils.isUiThread()) {
                T t = this.mHost;
                if (t != null && t.getLayerType() == 2 && isLayerTypeEnabled()) {
                    this.mHost.setLayerType(0, null);
                }
                removeAllEvent();
                removeStickyStyle();
                if (isFixed() && (view = getHostView()) != null) {
                    getInstance().removeFixedView(view);
                }
                ContentBoxMeasurement contentBoxMeasurement2 = this.contentBoxMeasurement;
                if (contentBoxMeasurement2 != null) {
                    contentBoxMeasurement2.destroy();
                    this.contentBoxMeasurement = null;
                }
                this.mIsDestroyed = true;
                ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> concurrentLinkedQueue = this.animations;
                if (concurrentLinkedQueue != null) {
                    concurrentLinkedQueue.clear();
                }
                ViewHover viewHover = this.mHover;
                if (viewHover != null) {
                    viewHover.destroy();
                    this.mHover = null;
                }
                this.mInstance = null;
                List<OnFocusChangeListener> list = this.mFocusChangeListeners;
                if (list != null) {
                    list.clear();
                }
                List<OnClickListener> list2 = this.mHostClickListeners;
                if (list2 != null) {
                    list2.clear();
                    return;
                }
                return;
            }
            throw new WXRuntimeException("[WXComponent] destroy can only be called in main thread");
        }
    }

    public boolean isDestoryed() {
        return this.mIsDestroyed;
    }

    public View detachViewAndClearPreInfo() {
        View original = this.mHost;
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealTop = 0;
        return original;
    }

    public void clearPreLayout() {
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealTop = 0;
    }

    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        View view = getRealView();
        pointF.set((float) view.getScrollX(), (float) view.getScrollY());
    }

    public boolean containsGesture(WXGestureType WXGestureType) {
        Set<String> set = this.mGestureType;
        return set != null && set.contains(WXGestureType.toString());
    }

    public boolean containsEvent(String event) {
        Set<String> set;
        return getEvents().contains(event) || ((set = this.mAppendEvents) != null && set.contains(event));
    }

    public void notifyAppearStateChange(String wxEventType, String direction) {
        if (containsEvent(Constants.Event.APPEAR) || containsEvent(Constants.Event.DISAPPEAR)) {
            Map<String, Object> params = new HashMap<>();
            params.put("direction", direction);
            fireEvent(wxEventType, params);
        }
    }

    public boolean isUsing() {
        return this.isUsing;
    }

    public void setUsing(boolean using) {
        this.isUsing = using;
    }

    public void readyToRender() {
        if (this.mParent != null && getInstance() != null && getInstance().isTrackComponent()) {
            this.mParent.readyToRender();
        }
    }

    public boolean isVirtualComponent() {
        return this.mType == 1;
    }

    public void removeVirtualComponent() {
    }

    public int getType() {
        return this.mType;
    }

    public boolean hasScrollParent(WXComponent component) {
        if (component.getParent() == null) {
            return true;
        }
        if (component.getParent() instanceof WXBaseScroller) {
            return false;
        }
        return hasScrollParent(component.getParent());
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:6:0x001f, code lost:
        if (r4.equals("backgroundColor") != false) goto L_0x00bd;
     */
    public Object convertEmptyProperty(String propName, Object originalValue) {
        char c = 0;
        switch (propName.hashCode()) {
            case -1989576717:
                if (propName.equals(Constants.Name.BORDER_RIGHT_COLOR)) {
                    c = 14;
                    break;
                }
                c = 65535;
                break;
            case -1971292586:
                if (propName.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case -1470826662:
                if (propName.equals(Constants.Name.BORDER_TOP_COLOR)) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case -1452542531:
                if (propName.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case -1308858324:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                    c = 15;
                    break;
                }
                c = 65535;
                break;
            case -1290574193:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case -1228066334:
                if (propName.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -242276144:
                if (propName.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case -223992013:
                if (propName.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 333432965:
                if (propName.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 581268560:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 588239831:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 722830999:
                if (propName.equals(Constants.Name.BORDER_COLOR)) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 741115130:
                if (propName.equals(Constants.Name.BORDER_WIDTH)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 1287124693:
                break;
            case 1349188574:
                if (propName.equals(Constants.Name.BORDER_RADIUS)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                return Constant.TRANSPARENT;
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
                return 0;
            case 6:
            case 7:
            case '\b':
            case '\t':
            case '\n':
                return 0;
            case 11:
            case '\f':
            case '\r':
            case 14:
            case 15:
                return "black";
            default:
                return originalValue;
        }
    }

    private void setActiveTouchListener() {
        View view;
        if (getStyles().getPesudoStyles().containsKey(Constants.PSEUDO.ACTIVE) && (view = getRealView()) != null) {
            view.setOnTouchListener(new TouchActivePseudoListener(this, !isConsumeTouch()));
        }
    }

    /* access modifiers changed from: protected */
    public boolean isConsumeTouch() {
        List<OnClickListener> list = this.mHostClickListeners;
        return (list != null && list.size() > 0) || this.mGesture != null;
    }

    @Override // com.taobao.weex.ui.component.pesudo.OnActivePseudoListner
    public void updateActivePseudo(boolean isSet) {
        if (getInstance() != null) {
            setPseudoClassStatus(Constants.PSEUDO.ACTIVE, isSet);
        }
    }

    /* access modifiers changed from: protected */
    public void setPseudoClassStatus(String clzName, boolean status) {
        WXStyle styles = getStyles();
        Map<String, Map<String, Object>> pesudoStyles = styles.getPesudoStyles();
        if (pesudoStyles != null && pesudoStyles.size() != 0) {
            if (this.mPesudoStatus == null) {
                this.mPesudoStatus = new PesudoStatus();
            }
            Map<String, Object> resultStyles = this.mPesudoStatus.updateStatusAndGetUpdateStyles(clzName, status, pesudoStyles, styles.getPesudoResetStyles());
            if (resultStyles != null) {
                if (status) {
                    this.mPseudoResetGraphicSize = new GraphicSize(getLayoutSize().getWidth(), getLayoutSize().getHeight());
                    if (resultStyles.keySet().contains("width")) {
                        getLayoutSize().setWidth(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(styles.getPesudoResetStyles().get("width:active")), getViewPortWidthForFloat()));
                    } else if (resultStyles.keySet().contains("height")) {
                        getLayoutSize().setHeight(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(styles.getPesudoResetStyles().get("height:active")), getViewPortWidthForFloat()));
                    }
                } else {
                    GraphicSize graphicSize = this.mPseudoResetGraphicSize;
                    if (graphicSize != null) {
                        setLayoutSize(graphicSize);
                    }
                }
            }
            updateStyleByPesudo(resultStyles);
        }
    }

    private void updateStyleByPesudo(Map<String, Object> styles) {
        if (getInstance() != null) {
            new GraphicActionUpdateStyle(getInstance(), getRef(), styles, getPadding(), getMargin(), getBorder(), true).executeActionOnRender();
            if (getLayoutWidth() != 0.0f || getLayoutHeight() != 0.0f) {
                if (styles.containsKey("width")) {
                    WXBridgeManager.getInstance().setStyleWidth(getInstanceId(), getRef(), getLayoutWidth());
                } else if (styles.containsKey("height")) {
                    WXBridgeManager.getInstance().setStyleHeight(getInstanceId(), getRef(), getLayoutHeight());
                }
            }
        }
    }

    public int getStickyOffset() {
        return this.mStickyOffset;
    }

    public boolean canRecycled() {
        return (!isFixed() || !isSticky()) && getAttrs().canRecycled();
    }

    public void setStickyOffset(int stickyOffset) {
        this.mStickyOffset = stickyOffset;
    }

    public boolean isLayerTypeEnabled() {
        return getInstance().isLayerTypeEnabled();
    }

    public void setNeedLayoutOnAnimation(boolean need) {
        this.mNeedLayoutOnAnimation = need;
    }

    public void notifyNativeSizeChanged(int w, int h) {
        if (this.mNeedLayoutOnAnimation) {
            UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
            if (uniBoxShadowData != null && uniBoxShadowData.getNormalShadows().size() > 0) {
                w -= this.mBoxShadowData.getNormalLeft();
                h -= this.mBoxShadowData.getNormalTop();
            }
            WXBridgeManager manager = WXBridgeManager.getInstance();
            manager.setStyleWidth(getInstanceId(), getRef(), (float) w);
            manager.setStyleHeight(getInstanceId(), getRef(), (float) h);
        }
    }

    public void onRenderFinish(int state) {
        if (WXTracing.isAvailable()) {
            double uiTime = Stopwatch.nanosToMillis(this.mTraceInfo.uiThreadNanos);
            if (state == 2 || state == 0) {
                WXTracing.TraceEvent domEvent = WXTracing.newEvent("DomExecute", getInstanceId(), this.mTraceInfo.rootEventId);
                domEvent.ph = "X";
                domEvent.ts = this.mTraceInfo.domThreadStart;
                domEvent.tname = "DOMThread";
                domEvent.name = getComponentType();
                domEvent.classname = getClass().getSimpleName();
                if (getParent() != null) {
                    domEvent.parentRef = getParent().getRef();
                }
                domEvent.submit();
            }
            if (state != 2 && state != 1) {
                return;
            }
            if (this.mTraceInfo.uiThreadStart != -1) {
                WXTracing.TraceEvent uiEvent = WXTracing.newEvent("UIExecute", getInstanceId(), this.mTraceInfo.rootEventId);
                uiEvent.ph = "X";
                uiEvent.duration = uiTime;
                uiEvent.ts = this.mTraceInfo.uiThreadStart;
                uiEvent.name = getComponentType();
                uiEvent.classname = getClass().getSimpleName();
                if (getParent() != null) {
                    uiEvent.parentRef = getParent().getRef();
                }
                uiEvent.submit();
            } else if (WXEnvironment.isApkDebugable()) {
                isLazy();
            }
        }
    }

    /* access modifiers changed from: protected */
    public boolean isRippleEnabled() {
        try {
            return WXUtils.getBoolean(getAttrs().get(Constants.Name.RIPPLE_ENABLED), false).booleanValue();
        } catch (Throwable th) {
            return false;
        }
    }

    public boolean isWaste() {
        return this.waste;
    }

    public void setWaste(boolean waste2) {
        if (this.waste != waste2) {
            this.waste = waste2;
            if (!WXBasicComponentType.RECYCLE_LIST.equals(getParent().getComponentType())) {
                NativeRenderObjectUtils.nativeRenderObjectChildWaste(getRenderObjectPtr(), waste2);
            }
            if (waste2) {
                getStyles().put(Constants.Name.VISIBILITY, (Object) "hidden");
                if (getHostView() != null) {
                    getHostView().setVisibility(8);
                } else if (!this.mLazy) {
                    lazy(true);
                }
            } else {
                getStyles().put(Constants.Name.VISIBILITY, (Object) "visible");
                if (getHostView() != null) {
                    getHostView().setVisibility(0);
                } else if (!this.mLazy) {
                } else {
                    if (this.mParent == null || !this.mParent.isLazy()) {
                        Statements.initLazyComponent(this, this.mParent);
                    } else {
                        lazy(false);
                    }
                }
            }
        }
    }

    public String getViewTreeKey() {
        if (this.mViewTreeKey == null) {
            if (getParent() == null) {
                this.mViewTreeKey = hashCode() + "_" + getRef();
            } else {
                this.mViewTreeKey = hashCode() + "_" + getRef() + "_" + getParent().indexOf(this);
            }
        }
        return this.mViewTreeKey;
    }

    public WXTransition getTransition() {
        return this.mTransition;
    }

    public void setTransition(WXTransition transition) {
        this.mTransition = transition;
    }

    public void addAnimationForElement(Map<String, Object> animMap) {
        if (animMap != null && !animMap.isEmpty()) {
            if (this.animations == null) {
                this.animations = new ConcurrentLinkedQueue<>();
            }
            this.animations.add(new Pair<>(getRef(), animMap));
        }
    }

    private void parseAnimation() {
        WXAnimationBean animationBean;
        ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> concurrentLinkedQueue = this.animations;
        if (concurrentLinkedQueue != null) {
            Iterator<Pair<String, Map<String, Object>>> it = concurrentLinkedQueue.iterator();
            while (it.hasNext()) {
                Pair<String, Map<String, Object>> pair = it.next();
                if (!TextUtils.isEmpty((CharSequence) pair.first) && (animationBean = createAnimationBean((String) pair.first, (Map) pair.second)) != null) {
                    new GraphicActionAnimation(getInstance(), getRef(), animationBean).executeAction();
                }
            }
            this.animations.clear();
        }
    }

    private WXAnimationBean createAnimationBean(String ref, Map<String, Object> style) {
        if (style != null) {
            try {
                Object transform = style.get("transform");
                if ((transform instanceof String) && !TextUtils.isEmpty((String) transform)) {
                    String transformOrigin = (String) style.get(Constants.Name.TRANSFORM_ORIGIN);
                    WXAnimationBean animationBean = new WXAnimationBean();
                    int width = (int) getLayoutWidth();
                    int height = (int) getLayoutHeight();
                    animationBean.styles = new WXAnimationBean.Style();
                    animationBean.styles.init(transformOrigin, (String) transform, width, height, WXSDKManager.getInstanceViewPortWidth(getInstanceId()), getInstance());
                    return animationBean;
                }
            } catch (RuntimeException e) {
                WXLogUtils.e("", e);
                return null;
            }
        }
        return null;
    }

    public void lazy(boolean lazy) {
        this.mLazy = lazy;
    }

    public long getRenderObjectPtr() {
        if (getBasicComponentData().isRenderPtrEmpty()) {
            getBasicComponentData().setRenderObjectPr(NativeRenderObjectUtils.nativeGetRenderObject(getInstanceId(), getRef()));
        }
        return getBasicComponentData().getRenderObjectPr();
    }

    public void updateNativeAttr(String key, Object value) {
        if (key != null) {
            if (value == null) {
                value = "";
            }
            getBasicComponentData().getAttrs().put(key, value);
            NativeRenderObjectUtils.nativeUpdateRenderObjectAttr(getRenderObjectPtr(), key, value.toString());
        }
    }

    public void nativeUpdateAttrs(Map<String, Object> dynamic) {
        for (Map.Entry<String, Object> objectEntry : dynamic.entrySet()) {
            if (objectEntry.getKey() != null) {
                updateNativeAttr(objectEntry.getKey(), objectEntry.getValue());
            }
        }
    }

    public void updateNativeStyle(String key, Object value) {
        if (key != null) {
            if (value == null) {
                value = "";
            }
            getBasicComponentData().getStyles().put(key, value);
            NativeRenderObjectUtils.nativeUpdateRenderObjectStyle(getRenderObjectPtr(), key, value.toString());
        }
    }

    public void updateNativeStyles(Map<String, Object> dynamic) {
        for (Map.Entry<String, Object> objectEntry : dynamic.entrySet()) {
            if (objectEntry.getKey() != null) {
                updateNativeStyle(objectEntry.getKey(), objectEntry.getValue());
            }
        }
    }

    public void addLayerOverFlowListener(String ref) {
        if (getInstance() != null) {
            getInstance().addLayerOverFlowListener(ref);
        }
    }

    public void removeLayerOverFlowListener(String ref) {
        if (getInstance() != null) {
            getInstance().removeLayerOverFlowListener(ref);
        }
    }

    @WXComponentProp(name = "hoverClass")
    public void hoverClass(String m) {
        JSONObject object = JSON.parseObject(m);
        if (object != null) {
            ViewHover viewHover = this.mHover;
            if (viewHover == null) {
                this.mHover = new ViewHover(this, object);
            } else {
                viewHover.update(object);
            }
            if (!getEvents().contains(ViewHover.VIEW_HOVER_EVENT)) {
                addEvent(ViewHover.VIEW_HOVER_EVENT);
            }
        }
    }

    @WXComponentProp(name = "hoverStopPropagation")
    public void hoverStopPropagation(boolean is) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStopPropagation(is);
        if (!getEvents().contains(ViewHover.VIEW_HOVER_EVENT)) {
            addEvent(ViewHover.VIEW_HOVER_EVENT);
        }
        if (this.mParent != null && is) {
            this.mParent.setHoverReceiveTouch(false);
        }
    }

    @WXComponentProp(name = "hoverStartTime")
    public void hoverStartTime(int n) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStartTime(n);
    }

    @WXComponentProp(name = "hoverStayTime")
    public void hoverStayTime(int n) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStayTime(n);
    }

    public void setHoverClassStatus(boolean status) {
        Map<String, Object> resultStyles = this.mHover.updateStatusAndGetUpdateStyles(status);
        if (resultStyles != null) {
            if (status) {
                boolean isWidth = resultStyles.keySet().contains("width");
                boolean isHeight = resultStyles.keySet().contains("height");
                if (isWidth || isHeight) {
                    this.mPseudoResetGraphicSize = new GraphicSize(getLayoutSize().getWidth(), getLayoutSize().getHeight());
                }
                if (isWidth) {
                    getLayoutSize().setWidth(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(resultStyles.get("width")), getViewPortWidthForFloat()));
                } else if (isHeight) {
                    getLayoutSize().setHeight(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(resultStyles.get("height")), getViewPortWidthForFloat()));
                }
            } else {
                GraphicSize graphicSize = this.mPseudoResetGraphicSize;
                if (graphicSize != null) {
                    setLayoutSize(graphicSize);
                }
            }
        }
        updateStyleByPesudo(resultStyles);
    }

    public void setHoverReceiveTouch(boolean receiveTouch) {
        if (getHover() != null) {
            getHover().setReceiveTouch(receiveTouch);
        }
        if (this.mParent != null) {
            this.mParent.setHoverReceiveTouch(receiveTouch);
        }
    }

    public ViewHover getHover() {
        return this.mHover;
    }

    public boolean isPreventGesture() {
        return this.isPreventGesture;
    }

    @WXComponentProp(name = "preventGesture")
    public void setPreventGesture(boolean enable) {
        this.isPreventGesture = enable;
        addEvent("preventGesture");
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public float getViewPortWidthForFloat() {
        if (getInstance() != null) {
            return getInstance().getInstanceViewPortWidthWithFloat();
        }
        return 720.0f;
    }
}
