package com.taobao.weex.ui.component;

import android.app.Activity;
import android.content.Context;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.ViewGroup;
import android.widget.ImageView;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXImageSharpen;
import com.taobao.weex.common.WXImageStrategy;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.dom.WXImageQuality;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.WXImageView;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.ImageDrawable;
import com.taobao.weex.utils.ImgURIUtil;
import com.taobao.weex.utils.SingleFunctionParser;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewToImageUtil;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component(lazyload = false)
public class WXImage extends WXComponent<ImageView> {
    private static SingleFunctionParser.FlatMapper<Integer> BLUR_RADIUS_MAPPER = new SingleFunctionParser.FlatMapper<Integer>() {
        /* class com.taobao.weex.ui.component.WXImage.AnonymousClass1 */

        @Override // com.taobao.weex.utils.SingleFunctionParser.FlatMapper
        public Integer map(String raw) {
            return WXUtils.getInteger(raw, 0);
        }
    };
    public static final String ERRORDESC = "errorDesc";
    public static final String SUCCEED = "success";
    private static final int WRITE_EXTERNAL_STORAGE_PERMISSION_REQUEST_CODE = 2;
    private boolean mAutoRecycle;
    private int mBlurRadius;
    private WXSDKInstance.FrameViewEventListener mFrameViewEventListener;
    protected boolean mIsUni;
    private String mSrc;
    private String preImgUrlStr;

    public interface Measurable {
        int getNaturalHeight();

        int getNaturalWidth();
    }

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXImage(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public WXImage(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXImage(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mAutoRecycle = true;
        this.mIsUni = false;
        this.preImgUrlStr = "";
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public ImageView initComponentHostView(Context context) {
        WXImageView view = new WXImageView(context);
        view.setScaleType(ImageView.ScaleType.FIT_XY);
        if (Build.VERSION.SDK_INT >= 16) {
            view.setCropToPadding(true);
        }
        view.holdComponent(this);
        return view;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -1285653259:
                if (key.equals(Constants.Name.AUTO_RECYCLE)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -1274492040:
                if (key.equals(Constants.Name.FILTER)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -934437708:
                if (key.equals("resize")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 114148:
                if (key.equals("src")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1249477412:
                if (key.equals(Constants.Name.IMAGE_QUALITY)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 2049757303:
                if (key.equals(Constants.Name.RESIZE_MODE)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            String resizeMode = WXUtils.getString(param, null);
            if (resizeMode != null) {
                setResizeMode(resizeMode);
            }
            return true;
        } else if (c == 1) {
            String resize = WXUtils.getString(param, null);
            if (resize != null) {
                setResize(resize);
            }
            return true;
        } else if (c == 2) {
            String src = WXUtils.getString(param, null);
            if (src != null) {
                setSrc(src);
            }
            return true;
        } else if (c == 3) {
            return true;
        } else {
            if (c == 4) {
                boolean booleanValue = WXUtils.getBoolean(param, Boolean.valueOf(this.mAutoRecycle)).booleanValue();
                this.mAutoRecycle = booleanValue;
                if (!booleanValue && getInstance() != null) {
                    getInstance().getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_IMG_UN_RECYCLE_NUM, 1.0d);
                }
                return true;
            } else if (c != 5) {
                return super.setProperty(key, param);
            } else {
                int blurRadius = 0;
                if (param != null && (param instanceof String)) {
                    blurRadius = parseBlurRadius((String) param);
                }
                if (!TextUtils.isEmpty(this.mSrc)) {
                    setBlurRadius(this.mSrc, blurRadius);
                }
                return true;
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void refreshData(WXComponent component) {
        super.refreshData(component);
        if (component instanceof WXImage) {
            setSrc(component.getAttrs().getImageSrc());
        }
    }

    @WXComponentProp(name = Constants.Name.RESIZE_MODE)
    public void setResizeMode(String resizeMode) {
        ((ImageView) getHostView()).setScaleType(getResizeMode(resizeMode));
        ((ImageView) getHostView()).setImageDrawable(((ImageView) getHostView()).getDrawable());
    }

    /* access modifiers changed from: protected */
    public ImageView.ScaleType getResizeMode(String resizeMode) {
        ImageView.ScaleType scaleType = ImageView.ScaleType.FIT_XY;
        if (TextUtils.isEmpty(resizeMode)) {
            return scaleType;
        }
        char c = 65535;
        int hashCode = resizeMode.hashCode();
        if (hashCode != -1881872635) {
            if (hashCode != 94852023) {
                if (hashCode == 951526612 && resizeMode.equals("contain")) {
                    c = 1;
                }
            } else if (resizeMode.equals(IApp.ConfigProperty.CONFIG_COVER)) {
                c = 0;
            }
        } else if (resizeMode.equals("stretch")) {
            c = 2;
        }
        if (c == 0) {
            return ImageView.ScaleType.CENTER_CROP;
        }
        if (c == 1) {
            return ImageView.ScaleType.FIT_CENTER;
        }
        if (c != 2) {
            return scaleType;
        }
        return ImageView.ScaleType.FIT_XY;
    }

    @WXComponentProp(name = "resize")
    public void setResize(String resize) {
        setResizeMode(resize);
    }

    private void setLocalSrc(Uri rewrited) {
        ImageView imageView;
        Drawable localDrawable = ImgURIUtil.getDrawableFromLoaclSrc(getContext(), rewrited);
        if (localDrawable != null && (imageView = (ImageView) getHostView()) != null) {
            imageView.setImageDrawable(localDrawable);
        }
    }

    @WXComponentProp(name = "src")
    public void setSrc(String src) {
        runSrc(src);
    }

    private void runSrc(String src) {
        if (getHostView() != null && getInstance() != null) {
            if (getInstance().getImageNetworkHandler() != null) {
                String localUrl = getInstance().getImageNetworkHandler().fetchLocal(src);
                if (!TextUtils.isEmpty(localUrl)) {
                    src = localUrl;
                }
            }
            if (!PdrUtil.isEmpty(src)) {
                ImageView image = (ImageView) getHostView();
                if (!(image == null || image.getDrawable() == null || TextUtils.equals(this.mSrc, src))) {
                    image.setImageDrawable(null);
                }
                this.mSrc = src;
                Uri rewrited = getInstance().rewriteUri(Uri.parse(src), "image");
                if ("local".equals(rewrited.getScheme())) {
                    setLocalSrc(rewrited);
                } else {
                    setRemoteSrc(rewrited, parseBlurRadius(getStyles().getBlur()));
                }
            }
        }
    }

    private void setBlurRadius(String src, int blurRadius) {
        if (getInstance() != null && blurRadius != this.mBlurRadius) {
            Uri parsedUri = getInstance().rewriteUri(Uri.parse(src), "image");
            if (!"local".equals(parsedUri.getScheme())) {
                setRemoteSrc(parsedUri, blurRadius);
            }
        }
    }

    private int parseBlurRadius(String rawRadius) {
        if (rawRadius == null) {
            return 0;
        }
        try {
            List<Integer> list = new SingleFunctionParser<>(rawRadius, BLUR_RADIUS_MAPPER).parse(Constants.Event.BLUR);
            if (list == null || list.isEmpty()) {
                return 0;
            }
            return list.get(0).intValue();
        } catch (Exception e) {
            return 0;
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void recycled() {
        super.recycled();
        if (getHostView() != null && getInstance() != null && getInstance().getImgLoaderAdapter() != null) {
            getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
        } else if (!WXEnvironment.isApkDebugable()) {
            WXLogUtils.e("Error getImgLoaderAdapter() == null");
        } else {
            throw new WXRuntimeException("getImgLoaderAdapter() == null");
        }
    }

    public void autoReleaseImage() {
        if (this.mAutoRecycle && getHostView() != null && getInstance() != null && getInstance().getImgLoaderAdapter() != null) {
            getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
        }
    }

    public void autoRecoverImage() {
        if (this.mAutoRecycle) {
            setSrc(this.mSrc);
        }
    }

    private void setRemoteSrc(Uri rewrited, int blurRadius) {
        WXImageStrategy imageStrategy = new WXImageStrategy(getInstanceId());
        imageStrategy.isClipping = true;
        imageStrategy.isSharpen = getAttrs().getImageSharpen() == WXImageSharpen.SHARPEN;
        imageStrategy.blurRadius = Math.max(0, blurRadius);
        this.mBlurRadius = blurRadius;
        String rewritedStr = rewrited.toString();
        imageStrategy.setImageListener(new MyImageListener(this, rewritedStr));
        if (getAttrs().containsKey("autoCompression")) {
            imageStrategy.setAutoCompression(WXUtils.getBoolean(getAttrs().get("autoCompression"), true).booleanValue());
        }
        String placeholder = null;
        if (getAttrs().containsKey(Constants.Name.PLACEHOLDER)) {
            placeholder = (String) getAttrs().get(Constants.Name.PLACEHOLDER);
        } else if (getAttrs().containsKey(Constants.Name.PLACE_HOLDER)) {
            placeholder = (String) getAttrs().get(Constants.Name.PLACE_HOLDER);
        }
        if (placeholder != null) {
            imageStrategy.placeHolder = getInstance().rewriteUri(Uri.parse(placeholder), "image").toString();
        }
        imageStrategy.instanceId = getInstanceId();
        setImage(rewritedStr, imageStrategy);
    }

    /* access modifiers changed from: protected */
    public void setImage(String rewritedStr, WXImageStrategy imageStrategy) {
        IWXImgLoaderAdapter imgLoaderAdapter = getInstance().getImgLoaderAdapter();
        if (imgLoaderAdapter != null) {
            imgLoaderAdapter.setImage(rewritedStr, (ImageView) getHostView(), getImageQuality(), imageStrategy);
        }
    }

    /* access modifiers changed from: protected */
    public WXImageQuality getImageQuality() {
        return getAttrs().getImageQuality();
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onFinishLayout() {
        super.onFinishLayout();
        updateBorderRadius();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        updateBorderRadius();
    }

    private void updateBorderRadius() {
        float[] borderRadius;
        if (getHostView() instanceof WXImageView) {
            WXImageView imageView = (WXImageView) getHostView();
            BorderDrawable borderDrawable = WXViewUtils.getBorderDrawable(getHostView());
            if (borderDrawable != null) {
                borderRadius = borderDrawable.getBorderInnerRadius(new RectF(0.0f, 0.0f, WXDomUtils.getContentWidth(this), WXDomUtils.getContentHeight(this)));
            } else {
                borderRadius = new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
            }
            imageView.setBorderRadius(borderRadius);
            if (imageView.getDrawable() instanceof ImageDrawable) {
                ImageDrawable imageDrawable = (ImageDrawable) imageView.getDrawable();
                if (!Arrays.equals(imageDrawable.getCornerRadii(), borderRadius)) {
                    imageDrawable.setCornerRadii(borderRadius);
                }
            }
        }
    }

    @JSMethod(uiThread = false)
    public void save(final JSCallback saveStatuCallback) {
        if (ContextCompat.checkSelfPermission(getContext(), "android.permission.WRITE_EXTERNAL_STORAGE") != 0 && (getContext() instanceof Activity)) {
            ActivityCompat.requestPermissions((Activity) getContext(), new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 2);
        }
        if (ContextCompat.checkSelfPermission(getContext(), "android.permission.WRITE_EXTERNAL_STORAGE") != 0) {
            if (saveStatuCallback != null) {
                Map<String, Object> result = new HashMap<>();
                result.put(SUCCEED, false);
                result.put(ERRORDESC, "Permission denied: android.permission.WRITE_EXTERNAL_STORAGE");
                saveStatuCallback.invoke(result);
            }
        } else if (this.mHost != null) {
            String str = this.mSrc;
            if (str != null && !str.equals("")) {
                WXViewToImageUtil.generateImage(this.mHost, 0, -460552, new WXViewToImageUtil.OnImageSavedCallback() {
                    /* class com.taobao.weex.ui.component.WXImage.AnonymousClass2 */

                    @Override // com.taobao.weex.utils.WXViewToImageUtil.OnImageSavedCallback
                    public void onSaveSucceed(String path) {
                        if (saveStatuCallback != null) {
                            Map<String, Object> result = new HashMap<>();
                            result.put(WXImage.SUCCEED, true);
                            saveStatuCallback.invoke(result);
                        }
                    }

                    @Override // com.taobao.weex.utils.WXViewToImageUtil.OnImageSavedCallback
                    public void onSaveFailed(String errorDesc) {
                        if (saveStatuCallback != null) {
                            Map<String, Object> result = new HashMap<>();
                            result.put(WXImage.SUCCEED, false);
                            result.put(WXImage.ERRORDESC, errorDesc);
                            saveStatuCallback.invoke(result);
                        }
                    }
                });
            } else if (saveStatuCallback != null) {
                Map<String, Object> result2 = new HashMap<>();
                result2.put(SUCCEED, false);
                result2.put(ERRORDESC, "Image does not have the correct src");
                saveStatuCallback.invoke(result2);
            }
        } else if (saveStatuCallback != null) {
            Map<String, Object> result3 = new HashMap<>();
            result3.put(SUCCEED, false);
            result3.put(ERRORDESC, "Image component not initialized");
            saveStatuCallback.invoke(result3);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void monitorImgSize(ImageView imageView, String currentImgUrlStr) {
        WXSDKInstance instance;
        if (imageView != null && (instance = getInstance()) != null) {
            ViewGroup.LayoutParams params = imageView.getLayoutParams();
            Drawable img = imageView.getDrawable();
            if (params == null) {
                return;
            }
            if (img != null) {
                int imgHeight = img.getIntrinsicHeight();
                int imgWidth = img.getIntrinsicWidth();
                if (!this.preImgUrlStr.equals(currentImgUrlStr)) {
                    this.preImgUrlStr = currentImgUrlStr;
                    if (imgHeight > 1081 && imgWidth > 721) {
                        instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_LARGE_IMG_COUNT, 1.0d);
                        if (WXAnalyzerDataTransfer.isOpenPerformance) {
                            WXAnalyzerDataTransfer.transferPerformance(getInstanceId(), "details", WXInstanceApm.KEY_PAGE_STATS_LARGE_IMG_COUNT, imgWidth + "*" + imgHeight + "," + currentImgUrlStr);
                        }
                    }
                    long imgSize = (long) (imgHeight * imgWidth);
                    long viewSize = (long) (imageView.getMeasuredHeight() * imageView.getMeasuredWidth());
                    if (viewSize != 0) {
                        if (((double) imgSize) / ((double) viewSize) > 1.2d && imgSize - viewSize > 1600) {
                            instance.getWXPerformance().wrongImgSizeCount += 1.0d;
                            instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_WRONG_IMG_SIZE_COUNT, 1.0d);
                            if (WXAnalyzerDataTransfer.isOpenPerformance) {
                                WXAnalyzerDataTransfer.transferPerformance(getInstanceId(), "details", WXInstanceApm.KEY_PAGE_STATS_WRONG_IMG_SIZE_COUNT, StringUtil.format("imgSize:[%d,%d],viewSize:[%d,%d],urL:%s", Integer.valueOf(imgWidth), Integer.valueOf(imgHeight), Integer.valueOf(imageView.getMeasuredWidth()), Integer.valueOf(imageView.getMeasuredHeight()), currentImgUrlStr));
                            }
                        }
                    }
                }
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (!(getHostView() == null || getInstance() == null || !(getHostView() instanceof WXImageView) || getInstance().getImgLoaderAdapter() == null)) {
            getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
        }
        super.destroy();
    }

    public void onImageFinish(boolean result, Map extra) {
    }

    public class MyImageListener implements WXImageStrategy.ImageListener {
        private String rewritedStr;
        private WeakReference<WXImage> wxImageWeakReference;

        MyImageListener(WXImage image, String rewritedStr2) {
            this.wxImageWeakReference = new WeakReference<>(image);
            this.rewritedStr = rewritedStr2;
        }

        @Override // com.taobao.weex.common.WXImageStrategy.ImageListener
        public void onImageFinish(String url, ImageView imageView, boolean result, Map extra) {
            WXImage image = this.wxImageWeakReference.get();
            if (image != null) {
                if (extra == null) {
                    Map<String, Object> params = new HashMap<>();
                    params.put(WXImage.SUCCEED, false);
                    image.fireEvent("error", params);
                    return;
                }
                image.onImageFinish(result, extra);
                Map<String, Object> params2 = new HashMap<>();
                Map<String, Object> size = new HashMap<>(2);
                size.put("width", extra.get("width"));
                size.put("height", extra.get("height"));
                if (WXImage.this.mIsUni) {
                    if (!result && image.containsEvent("error")) {
                        params2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                        params2.put("detail", size);
                        image.fireEvent("error", params2);
                    }
                    if (result && image.containsEvent("load")) {
                        params2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                        params2.put("detail", size);
                        image.fireEvent("load", params2);
                    }
                } else if (image.containsEvent("load")) {
                    params2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                    params2.put("detail", size);
                    image.fireEvent("load", params2);
                }
                image.monitorImgSize(imageView, this.rewritedStr);
            }
        }
    }
}
