package com.taobao.weex.ui.component;

import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import androidx.core.view.ViewCompat;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.component.helper.WXStickyHelper;
import com.taobao.weex.ui.view.IWXScroller;
import com.taobao.weex.ui.view.WXBaseRefreshLayout;
import com.taobao.weex.ui.view.WXHorizontalScrollView;
import com.taobao.weex.ui.view.WXScrollView;
import com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceScrollerView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component(lazyload = false)
public class WXScroller extends WXBaseScroller {
    public static final String DIRECTION = "direction";
    private static final int SWIPE_MIN_DISTANCE = 5;
    private static final int SWIPE_THRESHOLD_VELOCITY = 300;
    private Handler handler;
    private boolean isScrollable;
    private int mActiveFeature;
    private Map<String, AppearanceHelper> mAppearanceComponents;
    private int mChildrenLayoutOffset;
    private int mContentHeight;
    private int mContentWidth;
    private boolean mForceLoadmoreNextTime;
    private GestureDetector mGestureDetector;
    private boolean mHasAddScrollEvent;
    private boolean mIsHostAttachedToWindow;
    private Boolean mIslastDirectionRTL;
    private Point mLastReport;
    private int mOffsetAccuracy;
    private View.OnAttachStateChangeListener mOnAttachStateChangeListener;
    protected int mOrientation;
    private FrameLayout mRealView;
    private List<WXComponent> mRefreshs;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private FrameLayout mScrollerView;
    private Map<String, Map<String, WXComponent>> mStickyMap;
    private boolean mlastDirectionRTL;
    private boolean pageEnable;
    private int pageSize;
    private WXStickyHelper stickyHelper;

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            instance.setUseScroller(true);
            return new WXScroller(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public WXScroller(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXScroller(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mOrientation = 1;
        this.mRefreshs = new ArrayList();
        this.mChildrenLayoutOffset = 0;
        this.mForceLoadmoreNextTime = false;
        this.mOffsetAccuracy = 10;
        this.mLastReport = new Point(-1, -1);
        this.mHasAddScrollEvent = false;
        this.mActiveFeature = 0;
        this.pageSize = 0;
        this.pageEnable = false;
        this.mIsHostAttachedToWindow = false;
        this.mlastDirectionRTL = false;
        this.mAppearanceComponents = new HashMap();
        this.mStickyMap = new HashMap();
        this.mContentHeight = 0;
        this.mContentWidth = 0;
        this.handler = new Handler(Looper.getMainLooper());
        this.isScrollable = true;
        this.stickyHelper = new WXStickyHelper(this);
        instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_SCROLLER_NUM, 1.0d);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return this.mScrollerView;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        super.createViewImpl();
        for (int i = 0; i < this.mRefreshs.size(); i++) {
            WXComponent component = this.mRefreshs.get(i);
            component.createViewImpl();
            checkRefreshOrLoading(component);
        }
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public ViewGroup getInnerView() {
        if (getHostView() == null) {
            return null;
        }
        if (getHostView() instanceof BounceScrollerView) {
            return (ViewGroup) ((BounceScrollerView) getHostView()).getInnerView();
        }
        return (ViewGroup) getHostView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (ScrollStartEndHelper.isScrollEvent(type) && getInnerView() != null && !this.mHasAddScrollEvent) {
            this.mHasAddScrollEvent = true;
            if (getInnerView() instanceof WXScrollView) {
                ((WXScrollView) getInnerView()).addScrollViewListener(new WXScrollView.WXScrollViewListener() {
                    /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass1 */

                    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                    public void onScrollChanged(WXScrollView scrollView, int x, int y, int oldx, int oldy) {
                        WXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                        if (WXScroller.this.getEvents().contains("scroll") && WXScroller.this.shouldReport(x, y)) {
                            WXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                        }
                    }

                    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                    public void onScrollToBottom(WXScrollView scrollView, int x, int y) {
                    }

                    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                    public void onScrollStopped(WXScrollView scrollView, int x, int y) {
                    }

                    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                    public void onScroll(WXScrollView scrollView, int x, int y) {
                    }
                });
            } else if (getInnerView() instanceof WXHorizontalScrollView) {
                ((WXHorizontalScrollView) getInnerView()).addScrollViewListener(new WXHorizontalScrollView.ScrollViewListener() {
                    /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass2 */

                    @Override // com.taobao.weex.ui.view.WXHorizontalScrollView.ScrollViewListener
                    public void onScrollChanged(WXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                        WXScroller.this.getScrollStartEndHelper().onScrolled(x, y);
                        if (WXScroller.this.getEvents().contains("scroll") && WXScroller.this.shouldReport(x, y)) {
                            WXScroller.this.fireScrollEvent(scrollView.getContentFrame(), x, y, oldx, oldy);
                        }
                    }
                });
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireScrollEvent(Rect contentFrame, int x, int y, int oldx, int oldy) {
        fireEvent("scroll", getScrollEvent(x, y));
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Object> getScrollEvent(int x, int y) {
        Rect contentFrame = new Rect();
        if (getInnerView() instanceof WXScrollView) {
            contentFrame = ((WXScrollView) getInnerView()).getContentFrame();
        } else if (getInnerView() instanceof WXHorizontalScrollView) {
            contentFrame = ((WXHorizontalScrollView) getInnerView()).getContentFrame();
        }
        Map<String, Object> event = new HashMap<>(2);
        Map<String, Object> contentSize = new HashMap<>(2);
        Map<String, Object> contentOffset = new HashMap<>(2);
        float viewport = getInstance().getInstanceViewPortWidthWithFloat();
        contentSize.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.width(), viewport)));
        contentSize.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentFrame.height(), viewport)));
        contentOffset.put(Constants.Name.X, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) x, viewport)));
        contentOffset.put(Constants.Name.Y, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) y, viewport)));
        event.put(Constants.Name.CONTENT_SIZE, contentSize);
        event.put(Constants.Name.CONTENT_OFFSET, contentOffset);
        return event;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean shouldReport(int x, int y) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation == 0 && Math.abs(x - this.mLastReport.x) >= this.mOffsetAccuracy) {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        } else if (this.mOrientation != 1 || Math.abs(y - this.mLastReport.y) < this.mOffsetAccuracy) {
            return false;
        } else {
            this.mLastReport.x = x;
            this.mLastReport.y = y;
            return true;
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
        FrameLayout frameLayout;
        if (child != null && (frameLayout = this.mRealView) != null && !(child instanceof WXBaseRefreshLayout)) {
            int index2 = index >= frameLayout.getChildCount() ? -1 : index;
            if (index2 == -1) {
                this.mRealView.addView(child);
            } else {
                this.mRealView.addView(child, index2);
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        int listSize;
        if (this.mChildrenLayoutOffset == 0 && (listSize = this.mRefreshs.size()) > 0) {
            for (int i = 0; i < listSize; i++) {
                this.mChildrenLayoutOffset += this.mRefreshs.get(i).getLayoutTopOffsetForSibling();
            }
        }
        return this.mChildrenLayoutOffset;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        if ((child instanceof WXBaseRefresh) && checkRefreshOrLoading(child)) {
            this.mRefreshs.add(child);
        }
        super.addChild(child, index);
    }

    private boolean checkRefreshOrLoading(final WXComponent child) {
        boolean result = false;
        if ((child instanceof WXRefresh) && getHostView() != null) {
            ((BaseBounceView) getHostView()).setOnRefreshListener((WXRefresh) child);
            this.handler.postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass3 */

                public void run() {
                    ((BaseBounceView) WXScroller.this.getHostView()).setHeaderView(child);
                }
            }), 100);
            result = true;
        }
        if (!(child instanceof WXLoading) || getHostView() == null) {
            return result;
        }
        ((BaseBounceView) getHostView()).setOnLoadingListener((WXLoading) child);
        this.handler.postDelayed(WXThread.secure(new Runnable() {
            /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass4 */

            public void run() {
                ((BaseBounceView) WXScroller.this.getHostView()).setFooterView(child);
            }
        }), 100);
        return true;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destory) {
        super.remove(child, destory);
        if (child instanceof WXLoading) {
            ((BaseBounceView) getHostView()).removeFooterView(child);
        } else if (child instanceof WXRefresh) {
            ((BaseBounceView) getHostView()).removeHeaderView(child);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        Map<String, AppearanceHelper> map = this.mAppearanceComponents;
        if (map != null) {
            map.clear();
        }
        Map<String, Map<String, WXComponent>> map2 = this.mStickyMap;
        if (map2 != null) {
            map2.clear();
        }
        if (!(this.mOnAttachStateChangeListener == null || getInnerView() == null)) {
            getInnerView().removeOnAttachStateChangeListener(this.mOnAttachStateChangeListener);
        }
        if (getInnerView() != null && (getInnerView() instanceof IWXScroller)) {
            ((IWXScroller) getInnerView()).destroy();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        if (Build.VERSION.SDK_INT >= 17) {
            lp.setMargins(left, top, right, bottom);
            lp.setMarginStart(left);
            lp.setMarginEnd(right);
        } else if (lp instanceof FrameLayout.LayoutParams) {
            FrameLayout.LayoutParams lp_frameLayout = (FrameLayout.LayoutParams) lp;
            if (isLayoutRTL()) {
                lp_frameLayout.gravity = 53;
                lp.setMargins(right, top, left, bottom);
                return;
            }
            lp_frameLayout.gravity = 51;
            lp.setMargins(left, top, right, bottom);
        } else {
            lp.setMargins(left, top, right, bottom);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        if (!TextUtils.isEmpty(component.getComponentType()) && !TextUtils.isEmpty(component.getRef()) && component.getLayoutPosition() != null && component.getLayoutSize() != null) {
            if (component.getHostView() != null) {
                ViewCompat.setLayoutDirection(component.getHostView(), component.isLayoutRTL() ? 1 : 0);
            }
            super.setLayout(component);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        WXComponent.MeasureOutput measureOutput = new WXComponent.MeasureOutput();
        int i = -1;
        if (this.mOrientation == 0) {
            int screenW = WXViewUtils.getScreenWidth(WXEnvironment.sApplication);
            int weexW = WXViewUtils.getWeexWidth(getInstanceId());
            if (width <= (weexW >= screenW ? screenW : weexW)) {
                i = width;
            }
            measureOutput.width = i;
            measureOutput.height = height;
        } else {
            int screenH = WXViewUtils.getScreenHeight(WXEnvironment.sApplication);
            int weexH = WXViewUtils.getWeexHeight(getInstanceId());
            if (height <= (weexH >= screenH ? screenH : weexH)) {
                i = height;
            }
            measureOutput.height = i;
            measureOutput.width = width;
        }
        return measureOutput;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v8, resolved type: com.taobao.weex.ui.view.WXHorizontalScrollView */
    /* JADX WARN: Multi-variable type inference failed */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public ViewGroup initComponentHostView(Context context) {
        String scroll;
        BounceScrollerView scrollerView;
        if (getAttrs().isEmpty()) {
            scroll = "vertical";
        } else {
            scroll = getAttrs().getScrollDirection();
            Object o = getAttrs().get(Constants.Name.PAGE_ENABLED);
            this.pageEnable = o != null && Boolean.parseBoolean(o.toString());
            Object pageSize2 = getAttrs().get(Constants.Name.PAGE_SIZE);
            if (pageSize2 != null) {
                float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(pageSize2), getInstance().getInstanceViewPortWidthWithFloat());
                if (realPxByWidth != 0.0f) {
                    this.pageSize = (int) realPxByWidth;
                }
            }
        }
        if (Constants.Value.HORIZONTAL.equals(scroll)) {
            this.mOrientation = 0;
            final WXHorizontalScrollView scrollView = new WXHorizontalScrollView(context);
            this.mRealView = new FrameLayout(context);
            scrollView.setScrollViewListener(new WXHorizontalScrollView.ScrollViewListener() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass5 */

                @Override // com.taobao.weex.ui.view.WXHorizontalScrollView.ScrollViewListener
                public void onScrollChanged(WXHorizontalScrollView scrollView, int x, int y, int oldx, int oldy) {
                    WXScroller.this.procAppear(x, y, oldx, oldy);
                    WXScroller.this.onLoadMore(scrollView, x, y);
                }
            });
            scrollView.addView(this.mRealView, new FrameLayout.LayoutParams(-1, -1));
            scrollView.setHorizontalScrollBarEnabled(false);
            this.mScrollerView = scrollView;
            final View.OnLayoutChangeListener listener = new View.OnLayoutChangeListener() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass6 */

                public void onLayoutChange(View view, final int left, int top, final int right, int bottom, final int oldLeft, int oldTop, final int oldRight, int oldBottom) {
                    scrollView.post(new Runnable() {
                        /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass6.AnonymousClass1 */

                        public void run() {
                            int changedWidth;
                            if (WXScroller.this.mIslastDirectionRTL != null && WXScroller.this.isLayoutRTL() != WXScroller.this.mIslastDirectionRTL.booleanValue()) {
                                int currentX = WXScroller.this.getScrollX();
                                scrollView.scrollTo((WXScroller.this.getInnerView().getChildAt(0).getWidth() - currentX) - WXScroller.this.getInnerView().getMeasuredWidth(), this.getScrollY());
                            } else if (WXScroller.this.isLayoutRTL() && (changedWidth = (right - left) - (oldRight - oldLeft)) != 0) {
                                scrollView.scrollBy(changedWidth, this.getScrollY());
                            }
                            WXScroller.this.mIslastDirectionRTL = new Boolean(WXScroller.this.isLayoutRTL());
                        }
                    });
                }
            };
            this.mRealView.addOnAttachStateChangeListener(new View.OnAttachStateChangeListener() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass7 */

                public void onViewAttachedToWindow(View view) {
                    view.addOnLayoutChangeListener(listener);
                }

                public void onViewDetachedFromWindow(View view) {
                    view.removeOnLayoutChangeListener(listener);
                }
            });
            if (this.pageEnable) {
                this.mGestureDetector = new GestureDetector(new MyGestureDetector(scrollView));
                scrollView.setOnTouchListener(new View.OnTouchListener() {
                    /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass8 */

                    public boolean onTouch(View v, MotionEvent event) {
                        if (WXScroller.this.pageSize == 0) {
                            WXScroller.this.pageSize = v.getMeasuredWidth();
                        }
                        if (WXScroller.this.mGestureDetector.onTouchEvent(event)) {
                            return true;
                        }
                        if (event.getAction() != 1 && event.getAction() != 3) {
                            return false;
                        }
                        int scrollX = WXScroller.this.getScrollX();
                        int featureWidth = WXScroller.this.pageSize;
                        WXScroller.this.mActiveFeature = ((featureWidth / 2) + scrollX) / featureWidth;
                        scrollView.smoothScrollTo(WXScroller.this.mActiveFeature * featureWidth, 0);
                        return true;
                    }
                });
            }
            scrollerView = scrollView;
        } else {
            this.mOrientation = 1;
            scrollerView = new BounceScrollerView(context, this.mOrientation, this);
            this.mRealView = new FrameLayout(context);
            WXScrollView innerView = (WXScrollView) scrollerView.getInnerView();
            innerView.addScrollViewListener(this);
            FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-1, -1);
            this.mScrollerView = innerView;
            innerView.addView(this.mRealView, layoutParams);
            innerView.setVerticalScrollBarEnabled(true);
            innerView.setNestedScrollingEnabled(WXUtils.getBoolean(getAttrs().get(Constants.Name.NEST_SCROLLING_ENABLED), true).booleanValue());
            innerView.addScrollViewListener(new WXScrollView.WXScrollViewListener() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass9 */

                @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                public void onScrollChanged(WXScrollView scrollView, int x, int y, int oldx, int oldy) {
                }

                @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                public void onScrollToBottom(WXScrollView scrollView, int x, int y) {
                }

                @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                public void onScrollStopped(WXScrollView scrollView, int x, int y) {
                    List<OnWXScrollListener> listeners = WXScroller.this.getInstance().getWXScrollListeners();
                    if (listeners != null && listeners.size() > 0) {
                        for (OnWXScrollListener listener : listeners) {
                            if (listener != null) {
                                listener.onScrollStateChanged(scrollView, x, y, 0);
                            }
                        }
                    }
                    WXScroller.this.getScrollStartEndHelper().onScrollStateChanged(0);
                }

                @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                public void onScroll(WXScrollView scrollView, int x, int y) {
                    List<OnWXScrollListener> listeners = WXScroller.this.getInstance().getWXScrollListeners();
                    if (listeners != null && listeners.size() > 0) {
                        for (OnWXScrollListener listener : listeners) {
                            if (listener != null) {
                                if (!(listener instanceof ICheckBindingScroller)) {
                                    listener.onScrolled(scrollView, x, y);
                                } else if (((ICheckBindingScroller) listener).isNeedScroller(WXScroller.this.getRef(), null)) {
                                    listener.onScrolled(scrollView, x, y);
                                }
                            }
                        }
                    }
                }
            });
        }
        scrollerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass10 */

            public void onGlobalLayout() {
                WXScroller.this.procAppear(0, 0, 0, 0);
                View view = WXScroller.this.getHostView();
                if (view != null) {
                    if (Build.VERSION.SDK_INT >= 16) {
                        view.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                    } else {
                        view.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                    }
                }
            }
        });
        AnonymousClass11 r2 = new View.OnAttachStateChangeListener() {
            /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass11 */

            public void onViewAttachedToWindow(View v) {
                WXScroller.this.mIsHostAttachedToWindow = true;
                WXScroller wXScroller = WXScroller.this;
                wXScroller.procAppear(wXScroller.getScrollX(), WXScroller.this.getScrollY(), WXScroller.this.getScrollX(), WXScroller.this.getScrollY());
            }

            public void onViewDetachedFromWindow(View v) {
                WXScroller.this.mIsHostAttachedToWindow = false;
                WXScroller.this.dispatchDisappearEvent();
            }
        };
        this.mOnAttachStateChangeListener = r2;
        scrollerView.addOnAttachStateChangeListener(r2);
        return scrollerView;
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getScrollY() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getScrollX() {
        if (getInnerView() == null) {
            return 0;
        }
        return getInnerView().getScrollX();
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public int getOrientation() {
        return this.mOrientation;
    }

    @Override // com.taobao.weex.ui.component.WXBaseScroller
    public Map<String, Map<String, WXComponent>> getStickMap() {
        return this.mStickyMap;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x0038  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0063  */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        int hashCode = key.hashCode();
        if (hashCode != -223520855) {
            if (hashCode != -5620052) {
                if (hashCode == 66669991 && key.equals(Constants.Name.SCROLLABLE)) {
                    c = 1;
                    if (c != 0) {
                        Boolean result = WXUtils.getBoolean(param, null);
                        if (result != null) {
                            setShowScrollbar(result.booleanValue());
                        }
                        return true;
                    } else if (c == 1) {
                        setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                        return true;
                    } else if (c != 2) {
                        return super.setProperty(key, param);
                    } else {
                        setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
                        return true;
                    }
                }
            } else if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                c = 2;
                if (c != 0) {
                }
            }
        } else if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
            c = 0;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getInnerView() != null) {
            if (this.mOrientation == 1) {
                getInnerView().setVerticalScrollBarEnabled(show);
            } else {
                getInnerView().setHorizontalScrollBarEnabled(show);
            }
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        this.isScrollable = scrollable;
        View hostView = getInnerView();
        if (hostView instanceof WXHorizontalScrollView) {
            ((WXHorizontalScrollView) hostView).setScrollable(scrollable);
        } else if (hostView instanceof WXScrollView) {
            ((WXScrollView) hostView).setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth((float) accuracy, getInstance().getInstanceViewPortWidthWithFloat());
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public boolean isScrollable() {
        return this.isScrollable;
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindStickStyle(WXComponent component) {
        this.stickyHelper.bindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindStickStyle(WXComponent component) {
        this.stickyHelper.unbindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindAppearEvent(WXComponent component) {
        setWatch(0, component, true);
    }

    private void setWatch(int event, WXComponent component, boolean isWatch) {
        AppearanceHelper item = this.mAppearanceComponents.get(component.getRef());
        if (item == null) {
            item = new AppearanceHelper(component);
            this.mAppearanceComponents.put(component.getRef(), item);
        }
        item.setWatchEvent(event, isWatch);
        procAppear(0, 0, 0, 0);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void bindDisappearEvent(WXComponent component) {
        setWatch(1, component, true);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindAppearEvent(WXComponent component) {
        setWatch(0, component, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void unbindDisappearEvent(WXComponent component) {
        setWatch(1, component, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable, com.taobao.weex.ui.component.WXBaseScroller
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int viewXInScroller;
        float offsetFloat = 0.0f;
        boolean smooth = true;
        if (options != null) {
            String offset = options.get("offset") == null ? "0" : options.get("offset").toString();
            smooth = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (offset != null) {
                try {
                    offsetFloat = WXViewUtils.getRealPxByWidth(Float.parseFloat(offset), getInstance().getInstanceViewPortWidthWithFloat());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
        }
        if (this.pageEnable) {
            this.mActiveFeature = this.mChildren.indexOf(component);
        }
        int viewYInScroller = component.getAbsoluteY() - getAbsoluteY();
        if (isLayoutRTL()) {
            if (component.getParent() == null || component.getParent() != this) {
                viewXInScroller = ((int) component.getLayoutWidth()) + ((component.getAbsoluteX() - getAbsoluteX()) - getInnerView().getMeasuredWidth());
            } else if (getInnerView().getChildCount() > 0) {
                viewXInScroller = (getInnerView().getChildAt(0).getWidth() - (component.getAbsoluteX() - getAbsoluteX())) - getInnerView().getMeasuredWidth();
            } else {
                viewXInScroller = component.getAbsoluteX() - getAbsoluteX();
            }
            offsetFloat = -offsetFloat;
        } else {
            viewXInScroller = component.getAbsoluteX() - getAbsoluteX();
        }
        scrollBy((viewXInScroller - getScrollX()) + ((int) offsetFloat), (viewYInScroller - getScrollY()) + ((int) offsetFloat), smooth);
    }

    public void scrollBy(int x, int y) {
        scrollBy(x, y, false);
    }

    public void scrollBy(final int x, final int y, final boolean smooth) {
        if (getInnerView() != null) {
            getInnerView().postDelayed(new Runnable() {
                /* class com.taobao.weex.ui.component.WXScroller.AnonymousClass12 */

                public void run() {
                    if (WXScroller.this.mOrientation == 1) {
                        if (smooth) {
                            ((WXScrollView) WXScroller.this.getInnerView()).smoothScrollBy(0, y);
                        } else {
                            ((WXScrollView) WXScroller.this.getInnerView()).scrollBy(0, y);
                        }
                    } else if (smooth) {
                        ((WXHorizontalScrollView) WXScroller.this.getInnerView()).smoothScrollBy(x, 0);
                    } else {
                        ((WXHorizontalScrollView) WXScroller.this.getInnerView()).scrollBy(x, 0);
                    }
                    WXScroller.this.getInnerView().invalidate();
                }
            }, 16);
        }
    }

    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener, com.taobao.weex.ui.component.WXBaseScroller
    public void onScrollChanged(WXScrollView scrollView, int x, int y, int oldx, int oldy) {
        procAppear(x, y, oldx, oldy);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        if (containsEvent(Constants.Event.APPEAR) || containsEvent(Constants.Event.DISAPPEAR)) {
            Map<String, Object> params = new HashMap<>();
            params.put("direction", direction);
            fireEvent(wxEventType, params);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void procAppear(int x, int y, int oldx, int oldy) {
        String direction;
        int result;
        if (this.mIsHostAttachedToWindow) {
            int moveY = y - oldy;
            int moveX = x - oldx;
            if (moveY > 0) {
                direction = "up";
            } else {
                direction = moveY < 0 ? "down" : null;
            }
            if (this.mOrientation == 0 && moveX != 0) {
                direction = moveX > 0 ? "right" : "left";
            }
            for (Map.Entry<String, AppearanceHelper> item : this.mAppearanceComponents.entrySet()) {
                AppearanceHelper helper = item.getValue();
                if (helper.isWatch() && (result = helper.setAppearStatus(checkItemVisibleInScroller(helper.getAwareChild()))) != 0) {
                    helper.getAwareChild().notifyAppearStateChange(result == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, direction);
                }
            }
        }
    }

    private boolean checkItemVisibleInScroller(WXComponent component) {
        boolean visible = false;
        while (component != null && !(component instanceof WXScroller)) {
            if (component.getParent() instanceof WXScroller) {
                boolean z = true;
                if (this.mOrientation == 0) {
                    int offsetLeft = ((int) component.getLayoutPosition().getLeft()) - getScrollX();
                    if (((float) offsetLeft) <= 0.0f - component.getLayoutWidth() || ((float) offsetLeft) >= getLayoutWidth()) {
                        z = false;
                    }
                    visible = z;
                } else {
                    int offsetTop = ((int) component.getLayoutPosition().getTop()) - getScrollY();
                    if (((float) offsetTop) <= 0.0f - component.getLayoutHeight() || ((float) offsetTop) >= getLayoutHeight()) {
                        z = false;
                    }
                    visible = z;
                }
            }
            component = component.getParent();
        }
        return visible;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchDisappearEvent() {
        int result;
        for (Map.Entry<String, AppearanceHelper> item : this.mAppearanceComponents.entrySet()) {
            AppearanceHelper helper = item.getValue();
            if (helper.isWatch() && (result = helper.setAppearStatus(false)) != 0) {
                helper.getAwareChild().notifyAppearStateChange(result == 1 ? Constants.Event.APPEAR : Constants.Event.DISAPPEAR, "");
            }
        }
    }

    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener, com.taobao.weex.ui.component.WXBaseScroller
    public void onScrollToBottom(WXScrollView scrollView, int x, int y) {
    }

    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener, com.taobao.weex.ui.component.WXBaseScroller
    public void onScrollStopped(WXScrollView scrollView, int x, int y) {
    }

    @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener, com.taobao.weex.ui.component.WXBaseScroller
    public void onScroll(WXScrollView scrollView, int x, int y) {
        onLoadMore(scrollView, x, y);
    }

    /* access modifiers changed from: protected */
    public void onLoadMore(FrameLayout scrollView, int x, int y) {
        try {
            String offset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(offset)) {
                offset = String.valueOf(1);
            }
            int offsetInt = (int) WXViewUtils.getRealPxByWidth(Float.parseFloat(offset), getInstance().getInstanceViewPortWidthWithFloat());
            if (scrollView instanceof WXHorizontalScrollView) {
                int contentWidth = scrollView.getChildAt(0).getWidth();
                if ((contentWidth - x) - scrollView.getWidth() >= offsetInt) {
                    return;
                }
                if (this.mContentWidth != contentWidth || this.mForceLoadmoreNextTime) {
                    fireEvent(Constants.Event.LOADMORE);
                    this.mContentWidth = contentWidth;
                    this.mForceLoadmoreNextTime = false;
                    return;
                }
                return;
            }
            int contentH = scrollView.getChildAt(0).getHeight();
            int offScreenY = (contentH - y) - scrollView.getHeight();
            if (offScreenY < offsetInt) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("[WXScroller-onScroll] offScreenY :" + offScreenY);
                }
                if (this.mContentHeight != contentH || this.mForceLoadmoreNextTime) {
                    fireEvent(Constants.Event.LOADMORE);
                    this.mContentHeight = contentH;
                    this.mForceLoadmoreNextTime = false;
                }
            }
        } catch (Exception e) {
            WXLogUtils.d("[WXScroller-onScroll] ", e);
        }
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    /* access modifiers changed from: package-private */
    public class MyGestureDetector extends GestureDetector.SimpleOnGestureListener {
        private final WXHorizontalScrollView scrollView;

        public WXHorizontalScrollView getScrollView() {
            return this.scrollView;
        }

        MyGestureDetector(WXHorizontalScrollView horizontalScrollView) {
            this.scrollView = horizontalScrollView;
        }

        public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
            int mItems = WXScroller.this.mChildren.size();
            try {
                if (e1.getX() - e2.getX() <= 5.0f || Math.abs(velocityX) <= 300.0f) {
                    if (e2.getX() - e1.getX() > 5.0f && Math.abs(velocityX) > 300.0f) {
                        int featureWidth = WXScroller.this.pageSize;
                        WXScroller.this.mActiveFeature = WXScroller.this.mActiveFeature > 0 ? WXScroller.this.mActiveFeature - 1 : 0;
                        this.scrollView.smoothScrollTo(WXScroller.this.mActiveFeature * featureWidth, 0);
                        return true;
                    }
                    return false;
                }
                int featureWidth2 = WXScroller.this.pageSize;
                WXScroller.this.mActiveFeature = WXScroller.this.mActiveFeature < mItems + -1 ? WXScroller.this.mActiveFeature + 1 : mItems - 1;
                this.scrollView.smoothScrollTo(WXScroller.this.mActiveFeature * featureWidth2, 0);
                return true;
            } catch (Exception e) {
                WXLogUtils.e("There was an error processing the Fling event:" + e.getMessage());
            }
        }
    }
}
