package com.taobao.weex.ui.component;

import android.content.Context;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.WXCircleIndicator;
import com.taobao.weex.ui.view.WXCirclePageAdapter;
import com.taobao.weex.ui.view.WXCircleViewPager;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
import java.util.HashMap;
import java.util.Map;

@Component(lazyload = false)
public class WXSlider extends WXVContainer<FrameLayout> {
    public static final String INDEX = "index";
    public static final String INFINITE = "infinite";
    private int initIndex;
    private Runnable initRunnable;
    private boolean isInfinite;
    private boolean keepIndex;
    protected WXCirclePageAdapter mAdapter;
    protected WXIndicator mIndicator;
    protected ViewPager.OnPageChangeListener mPageChangeListener;
    protected boolean mShowIndicators;
    WXCircleViewPager mViewPager;
    private float offsetXAccuracy;
    Map<String, Object> params;

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXSlider(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public WXSlider(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXSlider(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.isInfinite = true;
        this.params = new HashMap();
        this.offsetXAccuracy = 0.1f;
        this.initIndex = -1;
        this.keepIndex = false;
        this.mPageChangeListener = new SliderPageChangeListener();
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BaseFrameLayout initComponentHostView(Context context) {
        BaseFrameLayout view = new BaseFrameLayout(context);
        if (getAttrs() != null) {
            this.isInfinite = WXUtils.getBoolean(getAttrs().get("infinite"), true).booleanValue();
        }
        FrameLayout.LayoutParams pagerParams = new FrameLayout.LayoutParams(-1, -1);
        WXCircleViewPager wXCircleViewPager = new WXCircleViewPager(context);
        this.mViewPager = wXCircleViewPager;
        wXCircleViewPager.setCircle(this.isInfinite);
        this.mViewPager.setLayoutParams(pagerParams);
        WXCirclePageAdapter wXCirclePageAdapter = new WXCirclePageAdapter(this.isInfinite);
        this.mAdapter = wXCirclePageAdapter;
        this.mViewPager.setAdapter(wXCirclePageAdapter);
        view.addView(this.mViewPager);
        this.mViewPager.addOnPageChangeListener(this.mPageChangeListener);
        registerActivityStateListener();
        return view;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View childView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.LayoutParams lp = childView.getLayoutParams();
        if (lp == null) {
            lp = new FrameLayout.LayoutParams(width, height);
        } else {
            lp.width = width;
            lp.height = height;
        }
        if (lp instanceof ViewGroup.MarginLayoutParams) {
            if (child instanceof WXIndicator) {
                setMarginsSupportRTL((ViewGroup.MarginLayoutParams) lp, left, top, right, bottom);
            } else {
                setMarginsSupportRTL((ViewGroup.MarginLayoutParams) lp, 0, 0, 0, 0);
            }
        }
        return lp;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        WXCircleViewPager wXCircleViewPager;
        super.addEvent(type);
        if ("scroll".equals(type) && (wXCircleViewPager = this.mViewPager) != null) {
            wXCircleViewPager.addOnPageChangeListener(new SliderOnScrollListener(this));
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean containsGesture(WXGestureType WXGestureType) {
        return super.containsGesture(WXGestureType);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return this.mViewPager;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View view, int index) {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (view != null && (wXCirclePageAdapter = this.mAdapter) != null && !(view instanceof WXCircleIndicator)) {
            wXCirclePageAdapter.addPageView(view);
            hackTwoItemsInfiniteScroll();
            if (this.initIndex != -1 && this.mAdapter.getRealCount() > this.initIndex) {
                if (this.initRunnable == null) {
                    this.initRunnable = new Runnable() {
                        /* class com.taobao.weex.ui.component.WXSlider.AnonymousClass1 */

                        public void run() {
                            WXSlider wXSlider = WXSlider.this;
                            wXSlider.initIndex = wXSlider.getInitIndex();
                            WXCircleViewPager wXCircleViewPager = WXSlider.this.mViewPager;
                            WXSlider wXSlider2 = WXSlider.this;
                            wXCircleViewPager.setCurrentItem(wXSlider2.getRealIndex(wXSlider2.initIndex));
                            WXSlider.this.initIndex = -1;
                            WXSlider.this.initRunnable = null;
                        }
                    };
                }
                this.mViewPager.removeCallbacks(this.initRunnable);
                this.mViewPager.postDelayed(this.initRunnable, 50);
            } else if (!this.keepIndex) {
                this.mViewPager.setCurrentItem(getRealIndex(0));
            }
            WXIndicator wXIndicator = this.mIndicator;
            if (wXIndicator != null) {
                ((WXCircleIndicator) wXIndicator.getHostView()).forceLayout();
                ((WXCircleIndicator) this.mIndicator.getHostView()).requestLayout();
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        WXCirclePageAdapter wXCirclePageAdapter = this.mAdapter;
        if (wXCirclePageAdapter != null) {
            wXCirclePageAdapter.setLayoutDirectionRTL(isLayoutRTL());
        }
        super.setLayout(component);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (child != null && child.getHostView() != null && (wXCirclePageAdapter = this.mAdapter) != null) {
            wXCirclePageAdapter.removePageView(child.getHostView());
            hackTwoItemsInfiniteScroll();
            super.remove(child, destroy);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        WXCircleViewPager wXCircleViewPager = this.mViewPager;
        if (wXCircleViewPager != null) {
            wXCircleViewPager.stopAutoScroll();
            this.mViewPager.removeAllViews();
            this.mViewPager.destory();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        super.onActivityResume();
        WXCircleViewPager wXCircleViewPager = this.mViewPager;
        if (wXCircleViewPager != null && wXCircleViewPager.isAutoScroll()) {
            this.mViewPager.startAutoScroll();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityStop() {
        super.onActivityStop();
        WXCircleViewPager wXCircleViewPager = this.mViewPager;
        if (wXCircleViewPager != null) {
            wXCircleViewPager.pauseAutoScroll();
        }
    }

    public void addIndicator(WXIndicator indicator) {
        FrameLayout root = (FrameLayout) getHostView();
        if (root != null) {
            this.mIndicator = indicator;
            WXCircleIndicator indicatorView = (WXCircleIndicator) indicator.getHostView();
            if (indicatorView != null) {
                indicatorView.setCircleViewPager(this.mViewPager);
                root.addView(indicatorView);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getInitIndex() {
        int select = WXUtils.getInteger(getAttrs().get("index"), Integer.valueOf(this.initIndex)).intValue();
        WXCirclePageAdapter wXCirclePageAdapter = this.mAdapter;
        if (wXCirclePageAdapter == null || wXCirclePageAdapter.getCount() == 0) {
            return 0;
        }
        if (select >= this.mAdapter.getRealCount()) {
            return select % this.mAdapter.getRealCount();
        }
        return select;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private int getRealIndex(int idx) {
        int retIdx = idx;
        if (this.mAdapter.getRealCount() > 0) {
            if (idx >= this.mAdapter.getRealCount()) {
                retIdx = this.mAdapter.getRealCount() - 1;
            }
            if (isLayoutRTL()) {
                retIdx = (this.mAdapter.getRealCount() - 1) - retIdx;
            }
        }
        return retIdx + 0;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -1768064947:
                if (key.equals(Constants.Name.KEEP_INDEX)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 100346066:
                if (key.equals("index")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 111972721:
                if (key.equals("value")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 570418373:
                if (key.equals("interval")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 996926241:
                if (key.equals(Constants.Name.SHOW_INDICATORS)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1438608771:
                if (key.equals(Constants.Name.AUTO_PLAY)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 1565939262:
                if (key.equals(Constants.Name.OFFSET_X_ACCURACY)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                String value = WXUtils.getString(param, null);
                if (value != null) {
                    setValue(value);
                }
                return true;
            case 1:
                String aotu_play = WXUtils.getString(param, null);
                if (aotu_play != null) {
                    setAutoPlay(aotu_play);
                }
                return true;
            case 2:
                String indicators = WXUtils.getString(param, null);
                if (indicators != null) {
                    setShowIndicators(indicators);
                }
                return true;
            case 3:
                Integer interval = WXUtils.getInteger(param, null);
                if (interval != null) {
                    setInterval(interval.intValue());
                }
                return true;
            case 4:
                Integer index = WXUtils.getInteger(param, null);
                if (index != null) {
                    setIndex(index.intValue());
                }
                return true;
            case 5:
                Float accuracy = WXUtils.getFloat(param, Float.valueOf(0.1f));
                if (accuracy.floatValue() != 0.0f) {
                    setOffsetXAccuracy(accuracy.floatValue());
                }
                return true;
            case 6:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            case 7:
                this.keepIndex = WXUtils.getBoolean(param, false).booleanValue();
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = "value")
    @Deprecated
    public void setValue(String value) {
        if (value != null && getHostView() != null) {
            try {
                setIndex(Integer.parseInt(value));
            } catch (NumberFormatException e) {
                WXLogUtils.e("", e);
            }
        }
    }

    @WXComponentProp(name = Constants.Name.AUTO_PLAY)
    public void setAutoPlay(String autoPlay) {
        if (TextUtils.isEmpty(autoPlay) || autoPlay.equals(AbsoluteConst.FALSE)) {
            this.mViewPager.stopAutoScroll();
            return;
        }
        this.mViewPager.stopAutoScroll();
        this.mViewPager.startAutoScroll();
    }

    @WXComponentProp(name = Constants.Name.SHOW_INDICATORS)
    public void setShowIndicators(String show) {
        if (TextUtils.isEmpty(show) || show.equals(AbsoluteConst.FALSE)) {
            this.mShowIndicators = false;
        } else {
            this.mShowIndicators = true;
        }
        WXIndicator wXIndicator = this.mIndicator;
        if (wXIndicator != null) {
            wXIndicator.setShowIndicators(this.mShowIndicators);
        }
    }

    @WXComponentProp(name = "interval")
    public void setInterval(int intervalMS) {
        WXCircleViewPager wXCircleViewPager = this.mViewPager;
        if (wXCircleViewPager != null && intervalMS > 0) {
            wXCircleViewPager.setIntervalTime((long) intervalMS);
        }
    }

    @WXComponentProp(name = "index")
    public void setIndex(int index) {
        WXCirclePageAdapter wXCirclePageAdapter;
        WXCirclePageAdapter wXCirclePageAdapter2;
        if (this.mViewPager != null && (wXCirclePageAdapter = this.mAdapter) != null) {
            if (index >= wXCirclePageAdapter.getRealCount() || index < 0) {
                this.initIndex = index;
                return;
            }
            int index2 = getRealIndex(index);
            this.mViewPager.setCurrentItem(index2);
            WXIndicator wXIndicator = this.mIndicator;
            if (wXIndicator != null && wXIndicator.getHostView() != null && ((WXCircleIndicator) this.mIndicator.getHostView()).getRealCurrentItem() != index2) {
                WXLogUtils.d("setIndex >>>> correction indicator to " + index2);
                ((WXCircleIndicator) this.mIndicator.getHostView()).setRealCurrentItem(index2);
                ((WXCircleIndicator) this.mIndicator.getHostView()).invalidate();
                ViewPager.OnPageChangeListener onPageChangeListener = this.mPageChangeListener;
                if (onPageChangeListener != null && (wXCirclePageAdapter2 = this.mAdapter) != null) {
                    onPageChangeListener.onPageSelected(wXCirclePageAdapter2.getFirst() + index2);
                }
            }
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        WXCircleViewPager wXCircleViewPager = this.mViewPager;
        if (wXCircleViewPager != null && this.mAdapter != null) {
            wXCircleViewPager.setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_X_ACCURACY)
    public void setOffsetXAccuracy(float accuracy) {
        this.offsetXAccuracy = accuracy;
    }

    protected class SliderPageChangeListener implements ViewPager.OnPageChangeListener {
        private int lastPos = -1;

        protected SliderPageChangeListener() {
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageSelected(int pos) {
            if (WXSlider.this.mAdapter.getRealPosition(pos) != this.lastPos) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("onPageSelected >>>>" + WXSlider.this.mAdapter.getRealPosition(pos) + " lastPos: " + this.lastPos);
                }
                if (WXSlider.this.mAdapter != null && WXSlider.this.mAdapter.getRealCount() != 0) {
                    int realPosition = WXSlider.this.mAdapter.getRealPosition(pos);
                    if (WXSlider.this.mChildren != null && realPosition < WXSlider.this.mChildren.size() && WXSlider.this.getEvents().size() != 0) {
                        WXEvent event = WXSlider.this.getEvents();
                        String ref = WXSlider.this.getRef();
                        if (event.contains(Constants.Event.CHANGE) && WXViewUtils.onScreenArea(WXSlider.this.getHostView())) {
                            WXSlider.this.params.put("index", Integer.valueOf(realPosition));
                            Map<String, Object> domChanges = new HashMap<>();
                            Map<String, Object> attrsChanges = new HashMap<>();
                            attrsChanges.put("index", Integer.valueOf(realPosition));
                            domChanges.put(TemplateDom.KEY_ATTRS, attrsChanges);
                            WXSDKManager.getInstance().fireEvent(WXSlider.this.getInstanceId(), ref, Constants.Event.CHANGE, WXSlider.this.params, domChanges);
                        }
                        WXSlider.this.mViewPager.requestLayout();
                        ((FrameLayout) WXSlider.this.getHostView()).invalidate();
                        this.lastPos = WXSlider.this.mAdapter.getRealPosition(pos);
                    }
                }
            }
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrollStateChanged(int arg0) {
            FrameLayout root = (FrameLayout) WXSlider.this.getHostView();
            if (root != null) {
                root.invalidate();
            }
        }
    }

    protected static class SliderOnScrollListener implements ViewPager.OnPageChangeListener {
        private float lastPositionOffset = 99.0f;
        private int selectedPosition;
        private WXSlider target;

        public SliderOnScrollListener(WXSlider target2) {
            this.target = target2;
            this.selectedPosition = target2.mViewPager.superGetCurrentItem();
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
            float f = this.lastPositionOffset;
            if (f == 99.0f) {
                this.lastPositionOffset = positionOffset;
            } else if (Math.abs(positionOffset - f) >= this.target.offsetXAccuracy) {
                int i = this.selectedPosition;
                if (position == i) {
                    Map<String, Object> event = new HashMap<>(1);
                    event.put(Constants.Name.OFFSET_X_RATIO, Float.valueOf(-positionOffset));
                    this.target.fireEvent("scroll", event);
                } else if (position < i) {
                    Map<String, Object> event2 = new HashMap<>(1);
                    event2.put(Constants.Name.OFFSET_X_RATIO, Float.valueOf(1.0f - positionOffset));
                    this.target.fireEvent("scroll", event2);
                }
                this.lastPositionOffset = positionOffset;
            }
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageSelected(int position) {
            this.selectedPosition = position;
        }

        @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
        public void onPageScrollStateChanged(int state) {
            if (state == 0) {
                this.lastPositionOffset = 99.0f;
                this.target.fireEvent(Constants.Event.SCROLL_END);
            } else if (state == 1) {
                this.target.fireEvent(Constants.Event.SCROLL_START);
            }
        }
    }

    private void hackTwoItemsInfiniteScroll() {
        WXCirclePageAdapter wXCirclePageAdapter;
        if (this.mViewPager != null && (wXCirclePageAdapter = this.mAdapter) != null && this.isInfinite) {
            if (wXCirclePageAdapter.getRealCount() == 2) {
                final GestureDetector gestureDetector = new GestureDetector(getContext(), new FlingGestureListener(this.mViewPager));
                this.mViewPager.setOnTouchListener(new View.OnTouchListener() {
                    /* class com.taobao.weex.ui.component.WXSlider.AnonymousClass2 */

                    public boolean onTouch(View v, MotionEvent event) {
                        return gestureDetector.onTouchEvent(event);
                    }
                });
                return;
            }
            this.mViewPager.setOnTouchListener(null);
        }
    }

    /* access modifiers changed from: private */
    public static class FlingGestureListener extends GestureDetector.SimpleOnGestureListener {
        private static final int SWIPE_MAX_OFF_PATH = WXViewUtils.dip2px(250.0f);
        private static final int SWIPE_MIN_DISTANCE = WXViewUtils.dip2px(50.0f);
        private static final int SWIPE_THRESHOLD_VELOCITY = WXViewUtils.dip2px(200.0f);
        private WeakReference<WXCircleViewPager> pagerRef;

        FlingGestureListener(WXCircleViewPager pager) {
            this.pagerRef = new WeakReference<>(pager);
        }

        public boolean onFling(MotionEvent e1, MotionEvent e2, float velocityX, float velocityY) {
            WXCircleViewPager mViewPager = this.pagerRef.get();
            if (mViewPager == null) {
                return false;
            }
            try {
                if (Math.abs(e1.getY() - e2.getY()) > ((float) SWIPE_MAX_OFF_PATH)) {
                    return false;
                }
                if (e1.getX() - e2.getX() <= ((float) SWIPE_MIN_DISTANCE) || Math.abs(velocityX) <= ((float) SWIPE_THRESHOLD_VELOCITY) || mViewPager.superGetCurrentItem() != 1) {
                    if (e2.getX() - e1.getX() > ((float) SWIPE_MIN_DISTANCE) && Math.abs(velocityX) > ((float) SWIPE_THRESHOLD_VELOCITY) && mViewPager.superGetCurrentItem() == 0) {
                        mViewPager.setCurrentItem(1, false);
                        return true;
                    }
                    return false;
                }
                mViewPager.setCurrentItem(0, false);
                return true;
            } catch (Exception e) {
            }
        }
    }
}
