package com.taobao.weex.ui.component;

import android.content.Context;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.WXCircleIndicator;
import com.taobao.weex.ui.view.WXCirclePageAdapter;
import com.taobao.weex.ui.view.WXCircleViewPager;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.lang.reflect.InvocationTargetException;
import java.util.List;

public class WXSliderNeighbor extends WXSlider {
    public static final String CURRENT_ITEM_SCALE = "currentItemScale";
    private static final float DEFAULT_CURRENT_ITEM_SCALE = 0.9f;
    private static final float DEFAULT_NEIGHBOR_ALPHA = 0.6f;
    private static final float DEFAULT_NEIGHBOR_SCALE = 0.8f;
    private static final int DEFAULT_NEIGHBOR_SPACE = 25;
    public static final String NEIGHBOR_ALPHA = "neighborAlpha";
    public static final String NEIGHBOR_SCALE = "neighborScale";
    public static final String NEIGHBOR_SPACE = "neighborSpace";
    private ZoomTransformer mCachedTransformer;
    private float mCurrentItemScale = 0.9f;
    private float mNeighborAlpha = DEFAULT_NEIGHBOR_ALPHA;
    private float mNeighborScale = DEFAULT_NEIGHBOR_SCALE;
    private float mNeighborSpace = 25.0f;

    public WXSliderNeighbor(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
    }

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXSliderNeighbor(instance, parent, basicComponentData);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void bindData(WXComponent component) {
        super.bindData(component);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXSlider, com.taobao.weex.ui.component.WXSlider, com.taobao.weex.ui.component.WXComponent
    public BaseFrameLayout initComponentHostView(Context context) {
        BaseFrameLayout view = new BaseFrameLayout(context);
        FrameLayout.LayoutParams pagerParams = new FrameLayout.LayoutParams(-1, -1);
        pagerParams.gravity = 17;
        this.mViewPager = new WXCircleViewPager(getContext());
        this.mViewPager.setLayoutParams(pagerParams);
        this.mAdapter = new WXCirclePageAdapter();
        this.mViewPager.setAdapter(this.mAdapter);
        view.addView(this.mViewPager);
        this.mViewPager.addOnPageChangeListener(this.mPageChangeListener);
        this.mViewPager.setOverScrollMode(2);
        registerActivityStateListener();
        this.mViewPager.setPageTransformer(false, createTransformer());
        return view;
    }

    /* access modifiers changed from: package-private */
    public ZoomTransformer createTransformer() {
        if (this.mCachedTransformer == null) {
            this.mCachedTransformer = new ZoomTransformer();
        }
        return this.mCachedTransformer;
    }

    @Override // com.taobao.weex.ui.component.WXSlider, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View view, final int index) {
        if (view != null && this.mAdapter != null && !(view instanceof WXCircleIndicator)) {
            FrameLayout wrapper = new FrameLayout(getContext());
            FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(-2, -2);
            params.gravity = 17;
            view.setLayoutParams(params);
            wrapper.addView(view);
            super.addSubView(wrapper, index);
            updateAdapterScaleAndAlpha(this.mNeighborAlpha, this.mNeighborScale);
            this.mViewPager.postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.WXSliderNeighbor.AnonymousClass1 */

                public void run() {
                    try {
                        if (WXSliderNeighbor.this.mViewPager.getRealCount() > 0 && index > 2) {
                            WXSliderNeighbor.this.mViewPager.beginFakeDrag();
                            WXSliderNeighbor.this.mViewPager.fakeDragBy(1.0f);
                        }
                        try {
                            WXSliderNeighbor.this.mViewPager.endFakeDrag();
                        } catch (Exception e) {
                        }
                    } catch (IndexOutOfBoundsException e2) {
                        WXSliderNeighbor.this.mViewPager.endFakeDrag();
                    } catch (Throwable th) {
                        try {
                            WXSliderNeighbor.this.mViewPager.endFakeDrag();
                        } catch (Exception e3) {
                        }
                        throw th;
                    }
                }
            }), 50);
        }
    }

    private void updateScaleAndAlpha(View view, float alpha, float scale) {
        if (view != null) {
            if (alpha >= 0.0f && view.getAlpha() != alpha) {
                view.setAlpha(alpha);
            }
            if (scale >= 0.0f && view.getScaleX() != scale) {
                view.setScaleX(scale);
                view.setScaleY(scale);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateAdapterScaleAndAlpha(final float alpha, final float scale) {
        List<View> pageViews = this.mAdapter.getViews();
        int curPos = this.mViewPager.getCurrentItem();
        if (pageViews.size() > 0) {
            final View currentPage = pageViews.get(curPos);
            updateScaleAndAlpha(((ViewGroup) currentPage).getChildAt(0), 1.0f, this.mCurrentItemScale);
            if (pageViews.size() >= 2) {
                currentPage.postDelayed(WXThread.secure(new Runnable() {
                    /* class com.taobao.weex.ui.component.WXSliderNeighbor.AnonymousClass2 */

                    public void run() {
                        WXSliderNeighbor.this.updateNeighbor(currentPage, alpha, scale);
                    }
                }), 17);
                int left = curPos == 0 ? pageViews.size() - 1 : curPos - 1;
                int right = curPos == pageViews.size() + -1 ? 0 : curPos + 1;
                for (int i = 0; i < this.mAdapter.getRealCount(); i++) {
                    if (!(i == left || i == curPos || i == right)) {
                        ((ViewGroup) pageViews.get(i)).getChildAt(0).setAlpha(0.0f);
                    }
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateNeighbor(View currentPage, float alpha, float scale) {
        List<View> pageViews = this.mAdapter.getViews();
        int curPos = this.mViewPager.getCurrentItem();
        float translation = calculateTranslation(currentPage);
        View leftPage = pageViews.get(curPos == 0 ? pageViews.size() - 1 : curPos - 1);
        View rightPage = pageViews.get(curPos == pageViews.size() - 1 ? 0 : curPos + 1);
        if (pageViews.size() != 2) {
            moveLeft(leftPage, translation, alpha, scale);
            moveRight(rightPage, translation, alpha, scale);
        } else if (curPos == 0) {
            moveRight(rightPage, translation, alpha, scale);
        } else if (curPos == 1) {
            moveLeft(leftPage, translation, alpha, scale);
        }
    }

    private void moveLeft(View page, float translation, float alpha, float scale) {
        updateScaleAndAlpha(((ViewGroup) page).getChildAt(0), alpha, scale);
        page.setTranslationX(translation);
        ((ViewGroup) page).getChildAt(0).setTranslationX(translation);
    }

    private void moveRight(View page, float translation, float alpha, float scale) {
        moveLeft(page, -translation, alpha, scale);
    }

    @WXComponentProp(name = NEIGHBOR_SCALE)
    public void setNeighborScale(String input) {
        float neighborScale = DEFAULT_NEIGHBOR_SCALE;
        if (!TextUtils.isEmpty(input)) {
            try {
                neighborScale = Float.parseFloat(input);
            } catch (NumberFormatException e) {
            }
        }
        if (this.mNeighborScale != neighborScale) {
            this.mNeighborScale = neighborScale;
            updateAdapterScaleAndAlpha(-1.0f, neighborScale);
        }
    }

    @WXComponentProp(name = NEIGHBOR_ALPHA)
    public void setNeighborAlpha(String input) {
        float neighborAlpha = DEFAULT_NEIGHBOR_ALPHA;
        if (!TextUtils.isEmpty(input)) {
            try {
                neighborAlpha = Float.parseFloat(input);
            } catch (NumberFormatException e) {
            }
        }
        if (this.mNeighborAlpha != neighborAlpha) {
            this.mNeighborAlpha = neighborAlpha;
            updateAdapterScaleAndAlpha(neighborAlpha, -1.0f);
        }
    }

    @WXComponentProp(name = NEIGHBOR_SPACE)
    public void setNeighborSpace(String input) {
        float neighborSpace = 25.0f;
        if (!TextUtils.isEmpty(input)) {
            try {
                neighborSpace = Float.parseFloat(input);
            } catch (NumberFormatException e) {
            }
        }
        if (this.mNeighborSpace != neighborSpace) {
            this.mNeighborSpace = neighborSpace;
        }
    }

    @WXComponentProp(name = CURRENT_ITEM_SCALE)
    public void setCurrentItemScale(String input) {
        float currentItemScale = 0.9f;
        if (!TextUtils.isEmpty(input)) {
            try {
                currentItemScale = Float.parseFloat(input);
            } catch (NumberFormatException e) {
            }
        }
        if (this.mCurrentItemScale != currentItemScale) {
            this.mCurrentItemScale = currentItemScale;
            updateAdapterScaleAndAlpha(-1.0f, -1.0f);
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXSlider, com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -1763701364:
                if (key.equals(NEIGHBOR_ALPHA)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -1747360392:
                if (key.equals(NEIGHBOR_SCALE)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -1746973388:
                if (key.equals(NEIGHBOR_SPACE)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1013904258:
                if (key.equals(CURRENT_ITEM_SCALE)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            String input = WXUtils.getString(param, null);
            if (input != null) {
                setNeighborScale(input);
            }
            return true;
        } else if (c == 1) {
            String input2 = WXUtils.getString(param, null);
            if (input2 != null) {
                setNeighborAlpha(input2);
            }
            return true;
        } else if (c == 2) {
            String input3 = WXUtils.getString(param, null);
            if (input3 != null) {
                setNeighborSpace(input3);
            }
            return true;
        } else if (c != 3) {
            return super.setProperty(key, param);
        } else {
            String input4 = WXUtils.getString(param, null);
            if (input4 != null) {
                setCurrentItemScale(input4);
            }
            return true;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private float calculateTranslation(View hostPage) {
        if (!(hostPage instanceof ViewGroup)) {
            return 0.0f;
        }
        View realView = ((ViewGroup) hostPage).getChildAt(0);
        return ((((float) hostPage.getMeasuredWidth()) - (((float) realView.getMeasuredWidth()) * this.mNeighborScale)) / 4.0f) + ((((((float) hostPage.getMeasuredWidth()) - (((float) realView.getMeasuredWidth()) * this.mCurrentItemScale)) / 2.0f) - WXViewUtils.getRealPxByWidth(this.mNeighborSpace, getInstance().getInstanceViewPortWidthWithFloat())) / 2.0f);
    }

    /* access modifiers changed from: package-private */
    public class ZoomTransformer implements ViewPager.PageTransformer {
        ZoomTransformer() {
        }

        @Override // androidx.viewpager.widget.ViewPager.PageTransformer
        public void transformPage(View page, float position) {
            View realView;
            int pagePosition = WXSliderNeighbor.this.mAdapter.getPagePosition(page);
            int curPosition = WXSliderNeighbor.this.mViewPager.getCurrentItem();
            int realCount = WXSliderNeighbor.this.mAdapter.getRealCount();
            boolean ignore = false;
            if (!(curPosition == 0 || curPosition == realCount - 1 || Math.abs(pagePosition - curPosition) <= 1)) {
                ignore = true;
            }
            if (curPosition == 0 && pagePosition < realCount - 1 && pagePosition > 1) {
                ignore = true;
            }
            if (curPosition == realCount - 1 && pagePosition < realCount - 2 && pagePosition > 0) {
                ignore = true;
            }
            if (!ignore && (realView = ((ViewGroup) page).getChildAt(0)) != null) {
                if (position <= ((float) ((-realCount) + 1))) {
                    position += (float) realCount;
                }
                if (position >= ((float) (realCount - 1))) {
                    position -= (float) realCount;
                }
                if (position >= -1.0f && position <= 1.0f) {
                    float factor = Math.abs(Math.abs(position) - 1.0f);
                    float scale = WXSliderNeighbor.this.mNeighborScale + ((WXSliderNeighbor.this.mCurrentItemScale - WXSliderNeighbor.this.mNeighborScale) * factor);
                    float alpha = ((1.0f - WXSliderNeighbor.this.mNeighborAlpha) * factor) + WXSliderNeighbor.this.mNeighborAlpha;
                    float translation = WXSliderNeighbor.this.calculateTranslation(page);
                    if (position > 0.0f) {
                        float translation2 = translation * position;
                        realView.setTranslationX(-translation2);
                        page.setTranslationX(-translation2);
                    } else if (position == 0.0f) {
                        page.setTranslationX(0.0f);
                        realView.setTranslationX(0.0f);
                        WXSliderNeighbor wXSliderNeighbor = WXSliderNeighbor.this;
                        wXSliderNeighbor.updateAdapterScaleAndAlpha(wXSliderNeighbor.mNeighborAlpha, WXSliderNeighbor.this.mNeighborScale);
                    } else if (realCount != 2 || Math.abs(position) != 1.0f) {
                        float translation3 = translation * (-position);
                        realView.setTranslationX(translation3);
                        page.setTranslationX(translation3);
                    } else {
                        return;
                    }
                    realView.setScaleX(scale);
                    realView.setScaleY(scale);
                    realView.setAlpha(alpha);
                }
            }
        }
    }
}
