package com.taobao.weex.ui.component;

import android.content.Context;
import android.view.View;
import android.widget.CompoundButton;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.common.Constants;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.WXSwitchView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.HashMap;
import java.util.Map;

@Component(lazyload = false)
public class WXSwitch extends WXComponent<WXSwitchView> {
    private CompoundButton.OnCheckedChangeListener mListener;

    @Deprecated
    public WXSwitch(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    public WXSwitch(final WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        setContentBoxMeasurement(new ContentBoxMeasurement() {
            /* class com.taobao.weex.ui.component.WXSwitch.AnonymousClass1 */

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                int widthSpec;
                this.mMeasureWidth = 0.0f;
                this.mMeasureHeight = 0.0f;
                try {
                    WXSwitchView wxSwitchView = new WXSwitchView(instance.getContext());
                    int heightSpec = View.MeasureSpec.makeMeasureSpec(0, 0);
                    if (Float.isNaN(width)) {
                        widthSpec = View.MeasureSpec.makeMeasureSpec(0, 0);
                    } else {
                        widthSpec = View.MeasureSpec.makeMeasureSpec((int) width, Integer.MIN_VALUE);
                    }
                    wxSwitchView.measure(widthSpec, heightSpec);
                    this.mMeasureWidth = (float) wxSwitchView.getMeasuredWidth();
                    this.mMeasureHeight = (float) wxSwitchView.getMeasuredHeight();
                } catch (RuntimeException e) {
                    WXLogUtils.e(WXLogUtils.getStackTrace(e));
                }
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXSwitchView initComponentHostView(Context context) {
        return new WXSwitchView(context);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (type != null && type.equals(Constants.Event.CHANGE) && getHostView() != null) {
            if (this.mListener == null) {
                this.mListener = new CompoundButton.OnCheckedChangeListener() {
                    /* class com.taobao.weex.ui.component.WXSwitch.AnonymousClass2 */

                    public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                        Map<String, Object> params = new HashMap<>(2);
                        params.put("value", Boolean.valueOf(isChecked));
                        Map<String, Object> domChanges = new HashMap<>();
                        Map<String, Object> attrsChanges = new HashMap<>();
                        attrsChanges.put(Constants.Name.CHECKED, Boolean.toString(isChecked));
                        domChanges.put(TemplateDom.KEY_ATTRS, attrsChanges);
                        WXSwitch.this.fireEvent(Constants.Event.CHANGE, params, domChanges);
                    }
                };
            }
            ((WXSwitchView) getHostView()).setOnCheckedChangeListener(this.mListener);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void removeEventFromView(String type) {
        super.removeEventFromView(type);
        if (getHostView() != null && Constants.Event.CHANGE.equals(type)) {
            ((WXSwitchView) getHostView()).setOnCheckedChangeListener(null);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        if (((key.hashCode() == 742313895 && key.equals(Constants.Name.CHECKED)) ? (char) 0 : 65535) != 0) {
            return super.setProperty(key, param);
        }
        Boolean result = WXUtils.getBoolean(param, null);
        if (result == null) {
            return true;
        }
        setChecked(result.booleanValue());
        return true;
    }

    @WXComponentProp(name = Constants.Name.CHECKED)
    public void setChecked(boolean checked) {
        ((WXSwitchView) getHostView()).setOnCheckedChangeListener(null);
        ((WXSwitchView) getHostView()).setChecked(checked);
        ((WXSwitchView) getHostView()).setOnCheckedChangeListener(this.mListener);
    }
}
