package com.taobao.weex.ui.component;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.text.Layout;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.flat.FlatComponent;
import com.taobao.weex.ui.flat.widget.TextWidget;
import com.taobao.weex.ui.view.WXTextView;
import com.taobao.weex.utils.FontDO;
import com.taobao.weex.utils.TypefaceUtil;
import com.taobao.weex.utils.WXLogUtils;
import java.lang.reflect.InvocationTargetException;

@Component(lazyload = false)
public class WXText extends WXComponent<WXTextView> implements FlatComponent<TextWidget> {
    private String mFontFamily;
    private TextWidget mTextWidget;
    private BroadcastReceiver mTypefaceObserver;

    @Override // com.taobao.weex.ui.flat.FlatComponent
    public boolean promoteToView(boolean checkAncestor) {
        if (getInstance().getFlatUIContext() != null) {
            return getInstance().getFlatUIContext().promoteToView(this, checkAncestor, WXText.class);
        }
        return false;
    }

    @Override // com.taobao.weex.ui.flat.FlatComponent
    public TextWidget getOrCreateFlatWidget() {
        if (this.mTextWidget == null) {
            this.mTextWidget = new TextWidget(getInstance().getFlatUIContext());
        }
        return this.mTextWidget;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean isVirtualComponent() {
        return true ^ promoteToView(true);
    }

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXText(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public WXText(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXText(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        setContentBoxMeasurement(new TextContentBoxMeasurement(this));
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXTextView initComponentHostView(Context context) {
        WXTextView textView = new WXTextView(context);
        textView.holdComponent(this);
        return textView;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void updateExtra(Object extra) {
        super.updateExtra(extra);
        if (extra instanceof Layout) {
            Layout layout = (Layout) extra;
            if (!promoteToView(true)) {
                getOrCreateFlatWidget().updateTextDrawable(layout);
            } else if (getHostView() != null && !extra.equals(((WXTextView) getHostView()).getTextLayout())) {
                ((WXTextView) getHostView()).setTextLayout(layout);
                ((WXTextView) getHostView()).invalidate();
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void setAriaLabel(String label) {
        WXTextView text = (WXTextView) getHostView();
        if (text != null) {
            text.setAriaLabel(label);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void refreshData(WXComponent component) {
        super.refreshData(component);
        if (component instanceof WXText) {
            updateExtra(component.getExtra());
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -1550943582:
                if (key.equals(Constants.Name.FONT_STYLE)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -1224696685:
                if (key.equals(Constants.Name.FONT_FAMILY)) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case -1065511464:
                if (key.equals(Constants.Name.TEXT_ALIGN)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case -879295043:
                if (key.equals(Constants.Name.TEXT_DECORATION)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -734428249:
                if (key.equals(Constants.Name.FONT_WEIGHT)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -515807685:
                if (key.equals(Constants.Name.LINE_HEIGHT)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 94842723:
                if (key.equals("color")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 102977279:
                if (key.equals(Constants.Name.LINES)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 111972721:
                if (key.equals("value")) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 261414991:
                if (key.equals(Constants.Name.TEXT_OVERFLOW)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case 365601008:
                if (key.equals(Constants.Name.FONT_SIZE)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7:
            case '\b':
            case '\t':
                return true;
            case '\n':
                if (param != null) {
                    registerTypefaceObserver(param.toString());
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x0027  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0031  */
    @Override // com.taobao.weex.ui.component.WXComponent
    public Object convertEmptyProperty(String propName, Object originalValue) {
        char c;
        int hashCode = propName.hashCode();
        if (hashCode != 94842723) {
            if (hashCode == 365601008 && propName.equals(Constants.Name.FONT_SIZE)) {
                c = 0;
                if (c == 0) {
                    return Integer.valueOf(getInstance().getDefaultFontSize());
                }
                if (c != 1) {
                    return super.convertEmptyProperty(propName, originalValue);
                }
                return "black";
            }
        } else if (propName.equals("color")) {
            c = 1;
            if (c == 0) {
            }
        }
        c = 65535;
        if (c == 0) {
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        if (promoteToView(true)) {
            super.createViewImpl();
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        if (WXEnvironment.getApplication() != null && this.mTypefaceObserver != null) {
            WXLogUtils.d("WXText", "Unregister the typeface observer");
            LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).unregisterReceiver(this.mTypefaceObserver);
            this.mTypefaceObserver = null;
        }
    }

    private void registerTypefaceObserver(String desiredFontFamily) {
        if (WXEnvironment.getApplication() == null) {
            WXLogUtils.w("WXText", "ApplicationContent is null on register typeface observer");
            return;
        }
        this.mFontFamily = desiredFontFamily;
        if (this.mTypefaceObserver == null) {
            this.mTypefaceObserver = new BroadcastReceiver() {
                /* class com.taobao.weex.ui.component.WXText.AnonymousClass1 */

                public void onReceive(Context context, Intent intent) {
                    FontDO fontDO;
                    String fontFamily = intent.getStringExtra(Constants.Name.FONT_FAMILY);
                    if (WXText.this.mFontFamily.equals(fontFamily) && (fontDO = TypefaceUtil.getFontDO(fontFamily)) != null && fontDO.getTypeface() != null && WXText.this.getHostView() != null) {
                        Layout layout = ((WXTextView) WXText.this.getHostView()).getTextLayout();
                        if (layout != null) {
                            layout.getPaint().setTypeface(fontDO.getTypeface());
                        } else {
                            WXLogUtils.d("WXText", "Layout not created");
                        }
                        WXBridgeManager.getInstance().markDirty(WXText.this.getInstanceId(), WXText.this.getRef(), true);
                        WXText.this.forceRelayout();
                    }
                }
            };
            LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).registerReceiver(this.mTypefaceObserver, new IntentFilter(TypefaceUtil.ACTION_TYPE_FACE_AVAILABLE));
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void layoutDirectionDidChanged(boolean isRTL) {
        forceRelayout();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void forceRelayout() {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class com.taobao.weex.ui.component.WXText.AnonymousClass2 */

            public void run() {
                if (WXText.this.contentBoxMeasurement instanceof TextContentBoxMeasurement) {
                    ((TextContentBoxMeasurement) WXText.this.contentBoxMeasurement).forceRelayout();
                }
            }
        });
    }
}
