package com.taobao.weex.ui.component;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.ui.component.AbsVContainer;

public abstract class WXVContainer<T extends ViewGroup> extends AbsVContainer<T> {
    private static final String TAG = "WXVContainer";
    private WXVContainer<T>.BoxShadowHost mBoxShadowHost;

    public WXVContainer(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, instanceId, isLazy, basicComponentData);
    }

    public WXVContainer(WXSDKInstance instance, WXVContainer parent, boolean lazy, BasicComponentData basicComponentData) {
        super(instance, parent, lazy, basicComponentData);
    }

    public WXVContainer(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public View getBoxShadowHost(boolean isClear) {
        if (isClear) {
            return this.mBoxShadowHost;
        }
        ViewGroup hostView = (ViewGroup) getHostView();
        if (hostView == null) {
            return null;
        }
        try {
            String type = getComponentType();
            if (!WXBasicComponentType.DIV.equals(type)) {
                if (!WXBasicComponentType.VIEW.equals(type)) {
                    return hostView;
                }
            }
            WXLogUtils.d("BoxShadow", "Draw box-shadow with BoxShadowHost on div: " + toString());
            if (this.mBoxShadowHost == null) {
                WXVContainer<T>.BoxShadowHost boxShadowHost = new BoxShadowHost(getContext());
                this.mBoxShadowHost = boxShadowHost;
                WXViewUtils.setBackGround(boxShadowHost, null, this);
                hostView.addView(this.mBoxShadowHost);
            }
            CSSShorthand padding = getPadding();
            CSSShorthand border = getBorder();
            int left = (int) (padding.get(CSSShorthand.EDGE.LEFT) + border.get(CSSShorthand.EDGE.LEFT));
            int top = (int) (padding.get(CSSShorthand.EDGE.TOP) + border.get(CSSShorthand.EDGE.TOP));
            int right = (int) (padding.get(CSSShorthand.EDGE.RIGHT) + border.get(CSSShorthand.EDGE.RIGHT));
            int bottom = (int) (padding.get(CSSShorthand.EDGE.BOTTOM) + border.get(CSSShorthand.EDGE.BOTTOM));
            ViewGroup.MarginLayoutParams layoutParams = new ViewGroup.MarginLayoutParams(hostView.getLayoutParams());
            setMarginsSupportRTL(layoutParams, -left, -top, -right, -bottom);
            this.mBoxShadowHost.setLayoutParams(layoutParams);
            hostView.removeView(this.mBoxShadowHost);
            hostView.addView(this.mBoxShadowHost);
            return this.mBoxShadowHost;
        } catch (Throwable t) {
            WXLogUtils.w("BoxShadow", t);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void removeBoxShadowHost() {
        ViewGroup hostView = (ViewGroup) getHostView();
        if (hostView != null) {
            try {
                String type = getComponentType();
                if (this.mBoxShadowHost == null) {
                    return;
                }
                if (WXBasicComponentType.DIV.equals(type) || WXBasicComponentType.VIEW.equals(type)) {
                    hostView.removeView(this.mBoxShadowHost);
                }
            } catch (Throwable th) {
            }
        }
    }

    private class BoxShadowHost extends View {
        public BoxShadowHost(Context context) {
            super(context);
        }
    }
}
