package com.taobao.weex.ui.component;

import android.content.Context;
import android.media.MediaPlayer;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.FrameLayout;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.WXVideoView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.HashMap;
import java.util.Map;

@Component(lazyload = false)
public class WXVideo extends WXComponent<FrameLayout> {
    private boolean mAutoPlay;
    private boolean mError;
    boolean mPrepared;
    private boolean mStopped;
    private WXVideoView.Wrapper mWrapper;

    @Deprecated
    public WXVideo(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    public WXVideo(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public FrameLayout initComponentHostView(Context context) {
        final WXVideoView.Wrapper video = new WXVideoView.Wrapper(context);
        video.setOnErrorListener(new MediaPlayer.OnErrorListener() {
            /* class com.taobao.weex.ui.component.WXVideo.AnonymousClass1 */

            public boolean onError(MediaPlayer mp, int what, int extra) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("Video", "onError:" + what);
                }
                video.getProgressBar().setVisibility(8);
                WXVideo.this.mPrepared = false;
                WXVideo.this.mError = true;
                if (WXVideo.this.getEvents().contains(Constants.Event.FAIL)) {
                    WXVideo.this.notify(Constants.Event.FAIL, Constants.Value.STOP);
                }
                return true;
            }
        });
        video.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
            /* class com.taobao.weex.ui.component.WXVideo.AnonymousClass2 */

            public void onPrepared(MediaPlayer mediaPlayer) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("Video", "onPrepared");
                }
                video.getProgressBar().setVisibility(8);
                WXVideo.this.mPrepared = true;
                if (WXVideo.this.mAutoPlay) {
                    video.start();
                }
                video.getVideoView().seekTo(5);
                if (video.getMediaController() != null) {
                    if (!WXVideo.this.mStopped) {
                        video.getMediaController().show(3);
                    } else {
                        video.getMediaController().hide();
                    }
                }
                WXVideo.this.mStopped = false;
            }
        });
        video.setOnCompletionListener(new MediaPlayer.OnCompletionListener() {
            /* class com.taobao.weex.ui.component.WXVideo.AnonymousClass3 */

            public void onCompletion(MediaPlayer mediaPlayer) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("Video", "onCompletion");
                }
                if (WXVideo.this.getEvents().contains(Constants.Event.FINISH)) {
                    WXVideo.this.notify(Constants.Event.FINISH, Constants.Value.STOP);
                }
            }
        });
        video.setOnVideoPauseListener(new WXVideoView.VideoPlayListener() {
            /* class com.taobao.weex.ui.component.WXVideo.AnonymousClass4 */

            @Override // com.taobao.weex.ui.view.WXVideoView.VideoPlayListener
            public void onPause() {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("Video", "onPause");
                }
                if (WXVideo.this.getEvents().contains("pause")) {
                    WXVideo.this.notify("pause", "pause");
                }
            }

            @Override // com.taobao.weex.ui.view.WXVideoView.VideoPlayListener
            public void onStart() {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("Video", "onStart");
                }
                if (WXVideo.this.getEvents().contains("start")) {
                    WXVideo.this.notify("start", Constants.Value.PLAY);
                }
            }
        });
        this.mWrapper = video;
        return video;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notify(String event, String newStatus) {
        Map<String, Object> params = new HashMap<>(2);
        params.put(Constants.Name.PLAY_STATUS, newStatus);
        params.put("timeStamp", Long.valueOf(System.currentTimeMillis()));
        Map<String, Object> domChanges = new HashMap<>();
        Map<String, Object> attrsChanges = new HashMap<>();
        attrsChanges.put(Constants.Name.PLAY_STATUS, newStatus);
        domChanges.put(TemplateDom.KEY_ATTRS, attrsChanges);
        WXSDKManager.getInstance().fireEvent(getInstanceId(), getRef(), event, params, domChanges);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void bindData(WXComponent component) {
        super.bindData(component);
        addEvent(Constants.Event.APPEAR);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        super.notifyAppearStateChange(wxEventType, direction);
        this.mWrapper.createVideoViewIfVisible();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -167173695:
                if (key.equals(Constants.Name.ZORDERTOP)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 114148:
                if (key.equals("src")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 1438608771:
                if (key.equals(Constants.Name.AUTO_PLAY)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 1439562083:
                if (key.equals(Constants.Name.AUTOPLAY)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1582764102:
                if (key.equals(Constants.Name.PLAY_STATUS)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            String src = WXUtils.getString(param, null);
            if (src != null) {
                setSrc(src);
            }
            return true;
        } else if (c == 1 || c == 2) {
            Boolean result = WXUtils.getBoolean(param, null);
            if (result != null) {
                setAutoPlay(result.booleanValue());
            }
            return true;
        } else if (c == 3) {
            Boolean zOrderTop = WXUtils.getBoolean(param, null);
            if (zOrderTop != null) {
                this.mWrapper.getVideoView().setZOrderOnTop(zOrderTop.booleanValue());
            }
            return true;
        } else if (c != 4) {
            return super.setProperty(key, param);
        } else {
            String status = WXUtils.getString(param, null);
            if (status != null) {
                setPlaystatus(status);
            }
            return true;
        }
    }

    @WXComponentProp(name = "src")
    public void setSrc(String src) {
        if (!TextUtils.isEmpty(src) && getHostView() != null && !TextUtils.isEmpty(src)) {
            this.mWrapper.setVideoURI(getInstance().rewriteUri(Uri.parse(src), "video"));
            this.mWrapper.getProgressBar().setVisibility(0);
        }
    }

    @WXComponentProp(name = Constants.Name.AUTO_PLAY)
    public void setAutoPlay(boolean autoPlay) {
        this.mAutoPlay = autoPlay;
        if (autoPlay) {
            this.mWrapper.createIfNotExist();
            this.mWrapper.start();
        }
    }

    @WXComponentProp(name = "controls")
    public void setControls(String controls) {
        if (TextUtils.equals("controls", controls)) {
            this.mWrapper.setControls(true);
        } else if (TextUtils.equals("nocontrols", controls)) {
            this.mWrapper.setControls(false);
        }
    }

    @WXComponentProp(name = Constants.Name.PLAY_STATUS)
    public void setPlaystatus(String playstatus) {
        if (!this.mPrepared || this.mError || this.mStopped) {
            if ((this.mError || this.mStopped) && playstatus.equals(Constants.Value.PLAY)) {
                this.mError = false;
                this.mWrapper.resume();
                this.mWrapper.getProgressBar().setVisibility(0);
            }
        } else if (playstatus.equals(Constants.Value.PLAY)) {
            this.mWrapper.start();
        } else if (playstatus.equals("pause")) {
            this.mWrapper.pause();
        } else if (playstatus.equals(Constants.Value.STOP)) {
            this.mWrapper.stopPlayback();
            this.mStopped = true;
        }
    }
}
