package com.taobao.weex.ui.component;

import android.content.Context;
import android.net.Uri;
import android.text.TextUtils;
import android.view.View;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.IWebView;
import com.taobao.weex.ui.view.WXWebView;
import com.taobao.weex.utils.WXUtils;
import java.util.HashMap;
import java.util.Map;

@Component(lazyload = false)
public class WXWeb extends WXComponent {
    public static final String GO_BACK = "goBack";
    public static final String GO_FORWARD = "goForward";
    public static final String POST_MESSAGE = "postMessage";
    public static final String RELOAD = "reload";
    protected IWebView mWebView;

    @Deprecated
    public WXWeb(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    public WXWeb(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        createWebView();
    }

    /* access modifiers changed from: protected */
    public void createWebView() {
        String origin = null;
        try {
            Uri uri = Uri.parse(WXSDKManager.getInstance().getSDKInstance(getInstanceId()).getBundleUrl());
            String scheme = uri.getScheme();
            String authority = uri.getAuthority();
            if (!TextUtils.isEmpty(scheme) && !TextUtils.isEmpty(authority)) {
                origin = scheme + "://" + authority;
            }
        } catch (Exception e) {
        }
        this.mWebView = new WXWebView(getContext(), origin);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public View initComponentHostView(Context context) {
        this.mWebView.setOnErrorListener(new IWebView.OnErrorListener() {
            /* class com.taobao.weex.ui.component.WXWeb.AnonymousClass1 */

            @Override // com.taobao.weex.ui.view.IWebView.OnErrorListener
            public void onError(String type, Object message) {
                WXWeb.this.fireEvent((WXWeb) type, (String) message);
            }
        });
        this.mWebView.setOnPageListener(new IWebView.OnPageListener() {
            /* class com.taobao.weex.ui.component.WXWeb.AnonymousClass2 */

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onReceivedTitle(String title) {
                if (WXWeb.this.getEvents().contains(Constants.Event.RECEIVEDTITLE)) {
                    Map<String, Object> params = new HashMap<>();
                    params.put("title", title);
                    WXWeb.this.fireEvent(Constants.Event.RECEIVEDTITLE, params);
                }
            }

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onPageStart(String url) {
                if (WXWeb.this.getEvents().contains(Constants.Event.PAGESTART)) {
                    Map<String, Object> params = new HashMap<>();
                    params.put("url", url);
                    WXWeb.this.fireEvent(Constants.Event.PAGESTART, params);
                }
            }

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onPageFinish(String url, boolean canGoBack, boolean canGoForward) {
                if (WXWeb.this.getEvents().contains(Constants.Event.PAGEFINISH)) {
                    Map<String, Object> params = new HashMap<>();
                    params.put("url", url);
                    params.put("canGoBack", Boolean.valueOf(canGoBack));
                    params.put("canGoForward", Boolean.valueOf(canGoForward));
                    WXWeb.this.fireEvent(Constants.Event.PAGEFINISH, params);
                }
            }
        });
        this.mWebView.setOnMessageListener(new IWebView.OnMessageListener() {
            /* class com.taobao.weex.ui.component.WXWeb.AnonymousClass3 */

            @Override // com.taobao.weex.ui.view.IWebView.OnMessageListener
            public void onMessage(Map<String, Object> params) {
                WXWeb.this.fireEvent("message", params);
            }
        });
        return this.mWebView.getView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        getWebView().destroy();
        this.mWebView = null;
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x003b  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0058  */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        int hashCode = key.hashCode();
        if (hashCode != -896505829) {
            if (hashCode != 114148) {
                if (hashCode == 537088620 && key.equals(Constants.Name.SHOW_LOADING)) {
                    c = 0;
                    if (c != 0) {
                        Boolean result = WXUtils.getBoolean(param, null);
                        if (result != null) {
                            setShowLoading(result.booleanValue());
                        }
                        return true;
                    } else if (c == 1) {
                        String src = WXUtils.getString(param, null);
                        if (src != null) {
                            setUrl(src);
                        }
                        return true;
                    } else if (c != 2) {
                        return super.setProperty(key, param);
                    } else {
                        String source = WXUtils.getString(param, null);
                        if (source != null) {
                            setSource(source);
                        }
                        return true;
                    }
                }
            } else if (key.equals("src")) {
                c = 1;
                if (c != 0) {
                }
            }
        } else if (key.equals("source")) {
            c = 2;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_LOADING)
    public void setShowLoading(boolean showLoading) {
        getWebView().setShowLoading(showLoading);
    }

    @WXComponentProp(name = "src")
    public void setUrl(String url) {
        if (!TextUtils.isEmpty(url) && getHostView() != null && !TextUtils.isEmpty(url)) {
            loadUrl(getInstance().rewriteUri(Uri.parse(url), "web").toString());
        }
    }

    @WXComponentProp(name = "source")
    public void setSource(String source) {
        if (!TextUtils.isEmpty(source) && getHostView() != null) {
            loadDataWithBaseURL(source);
        }
    }

    public void setAction(String action, Object data) {
        if (TextUtils.isEmpty(action)) {
            return;
        }
        if (action.equals(GO_BACK)) {
            goBack();
        } else if (action.equals(GO_FORWARD)) {
            goForward();
        } else if (action.equals(RELOAD)) {
            reload();
        } else if (action.equals(POST_MESSAGE)) {
            postMessage(data);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireEvent(String type, Object message) {
        if (getEvents().contains("error")) {
            Map<String, Object> params = new HashMap<>();
            params.put("type", type);
            params.put("errorMsg", message);
            fireEvent("error", params);
        }
    }

    /* access modifiers changed from: protected */
    public void loadUrl(String url) {
        getWebView().loadUrl(url);
    }

    private void loadDataWithBaseURL(String source) {
        getWebView().loadDataWithBaseURL(source);
    }

    @JSMethod
    public void reload() {
        getWebView().reload();
    }

    @JSMethod
    public void goForward() {
        getWebView().goForward();
    }

    @JSMethod
    public void goBack() {
        getWebView().goBack();
    }

    @JSMethod
    public void postMessage(Object msg) {
        getWebView().postMessage(msg);
    }

    private IWebView getWebView() {
        return this.mWebView;
    }
}
