package com.taobao.weex.ui.component.binding;

import android.os.AsyncTask;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.component.list.template.TemplateViewHolder;
import com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList;
import com.taobao.weex.ui.component.list.template.jni.NativeRenderObjectUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;

public class Layouts {
    public static void doLayoutAsync(TemplateViewHolder templateViewHolder, boolean async) {
        WXComponent component = templateViewHolder.getComponent();
        int position = templateViewHolder.getHolderPosition();
        if (templateViewHolder.asyncTask != null) {
            templateViewHolder.asyncTask.cancel(false);
            templateViewHolder.asyncTask = null;
        }
        if (async) {
            AsyncTask<Void, Void, Void> asyncTask = new AsynLayoutTask(templateViewHolder, position, component);
            templateViewHolder.asyncTask = asyncTask;
            asyncTask.executeOnExecutor(AsyncTask.SERIAL_EXECUTOR, new Void[0]);
            return;
        }
        doLayoutOnly(component, templateViewHolder);
        setLayout(component, false);
        if (templateViewHolder.getHolderPosition() >= 0) {
            templateViewHolder.getTemplateList().fireEvent(TemplateDom.ATTACH_CELL_SLOT, TemplateDom.findAllComponentRefs(templateViewHolder.getTemplateList().getRef(), position, component));
        }
    }

    public static void doLayoutSync(WXCell component, float layoutWidth, float layoutHeight) {
        doSafeLayout(component, layoutWidth, layoutHeight);
        setLayout(component, false);
    }

    public static void doLayoutOnly(WXComponent component, TemplateViewHolder holder) {
        doSafeLayout(component, holder.getTemplateList().getLayoutWidth(), holder.getTemplateList().getLayoutHeight());
    }

    private static void doSafeLayout(WXComponent component, float layoutWidth, float layoutHeight) {
        try {
            System.currentTimeMillis();
            int height = NativeRenderObjectUtils.nativeLayoutRenderObject(component.getRenderObjectPtr(), layoutWidth, layoutHeight);
            WXEnvironment.isOpenDebugLog();
            if (height <= 0) {
                WXLogUtils.e(WXRecyclerTemplateList.TAG, " WXTemplateList doSafeLayout wrong template " + component.getAttrs().get(Constants.Name.Recycler.SLOT_TEMPLATE_CASE) + " cell height " + height);
            }
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(WXRecyclerTemplateList.TAG, e);
            }
        }
    }

    public static final void setLayout(WXComponent component, boolean force) {
        if (!component.isWaste()) {
            if (component.getAttrs().containsKey(TemplateDom.KEY_RESET_ANIMATION) && WXUtils.getBoolean(component.getAttrs().get(TemplateDom.KEY_RESET_ANIMATION), true).booleanValue()) {
                TemplateDom.resetAnimaiton(component.getHostView());
            }
            long ptr = component.getRenderObjectPtr();
            if (NativeRenderObjectUtils.nativeRenderObjectHasNewLayout(ptr)) {
                NativeRenderObjectUtils.nativeRenderObjectUpdateComponent(ptr, component);
            }
            if (component instanceof WXVContainer) {
                WXVContainer container = (WXVContainer) component;
                int count = container.getChildCount();
                for (int i = 0; i < count; i++) {
                    WXComponent child = container.getChild(i);
                    if (child != null) {
                        setLayout(child, force);
                    }
                }
            }
        }
    }
}
