package com.taobao.weex.ui.component.binding;

import android.os.Looper;
import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.dom.binding.ELUtils;
import com.taobao.weex.dom.binding.JSONUtils;
import com.taobao.weex.dom.binding.WXStatement;
import com.taobao.weex.el.parse.ArrayStack;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.el.parse.Token;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentFactory;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.component.list.template.CellDataManager;
import com.taobao.weex.ui.component.list.template.CellRenderContext;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.component.list.template.VirtualComponentLifecycle;
import com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList;
import com.taobao.weex.ui.component.list.template.jni.NativeRenderObjectUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class Statements {
    private static final ThreadLocal<Map<String, Object>> dynamicLocal = new ThreadLocal<>();

    public static void parseStatementsToken(WXComponent component) {
        if (component.getBasicComponentData().isRenderPtrEmpty()) {
            component.getBasicComponentData().setRenderObjectPr(component.getRenderObjectPtr());
        }
        if (component.getBasicComponentData() != null) {
            BasicComponentData basicComponentData = component.getBasicComponentData();
            basicComponentData.getAttrs().parseStatements();
            basicComponentData.getStyles().parseStatements();
            basicComponentData.getEvents().parseStatements();
        }
        if (component instanceof WXVContainer) {
            WXVContainer container = (WXVContainer) component;
            int count = container.getChildCount();
            for (int i = 0; i < count; i++) {
                parseStatementsToken(container.getChild(i));
            }
        }
    }

    public static void initLazyComponent(WXComponent component, WXVContainer mParent) {
        if (component.isLazy() || component.getHostView() == null) {
            component.lazy(false);
            if (mParent != null) {
                mParent.createChildViewAt(mParent.indexOf(component));
            } else {
                component.createView();
            }
            component.applyLayoutAndEvent(component);
            component.bindData(component);
        }
    }

    public static WXComponent copyComponentTree(WXComponent component) {
        return copyComponentTree(component, component.getParent());
    }

    private static final WXComponent copyComponentTree(WXComponent source, WXVContainer parent) {
        BasicComponentData basicComponentData;
        BasicComponentData basicComponentData2 = null;
        try {
            basicComponentData2 = source.getBasicComponentData().clone();
        } catch (CloneNotSupportedException e) {
            e.printStackTrace();
        }
        WXComponent component = WXComponentFactory.newInstance(source.getInstance(), parent, basicComponentData2);
        GraphicPosition graphicPosition = source.getLayoutPosition();
        GraphicSize graphicSize = source.getLayoutSize();
        component.updateDemission(graphicPosition.getTop(), graphicPosition.getBottom(), graphicPosition.getLeft(), graphicPosition.getRight(), graphicSize.getHeight(), graphicSize.getWidth());
        component.updateExtra(source.getExtra());
        if (source instanceof WXVContainer) {
            WXVContainer container = (WXVContainer) source;
            WXVContainer childParent = (WXVContainer) component;
            int count = container.getChildCount();
            int i = 0;
            while (i < count) {
                WXComponent sourceChild = container.getChild(i);
                if (sourceChild != null) {
                    WXComponent targetChild = copyComponentTree(sourceChild, childParent);
                    childParent.addChild(targetChild);
                    basicComponentData = basicComponentData2;
                    NativeRenderObjectUtils.nativeAddChildRenderObject(childParent.getRenderObjectPtr(), targetChild.getRenderObjectPtr());
                } else {
                    basicComponentData = basicComponentData2;
                }
                i++;
                basicComponentData2 = basicComponentData;
            }
        }
        if (source.isWaste()) {
            component.setWaste(true);
        }
        return component;
    }

    public static final List<WXComponent> doRender(WXComponent component, CellRenderContext stack) {
        List<WXComponent> updates = new ArrayList<>(4);
        try {
            doRenderComponent(component, stack, updates);
        } catch (Exception e) {
            WXLogUtils.e("WeexStatementRender", e);
        }
        return updates;
    }

    public static final void doInitCompontent(List<WXComponent> updates) {
        if (!(updates == null || updates.size() == 0)) {
            for (WXComponent renderNode : updates) {
                if (renderNode.getParent() != null) {
                    WXVContainer parent = renderNode.getParent();
                    int renderIndex = parent.indexOf(renderNode);
                    if (renderIndex >= 0) {
                        parent.createChildViewAt(renderIndex);
                        renderNode.applyLayoutAndEvent(renderNode);
                        renderNode.bindData(renderNode);
                    } else {
                        throw new IllegalArgumentException("render node cann't find");
                    }
                } else {
                    throw new IllegalArgumentException("render node parent cann't find");
                }
            }
        }
    }

    /* JADX INFO: Multiple debug info for r11v10 java.util.HashMap: [D('data' java.lang.Object), D('loop' java.util.Map<java.lang.String, java.lang.Object>)] */
    private static final int doRenderComponent(WXComponent component, CellRenderContext context, List<WXComponent> updates) {
        int i;
        Map map;
        Collection collection;
        Map map2;
        Object value;
        Object item;
        Object data;
        HashMap hashMap;
        WXComponent renderNode;
        String indexKey;
        Token listBlock;
        String str;
        String str2;
        WXVContainer parent = component.getParent();
        WXStatement statement = component.getAttrs().getStatement();
        if (statement != null) {
            Token vif = null;
            JSONObject vfor = null;
            String str3 = WXStatement.WX_IF;
            if (statement.get(str3) instanceof Token) {
                vif = (Token) statement.get(str3);
            }
            String str4 = WXStatement.WX_FOR;
            if (statement.get(str4) instanceof JSONObject) {
                vfor = (JSONObject) statement.get(str4);
            }
            if (vfor != null) {
                int renderIndex = parent.indexOf(component);
                if (vfor.get(WXStatement.WX_FOR_LIST) instanceof Token) {
                    Token listBlock2 = (Token) vfor.get(WXStatement.WX_FOR_LIST);
                    String indexKey2 = vfor.getString(WXStatement.WX_FOR_INDEX);
                    String itemKey = vfor.getString(WXStatement.WX_FOR_ITEM);
                    Object data2 = listBlock2 != null ? listBlock2.execute(context.stack) : null;
                    if ((data2 instanceof List) || (data2 instanceof Map)) {
                        if (data2 instanceof List) {
                            collection = (List) data2;
                            map = null;
                        } else {
                            Map map3 = (Map) data2;
                            collection = map3.keySet();
                            map = map3;
                        }
                        HashMap hashMap2 = new HashMap();
                        int index = 0;
                        for (Object item2 : collection) {
                            if (map == null) {
                                Object valueOf = Integer.valueOf(index);
                                index++;
                                item = valueOf;
                                map2 = map;
                                value = item2;
                            } else {
                                Object value2 = map.get(item2);
                                item = item2;
                                map2 = map;
                                value = value2;
                            }
                            if (indexKey2 != null) {
                                data = data2;
                                hashMap = hashMap2;
                                hashMap.put(indexKey2, item);
                            } else {
                                data = data2;
                                hashMap = hashMap2;
                            }
                            if (itemKey != null) {
                                hashMap.put(itemKey, value);
                            } else {
                                context.stack.push(value);
                            }
                            if (hashMap.size() > 0) {
                                context.stack.push(hashMap);
                            }
                            if (vif == null || Operators.isTrue(vif.execute(context.stack))) {
                                if (renderIndex < parent.getChildCount()) {
                                    renderNode = parent.getChild(renderIndex);
                                    if (!isCreateFromNodeStatement(renderNode, component)) {
                                        renderNode = null;
                                    }
                                    if (renderNode != null) {
                                        if (renderNode.isWaste()) {
                                            renderNode.setWaste(false);
                                        }
                                    }
                                } else {
                                    renderNode = null;
                                }
                                if (renderNode == null) {
                                    long start = System.currentTimeMillis();
                                    renderNode = copyComponentTree(component, parent);
                                    renderNode.setWaste(false);
                                    if (renderNode.getAttrs().getStatement() != null) {
                                        renderNode.getAttrs().getStatement().remove(str4);
                                        renderNode.getAttrs().getStatement().remove(str3);
                                    }
                                    parent.addChild(renderNode, renderIndex);
                                    str2 = str3;
                                    str = str4;
                                    listBlock = listBlock2;
                                    indexKey = indexKey2;
                                    NativeRenderObjectUtils.nativeAddChildRenderObject(parent.getRenderObjectPtr(), renderNode.getRenderObjectPtr());
                                    updates.add(renderNode);
                                    if (WXEnvironment.isApkDebugable()) {
                                        WXLogUtils.d(WXRecyclerTemplateList.TAG, Thread.currentThread().getName() + renderNode.getRef() + renderNode.getComponentType() + "statements copy component tree used " + (System.currentTimeMillis() - start));
                                    }
                                } else {
                                    str2 = str3;
                                    str = str4;
                                    listBlock = listBlock2;
                                    indexKey = indexKey2;
                                }
                                doBindingAttrsEventAndRenderChildNode(renderNode, context, updates);
                                renderIndex++;
                                if (hashMap.size() > 0) {
                                    context.stack.push(hashMap);
                                }
                                if (itemKey == null) {
                                    context.stack.pop();
                                }
                                str3 = str2;
                                hashMap2 = hashMap;
                                collection = collection;
                                map = map2;
                                data2 = data;
                                str4 = str;
                                listBlock2 = listBlock;
                                indexKey2 = indexKey;
                            } else {
                                hashMap2 = hashMap;
                                collection = collection;
                                map = map2;
                                data2 = data;
                            }
                        }
                    }
                } else {
                    WXLogUtils.e(WXRecyclerTemplateList.TAG, vfor.toJSONString() + " not call vfor block, for pre compile");
                }
                while (renderIndex < parent.getChildCount()) {
                    WXComponent wasteNode = parent.getChild(renderIndex);
                    if (!isCreateFromNodeStatement(wasteNode, component)) {
                        break;
                    }
                    wasteNode.setWaste(true);
                    renderIndex++;
                }
                return renderIndex - parent.indexOf(component);
            } else if (vif == null) {
                i = 1;
            } else if (!Operators.isTrue(vif.execute(context.stack))) {
                component.setWaste(true);
                return 1;
            } else {
                i = 1;
                component.setWaste(false);
            }
        } else {
            i = 1;
        }
        doBindingAttrsEventAndRenderChildNode(component, context, updates);
        return i;
    }

    private static void doBindingAttrsEventAndRenderChildNode(WXComponent component, CellRenderContext context, List<WXComponent> updates) {
        ArrayStack stack;
        ArrayStack stack2;
        Object compoentData;
        WXAttr attr = component.getAttrs();
        ArrayStack stack3 = context.stack;
        String virtualComponentId = null;
        boolean callVirtualComponentAttach = false;
        if (attr.get(ELUtils.IS_COMPONENT_ROOT) == null) {
            stack = stack3;
        } else if (!WXUtils.getBoolean(attr.get(ELUtils.IS_COMPONENT_ROOT), false).booleanValue()) {
            stack = stack3;
        } else if (attr.get(ELUtils.COMPONENT_PROPS) == null) {
            stack = stack3;
        } else if (JSONUtils.isJSON(attr.get(ELUtils.COMPONENT_PROPS))) {
            String compoentId = (String) attr.get(CellDataManager.SUB_COMPONENT_TEMPLATE_ID);
            if (!TextUtils.isEmpty(compoentId)) {
                virtualComponentId = context.getRenderState().getVirtualComponentIds().get(component.getViewTreeKey());
                if (virtualComponentId == null) {
                    stack = stack3;
                    virtualComponentId = CellDataManager.createVirtualComponentId(context.templateList.getRef(), component.getViewTreeKey(), context.templateList.getItemId(context.position));
                    Map<String, Object> props = renderProps(JSONUtils.toJSON(attr.get(ELUtils.COMPONENT_PROPS)), context.stack);
                    EventResult result = WXBridgeManager.getInstance().syncCallJSEventWithResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, compoentId, VirtualComponentLifecycle.LIFECYCLE, "create", new Object[]{virtualComponentId, props}, null);
                    if (!(result == null || result.getResult() == null || !(result.getResult() instanceof Map))) {
                        props.putAll((Map) result.getResult());
                    }
                    compoentData = props;
                    context.getRenderState().getVirtualComponentIds().put(component.getViewTreeKey(), virtualComponentId);
                    context.templateList.getCellDataManager().createVirtualComponentData(context.position, virtualComponentId, compoentData);
                    callVirtualComponentAttach = true;
                } else {
                    stack = stack3;
                    Object compoentData2 = context.getRenderState().getVirtualComponentDatas().get(virtualComponentId);
                    if (context.getRenderState().isHasDataUpdate()) {
                        Map<String, Object> props2 = renderProps((JSONObject) attr.get(ELUtils.COMPONENT_PROPS), context.stack);
                        EventResult result2 = WXBridgeManager.getInstance().syncCallJSEventWithResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, virtualComponentId, VirtualComponentLifecycle.LIFECYCLE, VirtualComponentLifecycle.SYNSTATE, new Object[]{virtualComponentId, props2}, null);
                        if (!(result2 == null || result2.getResult() == null || !(result2.getResult() instanceof Map))) {
                            props2.putAll((Map) result2.getResult());
                            context.templateList.getCellDataManager().updateVirtualComponentData(virtualComponentId, props2);
                            compoentData = props2;
                        }
                    }
                    compoentData = compoentData2;
                }
                component.getAttrs().put(CellDataManager.VIRTUAL_COMPONENT_ID, (Object) virtualComponentId);
            } else {
                stack = stack3;
                compoentData = renderProps((JSONObject) attr.get(ELUtils.COMPONENT_PROPS), context.stack);
            }
            context.stack = new ArrayStack();
            if (compoentData != null) {
                context.stack.push(compoentData);
            }
        } else {
            stack = stack3;
        }
        Object vonce = null;
        if (attr.getStatement() != null) {
            vonce = attr.getStatement().get(WXStatement.WX_ONCE);
        }
        if (vonce != null) {
            ArrayStack onceStack = context.getRenderState().getOnceComponentStates().get(component.getViewTreeKey());
            if (onceStack == null) {
                stack2 = stack;
                onceStack = context.templateList.copyStack(context, stack2);
                context.getRenderState().getOnceComponentStates().put(component.getViewTreeKey(), onceStack);
            } else {
                stack2 = stack;
            }
            context.stack = onceStack;
        } else {
            stack2 = stack;
        }
        doRenderBindingAttrsAndEvent(component, context);
        if (component instanceof WXVContainer) {
            if (!component.isWaste() || (component instanceof WXCell)) {
                WXVContainer container = (WXVContainer) component;
                int k = 0;
                while (k < container.getChildCount()) {
                    k += doRenderComponent(container.getChild(k), context, updates);
                }
            } else {
                return;
            }
        }
        if (stack2 != context.stack) {
            context.stack = stack2;
        }
        if (callVirtualComponentAttach && virtualComponentId != null) {
            WXBridgeManager.getInstance().asyncCallJSEventVoidResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, virtualComponentId, VirtualComponentLifecycle.LIFECYCLE, "attach", new Object[]{TemplateDom.findAllComponentRefs(context.templateList.getRef(), context.position, component)});
        }
    }

    private static boolean isCreateFromNodeStatement(WXComponent renderNode, WXComponent component) {
        return renderNode.getRef() != null && renderNode.getRef().equals(component.getRef());
    }

    private static void doRenderBindingAttrsAndEvent(WXComponent component, CellRenderContext context) {
        ArrayStack stack = context.stack;
        component.setWaste(false);
        WXAttr attr = component.getAttrs();
        if (!(attr == null || attr.getBindingAttrs() == null || attr.getBindingAttrs().size() <= 0)) {
            Map<String, Object> dynamic = renderBindingAttrs(component.getAttrs().getBindingAttrs(), stack);
            Iterator<Map.Entry<String, Object>> iterator = dynamic.entrySet().iterator();
            while (iterator.hasNext()) {
                Map.Entry<String, Object> entry = iterator.next();
                Object value = entry.getValue();
                Object oldValue = attr.get(entry.getKey());
                if (value == null) {
                    if (oldValue == null) {
                        iterator.remove();
                    }
                } else if (value.equals(oldValue)) {
                    iterator.remove();
                }
            }
            if (dynamic.size() > 0) {
                if (dynamic.size() != 1 || dynamic.get("src") == null || !(component instanceof WXImage)) {
                    component.nativeUpdateAttrs(dynamic);
                } else {
                    component.getAttrs().put("src", dynamic.get("src"));
                }
                if (isMainThread()) {
                    component.updateProperties(dynamic);
                }
                dynamic.clear();
            }
        }
        WXStyle style = component.getStyles();
        if (!(style == null || style.getBindingStyle() == null)) {
            Map<String, Object> dynamic2 = renderBindingAttrs(style.getBindingStyle(), stack);
            Iterator<Map.Entry<String, Object>> iterator2 = dynamic2.entrySet().iterator();
            while (iterator2.hasNext()) {
                Map.Entry<String, Object> entry2 = iterator2.next();
                Object value2 = entry2.getValue();
                Object oldValue2 = style.get(entry2.getKey());
                if (value2 == null) {
                    if (oldValue2 == null) {
                        iterator2.remove();
                    }
                } else if (value2.equals(oldValue2)) {
                    iterator2.remove();
                }
            }
            if (dynamic2.size() > 0) {
                component.updateNativeStyles(dynamic2);
                if (isMainThread()) {
                    component.updateProperties(dynamic2);
                }
            }
        }
        WXEvent event = component.getEvents();
        if (!(event == null || event.getEventBindingArgs() == null)) {
            for (Map.Entry<String, Object> eventBindArgsEntry : event.getEventBindingArgs().entrySet()) {
                List<Object> values = getBindingEventArgs(stack, eventBindArgsEntry.getValue());
                if (values != null) {
                    event.putEventBindingArgsValue(eventBindArgsEntry.getKey(), values);
                }
            }
        }
    }

    public static Map<String, Object> renderBindingAttrs(ArrayMap bindAttrs, ArrayStack stack) {
        Set<Map.Entry<String, Object>> entrySet = bindAttrs.entrySet();
        Map<String, Object> dynamic = dynamicLocal.get();
        if (dynamic == null) {
            dynamic = new HashMap();
            dynamicLocal.set(dynamic);
        }
        if (dynamic.size() > 0) {
            dynamic.clear();
        }
        for (Map.Entry<String, Object> entry : entrySet) {
            Object value = entry.getValue();
            String key = entry.getKey();
            if ((value instanceof JSONObject) && (((JSONObject) value).get(ELUtils.BINDING) instanceof Token)) {
                dynamic.put(key, ((Token) ((JSONObject) value).get(ELUtils.BINDING)).execute(stack));
            } else if (value instanceof JSONArray) {
                JSONArray array = (JSONArray) value;
                StringBuilder builder = new StringBuilder();
                for (int i = 0; i < array.size(); i++) {
                    Object element = array.get(i);
                    if (element instanceof CharSequence) {
                        builder.append(element);
                    } else if ((element instanceof JSONObject) && (((JSONObject) element).get(ELUtils.BINDING) instanceof Token)) {
                        Object blockValue = ((Token) ((JSONObject) element).get(ELUtils.BINDING)).execute(stack);
                        if (blockValue == null) {
                            blockValue = "";
                        }
                        builder.append(blockValue);
                    }
                }
                String builderString = builder.toString();
                if (builderString.length() > 256 && WXEnvironment.isApkDebugable()) {
                    WXLogUtils.w(WXRecyclerTemplateList.TAG, " warn too big string " + builderString);
                }
                dynamic.put(key, builderString);
            }
        }
        return dynamic;
    }

    public static Map<String, Object> renderProps(JSONObject props, ArrayStack stack) {
        Set<Map.Entry<String, Object>> entrySet = props.entrySet();
        Map<String, Object> renderProps = new ArrayMap<>(4);
        for (Map.Entry<String, Object> entry : entrySet) {
            Object value = entry.getValue();
            String key = entry.getKey();
            if (!(value instanceof JSONObject) || !(((JSONObject) value).get(ELUtils.BINDING) instanceof Token)) {
                renderProps.put(key, value);
            } else {
                renderProps.put(key, ((Token) ((JSONObject) value).get(ELUtils.BINDING)).execute(stack));
            }
        }
        return renderProps;
    }

    public static List<Object> getBindingEventArgs(ArrayStack stack, Object bindings) {
        List<Object> params = new ArrayList<>(4);
        if (bindings instanceof JSONArray) {
            JSONArray array = (JSONArray) bindings;
            for (int i = 0; i < array.size(); i++) {
                Object value = array.get(i);
                if (!(value instanceof JSONObject) || !(((JSONObject) value).get(ELUtils.BINDING) instanceof Token)) {
                    params.add(value);
                } else {
                    params.add(((Token) ((JSONObject) value).get(ELUtils.BINDING)).execute(stack));
                }
            }
        } else if (bindings instanceof JSONObject) {
            JSONObject binding = (JSONObject) bindings;
            if (binding.get(ELUtils.BINDING) instanceof Token) {
                params.add(((Token) binding.get(ELUtils.BINDING)).execute(stack));
            } else {
                params.add(bindings.toString());
            }
        } else {
            params.add(bindings.toString());
        }
        return params;
    }

    private static boolean isMainThread() {
        return Thread.currentThread() == Looper.getMainLooper().getThread();
    }

    public static String getComponentId(WXComponent component) {
        if ((component instanceof WXCell) || component == null) {
            return null;
        }
        WXAttr attr = component.getAttrs();
        if (attr.get(ELUtils.IS_COMPONENT_ROOT) == null || !WXUtils.getBoolean(attr.get(ELUtils.IS_COMPONENT_ROOT), false).booleanValue() || attr.get(ELUtils.COMPONENT_PROPS) == null || !(attr.get(ELUtils.COMPONENT_PROPS) instanceof JSONObject)) {
            return getComponentId(component.getParent());
        }
        Object componentId = attr.get(CellDataManager.VIRTUAL_COMPONENT_ID);
        if (componentId == null) {
            return null;
        }
        return componentId.toString();
    }
}
