package com.taobao.weex.ui.component.helper;

import android.os.Handler;
import android.os.Looper;
import androidx.recyclerview.widget.RecyclerView;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.DCWXScroller;
import com.taobao.weex.ui.component.WXBaseScroller;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.list.BasicListComponent;
import com.taobao.weex.ui.component.list.ListComponentView;
import com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXUtils;
import java.util.Map;

public class ScrollStartEndHelper implements Runnable {
    private boolean canStart = false;
    private WXComponent component;
    private Handler handler;
    private boolean hasScrollEnd;
    private boolean hasStart;
    private long minInterval;
    private int oldState = 0;
    private int x;
    private int y;

    public ScrollStartEndHelper(WXComponent component2) {
        this.component = component2;
        this.handler = new Handler(Looper.getMainLooper());
        this.minInterval = (long) WXUtils.getNumberInt(component2.getAttrs().get("minscrolldelayinterval"), 32);
    }

    public void onScrolled(int x2, int y2) {
        Map<String, Object> event;
        if (this.component.getEvents().contains(Constants.Event.SCROLL_START) || this.component.getEvents().contains(Constants.Event.SCROLL_END)) {
            this.x = x2;
            this.y = y2;
            if (!this.hasStart && this.canStart) {
                if (this.component.getEvents().contains(Constants.Event.SCROLL_START) && (event = getScrollEvent(x2, y2)) != null && !event.isEmpty()) {
                    this.component.fireEvent(Constants.Event.SCROLL_START, event);
                }
                this.hasStart = true;
                this.canStart = false;
            }
            this.handler.removeCallbacks(this);
            this.handler.postDelayed(this, this.minInterval);
        }
    }

    public void run() {
        if (!this.component.isDestoryed() && this.hasScrollEnd) {
            if (this.canStart) {
                this.component.fireEvent(Constants.Event.SCROLL_START, getScrollEvent(this.x, this.y));
                this.canStart = false;
            }
            if (this.component.getEvents().contains(Constants.Event.SCROLL_END)) {
                this.component.fireEvent(Constants.Event.SCROLL_END, getScrollEvent(this.x, this.y));
            }
            this.hasStart = false;
            this.hasScrollEnd = false;
        }
    }

    private Map<String, Object> getScrollEvent(int offsetX, int offsetY) {
        ListComponentView componentView;
        WXComponent wXComponent = this.component;
        if (wXComponent instanceof BasicListComponent) {
            BasicListComponent basicListComponent = (BasicListComponent) wXComponent;
            if (!(basicListComponent.getHostView() instanceof ListComponentView) || (componentView = (ListComponentView) basicListComponent.getHostView()) == null) {
                return null;
            }
            return basicListComponent.getScrollEvent(componentView.getInnerView(), offsetX, offsetY);
        } else if (wXComponent instanceof WXRecyclerTemplateList) {
            WXRecyclerTemplateList templateList = (WXRecyclerTemplateList) wXComponent;
            return templateList.getScrollEvent((RecyclerView) ((BounceRecyclerView) templateList.getHostView()).getInnerView(), offsetX, offsetY);
        } else if (wXComponent instanceof DCWXScroller) {
            return ((DCWXScroller) wXComponent).getScrollEvent(offsetX, offsetY);
        } else {
            if (wXComponent instanceof WXBaseScroller) {
                return ((WXBaseScroller) wXComponent).getScrollEvent(offsetX, offsetY);
            }
            return null;
        }
    }

    public void onScrollStateChanged(int newState) {
        if (this.oldState == 0) {
            this.canStart = true;
        }
        if (newState == 0) {
            this.hasScrollEnd = true;
            this.handler.removeCallbacks(this);
            this.handler.postDelayed(this, this.minInterval);
        }
        this.oldState = newState;
    }

    public static boolean isScrollEvent(String type) {
        if (!"scroll".equals(type) && !Constants.Event.SCROLL_START.equals(type) && !Constants.Event.SCROLL_END.equals(type)) {
            return false;
        }
        return true;
    }
}
