package com.taobao.weex.ui.component.helper;

import android.app.Activity;
import android.graphics.Rect;
import android.os.Build;
import android.view.View;
import android.view.ViewTreeObserver;
import android.view.WindowManager;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.lang.ref.WeakReference;

public class SoftKeyboardDetector {
    private static final int KEYBOARD_VISIBLE_THRESHOLD_DIP = 100;

    public interface OnKeyboardEventListener {
        void onKeyboardEvent(boolean z);
    }

    public interface Unregister {
        void execute();
    }

    public static Unregister registerKeyboardEventListener(Activity activity, final OnKeyboardEventListener listener) {
        WindowManager.LayoutParams attributes;
        int softInputMode;
        if (activity == null || listener == null) {
            WXLogUtils.e("Activity or listener is null!");
            return null;
        } else if (activity.getWindow() == null || (attributes = activity.getWindow().getAttributes()) == null || !((softInputMode = attributes.softInputMode) == 48 || softInputMode == 32)) {
            final View activityRoot = getActivityRoot(activity);
            if (activityRoot == null) {
                WXLogUtils.e("Activity root is null!");
                return null;
            }
            ViewTreeObserver.OnGlobalLayoutListener layoutListener = new ViewTreeObserver.OnGlobalLayoutListener() {
                /* class com.taobao.weex.ui.component.helper.SoftKeyboardDetector.AnonymousClass1 */
                private final int threshold = WXViewUtils.dip2px(100.0f);
                private final Rect visibleFrame = new Rect();
                private boolean wasKeyboardOpened = false;

                public void onGlobalLayout() {
                    activityRoot.getWindowVisibleDisplayFrame(this.visibleFrame);
                    boolean isOpen = activityRoot.getRootView().getHeight() - this.visibleFrame.height() > this.threshold;
                    if (isOpen != this.wasKeyboardOpened) {
                        this.wasKeyboardOpened = isOpen;
                        listener.onKeyboardEvent(isOpen);
                    }
                }
            };
            activityRoot.getViewTreeObserver().addOnGlobalLayoutListener(layoutListener);
            return new DefaultUnRegister(activity, layoutListener);
        } else {
            WXLogUtils.e("SoftKeyboard detector can't work with softInputMode is SOFT_INPUT_ADJUST_NOTHING or SOFT_INPUT_ADJUST_PAN");
            return null;
        }
    }

    public static boolean isKeyboardVisible(Activity activity) {
        Rect windowFrame = new Rect();
        View root = getActivityRoot(activity);
        if (root == null) {
            return false;
        }
        root.getWindowVisibleDisplayFrame(windowFrame);
        if (root.getRootView().getHeight() - windowFrame.height() > WXViewUtils.dip2px(100.0f)) {
            return true;
        }
        return false;
    }

    public static View getActivityRoot(Activity activity) {
        if (activity != null) {
            return activity.findViewById(16908290);
        }
        return null;
    }

    public static final class DefaultUnRegister implements Unregister {
        private WeakReference<Activity> activityRef;
        private WeakReference<ViewTreeObserver.OnGlobalLayoutListener> listenerRef;

        public DefaultUnRegister(Activity activity, ViewTreeObserver.OnGlobalLayoutListener listener) {
            this.activityRef = new WeakReference<>(activity);
            this.listenerRef = new WeakReference<>(listener);
        }

        @Override // com.taobao.weex.ui.component.helper.SoftKeyboardDetector.Unregister
        public void execute() {
            View root;
            Activity activity = this.activityRef.get();
            ViewTreeObserver.OnGlobalLayoutListener listener = this.listenerRef.get();
            if (!(activity == null || listener == null || (root = SoftKeyboardDetector.getActivityRoot(activity)) == null)) {
                if (Build.VERSION.SDK_INT >= 16) {
                    root.getViewTreeObserver().removeOnGlobalLayoutListener(listener);
                } else {
                    root.getViewTreeObserver().removeGlobalOnLayoutListener(listener);
                }
            }
            this.activityRef.clear();
            this.listenerRef.clear();
        }
    }
}
