package com.taobao.weex.ui.component.list;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.os.Build;
import android.text.TextUtils;
import android.util.SparseArray;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.collection.ArrayMap;
import androidx.core.view.MotionEventCompat;
import androidx.core.view.ViewCompat;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.IWXObject;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.AppearanceHelper;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseRefresh;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXHeader;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXLoading;
import com.taobao.weex.ui.component.WXRefresh;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.component.helper.WXStickyHelper;
import com.taobao.weex.ui.component.list.ListComponentView;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener;
import com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener;
import com.taobao.weex.ui.view.listview.adapter.ListBaseViewHolder;
import com.taobao.weex.ui.view.listview.adapter.RecyclerViewBaseAdapter;
import com.taobao.weex.ui.view.listview.adapter.WXRecyclerViewOnScrollListener;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Deque;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;

public abstract class BasicListComponent<T extends ViewGroup & ListComponentView> extends WXVContainer<T> implements IRecyclerAdapterListener<ListBaseViewHolder>, IOnLoadMoreListener, Scrollable {
    private static final boolean DEFAULT_EXCLUDED = false;
    private static final String DEFAULT_TRIGGER_TYPE = "longpress";
    private static final String DRAG_ANCHOR = "dragAnchor";
    private static final String DRAG_TRIGGER_TYPE = "dragTriggerType";
    private static final String EXCLUDED = "dragExcluded";
    public static final String LOADMOREOFFSET = "loadmoreoffset";
    private static final int MAX_VIEWTYPE_ALLOW_CACHE = 9;
    public static final String TRANSFORM = "transform";
    private static boolean mAllowCacheViewHolder = true;
    private static boolean mDownForBidCacheViewHolder = false;
    private static final Pattern transformPattern = Pattern.compile("([a-z]+)\\(([0-9\\.]+),?([0-9\\.]+)?\\)");
    private String TAG = "BasicListComponent";
    private boolean isScrollable = true;
    boolean isThisGroupFinished = false;
    private WXComponent keepPositionCell = null;
    private Runnable keepPositionCellRunnable = null;
    private long keepPositionLayoutDelay = 150;
    ListStanceCell listStanceObject;
    private Runnable mAppearChangeRunnable = null;
    private long mAppearChangeRunnableDelay = 50;
    private Map<String, AppearanceHelper> mAppearComponents = new HashMap();
    protected int mColumnCount = 1;
    protected float mColumnGap = 0.0f;
    protected float mColumnWidth = 0.0f;
    private DragHelper mDragHelper;
    private boolean mForceLoadmoreNextTime = false;
    private boolean mHasAddScrollEvent = false;
    private RecyclerView.ItemAnimator mItemAnimator;
    private Point mLastReport = new Point(-1, -1);
    protected int mLayoutType = 1;
    protected float mLeftGap = 0.0f;
    private int mListCellCount = 0;
    private int mOffsetAccuracy = 10;
    private ArrayMap<String, Long> mRefToViewType;
    protected float mRightGap = 0.0f;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private Map<String, Map<String, WXComponent>> mStickyMap = new HashMap();
    private String mTriggerType;
    private WXRecyclerViewOnScrollListener mViewOnScrollListener = new WXRecyclerViewOnScrollListener(this);
    private SparseArray<ArrayList<WXComponent>> mViewTypes;
    private WXStickyHelper stickyHelper = new WXStickyHelper(this);

    interface DragTriggerType {
        public static final String LONG_PRESS = "longpress";
        public static final String PAN = "pan";
    }

    /* access modifiers changed from: package-private */
    public abstract T generateListView(Context context, int i);

    public BasicListComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        if (Build.VERSION.SDK_INT >= 17) {
            lp.setMargins(left, top, right, bottom);
            lp.setMarginStart(left);
            lp.setMarginEnd(right);
        } else if (lp instanceof FrameLayout.LayoutParams) {
            FrameLayout.LayoutParams lp_frameLayout = (FrameLayout.LayoutParams) lp;
            if (isLayoutRTL()) {
                lp_frameLayout.gravity = 53;
                lp.setMargins(right, top, left, bottom);
                return;
            }
            lp_frameLayout.gravity = 51;
            lp.setMargins(left, top, right, bottom);
        } else {
            lp.setMargins(left, top, right, bottom);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        if (component.getHostView() != null) {
            ViewCompat.setLayoutDirection(component.getHostView(), component.isLayoutRTL() ? 1 : 0);
        }
        super.setLayout(component);
    }

    /* access modifiers changed from: protected */
    public void onHostViewInitialized(T host) {
        super.onHostViewInitialized((View) host);
        WXRecyclerView recyclerView = host.getInnerView();
        if (recyclerView == null || recyclerView.getAdapter() == null) {
            WXLogUtils.e(this.TAG, "RecyclerView is not found or Adapter is not bound");
            return;
        }
        if (WXUtils.getBoolean(getAttrs().get("prefetchGapDisable"), false).booleanValue() && recyclerView.getLayoutManager() != null) {
            recyclerView.getLayoutManager().setItemPrefetchEnabled(false);
        }
        if (this.mChildren == null) {
            WXLogUtils.e(this.TAG, "children is null");
            return;
        }
        this.mDragHelper = new DefaultDragHelper(this.mChildren, recyclerView, new EventTrigger() {
            /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass1 */

            @Override // com.taobao.weex.ui.component.list.EventTrigger
            public void triggerEvent(String type, Map<String, Object> args) {
                BasicListComponent.this.fireEvent(type, args);
            }
        });
        this.mTriggerType = getTriggerType(this);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        return super.measure(width, height);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getOrientation() {
        return 1;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (!(this.mAppearChangeRunnable == null || getHostView() == null)) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            this.mAppearChangeRunnable = null;
        }
        if (!(getHostView() == null || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null)) {
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().clearOnScrollListeners();
        }
        super.destroy();
        Map<String, Map<String, WXComponent>> map = this.mStickyMap;
        if (map != null) {
            map.clear();
        }
        SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
        if (sparseArray != null) {
            sparseArray.clear();
        }
        ArrayMap<String, Long> arrayMap = this.mRefToViewType;
        if (arrayMap != null) {
            arrayMap.clear();
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View hostView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.MarginLayoutParams params = (ViewGroup.MarginLayoutParams) hostView.getLayoutParams();
        if ((child instanceof WXBaseRefresh) && params == null) {
            return new LinearLayout.LayoutParams(width, height);
        }
        if (params == null) {
            return new RecyclerView.LayoutParams(width, height);
        }
        params.width = width;
        params.height = height;
        setMarginsSupportRTL(params, left, 0, right, 0);
        return params;
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public T initComponentHostView(Context context) {
        T bounceRecyclerView = generateListView(context, getOrientation());
        String transforms = getAttrByKey("transform");
        if (transforms != null) {
            bounceRecyclerView.getInnerView().addItemDecoration(RecyclerTransform.parseTransforms(getOrientation(), transforms));
        }
        if (getAttrs().get(Constants.Name.KEEP_POSITION_LAYOUT_DELAY) != null) {
            this.keepPositionLayoutDelay = (long) WXUtils.getNumberInt(getAttrs().get(Constants.Name.KEEP_POSITION_LAYOUT_DELAY), (int) this.keepPositionLayoutDelay);
        }
        if (getAttrs().get("appearActionDelay") != null) {
            this.mAppearChangeRunnableDelay = (long) WXUtils.getNumberInt(getAttrs().get("appearActionDelay"), (int) this.mAppearChangeRunnableDelay);
        }
        this.mItemAnimator = bounceRecyclerView.getInnerView().getItemAnimator();
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = new RecyclerViewBaseAdapter(this);
        recyclerViewBaseAdapter.setHasStableIds(true);
        bounceRecyclerView.setRecyclerViewBaseAdapter(recyclerViewBaseAdapter);
        bounceRecyclerView.getInnerView().addOnScrollListener(this.mViewOnScrollListener);
        if (getAttrs().get(Constants.Name.HAS_FIXED_SIZE) != null) {
            bounceRecyclerView.getInnerView().setHasFixedSize(WXUtils.getBoolean(getAttrs().get(Constants.Name.HAS_FIXED_SIZE), false).booleanValue());
        }
        bounceRecyclerView.getInnerView().addOnScrollListener(new RecyclerView.OnScrollListener() {
            /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass2 */

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                int size;
                View topView;
                super.onScrollStateChanged(recyclerView, newState);
                BasicListComponent.this.getScrollStartEndHelper().onScrollStateChanged(newState);
                List<OnWXScrollListener> listeners = BasicListComponent.this.getInstance().getWXScrollListeners();
                if (listeners != null && (size = listeners.size()) > 0) {
                    int i = 0;
                    while (i < size && i < listeners.size()) {
                        OnWXScrollListener listener = listeners.get(i);
                        if (!(listener == null || (topView = recyclerView.getChildAt(0)) == null)) {
                            listener.onScrollStateChanged(recyclerView, 0, topView.getTop(), newState);
                        }
                        i++;
                    }
                }
            }

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);
                List<OnWXScrollListener> listeners = BasicListComponent.this.getInstance().getWXScrollListeners();
                if (listeners != null && listeners.size() > 0) {
                    try {
                        for (OnWXScrollListener listener : listeners) {
                            if (listener != null) {
                                if (!(listener instanceof ICheckBindingScroller)) {
                                    listener.onScrolled(recyclerView, dx, dy);
                                } else if (((ICheckBindingScroller) listener).isNeedScroller(BasicListComponent.this.getRef(), null)) {
                                    listener.onScrolled(recyclerView, dx, dy);
                                }
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        });
        bounceRecyclerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass3 */

            public void onGlobalLayout() {
                ViewGroup viewGroup = (ViewGroup) BasicListComponent.this.getHostView();
                if (viewGroup != null) {
                    BasicListComponent.this.mViewOnScrollListener.onScrolled(((ListComponentView) viewGroup).getInnerView(), 0, 0);
                    if (Build.VERSION.SDK_INT >= 16) {
                        viewGroup.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                    } else {
                        viewGroup.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                    }
                }
            }
        });
        return bounceRecyclerView;
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindStickStyle(WXComponent component) {
        this.stickyHelper.bindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindStickStyle(WXComponent component) {
        this.stickyHelper.unbindStickStyle(component, this.mStickyMap);
        WXHeader cell = (WXHeader) findTypeParent(component, WXHeader.class);
        if (cell != null && getHostView() != null) {
            ((ListComponentView) ((ViewGroup) getHostView())).notifyStickyRemove(cell);
        }
    }

    private WXComponent findDirectListChild(WXComponent comp) {
        WXComponent parent;
        if (comp == null || (parent = comp.getParent()) == null) {
            return null;
        }
        if (parent instanceof BasicListComponent) {
            return comp;
        }
        return findDirectListChild(parent);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -304480883:
                if (key.equals(Constants.Name.DRAGGABLE)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -112563826:
                if (key.equals("loadmoreoffset")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            return true;
        }
        if (c == 1) {
            setScrollable(WXUtils.getBoolean(param, true).booleanValue());
            return true;
        } else if (c == 2) {
            setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
            return true;
        } else if (c == 3) {
            setDraggable(WXUtils.getBoolean(param, false).booleanValue());
            return true;
        } else if (c != 4) {
            return super.setProperty(key, param);
        } else {
            Boolean result = WXUtils.getBoolean(param, null);
            if (result != null) {
                setShowScrollbar(result.booleanValue());
            }
            return true;
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        this.isScrollable = scrollable;
        WXRecyclerView inner = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        if (inner != null) {
            inner.setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth((float) accuracy, getInstance().getInstanceViewPortWidthWithFloat());
    }

    @WXComponentProp(name = Constants.Name.DRAGGABLE)
    public void setDraggable(boolean isDraggable) {
        DragHelper dragHelper = this.mDragHelper;
        if (dragHelper != null) {
            dragHelper.setDraggable(isDraggable);
        }
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("set draggable : " + isDraggable);
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getHostView() != null && ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() != null) {
            if (getOrientation() == 1) {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setVerticalScrollBarEnabled(show);
            } else {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setHorizontalScrollBarEnabled(show);
            }
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public boolean isScrollable() {
        return this.isScrollable;
    }

    private void setAppearanceWatch(WXComponent component, int event, boolean enable) {
        int index;
        AppearanceHelper item = this.mAppearComponents.get(component.getRef());
        if (item != null) {
            item.setWatchEvent(event, enable);
        } else if (enable && (index = this.mChildren.indexOf(findDirectListChild(component))) != -1) {
            AppearanceHelper item2 = new AppearanceHelper(component, index);
            item2.setWatchEvent(event, true);
            this.mAppearComponents.put(component.getRef(), item2);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() {
                /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass4 */

                public void run() {
                    if (BasicListComponent.this.mAppearChangeRunnable != null) {
                        BasicListComponent.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != null) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((ViewGroup) getHostView()).postDelayed(this.mAppearChangeRunnable, this.mAppearChangeRunnableDelay);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, true);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, false);
    }

    /* JADX INFO: Multiple debug info for r2v0 int: [D('offsetStr' java.lang.String), D('offset' int)] */
    @Override // com.taobao.weex.ui.component.Scrollable
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int pos;
        float offsetFloat = 0.0f;
        boolean smooth = true;
        if (options != null) {
            String offsetStr = options.get("offset") == null ? "0" : options.get("offset").toString();
            smooth = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (offsetStr != null) {
                try {
                    offsetFloat = WXViewUtils.getRealPxByWidth(Float.parseFloat(offsetStr), getInstance().getInstanceViewPortWidthWithFloat());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
        }
        int offset = (int) offsetFloat;
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            WXComponent parent = component;
            WXCell cell = null;
            while (true) {
                if (parent == null) {
                    break;
                } else if (parent instanceof WXCell) {
                    cell = (WXCell) parent;
                    break;
                } else {
                    parent = parent.getParent();
                }
            }
            if (cell != null && (pos = this.mChildren.indexOf(cell)) != -1) {
                ((ListComponentView) viewGroup).getInnerView().scrollTo(smooth, pos, offset, getOrientation());
            }
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:30:0x00bb, code lost:
        if (r11 <= r7.getStickyOffset()) goto L_0x00c4;
     */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x0106  */
    /* JADX WARNING: Removed duplicated region for block: B:61:0x0121  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x012f  */
    /* JADX WARNING: Removed duplicated region for block: B:69:0x0136 A[ADDED_TO_REGION] */
    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onBeforeScroll(int dx, int dy) {
        Map<String, WXComponent> stickyMap;
        Iterator<Map.Entry<String, WXComponent>> iterator;
        Map<String, WXComponent> stickyMap2;
        boolean showSticky;
        ViewGroup viewGroup = (ViewGroup) getHostView();
        Map<String, Map<String, WXComponent>> map = this.mStickyMap;
        if (map != null && viewGroup != null && (stickyMap = map.get(getRef())) != null) {
            Iterator<Map.Entry<String, WXComponent>> iterator2 = stickyMap.entrySet().iterator();
            int currentStickyPos = -1;
            while (iterator2.hasNext()) {
                WXComponent stickyComponent = iterator2.next().getValue();
                if (stickyComponent == null || !(stickyComponent instanceof WXCell)) {
                    stickyMap = stickyMap;
                    iterator2 = iterator2;
                } else {
                    WXCell cell = (WXCell) stickyComponent;
                    if (cell.getHostView() != null) {
                        int[] location = new int[2];
                        stickyComponent.getHostView().getLocationOnScreen(location);
                        int[] parentLocation = new int[2];
                        stickyComponent.getParentScroller().getView().getLocationOnScreen(parentLocation);
                        int top = location[1] - parentLocation[1];
                        boolean beforeFirstVisibleItem = false;
                        boolean removeOldSticky = false;
                        RecyclerView.LayoutManager layoutManager = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getLayoutManager();
                        if (layoutManager instanceof LinearLayoutManager) {
                            stickyMap2 = stickyMap;
                            iterator = iterator2;
                        } else if (layoutManager instanceof GridLayoutManager) {
                            stickyMap2 = stickyMap;
                            iterator = iterator2;
                        } else {
                            if (layoutManager instanceof StaggeredGridLayoutManager) {
                                int[] firstItems = new int[3];
                                int firstVisiblePosition = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(firstItems)[0];
                                stickyMap2 = stickyMap;
                                int lastVisiblePosition = ((StaggeredGridLayoutManager) layoutManager).findLastVisibleItemPositions(firstItems)[0];
                                iterator = iterator2;
                                int pos = this.mChildren.indexOf(cell);
                                if (pos > firstVisiblePosition) {
                                    if (cell.getStickyOffset() <= 0 || firstVisiblePosition >= pos || pos > lastVisiblePosition) {
                                    }
                                    removeOldSticky = true;
                                }
                                beforeFirstVisibleItem = true;
                                if (pos > currentStickyPos) {
                                    currentStickyPos = pos;
                                }
                            } else {
                                stickyMap2 = stickyMap;
                                iterator = iterator2;
                            }
                            showSticky = !beforeFirstVisibleItem && cell.getLocationFromStart() >= 0 && top <= cell.getStickyOffset() && dy >= 0;
                            boolean removeSticky = cell.getLocationFromStart() > cell.getStickyOffset() && top > cell.getStickyOffset() && dy <= 0;
                            if (showSticky) {
                                ((ListComponentView) viewGroup).notifyStickyShow(cell);
                            } else if (removeSticky || removeOldSticky) {
                                ((ListComponentView) viewGroup).notifyStickyRemove(cell);
                            }
                            cell.setLocationFromStart(top);
                            stickyMap = stickyMap2;
                            iterator2 = iterator;
                        }
                        int firstVisiblePosition2 = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
                        int lastVisiblePosition2 = ((LinearLayoutManager) layoutManager).findLastVisibleItemPosition();
                        int pos2 = this.mChildren.indexOf(cell);
                        cell.setScrollPositon(pos2);
                        if (pos2 <= firstVisiblePosition2 || (cell.getStickyOffset() > 0 && firstVisiblePosition2 < pos2 && pos2 <= lastVisiblePosition2 && top <= cell.getStickyOffset())) {
                            beforeFirstVisibleItem = true;
                            if (pos2 > currentStickyPos) {
                                currentStickyPos = pos2;
                            }
                            if (!beforeFirstVisibleItem) {
                            }
                            if (cell.getLocationFromStart() > cell.getStickyOffset()) {
                            }
                            if (showSticky) {
                            }
                            cell.setLocationFromStart(top);
                            stickyMap = stickyMap2;
                            iterator2 = iterator;
                        } else {
                            removeOldSticky = true;
                            if (!beforeFirstVisibleItem) {
                            }
                            if (cell.getLocationFromStart() > cell.getStickyOffset()) {
                            }
                            if (showSticky) {
                            }
                            cell.setLocationFromStart(top);
                            stickyMap = stickyMap2;
                            iterator2 = iterator;
                        }
                    } else {
                        return;
                    }
                }
            }
            if (currentStickyPos >= 0) {
                ((ListComponentView) viewGroup).updateStickyView(currentStickyPos);
            } else if (viewGroup instanceof BounceRecyclerView) {
                ((BounceRecyclerView) viewGroup).getStickyHeaderHelper().clearStickyHeaders();
            }
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollY() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return 0;
        }
        return ((ListComponentView) viewGroup).getInnerView().getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollX() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return 0;
        }
        return ((ListComponentView) viewGroup).getInnerView().getScrollX();
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        super.addChild(child, index);
        if (child != null && index >= -1) {
            int index2 = index >= this.mChildren.size() ? -1 : index;
            bindViewType(child);
            boolean isBottomItem = false;
            if (!this.isThisGroupFinished && isRenderFromBottom()) {
                if (child.getAttrs().containsKey("renderReversePosition")) {
                    isBottomItem = true;
                } else {
                    return;
                }
            }
            this.isThisGroupFinished = true;
            int adapterPosition = index2 == -1 ? this.mChildren.size() - 1 : index2;
            final ViewGroup viewGroup = (ViewGroup) getHostView();
            if (viewGroup != null) {
                boolean isAddAnimation = false;
                if (getBasicComponentData() != null && "default".equals(getAttrs().get(Constants.Name.INSERT_CELL_ANIMATION))) {
                    isAddAnimation = true;
                }
                if (isAddAnimation) {
                    ((ListComponentView) viewGroup).getInnerView().setItemAnimator(this.mItemAnimator);
                } else {
                    ((ListComponentView) viewGroup).getInnerView().setItemAnimator(null);
                }
                boolean isKeepScrollPosition = false;
                if (child.getBasicComponentData() != null && WXUtils.getBoolean(child.getAttrs().get(Constants.Name.KEEP_SCROLL_POSITION), false).booleanValue() && index2 <= getChildCount() && index2 > -1) {
                    isKeepScrollPosition = true;
                }
                if (!isKeepScrollPosition && isBottomItem) {
                    isKeepScrollPosition = true;
                }
                if (isKeepScrollPosition) {
                    if (((ListComponentView) viewGroup).getInnerView().getLayoutManager() instanceof LinearLayoutManager) {
                        if (this.keepPositionCell == null) {
                            ListBaseViewHolder holder = (ListBaseViewHolder) ((ListComponentView) viewGroup).getInnerView().findViewHolderForAdapterPosition(((LinearLayoutManager) ((ListComponentView) viewGroup).getInnerView().getLayoutManager()).findLastCompletelyVisibleItemPosition());
                            if (holder != null) {
                                this.keepPositionCell = holder.getComponent();
                            }
                            if (this.keepPositionCell != null) {
                                if (!((ListComponentView) viewGroup).getInnerView().isLayoutFrozen()) {
                                    ((ListComponentView) viewGroup).getInnerView().setLayoutFrozen(true);
                                }
                                Runnable runnable = this.keepPositionCellRunnable;
                                if (runnable != null) {
                                    viewGroup.removeCallbacks(runnable);
                                }
                                this.keepPositionCellRunnable = new Runnable() {
                                    /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass5 */

                                    public void run() {
                                        if (BasicListComponent.this.keepPositionCell != null) {
                                            BasicListComponent basicListComponent = BasicListComponent.this;
                                            int keepPosition = basicListComponent.indexOf(basicListComponent.keepPositionCell);
                                            int offset = 0;
                                            if (BasicListComponent.this.keepPositionCell.getHostView() != null) {
                                                offset = BasicListComponent.this.keepPositionCell.getHostView().getTop();
                                            }
                                            if (offset > 0) {
                                                ((LinearLayoutManager) ((ListComponentView) viewGroup).getInnerView().getLayoutManager()).scrollToPositionWithOffset(keepPosition, offset);
                                            } else {
                                                ((ListComponentView) viewGroup).getInnerView().getLayoutManager().scrollToPosition(keepPosition);
                                            }
                                            ((ListComponentView) viewGroup).getInnerView().setLayoutFrozen(false);
                                            BasicListComponent.this.keepPositionCell = null;
                                            BasicListComponent.this.keepPositionCellRunnable = null;
                                        }
                                    }
                                };
                            }
                        }
                        if (this.keepPositionCellRunnable == null) {
                            int bottomItemPosition = ((LinearLayoutManager) ((ListComponentView) viewGroup).getInnerView().getLayoutManager()).findLastVisibleItemPosition();
                            if (isBottomItem) {
                                bottomItemPosition = index2;
                            }
                            ((ListComponentView) viewGroup).getInnerView().scrollToPosition(bottomItemPosition);
                        }
                    }
                    ((ListComponentView) viewGroup).getRecyclerViewBaseAdapter().notifyItemRangeInserted(adapterPosition, 20);
                    Runnable runnable2 = this.keepPositionCellRunnable;
                    if (runnable2 != null) {
                        viewGroup.removeCallbacks(runnable2);
                        viewGroup.postDelayed(this.keepPositionCellRunnable, this.keepPositionLayoutDelay);
                    }
                } else {
                    ((ListComponentView) viewGroup).getRecyclerViewBaseAdapter().notifyDataSetChanged();
                }
            }
            relocateAppearanceHelper();
        }
    }

    private void relocateAppearanceHelper() {
        for (Map.Entry<String, AppearanceHelper> item : this.mAppearComponents.entrySet()) {
            AppearanceHelper value = item.getValue();
            value.setCellPosition(this.mChildren.indexOf(findDirectListChild(value.getAwareChild())));
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        int index = this.mChildren.indexOf(child);
        if (destroy) {
            child.detachViewAndClearPreInfo();
        }
        unBindViewType(child);
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            boolean isRemoveAnimation = false;
            if ("default".equals(child.getAttrs().get(Constants.Name.DELETE_CELL_ANIMATION))) {
                isRemoveAnimation = true;
            }
            if (isRemoveAnimation) {
                ((ListComponentView) viewGroup).getInnerView().setItemAnimator(this.mItemAnimator);
            } else {
                ((ListComponentView) viewGroup).getInnerView().setItemAnimator(null);
            }
            ((ListComponentView) viewGroup).getRecyclerViewBaseAdapter().notifyItemRemoved(index);
            if (WXEnvironment.isApkDebugable()) {
                String str = this.TAG;
                WXLogUtils.d(str, "removeChild child at " + index);
            }
            super.remove(child, destroy);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        RecyclerView view = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        pointF.set((float) view.computeHorizontalScrollOffset(), (float) view.computeVerticalScrollOffset());
    }

    public void onViewRecycled(ListBaseViewHolder holder) {
        long begin = System.currentTimeMillis();
        holder.setComponentUsing(false);
        if (holder == null || !holder.canRecycled() || holder.getComponent() == null || holder.getComponent().isUsing()) {
            WXLogUtils.w(this.TAG, "this holder can not be allowed to  recycled");
        } else {
            holder.recycled();
        }
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.d(str, "Recycle holder " + (System.currentTimeMillis() - begin) + "  Thread:" + Thread.currentThread().getName());
        }
    }

    public void onBindViewHolder(final ListBaseViewHolder holder, int position) {
        int color;
        if (holder != null) {
            holder.setComponentUsing(true);
            IWXObject iwxObject = getListChild(position);
            if (iwxObject instanceof ListStanceCell) {
                holder.getView().setBackgroundColor(WXResourceUtils.getColor(((ListStanceCell) iwxObject).getBackgroundColor(), -1));
                holder.getView().setVisibility(0);
                holder.getView().postInvalidate();
            } else if (iwxObject instanceof WXComponent) {
                WXComponent component = (WXComponent) iwxObject;
                if (component == null || (component instanceof WXRefresh) || (component instanceof WXLoading) || component.isFixed()) {
                    if (WXEnvironment.isApkDebugable()) {
                        String str = this.TAG;
                        WXLogUtils.d(str, "Bind WXRefresh & WXLoading " + holder);
                    }
                    if ((component instanceof WXBaseRefresh) && holder.getView() != null) {
                        if (component.getAttrs().get("holderBackground") != null || component.getStyles().containsKey("backgroundColor")) {
                            Object holderBackground = component.getAttrs().get("holderBackground");
                            if (holderBackground != null) {
                                color = WXResourceUtils.getColor(holderBackground.toString(), -1);
                            } else {
                                color = WXResourceUtils.getColor(component.getStyles().getBackgroundColor(), -1);
                            }
                            holder.getView().setBackgroundColor(color);
                            holder.getView().setVisibility(0);
                            holder.getView().postInvalidate();
                        }
                    }
                } else if (holder.getComponent() != null && (holder.getComponent() instanceof WXCell)) {
                    if (holder.isRecycled()) {
                        holder.bindData(component);
                        component.onRenderFinish(1);
                    }
                    DragHelper dragHelper = this.mDragHelper;
                    if (dragHelper != null && dragHelper.isDraggable()) {
                        String str2 = this.mTriggerType;
                        if (str2 == null) {
                            str2 = "longpress";
                        }
                        this.mTriggerType = str2;
                        WXCell cell = (WXCell) holder.getComponent();
                        boolean isExcluded = WXUtils.getBoolean(cell.getAttrs().get(EXCLUDED), false).booleanValue();
                        this.mDragHelper.setDragExcluded(holder, isExcluded);
                        if ("pan".equals(this.mTriggerType)) {
                            this.mDragHelper.setLongPressDragEnabled(false);
                            WXComponent anchorComponent = findComponentByAnchorName(cell, DRAG_ANCHOR);
                            if (anchorComponent != null && anchorComponent.getHostView() != null && !isExcluded) {
                                anchorComponent.getHostView().setOnTouchListener(new View.OnTouchListener() {
                                    /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass6 */

                                    public boolean onTouch(View v, MotionEvent event) {
                                        if (MotionEventCompat.getActionMasked(event) != 0) {
                                            return true;
                                        }
                                        BasicListComponent.this.mDragHelper.startDrag(holder);
                                        return true;
                                    }
                                });
                            } else if (!WXEnvironment.isApkDebugable()) {
                            } else {
                                if (!isExcluded) {
                                    WXLogUtils.e(this.TAG, "[error] onBindViewHolder: the anchor component or view is not found");
                                    return;
                                }
                                String str3 = this.TAG;
                                WXLogUtils.d(str3, "onBindViewHolder: position " + position + " is drag excluded");
                            }
                        } else if ("longpress".equals(this.mTriggerType)) {
                            this.mDragHelper.setLongPressDragEnabled(true);
                        }
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    public void markComponentUsable() {
        Iterator it = this.mChildren.iterator();
        while (it.hasNext()) {
            ((WXComponent) it.next()).setUsing(false);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public ListBaseViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        if (((long) viewType) == -1) {
            return createVHForRefreshComponent(viewType);
        }
        if (this.mChildren != null) {
            SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
            if (sparseArray == null) {
                return createVHForFakeComponent(viewType);
            }
            ArrayList<WXComponent> mTypes = sparseArray.get(viewType);
            checkRecycledViewPool(viewType);
            if (mTypes == null) {
                return createVHForFakeComponent(viewType);
            }
            for (int i = 0; i < mTypes.size(); i++) {
                WXComponent component = mTypes.get(i);
                if (component != null && !component.isUsing()) {
                    if (component.isFixed()) {
                        return createVHForFakeComponent(viewType);
                    } else {
                        if (component instanceof WXCell) {
                            if (component.getRealView() != null) {
                                return new ListBaseViewHolder(component, viewType);
                            }
                            component.lazy(false);
                            component.createView();
                            component.applyLayoutAndEvent(component);
                            return new ListBaseViewHolder(component, viewType, true);
                        } else if (component instanceof WXBaseRefresh) {
                            return createVHForRefreshComponent(viewType);
                        } else {
                            WXLogUtils.e(this.TAG, "List cannot include element except cell、header、fixed、refresh and loading");
                            return createVHForFakeComponent(viewType);
                        }
                    }
                }
            }
        }
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.e(str, "Cannot find request viewType: " + viewType);
        }
        return createVHForFakeComponent(viewType);
    }

    private void checkRecycledViewPool(int viewType) {
        try {
            if (this.mViewTypes.size() > 9) {
                mAllowCacheViewHolder = false;
            }
            if (!(!mDownForBidCacheViewHolder || getHostView() == null || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null)) {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getRecycledViewPool().setMaxRecycledViews(viewType, 0);
            }
            if (!(mDownForBidCacheViewHolder || mAllowCacheViewHolder || getHostView() == null || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null)) {
                for (int i = 0; i < this.mViewTypes.size(); i++) {
                    ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getRecycledViewPool().setMaxRecycledViews(this.mViewTypes.keyAt(i), 0);
                }
                mDownForBidCacheViewHolder = true;
            }
        } catch (Exception e) {
            WXLogUtils.e(this.TAG, "Clear recycledViewPool error!");
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemViewType(int position) {
        return generateViewType(getListChild(position));
    }

    private WXComponent findComponentByAnchorName(WXComponent root, String anchorName) {
        String isAnchorSet;
        long start = 0;
        if (WXEnvironment.isApkDebugable()) {
            start = System.currentTimeMillis();
        }
        Deque<WXComponent> deque = new ArrayDeque<>();
        deque.add(root);
        while (!deque.isEmpty()) {
            WXComponent curComponent = deque.removeFirst();
            if (curComponent != null && (isAnchorSet = WXUtils.getString(curComponent.getAttrs().get(anchorName), null)) != null && isAnchorSet.equals(AbsoluteConst.TRUE)) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("dragPerf", "findComponentByAnchorName time: " + (System.currentTimeMillis() - start) + "ms");
                }
                return curComponent;
            } else if (curComponent instanceof WXVContainer) {
                WXVContainer container = (WXVContainer) curComponent;
                int len = container.childCount();
                for (int i = 0; i < len; i++) {
                    deque.add(container.getChild(i));
                }
            }
        }
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("dragPerf", "findComponentByAnchorName elapsed time: " + (System.currentTimeMillis() - start) + "ms");
        }
        return null;
    }

    private String getTriggerType(WXComponent component) {
        if (component == null) {
            return "longpress";
        }
        String triggerType = WXUtils.getString(component.getAttrs().get(DRAG_TRIGGER_TYPE), "longpress");
        if (!"longpress".equals(triggerType) && !"pan".equals(triggerType)) {
            triggerType = "longpress";
        }
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.d(str, "trigger type is " + triggerType);
        }
        return triggerType;
    }

    private void bindViewType(WXComponent component) {
        int id = generateViewType(component);
        if (this.mViewTypes == null) {
            this.mViewTypes = new SparseArray<>();
        }
        ArrayList<WXComponent> mTypes = this.mViewTypes.get(id);
        if (mTypes == null) {
            mTypes = new ArrayList<>();
            this.mViewTypes.put(id, mTypes);
        }
        mTypes.add(component);
    }

    private void unBindViewType(WXComponent component) {
        ArrayList<WXComponent> mTypes;
        int id = generateViewType(component);
        SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
        if (sparseArray != null && (mTypes = sparseArray.get(id)) != null) {
            mTypes.remove(component);
        }
    }

    private int generateViewType(IWXObject object) {
        long id = -1;
        try {
            if (!(object instanceof ListStanceCell)) {
                if (object instanceof WXComponent) {
                    WXComponent component = (WXComponent) object;
                    id = (long) Integer.parseInt(component.getRef());
                    String type = component.getAttrs().getScope();
                    if (!TextUtils.isEmpty(type)) {
                        if (this.mRefToViewType == null) {
                            this.mRefToViewType = new ArrayMap<>();
                        }
                        if (!this.mRefToViewType.containsKey(type)) {
                            this.mRefToViewType.put(type, Long.valueOf(id));
                        }
                        id = this.mRefToViewType.get(type).longValue();
                    }
                }
            }
        } catch (RuntimeException e) {
            WXLogUtils.eTag(this.TAG, e);
            id = -1;
            WXLogUtils.e(this.TAG, "getItemViewType: NO ID, this will crash the whole render system of WXListRecyclerView");
        }
        return (int) id;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemCount() {
        if (this.isThisGroupFinished) {
            return getChildCount();
        }
        return 0;
    }

    public boolean onFailedToRecycleView(ListBaseViewHolder holder) {
        if (!WXEnvironment.isApkDebugable()) {
            return false;
        }
        String str = this.TAG;
        WXLogUtils.d(str, "Failed to recycle " + holder);
        return false;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public long getItemId(int position) {
        try {
            IWXObject object = getListChild(position);
            if (object instanceof ListStanceCell) {
                return -1;
            }
            if (object instanceof WXComponent) {
                return Long.parseLong(((WXComponent) object).getRef());
            }
            return -1;
        } catch (RuntimeException e) {
            WXLogUtils.e(this.TAG, WXLogUtils.getStackTrace(e));
            return -1;
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onLoadMore(int offScreenY) {
        try {
            String offset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(offset)) {
                offset = "0";
            }
            if (((float) offScreenY) <= WXViewUtils.getRealPxByWidth((float) WXUtils.getInt(offset), getInstance().getInstanceViewPortWidthWithFloat()) && getEvents().contains(Constants.Event.LOADMORE)) {
                if (this.mListCellCount != this.mChildren.size() || this.mForceLoadmoreNextTime) {
                    fireEvent(Constants.Event.LOADMORE);
                    this.mListCellCount = this.mChildren.size();
                    this.mForceLoadmoreNextTime = false;
                }
            }
        } catch (Exception e) {
            WXLogUtils.d(this.TAG + "onLoadMore :", e);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void notifyAppearStateChange(int firstVisible, int lastVisible, int directionX, int directionY) {
        View view;
        String direction = null;
        if (this.mAppearChangeRunnable != null) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            this.mAppearChangeRunnable = null;
        }
        if (directionY > 0) {
            direction = "up";
        } else if (directionY < 0) {
            direction = "down";
        }
        if (getOrientation() == 0 && directionX != 0) {
            direction = directionX > 0 ? "left" : "right";
        }
        for (AppearanceHelper item : this.mAppearComponents.values()) {
            WXComponent component = item.getAwareChild();
            if (item.isWatch() && (view = component.getHostView()) != null) {
                int result = item.setAppearStatus(!(ViewCompat.isAttachedToWindow(view) ^ true) && item.isViewVisible(true));
                if (result != 0) {
                    boolean isApkDebugable = WXEnvironment.isApkDebugable();
                    String str = Constants.Event.APPEAR;
                    if (isApkDebugable) {
                        WXLogUtils.d(str, "item " + item.getCellPositionINScollable() + " result " + result);
                    }
                    if (result != 1) {
                        str = Constants.Event.DISAPPEAR;
                    }
                    component.notifyAppearStateChange(str, direction);
                }
            }
        }
    }

    private ListBaseViewHolder createVHForFakeComponent(int viewType) {
        FrameLayout view = new FrameLayout(getContext());
        view.setBackgroundColor(-1);
        view.setLayoutParams(new FrameLayout.LayoutParams(0, 0));
        return new ListBaseViewHolder(view, viewType);
    }

    private ListBaseViewHolder createVHForRefreshComponent(int viewType) {
        FrameLayout view = new FrameLayout(getContext());
        view.setLayoutParams(new FrameLayout.LayoutParams(-1, 1));
        return new ListBaseViewHolder(view, viewType);
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
        this.mListCellCount = 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (ScrollStartEndHelper.isScrollEvent(type) && getHostView() != null && ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() != null && !this.mHasAddScrollEvent) {
            this.mHasAddScrollEvent = true;
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().addOnScrollListener(new RecyclerView.OnScrollListener() {
                /* class com.taobao.weex.ui.component.list.BasicListComponent.AnonymousClass7 */
                private boolean mFirstEvent = true;
                private int offsetXCorrection;
                private int offsetYCorrection;

                @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                    int offsetY;
                    int offsetX;
                    super.onScrolled(recyclerView, dx, dy);
                    int offsetX2 = recyclerView.computeHorizontalScrollOffset();
                    int offsetY2 = recyclerView.computeVerticalScrollOffset();
                    if (dx == 0 && dy == 0) {
                        this.offsetXCorrection = offsetX2;
                        this.offsetYCorrection = offsetY2;
                        offsetX = 0;
                        offsetY = 0;
                    } else {
                        offsetX = offsetX2 - this.offsetXCorrection;
                        offsetY = offsetY2 - this.offsetYCorrection;
                    }
                    BasicListComponent.this.getScrollStartEndHelper().onScrolled(offsetX, offsetY);
                    if (BasicListComponent.this.getEvents().contains("scroll")) {
                        if (this.mFirstEvent) {
                            this.mFirstEvent = false;
                            return;
                        }
                        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
                        if (BasicListComponent.this.getOrientation() == 1) {
                            if (!layoutManager.canScrollVertically()) {
                                return;
                            }
                        } else if (BasicListComponent.this.getOrientation() == 0 && !layoutManager.canScrollHorizontally()) {
                            return;
                        }
                        if (BasicListComponent.this.shouldReport(offsetX, offsetY)) {
                            BasicListComponent.this.fireScrollEvent(recyclerView, offsetX, offsetY);
                        }
                    }
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        if (getInstance() != null) {
            fireEvent("scroll", getScrollEvent(recyclerView, offsetX, offsetY));
        }
    }

    public Map<String, Object> getScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        boolean z = true;
        if (getOrientation() == 1) {
            offsetY = -calcContentOffset(recyclerView);
        }
        int contentWidth = recyclerView.getMeasuredWidth() + recyclerView.computeHorizontalScrollRange();
        int contentHeight = 0;
        for (int i = 0; i < getChildCount(); i++) {
            contentHeight = (int) (((float) contentHeight) + getListChildLayoutHeight(i));
        }
        Map<String, Object> event = new HashMap<>(3);
        Map<String, Object> contentSize = new HashMap<>(3);
        Map<String, Object> contentOffset = new HashMap<>(3);
        contentSize.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentWidth, getInstance().getInstanceViewPortWidthWithFloat())));
        contentSize.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentHeight, getInstance().getInstanceViewPortWidthWithFloat())));
        contentOffset.put(Constants.Name.X, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) offsetX, getInstance().getInstanceViewPortWidthWithFloat())));
        contentOffset.put(Constants.Name.Y, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) offsetY, getInstance().getInstanceViewPortWidthWithFloat())));
        event.put(Constants.Name.CONTENT_SIZE, contentSize);
        event.put(Constants.Name.CONTENT_OFFSET, contentOffset);
        if (recyclerView.getScrollState() != 1) {
            z = false;
        }
        event.put(Constants.Name.ISDRAGGING, Boolean.valueOf(z));
        return event;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean shouldReport(int offsetX, int offsetY) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        int gapX = Math.abs(this.mLastReport.x - offsetX);
        int gapY = Math.abs(this.mLastReport.y - offsetY);
        int i = this.mOffsetAccuracy;
        if (gapX < i && gapY < i) {
            return false;
        }
        this.mLastReport.x = offsetX;
        this.mLastReport.y = offsetY;
        return true;
    }

    public int calcContentOffset(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        if (layoutManager instanceof LinearLayoutManager) {
            int firstVisibleItemPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
            if (firstVisibleItemPosition == -1) {
                return 0;
            }
            View firstVisibleView = layoutManager.findViewByPosition(firstVisibleItemPosition);
            int firstVisibleViewOffset = 0;
            if (firstVisibleView != null) {
                firstVisibleViewOffset = firstVisibleView.getTop();
            }
            int offset = 0;
            for (int i = 0; i < firstVisibleItemPosition; i++) {
                offset = (int) (((float) offset) - getListChildLayoutHeight(i));
            }
            if (layoutManager instanceof GridLayoutManager) {
                offset /= ((GridLayoutManager) layoutManager).getSpanCount();
            }
            return offset + firstVisibleViewOffset;
        } else if (!(layoutManager instanceof StaggeredGridLayoutManager)) {
            return -1;
        } else {
            int spanCount = ((StaggeredGridLayoutManager) layoutManager).getSpanCount();
            int firstVisibleItemPosition2 = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(null)[0];
            if (firstVisibleItemPosition2 == -1) {
                return 0;
            }
            View firstVisibleView2 = layoutManager.findViewByPosition(firstVisibleItemPosition2);
            int firstVisibleViewOffset2 = 0;
            if (firstVisibleView2 != null) {
                firstVisibleViewOffset2 = firstVisibleView2.getTop();
            }
            int offset2 = 0;
            for (int i2 = 0; i2 < firstVisibleItemPosition2; i2++) {
                offset2 = (int) (((float) offset2) - getListChildLayoutHeight(i2));
            }
            return (offset2 / spanCount) + firstVisibleViewOffset2;
        }
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    @JSMethod
    public void setSpecialEffects(JSONObject info) {
        if (getHostView() != null && (getHostView() instanceof BounceRecyclerView)) {
            if (info == null || !info.containsKey("id")) {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setNestInfo(null);
                return;
            }
            String parentId = info.getString("id");
            JSONObject nestInfo = new JSONObject();
            nestInfo.put("isNestParent", (Object) false);
            nestInfo.put("instanceId", (Object) getInstance().getInstanceId());
            nestInfo.put("listParentId", (Object) parentId);
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setNestInfo(nestInfo);
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().callBackNestParent(getRef(), getInstance().getInstanceId(), WXViewUtils.getRealPxByWidth(WXUtils.getFloat(info.getString("headerHeight")), getInstance().getInstanceViewPortWidthWithFloat()));
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildCount() {
        WXComponent component = super.getChild(0);
        if (component == null || !(component instanceof WXRefresh) || this.mColumnCount <= 1) {
            return super.getChildCount();
        }
        return super.getChildCount() + (this.mColumnCount - 1);
    }

    public IWXObject getListChild(int index) {
        int i;
        WXComponent component = super.getChild(0);
        if (index == 0) {
            return component;
        }
        if (component == null || !(component instanceof WXRefresh) || (i = this.mColumnCount) <= 1) {
            return super.getChild(index);
        }
        if (index - i < 0) {
            return getListStanceCell(component.getStyles().getBackgroundColor());
        }
        return super.getChild(index - (i - 1));
    }

    private IWXObject getListStanceCell(String backgroundColor) {
        if (this.listStanceObject == null) {
            this.listStanceObject = new ListStanceCell(backgroundColor);
        }
        return this.listStanceObject;
    }

    private float getListChildLayoutHeight(int index) {
        WXComponent child;
        IWXObject object = getListChild(index);
        if (object == null) {
            return 0.0f;
        }
        if (object instanceof ListStanceCell) {
            return 1.0f;
        }
        if (!(object instanceof WXComponent) || (child = (WXComponent) object) == null) {
            return 0.0f;
        }
        return child.getLayoutHeight();
    }

    @WXComponentProp(name = "bounce")
    public void setBounce(String isBounce) {
        WXRecyclerView inner = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        if (Boolean.valueOf(isBounce).booleanValue()) {
            inner.setOverScrollMode(0);
        } else {
            inner.setOverScrollMode(2);
        }
    }

    @JSMethod
    public void scrollTo(String op, JSCallback callback) {
        float realPx = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(JSON.parseObject(op).getString(Constants.Name.SCROLL_TOP)), getInstance().getInstanceViewPortWidthWithFloat());
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            WXRecyclerView view = ((ListComponentView) viewGroup).getInnerView();
            if (getOrientation() == 1) {
                view.scrollTo(0, (int) realPx, getOrientation());
            } else {
                view.scrollTo((int) realPx, 0, getOrientation());
            }
            if (callback != null) {
                Map<String, Object> params = new HashMap<>();
                params.put("type", WXImage.SUCCEED);
                callback.invoke(params);
            }
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            ((ListComponentView) viewGroup).getInnerView().scrollTo(0, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidthWithFloat()), getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            ((ListComponentView) viewGroup).getInnerView().scrollTo((int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidthWithFloat()), 0, getOrientation());
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void setIsLayoutRTL(boolean isRTL) {
        super.setIsLayoutRTL(isRTL);
        this.mViewOnScrollListener.setLayoutRTL(isRTL);
    }

    /* access modifiers changed from: protected */
    public boolean isRenderFromBottom() {
        return false;
    }
}
