package com.taobao.weex.ui.component.list;

import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.ItemTouchHelper;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.taobao.weex.ui.view.listview.adapter.ListBaseViewHolder;
import com.taobao.weex.utils.WXLogUtils;

class DragSupportCallback extends ItemTouchHelper.Callback {
    private static final String TAG = "WXListExComponent";
    private int dragFrom = -1;
    private int dragTo = -1;
    private final DragHelper mDragHelper;
    private boolean mEnableDifferentViewTypeDrag = false;

    DragSupportCallback(DragHelper DragHelper) {
        this.mDragHelper = DragHelper;
        this.mEnableDifferentViewTypeDrag = false;
    }

    DragSupportCallback(DragHelper DragHelper, boolean enableDifferentViewTypeDrag) {
        this.mDragHelper = DragHelper;
        this.mEnableDifferentViewTypeDrag = enableDifferentViewTypeDrag;
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public int getMovementFlags(RecyclerView recyclerView, RecyclerView.ViewHolder viewHolder) {
        if ((recyclerView.getLayoutManager() instanceof GridLayoutManager) || (recyclerView.getLayoutManager() instanceof StaggeredGridLayoutManager)) {
            return makeMovementFlags(15, 0);
        }
        return makeMovementFlags(3, 48);
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public boolean onMove(RecyclerView recyclerView, RecyclerView.ViewHolder viewHolder, RecyclerView.ViewHolder target) {
        if (viewHolder == null || target == null) {
            return false;
        }
        if ((!this.mEnableDifferentViewTypeDrag && viewHolder.getItemViewType() != target.getItemViewType()) || this.mDragHelper.isDragExcluded(viewHolder)) {
            return false;
        }
        try {
            int fromPos = viewHolder.getAdapterPosition();
            int toPos = target.getAdapterPosition();
            if (this.dragFrom == -1) {
                this.dragFrom = fromPos;
            }
            this.dragTo = toPos;
            this.mDragHelper.onDragging(fromPos, toPos);
            return true;
        } catch (Exception e) {
            WXLogUtils.e(TAG, e.getMessage());
            return false;
        }
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public boolean isLongPressDragEnabled() {
        return this.mDragHelper.isDraggable() && this.mDragHelper.isLongPressDragEnabled();
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public void onSwiped(RecyclerView.ViewHolder viewHolder, int direction) {
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public boolean isItemViewSwipeEnabled() {
        return false;
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public void onSelectedChanged(RecyclerView.ViewHolder viewHolder, int actionState) {
        if (actionState != 0 && (viewHolder instanceof ListBaseViewHolder)) {
            ListBaseViewHolder vh = (ListBaseViewHolder) viewHolder;
            if (vh.getComponent() != null) {
                this.mDragHelper.onDragStart(vh.getComponent(), vh.getAdapterPosition());
            }
        }
        super.onSelectedChanged(viewHolder, actionState);
    }

    @Override // androidx.recyclerview.widget.ItemTouchHelper.Callback
    public void clearView(RecyclerView recyclerView, RecyclerView.ViewHolder viewHolder) {
        super.clearView(recyclerView, viewHolder);
        if (viewHolder instanceof ListBaseViewHolder) {
            ListBaseViewHolder vh = (ListBaseViewHolder) viewHolder;
            if (!(vh.getComponent() == null || this.dragFrom == -1 || this.dragTo == -1)) {
                this.mDragHelper.onDragEnd(vh.getComponent(), this.dragFrom, this.dragTo);
            }
        }
        this.dragTo = -1;
        this.dragFrom = -1;
    }
}
