package com.taobao.weex.ui.component.list;

import android.view.View;
import android.view.ViewGroup;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

public class StickyHeaderHelper {
    private String mCurrentStickyRef = null;
    private Map<String, WXCell> mHeaderComps = new HashMap();
    private Map<String, View> mHeaderViews = new HashMap();
    private final ViewGroup mParent;

    public StickyHeaderHelper(ViewGroup parent) {
        this.mParent = parent;
    }

    public void notifyStickyShow(WXCell component) {
        if (component != null) {
            this.mHeaderComps.put(component.getRef(), component);
            String str = this.mCurrentStickyRef;
            if (str != null) {
                WXCell cell = this.mHeaderComps.get(str);
                if (cell == null || component.getScrollPositon() > cell.getScrollPositon()) {
                    this.mCurrentStickyRef = component.getRef();
                }
            } else {
                this.mCurrentStickyRef = component.getRef();
            }
            String str2 = this.mCurrentStickyRef;
            if (str2 == null) {
                WXLogUtils.e("Current Sticky ref is null.");
                return;
            }
            WXCell headComponent = this.mHeaderComps.get(str2);
            View headerView = headComponent.getRealView();
            if (headerView == null) {
                WXLogUtils.e("Sticky header's real view is null.");
                return;
            }
            View header = this.mHeaderViews.get(headComponent.getRef());
            if (header != null) {
                header.bringToFront();
            } else {
                this.mHeaderViews.put(headComponent.getRef(), headerView);
                float translationX = headerView.getTranslationX();
                float translationY = headerView.getTranslationY();
                headComponent.removeSticky();
                ViewGroup existedParent = (ViewGroup) headerView.getParent();
                if (existedParent != null) {
                    existedParent.removeView(headerView);
                }
                headerView.setTag(headComponent.getRef());
                this.mParent.addView(headerView, new ViewGroup.MarginLayoutParams(-2, -2));
                headerView.setTag(this);
                if (headComponent.getStickyOffset() > 0) {
                    ViewGroup.MarginLayoutParams params = (ViewGroup.MarginLayoutParams) headerView.getLayoutParams();
                    if (headComponent.getStickyOffset() != params.topMargin) {
                        params.topMargin = headComponent.getStickyOffset();
                    }
                }
                headerView.setTranslationX(translationX);
                headerView.setTranslationY(translationY);
            }
            changeFrontStickyVisible();
            if (headComponent.getEvents().contains("sticky")) {
                headComponent.fireEvent("sticky");
            }
        }
    }

    public void notifyStickyRemove(WXCell compToRemove) {
        if (compToRemove != null) {
            final WXCell component = this.mHeaderComps.containsValue(compToRemove) ? this.mHeaderComps.remove(compToRemove.getRef()) : compToRemove;
            final View headerView = this.mHeaderViews.remove(compToRemove.getRef());
            if (component == null || headerView == null) {
                WXEnvironment.isApkDebugable();
                return;
            }
            String str = this.mCurrentStickyRef;
            if (str != null && str.equals(compToRemove.getRef())) {
                this.mCurrentStickyRef = null;
            }
            this.mParent.post(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.list.StickyHeaderHelper.AnonymousClass1 */

                public void run() {
                    StickyHeaderHelper.this.mParent.removeView(headerView);
                    if (headerView.getVisibility() != 0) {
                        headerView.setVisibility(0);
                    }
                    component.recoverySticky();
                    StickyHeaderHelper.this.changeFrontStickyVisible();
                }
            }));
            if (component.getEvents().contains(Constants.Event.UNSTICKY)) {
                component.fireEvent(Constants.Event.UNSTICKY);
            }
        }
    }

    public void updateStickyView(int currentStickyPos) {
        List<WXCell> toRemove = new ArrayList<>();
        for (Map.Entry<String, WXCell> next : this.mHeaderComps.entrySet()) {
            WXCell cell = next.getValue();
            int pos = cell.getScrollPositon();
            if (pos > currentStickyPos) {
                toRemove.add(cell);
            } else if (pos == currentStickyPos) {
                this.mCurrentStickyRef = cell.getRef();
                View view = this.mHeaderViews.get(cell.getRef());
                if (view != null) {
                    view.bringToFront();
                    changeFrontStickyVisible();
                }
            }
        }
        for (WXCell cell2 : toRemove) {
            notifyStickyRemove(cell2);
        }
    }

    public void clearStickyHeaders() {
        if (this.mHeaderViews.size() > 0) {
            Iterator<Map.Entry<String, WXCell>> iterator = this.mHeaderComps.entrySet().iterator();
            while (iterator.hasNext()) {
                iterator.remove();
                notifyStickyRemove(iterator.next().getValue());
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void changeFrontStickyVisible() {
        if (this.mHeaderViews.size() > 0) {
            boolean fontVisible = false;
            for (int i = this.mParent.getChildCount() - 1; i >= 0; i--) {
                View view = this.mParent.getChildAt(i);
                if (!fontVisible || !(view.getTag() instanceof StickyHeaderHelper)) {
                    if (view.getTag() instanceof StickyHeaderHelper) {
                        fontVisible = true;
                        if (!(view == null || view.getVisibility() == 0)) {
                            view.setVisibility(0);
                        }
                    }
                } else if (view.getVisibility() != 8) {
                    view.setVisibility(8);
                }
            }
        }
    }
}
