package com.taobao.weex.ui.component.list.template;

import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONArray;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.utils.WXUtils;
import java.util.HashMap;
import java.util.Map;

public class CellDataManager {
    public static final String SUB_COMPONENT_TEMPLATE_ID = "@templateId";
    public static final String VIRTUAL_COMPONENT_ID = "@virtualComponentId";
    private static final String VIRTUAL_COMPONENT_SEPRATOR = "@";
    JSONArray listData;
    private Map<Integer, CellRenderState> renderStates = new ArrayMap();
    public final WXRecyclerTemplateList templateList;
    private Map<String, CellRenderState> virtualComponentRenderStates;

    public CellDataManager(WXRecyclerTemplateList templateList2) {
        this.templateList = templateList2;
    }

    public CellRenderState getRenderState(int position) {
        CellRenderState renderState = this.renderStates.get(Integer.valueOf(position));
        if (renderState == null) {
            renderState = new CellRenderState();
            renderState.position = position;
            this.renderStates.put(Integer.valueOf(position), renderState);
        }
        if (position != renderState.position) {
            renderState.position = position;
            renderState.hasPositionChange = true;
        }
        return renderState;
    }

    public void updateVirtualComponentData(String virutalComponentId, Object data) {
        Map<String, CellRenderState> map = this.virtualComponentRenderStates;
        if (map != null) {
            CellRenderState cellRenderState = map.get(virutalComponentId);
            if (cellRenderState != null) {
                cellRenderState.getVirtualComponentDatas().put(virutalComponentId, data);
                cellRenderState.hasVirtualCompoentUpdate = true;
            } else if (WXEnvironment.isApkDebugable()) {
                throw new IllegalArgumentException("virtualComponentDatas illegal state empty render state" + virutalComponentId);
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new IllegalArgumentException("virtualComponentDatas illegal state " + virutalComponentId);
        }
    }

    public void createVirtualComponentData(int position, String virutalComponentId, Object data) {
        if (this.virtualComponentRenderStates == null) {
            this.virtualComponentRenderStates = new HashMap(8);
        }
        CellRenderState renderState = this.renderStates.get(Integer.valueOf(position));
        renderState.getVirtualComponentDatas().put(virutalComponentId, data);
        this.virtualComponentRenderStates.put(virutalComponentId, renderState);
    }

    public void setListData(JSONArray listData2) {
        JSONArray jSONArray = this.listData;
        if (jSONArray != listData2) {
            if (jSONArray != null && WXUtils.getBoolean(this.templateList.getAttrs().get("exitDetach"), true).booleanValue()) {
                for (int i = 0; i < this.listData.size(); i++) {
                    cleanRenderState(this.renderStates.remove(Integer.valueOf(i)));
                }
            }
            this.listData = listData2;
            this.renderStates.clear();
            Map<String, CellRenderState> map = this.virtualComponentRenderStates;
            if (map != null) {
                map.clear();
            }
        }
    }

    public boolean insertData(int index, Object data) {
        this.listData.add(index, data);
        boolean renderStateChange = false;
        for (int i = this.listData.size(); i >= index; i--) {
            CellRenderState state = this.renderStates.remove(Integer.valueOf(i));
            if (state != null) {
                this.renderStates.put(Integer.valueOf(i + 1), state);
                renderStateChange = true;
            }
        }
        return renderStateChange;
    }

    public boolean insertRange(int index, JSONArray data) {
        this.listData.addAll(index, data);
        boolean renderStateChange = false;
        for (int i = this.listData.size() - 1; i >= index; i--) {
            CellRenderState state = this.renderStates.remove(Integer.valueOf(i));
            if (state != null) {
                this.renderStates.put(Integer.valueOf(i + 1), state);
                renderStateChange = true;
            }
        }
        return renderStateChange;
    }

    public boolean updateData(Object data, int index) {
        boolean onlyDataChange = TextUtils.equals(this.templateList.getTemplateKey(index), this.templateList.getTemplateKey(data));
        this.listData.set(index, data);
        if (!onlyDataChange) {
            cleanRenderState(this.renderStates.remove(Integer.valueOf(index)));
        } else {
            CellRenderState renderState = this.renderStates.get(Integer.valueOf(index));
            if (renderState != null) {
                renderState.hasDataUpdate = true;
            }
        }
        return onlyDataChange;
    }

    public void removeData(Integer index) {
        this.listData.remove(index.intValue());
        cleanRenderState(this.renderStates.remove(index));
        int count = this.listData.size() + 1;
        for (int i = index.intValue() + 1; i < count; i++) {
            CellRenderState state = this.renderStates.remove(Integer.valueOf(i));
            if (state != null) {
                this.renderStates.put(Integer.valueOf(i - 1), state);
            }
        }
    }

    private void cleanRenderState(CellRenderState renderState) {
        if (renderState != null && renderState.hasVirtualComponents()) {
            for (String virtualComponentId : renderState.getVirtualComponentIds().values()) {
                Map<String, CellRenderState> map = this.virtualComponentRenderStates;
                if (map != null) {
                    map.remove(virtualComponentId);
                }
                WXBridgeManager.getInstance().asyncCallJSEventVoidResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, this.templateList.getInstanceId(), null, virtualComponentId, VirtualComponentLifecycle.LIFECYCLE, "detach", null);
            }
        }
    }

    public static String createVirtualComponentId(String listRef, String viewTreeKey, long itemId) {
        return listRef + VIRTUAL_COMPONENT_SEPRATOR + viewTreeKey + VIRTUAL_COMPONENT_SEPRATOR + itemId;
    }

    public static String getListRef(String virtualComponentId) {
        if (virtualComponentId == null) {
            return null;
        }
        return virtualComponentId.split(VIRTUAL_COMPONENT_SEPRATOR)[0];
    }
}
