package com.taobao.weex.ui.component.list.template;

import android.view.View;
import androidx.core.view.ViewCompat;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class TemplateDom {
    public static final String ATTACH_CELL_SLOT = "_attach_slot";
    public static final String ATTRS_KEY_REF = "ref";
    public static final String DETACH_CELL_SLOT = "_detach_slot";
    public static final String KEY_ATTRS = "attrs";
    public static final String KEY_RESET_ANIMATION = "resetAnimation";
    public static final String KEY_TYPE = "type";
    public static final String KEY_VIRTUAL_DOM_REF = "ref";
    public static final char SEPARATOR = '@';
    public static final String VIRTUAL_DOM_IDENTIFY = "[[VirtualElement]]";

    public static String genKeyVirtualDomRef(String listRef, int position, String key) {
        return listRef + SEPARATOR + position + SEPARATOR + key;
    }

    public static WXComponent findVirtualComponentByVRef(String pageId, String virtualRef) {
        try {
            String[] segments = virtualRef.split("@");
            WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(pageId, segments[0]);
            if (!(component instanceof WXRecyclerTemplateList)) {
                return null;
            }
            WXRecyclerTemplateList templateList = (WXRecyclerTemplateList) component;
            if (templateList.getHostView() != null) {
                if (((BounceRecyclerView) templateList.getHostView()).getInnerView() != null) {
                    TemplateViewHolder itemHolder = (TemplateViewHolder) ((WXRecyclerView) ((BounceRecyclerView) templateList.getHostView()).getInnerView()).findViewHolderForAdapterPosition(Integer.parseInt(segments[1]));
                    if (itemHolder == null) {
                        return null;
                    }
                    return findComponentByViewTreeKey(itemHolder.getTemplate(), segments[2]);
                }
            }
            return null;
        } catch (Exception e) {
            return null;
        }
    }

    public static Map<String, Object> findAllComponentRefs(String listRef, int position, WXComponent component) {
        HashMap hashMap = new HashMap();
        findAllComponentRefs(listRef, position, component, hashMap);
        Map<String, Object> refsMap = new HashMap<>();
        refsMap.put("refs", hashMap);
        refsMap.put("position", Integer.valueOf(position));
        refsMap.put("listRef", listRef);
        return refsMap;
    }

    private static void findAllComponentRefs(String listRef, int position, WXComponent component, Map<String, Object> refs) {
        if (!component.isWaste()) {
            if (component instanceof WXVContainer) {
                WXVContainer container = (WXVContainer) component;
                for (int i = 0; i < container.getChildCount(); i++) {
                    findAllComponentRefs(listRef, position, container.getChild(i), refs);
                }
            }
            WXAttr attrs = component.getAttrs();
            if (attrs == null || attrs.get("ref") != null) {
                String ref = attrs.get("ref").toString();
                List<Object> refList = (List) refs.get(ref);
                if (refList == null) {
                    refList = new ArrayList<>();
                    refs.put(ref, refList);
                }
                refList.add(toMap(listRef, position, component));
            }
        }
    }

    public static Map toMap(String listRef, int position, WXComponent component) {
        Map map = new HashMap();
        map.put(KEY_ATTRS, component.getAttrs());
        map.put("type", component.getComponentType());
        map.put("ref", genKeyVirtualDomRef(listRef, position, component.getViewTreeKey()));
        map.put(VIRTUAL_DOM_IDENTIFY, true);
        return map;
    }

    public static boolean isVirtualDomRef(String ref) {
        if (ref == null || ref.indexOf(64) <= 0) {
            return false;
        }
        return true;
    }

    public static void resetAnimaiton(View view) {
        if (view != null) {
            if (ViewCompat.getTranslationX(view) != 0.0f) {
                ViewCompat.setTranslationX(view, 0.0f);
            }
            if (ViewCompat.getTranslationY(view) != 0.0f) {
                ViewCompat.setTranslationY(view, 0.0f);
            }
            if (ViewCompat.getTranslationZ(view) != 0.0f) {
                ViewCompat.setTranslationZ(view, 0.0f);
            }
            if (ViewCompat.getScaleX(view) != 1.0f) {
                ViewCompat.setScaleX(view, 1.0f);
            }
            if (ViewCompat.getScaleY(view) != 1.0f) {
                ViewCompat.setScaleY(view, 1.0f);
            }
            if (ViewCompat.getRotationX(view) != 0.0f) {
                ViewCompat.setRotationX(view, 0.0f);
            }
            if (ViewCompat.getRotationY(view) != 0.0f) {
                ViewCompat.setRotationY(view, 0.0f);
            }
            if (ViewCompat.getElevation(view) != 0.0f) {
                ViewCompat.setElevation(view, 0.0f);
            }
        }
    }

    public static final WXComponent findComponentByViewTreeKey(WXComponent component, String viewKey) {
        if (component.getViewTreeKey().equals(viewKey)) {
            return component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        for (int i = 0; i < container.getChildCount(); i++) {
            WXComponent element = container.getChild(i);
            if (findComponentByViewTreeKey(element, viewKey) != null) {
                return element;
            }
        }
        return null;
    }

    private static WXComponent findChildByAttrsRef(WXComponent component, String ref) {
        if (component.getAttrs() != null && ref.equals(component.getAttrs().get("ref"))) {
            return component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        for (int i = 0; i < container.getChildCount(); i++) {
            WXComponent child = findChildByAttrsRef(container.getChild(i), ref);
            if (child != null) {
                return child;
            }
        }
        return null;
    }
}
