package com.taobao.weex.ui.component.list.template;

import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.collection.ArrayMap;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import java.util.ArrayList;
import java.util.List;

public class TemplateStickyHelper {
    private List<String> mStickyTypes = new ArrayList(8);
    private WXRecyclerTemplateList recyclerTemplateList;
    private ArrayMap<Integer, TemplateViewHolder> stickyHolderCache = new ArrayMap<>();
    private List<Integer> stickyPositions = new ArrayList();

    public TemplateStickyHelper(WXRecyclerTemplateList recyclerTemplateList2) {
        this.recyclerTemplateList = recyclerTemplateList2;
    }

    public void onBeforeScroll(int dx, int dy) {
        TemplateViewHolder firstVisibleItemHolder;
        List<Integer> list = this.stickyPositions;
        if (list != null && list.size() != 0) {
            BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) this.recyclerTemplateList.getHostView();
            RecyclerView recyclerView = (RecyclerView) ((BounceRecyclerView) this.recyclerTemplateList.getHostView()).getInnerView();
            RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
            int firstVisiblePosition = -1;
            int lastVisiblePosition = -1;
            if (layoutManager instanceof LinearLayoutManager) {
                firstVisiblePosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
                lastVisiblePosition = ((LinearLayoutManager) layoutManager).findLastVisibleItemPosition();
            } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                int[] firstVisibleItemPositions = new int[3];
                firstVisiblePosition = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(firstVisibleItemPositions)[0];
                lastVisiblePosition = ((StaggeredGridLayoutManager) layoutManager).findLastVisibleItemPositions(firstVisibleItemPositions)[0];
            }
            if (firstVisiblePosition >= 0 && (firstVisibleItemHolder = (TemplateViewHolder) recyclerView.findViewHolderForAdapterPosition(firstVisiblePosition)) != null) {
                int matchStickyPosition = -1;
                for (Integer headerPosition : this.stickyPositions) {
                    if (headerPosition != null) {
                        if (headerPosition.intValue() > firstVisiblePosition) {
                            break;
                        }
                        matchStickyPosition = Math.max(matchStickyPosition, headerPosition.intValue());
                    }
                }
                if (matchStickyPosition < 0) {
                    View stickyFakeView = bounceRecyclerView.getChildAt(bounceRecyclerView.getChildCount() - 1);
                    if (stickyFakeView.getTag() instanceof TemplateViewHolder) {
                        TemplateViewHolder stickyFakeViewHolder = (TemplateViewHolder) stickyFakeView.getTag();
                        bounceRecyclerView.removeView(stickyFakeViewHolder.itemView);
                        stickyFakeViewHolder.itemView.setTranslationY(0.0f);
                        if (stickyFakeViewHolder.getComponent() != null && stickyFakeViewHolder.getComponent().getEvents().contains(Constants.Event.UNSTICKY)) {
                            stickyFakeViewHolder.getComponent().fireEvent(Constants.Event.UNSTICKY);
                        }
                    }
                    for (int i = 0; i < recyclerView.getChildCount(); i++) {
                        View itemView = recyclerView.getChildAt(i);
                        TemplateViewHolder itemHolder = (TemplateViewHolder) recyclerView.getChildViewHolder(itemView);
                        if (itemHolder != null) {
                            if (this.stickyPositions.contains(Integer.valueOf(itemHolder.getAdapterPosition())) && itemView.getVisibility() != 0) {
                                itemView.setVisibility(0);
                            }
                        }
                    }
                    return;
                }
                View stickyFakeView2 = bounceRecyclerView.getChildAt(bounceRecyclerView.getChildCount() - 1);
                if (!(stickyFakeView2.getTag() instanceof TemplateViewHolder) || ((TemplateViewHolder) stickyFakeView2.getTag()).getHolderPosition() != matchStickyPosition) {
                    if ((stickyFakeView2.getTag() instanceof TemplateViewHolder) && ((TemplateViewHolder) stickyFakeView2.getTag()).getHolderPosition() != matchStickyPosition) {
                        TemplateViewHolder stickyFakeViewHolder2 = (TemplateViewHolder) stickyFakeView2.getTag();
                        bounceRecyclerView.removeView(stickyFakeViewHolder2.itemView);
                        stickyFakeViewHolder2.itemView.setTranslationY(0.0f);
                        if (stickyFakeViewHolder2.getComponent() != null && stickyFakeViewHolder2.getComponent().getEvents().contains(Constants.Event.UNSTICKY)) {
                            stickyFakeViewHolder2.getComponent().fireEvent(Constants.Event.UNSTICKY);
                        }
                    }
                    int stickyHolderType = this.recyclerTemplateList.getItemViewType(matchStickyPosition);
                    TemplateViewHolder fakeStickyHolder = this.stickyHolderCache.get(Integer.valueOf(stickyHolderType));
                    if (fakeStickyHolder == null) {
                        fakeStickyHolder = this.recyclerTemplateList.onCreateViewHolder((ViewGroup) recyclerView, stickyHolderType);
                        this.stickyHolderCache.put(Integer.valueOf(stickyHolderType), fakeStickyHolder);
                    }
                    this.recyclerTemplateList.onBindViewHolder(fakeStickyHolder, matchStickyPosition);
                    fakeStickyHolder.itemView.setTranslationY(0.0f);
                    fakeStickyHolder.itemView.setTag(fakeStickyHolder);
                    FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(-1, -2);
                    fakeStickyHolder.getComponent().clearPreLayout();
                    if (fakeStickyHolder.itemView.getParent() != null) {
                        ((ViewGroup) fakeStickyHolder.itemView.getParent()).removeView(fakeStickyHolder.itemView);
                    }
                    bounceRecyclerView.addView(fakeStickyHolder.itemView, params);
                    fakeStickyHolder.getComponent().setLayout(fakeStickyHolder.getComponent());
                    stickyFakeView2 = fakeStickyHolder.itemView;
                    if (fakeStickyHolder.getComponent() != null && fakeStickyHolder.getComponent().getEvents().contains("sticky")) {
                        fakeStickyHolder.getComponent().fireEvent("sticky");
                    }
                }
                TemplateViewHolder stickyFakeViewHolder3 = (TemplateViewHolder) stickyFakeView2.getTag();
                for (int i2 = 0; i2 < recyclerView.getChildCount(); i2++) {
                    View itemView2 = recyclerView.getChildAt(i2);
                    TemplateViewHolder itemHolder2 = (TemplateViewHolder) recyclerView.getChildViewHolder(itemView2);
                    if (itemHolder2 != null) {
                        int adapterPosition = itemHolder2.getAdapterPosition();
                        if (this.stickyPositions.contains(Integer.valueOf(adapterPosition))) {
                            if (adapterPosition == stickyFakeViewHolder3.getHolderPosition()) {
                                if (itemView2.getVisibility() != 4) {
                                    itemView2.setVisibility(4);
                                }
                            } else if (itemView2.getVisibility() != 0) {
                                itemView2.setVisibility(0);
                            }
                        }
                    }
                }
                if (firstVisibleItemHolder.getComponent().isSticky()) {
                    if (firstVisibleItemHolder.itemView.getY() < 0.0f) {
                        if (firstVisibleItemHolder.itemView.getVisibility() != 4) {
                            firstVisibleItemHolder.itemView.setVisibility(4);
                        }
                        if (stickyFakeView2.getVisibility() != 0) {
                            stickyFakeView2.setVisibility(0);
                        }
                        stickyFakeView2.bringToFront();
                    } else {
                        if (firstVisibleItemHolder.itemView.getVisibility() != 0) {
                            firstVisibleItemHolder.itemView.setVisibility(0);
                        }
                        if (stickyFakeView2.getVisibility() != 8) {
                            stickyFakeView2.setVisibility(8);
                        }
                    }
                } else if (stickyFakeView2.getVisibility() != 0) {
                    stickyFakeView2.setVisibility(0);
                }
                int nextVisiblePostion = firstVisiblePosition + 1;
                if (lastVisiblePosition > 0) {
                    int i3 = nextVisiblePostion;
                    while (true) {
                        if (i3 > lastVisiblePosition) {
                            break;
                        } else if (this.stickyPositions.contains(Integer.valueOf(i3))) {
                            nextVisiblePostion = i3;
                            break;
                        } else {
                            i3++;
                        }
                    }
                }
                if (this.stickyPositions.contains(Integer.valueOf(nextVisiblePostion))) {
                    TemplateViewHolder nextStickyHolder = (TemplateViewHolder) recyclerView.findViewHolderForAdapterPosition(nextVisiblePostion);
                    if (nextStickyHolder != null && nextStickyHolder.getComponent() != null) {
                        int translationY = (int) (nextStickyHolder.itemView.getY() - ((float) stickyFakeViewHolder3.itemView.getMeasuredHeight()));
                        if (translationY <= 0) {
                            stickyFakeViewHolder3.itemView.setTranslationY((float) translationY);
                        } else {
                            stickyFakeViewHolder3.itemView.setTranslationY(0.0f);
                        }
                    }
                } else if (stickyFakeViewHolder3.itemView.getTranslationY() < 0.0f) {
                    stickyFakeViewHolder3.itemView.setTranslationY(0.0f);
                }
            }
        }
    }

    public List<Integer> getStickyPositions() {
        if (this.stickyPositions == null) {
            this.stickyPositions = new ArrayList();
        }
        return this.stickyPositions;
    }

    public List<String> getStickyTypes() {
        return this.mStickyTypes;
    }
}
