package com.taobao.weex.ui.component.list.template;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.os.Build;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.collection.ArrayMap;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.el.parse.ArrayStack;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.AppearanceHelper;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseRefresh;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXLoading;
import com.taobao.weex.ui.component.WXRefresh;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.binding.Layouts;
import com.taobao.weex.ui.component.binding.Statements;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.component.list.RecyclerTransform;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener;
import com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener;
import com.taobao.weex.ui.view.listview.adapter.RecyclerViewBaseAdapter;
import com.taobao.weex.ui.view.listview.adapter.WXRecyclerViewOnScrollListener;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

@Component(lazyload = false)
public class WXRecyclerTemplateList extends WXVContainer<BounceRecyclerView> implements IRecyclerAdapterListener<TemplateViewHolder>, IOnLoadMoreListener, Scrollable {
    private static final long APPEAR_CHANGE_RUNNABLE_DELAY = 50;
    private static final String EMPTY_HOLDER_TEMPLATE_KEY = "";
    public static final boolean ENABLE_TRACE_LOG = false;
    private static final String NAME_HAS_FIXED_SIZE = "hasFixedSize";
    private static final String NAME_ITEM_VIEW_CACHE_SIZE = "itemViewCacheSize";
    private static final String NAME_TEMPLATE_CACHE_SIZE = "templateCacheSize";
    public static final String TAG = "WXRecyclerTemplateList";
    private CellDataManager cellDataManager;
    private CellRenderContext cellRenderContext = new CellRenderContext();
    private WXCell defaultTemplateCell;
    private String defaultTemplateKey = "@default_template_cell";
    private boolean hasAppendTreeDone = false;
    private boolean hasLayoutDone = false;
    private boolean isScrollable = true;
    private String listDataIndexKey = null;
    private String listDataItemKey = null;
    private String listDataKey = Constants.Name.Recycler.LIST_DATA;
    private String listDataTemplateKey = Constants.Name.Recycler.SLOT_TEMPLATE_CASE;
    private Runnable listUpdateRunnable;
    private Runnable mAppearChangeRunnable = null;
    private ArrayMap<Integer, List<AppearanceHelper>> mAppearHelpers = new ArrayMap<>();
    protected int mColumnCount = 1;
    protected float mColumnGap = 0.0f;
    protected float mColumnWidth = 0.0f;
    private ArrayMap<Integer, Map<String, Map<Integer, List<Object>>>> mDisAppearWatchList = new ArrayMap<>();
    private boolean mForceLoadmoreNextTime = false;
    private boolean mHasAddScrollEvent = false;
    private RecyclerView.ItemAnimator mItemAnimator;
    private Point mLastReport = new Point(-1, -1);
    protected int mLayoutType = 1;
    private int mListCellCount = 0;
    private int mOffsetAccuracy = 10;
    private float mPaddingLeft;
    private float mPaddingRight;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private TemplateStickyHelper mStickyHelper;
    private Map<String, WXCell> mTemplateSources;
    private ArrayMap<String, Integer> mTemplateViewTypes;
    private ConcurrentHashMap<String, TemplateCache> mTemplatesCache;
    private WXRecyclerViewOnScrollListener mViewOnScrollListener = new WXRecyclerViewOnScrollListener(this);
    private int orientation = 1;
    private int templateCacheSize = 2;

    public WXRecyclerTemplateList(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        initRecyclerTemplateList(instance, basicComponentData, parent);
    }

    private void initRecyclerTemplateList(WXSDKInstance instance, BasicComponentData basicComponentData, WXVContainer parent) {
        updateRecyclerAttr();
        ArrayMap<String, Integer> arrayMap = new ArrayMap<>();
        this.mTemplateViewTypes = arrayMap;
        arrayMap.put("", 0);
        this.mTemplateSources = new HashMap();
        this.mTemplatesCache = new ConcurrentHashMap<>();
        this.mStickyHelper = new TemplateStickyHelper(this);
        this.orientation = basicComponentData.getAttrs().getOrientation();
        this.listDataTemplateKey = WXUtils.getString(getAttrs().get(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY), Constants.Name.Recycler.SLOT_TEMPLATE_CASE);
        this.listDataItemKey = WXUtils.getString(getAttrs().get("alias"), this.listDataItemKey);
        this.listDataIndexKey = WXUtils.getString(getAttrs().get("index"), this.listDataIndexKey);
        CellDataManager cellDataManager2 = new CellDataManager(this);
        this.cellDataManager = cellDataManager2;
        cellDataManager2.listData = parseListDataToJSONArray(getAttrs().get(Constants.Name.Recycler.LIST_DATA));
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BounceRecyclerView initComponentHostView(Context context) {
        BounceRecyclerView bounceRecyclerView = new BounceRecyclerView(context, this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        WXAttr attrs = getAttrs();
        String transforms = (String) attrs.get("transform");
        if (transforms != null) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).addItemDecoration(RecyclerTransform.parseTransforms(getOrientation(), transforms));
        }
        this.mItemAnimator = ((WXRecyclerView) bounceRecyclerView.getInnerView()).getItemAnimator();
        if (attrs.get(NAME_TEMPLATE_CACHE_SIZE) != null) {
            this.templateCacheSize = WXUtils.getInteger(attrs.get(NAME_TEMPLATE_CACHE_SIZE), Integer.valueOf(this.templateCacheSize)).intValue();
        }
        boolean hasFixedSize = false;
        int itemViewCacheSize = 2;
        if (attrs.get(NAME_ITEM_VIEW_CACHE_SIZE) != null) {
            itemViewCacheSize = WXUtils.getNumberInt(getAttrs().get(NAME_ITEM_VIEW_CACHE_SIZE), 2);
        }
        if (attrs.get("hasFixedSize") != null) {
            hasFixedSize = WXUtils.getBoolean(attrs.get("hasFixedSize"), false).booleanValue();
        }
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = new RecyclerViewBaseAdapter(this);
        recyclerViewBaseAdapter.setHasStableIds(true);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).setItemAnimator(null);
        if (itemViewCacheSize != 2) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).setItemViewCacheSize(itemViewCacheSize);
        }
        if (bounceRecyclerView.getSwipeLayout() != null && WXUtils.getBoolean(getAttrs().get(Constants.Name.NEST_SCROLLING_ENABLED), false).booleanValue()) {
            bounceRecyclerView.getSwipeLayout().setNestedScrollingEnabled(true);
        }
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).setHasFixedSize(hasFixedSize);
        bounceRecyclerView.setRecyclerViewBaseAdapter(recyclerViewBaseAdapter);
        bounceRecyclerView.setOverScrollMode(2);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).clearOnScrollListeners();
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).addOnScrollListener(this.mViewOnScrollListener);
        ((WXRecyclerView) bounceRecyclerView.getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() {
            /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass1 */

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                View topView;
                super.onScrollStateChanged(recyclerView, newState);
                WXRecyclerTemplateList.this.getScrollStartEndHelper().onScrollStateChanged(newState);
                List<OnWXScrollListener> listeners = WXRecyclerTemplateList.this.getInstance().getWXScrollListeners();
                if (listeners != null && listeners.size() > 0) {
                    for (OnWXScrollListener listener : listeners) {
                        if (!(listener == null || (topView = recyclerView.getChildAt(0)) == null)) {
                            listener.onScrollStateChanged(recyclerView, 0, topView.getTop(), newState);
                        }
                    }
                }
            }

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);
                List<OnWXScrollListener> listeners = WXRecyclerTemplateList.this.getInstance().getWXScrollListeners();
                if (listeners != null && listeners.size() > 0) {
                    try {
                        for (OnWXScrollListener listener : listeners) {
                            if (listener != null) {
                                if (!(listener instanceof ICheckBindingScroller)) {
                                    listener.onScrolled(recyclerView, dx, dy);
                                } else if (((ICheckBindingScroller) listener).isNeedScroller(WXRecyclerTemplateList.this.getRef(), null)) {
                                    listener.onScrolled(recyclerView, dx, dy);
                                }
                            }
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        });
        bounceRecyclerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass2 */

            public void onGlobalLayout() {
                BounceRecyclerView view = (BounceRecyclerView) WXRecyclerTemplateList.this.getHostView();
                if (view != null) {
                    WXRecyclerTemplateList.this.mViewOnScrollListener.onScrolled((RecyclerView) view.getInnerView(), 0, 0);
                    if (Build.VERSION.SDK_INT >= 16) {
                        view.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                    } else {
                        view.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                    }
                }
            }
        });
        this.listUpdateRunnable = new Runnable() {
            /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass3 */

            public void run() {
                if (WXRecyclerTemplateList.this.mStickyHelper != null && WXRecyclerTemplateList.this.mStickyHelper.getStickyTypes().size() > 0) {
                    WXRecyclerTemplateList.this.mStickyHelper.getStickyPositions().clear();
                    if (WXRecyclerTemplateList.this.cellDataManager.listData != null) {
                        for (int i = 0; i < WXRecyclerTemplateList.this.cellDataManager.listData.size(); i++) {
                            WXCell cell = WXRecyclerTemplateList.this.getSourceTemplate(i);
                            if (cell != null && cell.isSticky()) {
                                WXRecyclerTemplateList.this.mStickyHelper.getStickyPositions().add(Integer.valueOf(i));
                            }
                        }
                    }
                }
                if (!(WXRecyclerTemplateList.this.getHostView() == null || ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).getRecyclerViewBaseAdapter() == null)) {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).getRecyclerViewBaseAdapter().notifyDataSetChanged();
                }
                WXEnvironment.isOpenDebugLog();
            }
        };
        return bounceRecyclerView;
    }

    /* access modifiers changed from: protected */
    public void onHostViewInitialized(BounceRecyclerView host) {
        super.onHostViewInitialized((View) host);
        WXRecyclerView recyclerView = (WXRecyclerView) host.getInnerView();
        if (recyclerView == null || recyclerView.getAdapter() == null) {
            WXLogUtils.e(TAG, "RecyclerView is not found or Adapter is not bound");
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        int screenH = WXViewUtils.getScreenHeight(WXEnvironment.sApplication);
        int weexH = WXViewUtils.getWeexHeight(getInstanceId());
        return super.measure(width, height > (weexH >= screenH ? screenH : weexH) ? weexH - getAbsoluteY() : height);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindStickStyle(WXComponent component) {
        TemplateStickyHelper templateStickyHelper;
        WXComponent template = findParentType(component, WXCell.class);
        if (template != null && (templateStickyHelper = this.mStickyHelper) != null && !templateStickyHelper.getStickyTypes().contains(template.getRef())) {
            this.mStickyHelper.getStickyTypes().add(template.getRef());
            notifyUpdateList();
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindStickStyle(WXComponent component) {
        TemplateStickyHelper templateStickyHelper;
        WXComponent template = findParentType(component, WXCell.class);
        if (template != null && (templateStickyHelper = this.mStickyHelper) != null && templateStickyHelper.getStickyTypes().contains(template.getRef())) {
            this.mStickyHelper.getStickyTypes().remove(template.getRef());
            notifyUpdateList();
        }
    }

    private WXCell findCell(WXComponent component) {
        WXComponent parent;
        if (component instanceof WXCell) {
            return (WXCell) component;
        }
        if (component == null || (parent = component.getParent()) == null) {
            return null;
        }
        return findCell(parent);
    }

    private void setAppearanceWatch(WXComponent component, int event, boolean enable) {
        int type;
        if (this.cellDataManager.listData != null && this.mAppearHelpers != null && !TextUtils.isEmpty(component.getRef()) && (type = getCellTemplateItemType(findCell(component))) >= 0) {
            List<AppearanceHelper> mAppearListeners = this.mAppearHelpers.get(Integer.valueOf(type));
            if (mAppearListeners == null) {
                mAppearListeners = new ArrayList();
                this.mAppearHelpers.put(Integer.valueOf(type), mAppearListeners);
            }
            AppearanceHelper item = null;
            Iterator<AppearanceHelper> it = mAppearListeners.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                AppearanceHelper mAppearListener = it.next();
                if (component.getRef().equals(mAppearListener.getAwareChild().getRef())) {
                    item = mAppearListener;
                    break;
                }
            }
            if (item != null) {
                item.setWatchEvent(event, enable);
                return;
            }
            AppearanceHelper item2 = new AppearanceHelper(component, type);
            item2.setWatchEvent(event, enable);
            mAppearListeners.add(item2);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass4 */

                public void run() {
                    if (WXRecyclerTemplateList.this.mAppearChangeRunnable != null) {
                        WXRecyclerTemplateList.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != null) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((BounceRecyclerView) getHostView()).postDelayed(this.mAppearChangeRunnable, APPEAR_CHANGE_RUNNABLE_DELAY);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass5 */

                public void run() {
                    if (WXRecyclerTemplateList.this.mAppearChangeRunnable != null) {
                        WXRecyclerTemplateList.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != null) {
            ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((BounceRecyclerView) getHostView()).postDelayed(this.mAppearChangeRunnable, APPEAR_CHANGE_RUNNABLE_DELAY);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, false);
    }

    @JSMethod(uiThread = true)
    public void queryElement(String virtualRef, String selector, JSCallback callback) {
        try {
            String[] segments = virtualRef.split("@");
            String listRef = segments[0];
            int position = Integer.parseInt(segments[1]);
            WXComponent component = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (component != null && getHostView() != null) {
                if (((BounceRecyclerView) getHostView()).getInnerView() != null) {
                    List<WXComponent> componentList = new ArrayList<>(4);
                    Selector.queryElementAll(component, selector, componentList);
                    if (componentList.size() > 0) {
                        callback.invoke(TemplateDom.toMap(listRef, position, componentList.get(0)));
                    } else {
                        callback.invoke(new HashMap(4));
                    }
                }
            }
        } catch (Exception e) {
            callback.invoke(new HashMap(4));
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void queryElementAll(String virtualRef, String selector, JSCallback callback) {
        List datas = new ArrayList();
        try {
            String[] segments = virtualRef.split("@");
            String listRef = segments[0];
            int position = Integer.parseInt(segments[1]);
            WXComponent component = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (!(component == null || getHostView() == null)) {
                if (((BounceRecyclerView) getHostView()).getInnerView() != null) {
                    List<WXComponent> componentList = new ArrayList<>(4);
                    Selector.queryElementAll(component, selector, componentList);
                    for (WXComponent child : componentList) {
                        datas.add(TemplateDom.toMap(listRef, position, child));
                    }
                    callback.invoke(datas);
                }
            }
        } catch (Exception e) {
            callback.invoke(datas);
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void closest(String virtualRef, String selector, JSCallback callback) {
        try {
            String[] segments = virtualRef.split("@");
            String listRef = segments[0];
            int position = Integer.parseInt(segments[1]);
            WXComponent component = TemplateDom.findVirtualComponentByVRef(getInstanceId(), virtualRef);
            if (component != null && getHostView() != null) {
                if (((BounceRecyclerView) getHostView()).getInnerView() != null) {
                    List<WXComponent> componentList = new ArrayList<>(4);
                    Selector.closest(component, selector, componentList);
                    if (componentList.size() > 0) {
                        callback.invoke(TemplateDom.toMap(listRef, position, componentList.get(0)));
                    } else {
                        callback.invoke(new HashMap(4));
                    }
                }
            }
        } catch (Exception e) {
            callback.invoke(new HashMap(4));
            WXLogUtils.e(TAG, e);
        }
    }

    @JSMethod(uiThread = true)
    public void scrollToElement(String virtualRef, Map<String, Object> options) {
        scrollTo(virtualRef, options);
    }

    /* JADX INFO: Multiple debug info for r0v2 int: [D('offsetStr' java.lang.String), D('offset' int)] */
    @JSMethod(uiThread = true)
    public void scrollTo(String virtualRef, Map<String, Object> options) {
        int position;
        try {
            if (virtualRef.indexOf(64) > 0) {
                position = Integer.parseInt(virtualRef.split("@")[0]);
            } else {
                position = (int) Float.parseFloat(virtualRef);
            }
            if (position >= 0) {
                boolean smooth = true;
                float offsetFloat = 0.0f;
                if (options != null) {
                    WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
                    String offsetStr = options.get("offset") == null ? "0" : options.get("offset").toString();
                    smooth = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
                    if (offsetStr != null) {
                        try {
                            offsetFloat = WXViewUtils.getRealPxByWidth(Float.parseFloat(offsetStr), getInstance().getInstanceViewPortWidthWithFloat());
                        } catch (Exception e) {
                            WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                        }
                    }
                }
                int offset = (int) offsetFloat;
                BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
                if (bounceRecyclerView != null) {
                    ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(smooth, position, offset, getOrientation());
                }
            }
        } catch (Exception e2) {
            WXLogUtils.e(TAG, e2);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        float offsetFloat = 0.0f;
        boolean smooth = true;
        int position = -1;
        int typeIndex = -1;
        if (options != null) {
            String offsetStr = options.get("offset") == null ? "0" : options.get("offset").toString();
            smooth = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (offsetStr != null) {
                try {
                    offsetFloat = WXViewUtils.getRealPxByWidth(Float.parseFloat(offsetStr), getInstance().getInstanceViewPortWidthWithFloat());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
            position = WXUtils.getNumberInt(options.get(Constants.Name.Recycler.CELL_INDEX), -1);
            typeIndex = WXUtils.getNumberInt(options.get(Constants.Name.Recycler.TYPE_INDEX), -1);
        }
        WXCell cell = findCell(component);
        if (!(typeIndex < 0 || this.cellDataManager.listData == null || component.getRef() == null)) {
            int typePosition = 0;
            int i = 0;
            while (true) {
                if (i >= this.cellDataManager.listData.size()) {
                    break;
                }
                WXCell template = getSourceTemplate(i);
                if (template != null) {
                    if (cell.getRef().equals(template.getRef())) {
                        typePosition++;
                    }
                    if (typePosition > typeIndex) {
                        position = i;
                        break;
                    }
                }
                i++;
            }
            if (position < 0) {
                position = this.cellDataManager.listData.size() - 1;
            }
        }
        int offset = (int) offsetFloat;
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView != null && position >= 0) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(smooth, position, offset, getOrientation());
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollY() {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return 0;
        }
        return ((WXRecyclerView) bounceRecyclerView.getInnerView()).getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollX() {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView == null) {
            return 0;
        }
        return ((WXRecyclerView) bounceRecyclerView.getInnerView()).getScrollX();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getOrientation() {
        return this.orientation;
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public boolean isScrollable() {
        return this.isScrollable;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        if (!(child instanceof WXCell)) {
            super.addChild(child, index);
        }
        if (!(child instanceof WXBaseRefresh) && (child instanceof WXCell)) {
            if (child.getAttrs() != null) {
                String key = WXUtils.getString(child.getAttrs().get(Constants.Name.Recycler.SLOT_TEMPLATE_CASE), null);
                if (getAttrs().containsKey(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY)) {
                    if (this.defaultTemplateCell == null) {
                        this.defaultTemplateCell = (WXCell) child;
                        if (!TextUtils.isEmpty(key)) {
                            this.defaultTemplateKey = key;
                        } else {
                            key = this.defaultTemplateKey;
                            child.getAttrs().put(Constants.Name.Recycler.SLOT_TEMPLATE_CASE, (Object) key);
                        }
                    }
                } else if (this.defaultTemplateCell == null || child.getAttrs().containsKey("default")) {
                    this.defaultTemplateCell = (WXCell) child;
                    if (!TextUtils.isEmpty(key)) {
                        this.defaultTemplateKey = key;
                    } else {
                        key = this.defaultTemplateKey;
                        child.getAttrs().put(Constants.Name.Recycler.SLOT_TEMPLATE_CASE, (Object) key);
                    }
                }
                if (key != null) {
                    this.mTemplateSources.put(key, (WXCell) child);
                    if (this.mTemplateViewTypes.get(key) == null) {
                        ArrayMap<String, Integer> arrayMap = this.mTemplateViewTypes;
                        arrayMap.put(key, Integer.valueOf(arrayMap.size()));
                    }
                }
            }
            ((WXCell) child).setCellAppendTreeListener(new WXCell.CellAppendTreeListener() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass6 */

                @Override // com.taobao.weex.ui.component.list.WXCell.CellAppendTreeListener
                public void onAppendTreeDone() {
                    WXRecyclerTemplateList.this.checkAppendDone(false);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void checkAppendDone(boolean listDone) {
        if (this.mTemplateSources.size() != 0) {
            for (Map.Entry<String, WXCell> entry : this.mTemplateSources.entrySet()) {
                if (!entry.getValue().isAppendTreeDone()) {
                    return;
                }
            }
            this.hasAppendTreeDone = true;
            if (this.hasLayoutDone) {
                notifyUpdateList();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void setHostLayoutParams(BounceRecyclerView host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((View) host, width, height, left, right, top, bottom);
        if (!this.hasLayoutDone) {
            this.hasLayoutDone = true;
            this.hasAppendTreeDone = true;
            notifyUpdateList();
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void createChildViewAt(int index) {
        int indexToCreate = index;
        if (indexToCreate >= 0 || childCount() - 1 >= 0) {
            WXComponent child = getChild(indexToCreate);
            if (child instanceof WXBaseRefresh) {
                child.createView();
                setRefreshOrLoading(child);
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        removeFooterOrHeader(child);
        super.remove(child, destroy);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        RecyclerView view = (RecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
        pointF.set((float) view.computeHorizontalScrollOffset(), (float) view.computeVerticalScrollOffset());
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -889473228:
                if (key.equals(Constants.Name.Recycler.LIST_DATA_TEMPLATE_SWITCH_KEY)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -713683669:
                if (key.equals(NAME_ITEM_VIEW_CACHE_SIZE)) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case -338674661:
                if (key.equals("hasFixedSize")) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case -112563826:
                if (key.equals("loadmoreoffset")) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 3046192:
                if (key.equals(Constants.Name.Recycler.SLOT_TEMPLATE_CASE)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 92902992:
                if (key.equals("alias")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 100346066:
                if (key.equals("index")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1345164648:
                if (key.equals(Constants.Name.Recycler.LIST_DATA)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 1614714674:
                if (key.equals(Constants.Name.SCROLL_DIRECTION)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                setListData(param);
                return true;
            case 1:
                this.listDataItemKey = WXUtils.getString(param, this.listDataItemKey);
                return true;
            case 2:
                this.listDataIndexKey = WXUtils.getString(param, this.listDataIndexKey);
                return true;
            case 3:
            case 4:
                this.listDataTemplateKey = WXUtils.getString(param, Constants.Name.Recycler.SLOT_TEMPLATE_CASE);
                return true;
            case 5:
                return true;
            case 6:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            case 7:
                if (param != null) {
                    setScrollDirection(param.toString());
                }
                return true;
            case '\b':
                Boolean result = WXUtils.getBoolean(param, null);
                if (result != null) {
                    setShowScrollbar(result.booleanValue());
                }
                return true;
            case '\t':
                return true;
            case '\n':
                return true;
            case 11:
                setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth((float) accuracy, getInstance().getInstanceViewPortWidthWithFloat());
    }

    private void updateRecyclerAttr() {
        this.mLayoutType = getAttrs().getLayoutType();
        int columnCount = getAttrs().getColumnCount();
        this.mColumnCount = columnCount;
        if (columnCount <= 0 && this.mLayoutType != 1) {
            Map<String, String> ext = new ArrayMap<>();
            ext.put("componentType", getComponentType());
            ext.put("attribute", getAttrs().toString());
            ext.put("stackTrace", Arrays.toString(Thread.currentThread().getStackTrace()));
            WXExceptionUtils.commitCriticalExceptionRT(getInstanceId(), WXErrorCode.WX_RENDER_ERR_LIST_INVALID_COLUMN_COUNT, Constants.Name.COLUMN_COUNT, String.format(Locale.ENGLISH, "You are trying to set the list/recycler/vlist/waterfall's column to %d, which is illegal. The column count should be a positive integer", Integer.valueOf(this.mColumnCount)), ext);
            this.mColumnCount = 1;
        }
        this.mColumnGap = getAttrs().getColumnGap();
        this.mColumnWidth = getAttrs().getColumnWidth();
        this.mPaddingLeft = getPadding().get(CSSShorthand.EDGE.LEFT);
        this.mPaddingRight = getPadding().get(CSSShorthand.EDGE.RIGHT);
    }

    @WXComponentProp(name = Constants.Name.SCROLL_DIRECTION)
    public void setScrollDirection(String direction) {
        if (this.orientation != getAttrs().getOrientation()) {
            this.orientation = getAttrs().getOrientation();
            updateRecyclerAttr();
            WXRecyclerView wxRecyclerView = (WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
            if (this.orientation == 0) {
                wxRecyclerView.setHorizontalScrollBarEnabled(true);
            } else {
                wxRecyclerView.setHorizontalScrollBarEnabled(false);
            }
            wxRecyclerView.initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_WIDTH)
    public void setColumnWidth(int columnCount) {
        if (getAttrs().getColumnWidth() != this.mColumnWidth) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getHostView() != null && ((BounceRecyclerView) getHostView()).getInnerView() != null) {
            if (getOrientation() == 1) {
                ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setVerticalScrollBarEnabled(show);
            } else {
                ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setHorizontalScrollBarEnabled(show);
            }
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_COUNT)
    public void setColumnCount(int columnCount) {
        if (getAttrs().getColumnCount() != this.mColumnCount) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.COLUMN_GAP)
    public void setColumnGap(float columnGap) throws InterruptedException {
        if (getAttrs().getColumnGap() != this.mColumnGap) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setScrollable(scrollable);
    }

    @JSMethod
    public void setListData(Object param) {
        Object param2 = parseListDataToJSONArray(param);
        boolean update = this.cellDataManager.listData != param2;
        if ((param2 instanceof JSONArray) && update) {
            this.cellDataManager.setListData((JSONArray) param2);
            notifyUpdateList();
        }
    }

    @JSMethod
    public void appendData(JSONArray data) {
        if (data != null && data.size() != 0) {
            if (this.cellDataManager.listData == null) {
                this.cellDataManager.listData = new JSONArray();
            }
            int position = this.cellDataManager.listData.size();
            if (position < 0) {
                position = 0;
            }
            if (data instanceof JSONArray) {
                this.cellDataManager.listData.addAll(data);
            }
            ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemRangeInserted(position, data.size());
        }
    }

    @JSMethod
    public void insertData(int index, Object data) {
        if (data != null && this.cellDataManager.listData != null && index <= this.cellDataManager.listData.size()) {
            if (this.cellDataManager.insertData(index, data)) {
                notifyUpdateList();
            } else {
                ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemInserted(index);
            }
        }
    }

    @JSMethod
    public void appendRange(int index, JSONArray data) {
        insertRange(index, data);
    }

    @JSMethod
    public void insertRange(int index, JSONArray data) {
        if (data != null && data.size() != 0 && this.cellDataManager.listData != null && index <= this.cellDataManager.listData.size()) {
            if (this.cellDataManager.insertRange(index, data)) {
                notifyUpdateList();
            } else {
                ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemRangeInserted(index, data.size());
            }
        }
    }

    @JSMethod
    public void updateData(int index, Object data) {
        if (data != null && this.cellDataManager.listData != null && index < this.cellDataManager.listData.size()) {
            if (this.cellDataManager.updateData(data, index)) {
                ((BounceRecyclerView) getHostView()).getRecyclerViewBaseAdapter().notifyItemChanged(index, data);
            } else {
                notifyUpdateList();
            }
        }
    }

    @JSMethod
    public void removeData(int index, int count) {
        if (this.cellDataManager.listData != null && index < this.cellDataManager.listData.size()) {
            if (count <= 0) {
                count = 1;
            }
            int removeCount = 0;
            while (count > 0 && index < this.cellDataManager.listData.size()) {
                this.cellDataManager.removeData(Integer.valueOf(index));
                count--;
                removeCount++;
            }
            if (removeCount > 0) {
                notifyUpdateList();
            }
        }
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
        this.mListCellCount = 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        if (!props.containsKey("padding") && !props.containsKey(Constants.Name.PADDING_LEFT) && !props.containsKey(Constants.Name.PADDING_RIGHT)) {
            return;
        }
        if (this.mPaddingLeft != getPadding().get(CSSShorthand.EDGE.LEFT) || this.mPaddingRight != getPadding().get(CSSShorthand.EDGE.RIGHT)) {
            updateRecyclerAttr();
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).initView(getContext(), this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (ScrollStartEndHelper.isScrollEvent(type) && getHostView() != null && ((BounceRecyclerView) getHostView()).getInnerView() != null && !this.mHasAddScrollEvent) {
            this.mHasAddScrollEvent = true;
            ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass7 */
                private boolean mFirstEvent = true;
                private int offsetXCorrection;
                private int offsetYCorrection;

                @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                    int offsetY;
                    int offsetX;
                    super.onScrolled(recyclerView, dx, dy);
                    if (recyclerView.getLayoutManager().canScrollVertically()) {
                        int offsetX2 = recyclerView.computeHorizontalScrollOffset();
                        int offsetY2 = recyclerView.computeVerticalScrollOffset();
                        if (dx == 0 && dy == 0) {
                            this.offsetXCorrection = offsetX2;
                            this.offsetYCorrection = offsetY2;
                            offsetX = 0;
                            offsetY = 0;
                        } else {
                            offsetX = offsetX2 - this.offsetXCorrection;
                            offsetY = offsetY2 - this.offsetYCorrection;
                        }
                        WXRecyclerTemplateList.this.getScrollStartEndHelper().onScrolled(offsetX, offsetY);
                        if (WXRecyclerTemplateList.this.getEvents().contains("scroll")) {
                            if (this.mFirstEvent) {
                                this.mFirstEvent = false;
                            } else if (WXRecyclerTemplateList.this.shouldReport(offsetX, offsetY)) {
                                WXRecyclerTemplateList.this.fireScrollEvent(recyclerView, offsetX, offsetY);
                            }
                        }
                    }
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        fireEvent("scroll", getScrollEvent(recyclerView, offsetX, offsetY));
    }

    public Map<String, Object> getScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        int offsetY2 = -calcContentOffset(recyclerView);
        int contentWidth = recyclerView.getMeasuredWidth() + recyclerView.computeHorizontalScrollRange();
        int contentHeight = calcContentSize();
        Map<String, Object> event = new HashMap<>(3);
        Map<String, Object> contentSize = new HashMap<>(3);
        Map<String, Object> contentOffset = new HashMap<>(3);
        contentSize.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentWidth, getInstance().getInstanceViewPortWidthWithFloat())));
        contentSize.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth((float) contentHeight, getInstance().getInstanceViewPortWidthWithFloat())));
        contentOffset.put(Constants.Name.X, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) offsetX, getInstance().getInstanceViewPortWidthWithFloat())));
        contentOffset.put(Constants.Name.Y, Float.valueOf(-WXViewUtils.getWebPxByWidth((float) offsetY2, getInstance().getInstanceViewPortWidthWithFloat())));
        event.put(Constants.Name.CONTENT_SIZE, contentSize);
        event.put(Constants.Name.CONTENT_OFFSET, contentOffset);
        boolean z = true;
        if (recyclerView.getScrollState() != 1) {
            z = false;
        }
        event.put(Constants.Name.ISDRAGGING, Boolean.valueOf(z));
        return event;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean shouldReport(int offsetX, int offsetY) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        int gapX = Math.abs(this.mLastReport.x - offsetX);
        int gapY = Math.abs(this.mLastReport.y - offsetY);
        int i = this.mOffsetAccuracy;
        if (gapX < i && gapY < i) {
            return false;
        }
        this.mLastReport.x = offsetX;
        this.mLastReport.y = offsetY;
        return true;
    }

    private boolean setRefreshOrLoading(final WXComponent child) {
        if ((child instanceof WXRefresh) && getHostView() != null) {
            ((BounceRecyclerView) getHostView()).setOnRefreshListener((WXRefresh) child);
            ((BounceRecyclerView) getHostView()).postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass8 */

                public void run() {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).setHeaderView(child);
                }
            }), 100);
            return true;
        } else if (!(child instanceof WXLoading) || getHostView() == null) {
            return false;
        } else {
            ((BounceRecyclerView) getHostView()).setOnLoadingListener((WXLoading) child);
            ((BounceRecyclerView) getHostView()).postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList.AnonymousClass9 */

                public void run() {
                    ((BounceRecyclerView) WXRecyclerTemplateList.this.getHostView()).setFooterView(child);
                }
            }), 100);
            return true;
        }
    }

    private void removeFooterOrHeader(WXComponent child) {
        if (child instanceof WXLoading) {
            ((BounceRecyclerView) getHostView()).removeFooterView(child);
        } else if (child instanceof WXRefresh) {
            ((BounceRecyclerView) getHostView()).removeHeaderView(child);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View hostView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.MarginLayoutParams params = (ViewGroup.MarginLayoutParams) hostView.getLayoutParams();
        if ((child instanceof WXBaseRefresh) && params == null) {
            return new LinearLayout.LayoutParams(width, height);
        }
        if (params == null) {
            return new RecyclerView.LayoutParams(width, height);
        }
        params.width = width;
        params.height = height;
        setMarginsSupportRTL(params, left, 0, right, 0);
        return params;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        synchronized (this) {
            if (getHostView() != null) {
                if (this.mAppearChangeRunnable != null) {
                    ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
                    this.mAppearChangeRunnable = null;
                }
                ((BounceRecyclerView) getHostView()).removeCallbacks(this.listUpdateRunnable);
                if (((BounceRecyclerView) getHostView()).getInnerView() != null) {
                    ((WXRecyclerView) ((BounceRecyclerView) getHostView()).getInnerView()).setAdapter(null);
                }
            }
            if (this.cellDataManager.listData != null) {
                this.cellDataManager.setListData(null);
            }
            if (this.mStickyHelper != null) {
                this.mStickyHelper = null;
            }
            if (this.mTemplateViewTypes != null) {
                this.mTemplateViewTypes.clear();
            }
            if (this.mTemplateSources != null) {
                this.mTemplateSources.clear();
            }
            if (this.mAppearHelpers != null) {
                this.mAppearHelpers.clear();
            }
            if (this.mDisAppearWatchList != null) {
                this.mDisAppearWatchList.clear();
            }
            super.destroy();
        }
    }

    public void onViewRecycled(TemplateViewHolder holder) {
    }

    public void onBindViewHolder(TemplateViewHolder templateViewHolder, int position) {
        WXCell component;
        if (templateViewHolder != null && (component = templateViewHolder.getTemplate()) != null) {
            if (templateViewHolder.getHolderPosition() >= 0) {
                fireEvent(TemplateDom.DETACH_CELL_SLOT, TemplateDom.findAllComponentRefs(getRef(), position, component));
            }
            System.currentTimeMillis();
            templateViewHolder.setHolderPosition(position);
            Object data = this.cellDataManager.listData.get(position);
            CellRenderState cellRenderState = this.cellDataManager.getRenderState(position);
            if (component.getRenderData() != data || (cellRenderState != null && cellRenderState.isDirty())) {
                Statements.doInitCompontent(doRenderTemplate(component, position));
                component.setRenderData(data);
                Layouts.doLayoutAsync(templateViewHolder, true);
                WXEnvironment.isOpenDebugLog();
                return;
            }
            WXEnvironment.isOpenDebugLog();
            fireEvent(TemplateDom.ATTACH_CELL_SLOT, TemplateDom.findAllComponentRefs(getRef(), position, component));
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public TemplateViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        String template = this.mTemplateViewTypes.keyAt(viewType);
        WXCell source = this.mTemplateSources.get(template);
        if (source == null) {
            FrameLayout view = new FrameLayout(getContext());
            view.setLayoutParams(new FrameLayout.LayoutParams(0, 0));
            return new TemplateViewHolder(this, view, viewType);
        }
        WXCell component = getCellTemplateFromCache(template);
        if (component == null && !source.isSourceUsed()) {
            source.setSourceUsed(true);
            renderTemplateCellWithData(source);
            component = source;
            WXEnvironment.isOpenDebugLog();
        }
        if (component == null) {
            System.currentTimeMillis();
            component = (WXCell) copyComponentFromSourceCell(source);
            WXEnvironment.isOpenDebugLog();
        }
        if (component.isLazy() || component.getHostView() == null) {
            doCreateCellViewBindData(component, template, false);
            WXEnvironment.isOpenDebugLog();
        } else {
            WXEnvironment.isOpenDebugLog();
        }
        return new TemplateViewHolder(this, component, viewType);
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemViewType(int position) {
        int type = this.mTemplateViewTypes.indexOfKey(getTemplateKey(position));
        if (type < 0) {
            return this.mTemplateViewTypes.indexOfKey("");
        }
        return type;
    }

    private List<WXComponent> doRenderTemplate(WXCell cell, int position) {
        this.cellRenderContext.clear();
        Object item = this.cellDataManager.listData.get(position);
        CellRenderState cellRenderState = this.cellDataManager.getRenderState(position);
        this.cellRenderContext.renderState = cellRenderState;
        this.cellRenderContext.templateList = this;
        this.cellRenderContext.position = position;
        ArrayStack stack = this.cellRenderContext.stack;
        Map map = this.cellRenderContext.map;
        if (this.cellDataManager.listData != null) {
            stack.push(map);
            map.put(this.listDataKey, this.cellDataManager.listData);
            if (!TextUtils.isEmpty(this.listDataIndexKey)) {
                map.put(this.listDataIndexKey, new PositionRef(cellRenderState));
            }
            if (!TextUtils.isEmpty(this.listDataItemKey)) {
                map.put(this.listDataItemKey, item);
            } else {
                stack.push(item);
            }
        }
        if (cellRenderState.itemId <= 0) {
            getItemId(position);
        }
        List<WXComponent> updates = Statements.doRender(cell, this.cellRenderContext);
        if (cellRenderState.isDirty()) {
            cellRenderState.resetDirty();
        }
        return updates;
    }

    public ArrayStack copyStack(CellRenderContext context, ArrayStack stack) {
        ArrayStack onceStack = new ArrayStack();
        for (int index = 0; index < stack.size(); index++) {
            Object value = stack.get(index);
            if (value instanceof Map) {
                value = new HashMap((Map) value);
            }
            onceStack.push(value);
        }
        return onceStack;
    }

    public String getTemplateKey(int position) {
        return getTemplateKey(safeGetListData(position));
    }

    public String getTemplateKey(Object data) {
        String template = null;
        if (data instanceof JSONObject) {
            template = ((JSONObject) data).getString(this.listDataTemplateKey);
        }
        if (!TextUtils.isEmpty(template)) {
            return template;
        }
        if (this.defaultTemplateCell != null) {
            return this.defaultTemplateKey;
        }
        return "";
    }

    public WXCell getSourceTemplate(int position) {
        return this.mTemplateSources.get(getTemplateKey(position));
    }

    private int getCellTemplateItemType(WXCell cell) {
        if (cell == null) {
            return -1;
        }
        if (cell.getAttrs() == null) {
            return 0;
        }
        String template = WXUtils.getString(cell.getAttrs().get(Constants.Name.Recycler.SLOT_TEMPLATE_CASE), null);
        if (cell == this.defaultTemplateCell) {
            template = this.defaultTemplateKey;
        }
        int type = this.mTemplateViewTypes.indexOfKey(template);
        if (type < 0) {
            return -1;
        }
        return type;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemCount() {
        ArrayMap<String, Integer> arrayMap;
        Map<String, WXCell> map;
        if (!this.hasLayoutDone || !this.hasAppendTreeDone || this.cellDataManager.listData == null || (arrayMap = this.mTemplateViewTypes) == null || arrayMap.size() <= 1 || (map = this.mTemplateSources) == null || map.size() == 0) {
            return 0;
        }
        return this.cellDataManager.listData.size();
    }

    public boolean onFailedToRecycleView(TemplateViewHolder holder) {
        return false;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public long getItemId(int position) {
        CellRenderState renderState = this.cellDataManager.getRenderState(position);
        if (renderState.itemId <= 0) {
            if (TextUtils.isEmpty(getTemplateKey(position))) {
                return -1;
            }
            Object data = safeGetListData(position);
            if (!(data instanceof JSONObject) || !((JSONObject) data).containsKey("keyItemId")) {
                renderState.itemId = (((long) Math.abs(data.hashCode())) << 24) + ((long) position);
            } else {
                renderState.itemId = ((JSONObject) data).getLongValue("keyItemId");
            }
        }
        return renderState.itemId;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onBeforeScroll(int dx, int dy) {
        TemplateStickyHelper templateStickyHelper = this.mStickyHelper;
        if (templateStickyHelper != null) {
            templateStickyHelper.onBeforeScroll(dx, dy);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onLoadMore(int offScreenY) {
        try {
            String offset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(offset)) {
                offset = "0";
            }
            if (((float) offScreenY) <= WXViewUtils.getRealPxByWidth((float) Integer.parseInt(offset), getInstance().getInstanceViewPortWidthWithFloat()) && this.cellDataManager.listData != null) {
                if (this.mListCellCount != this.cellDataManager.listData.size() || this.mForceLoadmoreNextTime) {
                    fireEvent(Constants.Event.LOADMORE);
                    this.mListCellCount = this.cellDataManager.listData.size();
                    this.mForceLoadmoreNextTime = false;
                }
            }
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("WXRecyclerTemplateList onLoadMore : ", e);
            }
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void notifyAppearStateChange(int firstVisible, int lastVisible, int directionX, int directionY) {
        RecyclerView recyclerView;
        int type;
        RecyclerView recyclerView2;
        List<Object> eventArgs;
        List<Object> eventArgs2;
        int i = lastVisible;
        ArrayMap<Integer, List<AppearanceHelper>> arrayMap = this.mAppearHelpers;
        if (arrayMap == null) {
            return;
        }
        if (arrayMap.size() > 0) {
            String str = null;
            if (this.mAppearChangeRunnable != null) {
                ((BounceRecyclerView) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
                this.mAppearChangeRunnable = null;
            }
            if (directionY > 0) {
                str = "up";
            } else if (directionY < 0) {
                str = "down";
            }
            String direction = str;
            if (getOrientation() == 0 && directionX != 0) {
                direction = directionX > 0 ? "left" : "right";
            }
            RecyclerView recyclerView3 = (RecyclerView) ((BounceRecyclerView) getHostView()).getInnerView();
            int position = firstVisible;
            while (position <= i) {
                int type2 = getItemViewType(position);
                List<AppearanceHelper> helpers = this.mAppearHelpers.get(Integer.valueOf(type2));
                if (helpers != null) {
                    Iterator<AppearanceHelper> it = helpers.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            recyclerView = recyclerView3;
                            break;
                        }
                        AppearanceHelper helper = it.next();
                        if (helper.isWatch()) {
                            TemplateViewHolder itemHolder = (TemplateViewHolder) recyclerView3.findViewHolderForAdapterPosition(position);
                            if (itemHolder != null) {
                                if (itemHolder.getComponent() == null) {
                                    recyclerView = recyclerView3;
                                    break;
                                }
                                List<WXComponent> childListeners = findChildListByRef(itemHolder.getComponent(), helper.getAwareChild().getRef());
                                if (childListeners == null) {
                                    recyclerView = recyclerView3;
                                    break;
                                } else if (childListeners.size() == 0) {
                                    recyclerView = recyclerView3;
                                    break;
                                } else {
                                    Map<String, Map<Integer, List<Object>>> disAppearList = this.mDisAppearWatchList.get(Integer.valueOf(position));
                                    if (disAppearList == null) {
                                        disAppearList = new ArrayMap();
                                        this.mDisAppearWatchList.put(Integer.valueOf(position), disAppearList);
                                    }
                                    Map<Integer, List<Object>> componentDisAppearList = disAppearList.get(helper.getAwareChild().getRef());
                                    if (componentDisAppearList == null) {
                                        componentDisAppearList = new ArrayMap();
                                        disAppearList.put(helper.getAwareChild().getRef(), componentDisAppearList);
                                    }
                                    int m = 0;
                                    while (m < childListeners.size()) {
                                        WXComponent childLisener = childListeners.get(m);
                                        if (childLisener.getHostView() == null) {
                                            recyclerView2 = recyclerView3;
                                            type = type2;
                                        } else {
                                            recyclerView2 = recyclerView3;
                                            boolean appear = helper.isViewVisible(childLisener.getHostView());
                                            int key = childLisener.getHostView().hashCode();
                                            if (!appear) {
                                                type = type2;
                                                if (componentDisAppearList.containsKey(Integer.valueOf(key))) {
                                                    childLisener.notifyAppearStateChange(Constants.Event.DISAPPEAR, direction);
                                                    componentDisAppearList.remove(Integer.valueOf(key));
                                                }
                                            } else if (!componentDisAppearList.containsKey(Integer.valueOf(key))) {
                                                childLisener.notifyAppearStateChange(Constants.Event.APPEAR, direction);
                                                if (childLisener.getEvents() == null) {
                                                    eventArgs2 = null;
                                                } else if (childLisener.getEvents().getEventBindingArgsValues() != null) {
                                                    eventArgs2 = null;
                                                    if (childLisener.getEvents().getEventBindingArgsValues().get(Constants.Event.DISAPPEAR) != null) {
                                                        eventArgs = childLisener.getEvents().getEventBindingArgsValues().get(Constants.Event.DISAPPEAR);
                                                        type = type2;
                                                        componentDisAppearList.put(Integer.valueOf(key), eventArgs);
                                                    }
                                                } else {
                                                    eventArgs2 = null;
                                                }
                                                eventArgs = eventArgs2;
                                                type = type2;
                                                componentDisAppearList.put(Integer.valueOf(key), eventArgs);
                                            } else {
                                                type = type2;
                                            }
                                        }
                                        m++;
                                        recyclerView3 = recyclerView2;
                                        type2 = type;
                                    }
                                }
                            } else {
                                recyclerView = recyclerView3;
                                break;
                            }
                        }
                    }
                } else {
                    recyclerView = recyclerView3;
                }
                position++;
                recyclerView3 = recyclerView;
            }
            int count = getItemCount();
            int position2 = 0;
            while (position2 < count) {
                if (position2 < firstVisible || position2 > i) {
                    Map<String, Map<Integer, List<Object>>> map = this.mDisAppearWatchList.get(Integer.valueOf(position2));
                    if (map != null) {
                        WXCell template = this.mTemplateSources.get(getTemplateKey(position2));
                        if (template != null) {
                            for (Map.Entry<String, Map<Integer, List<Object>>> cellWatcherEntry : map.entrySet()) {
                                WXComponent component = findChildByRef(template, cellWatcherEntry.getKey());
                                if (component != null) {
                                    Map<Integer, List<Object>> eventWatchers = cellWatcherEntry.getValue();
                                    if (eventWatchers != null) {
                                        if (eventWatchers.size() != 0) {
                                            WXEvent events = component.getEvents();
                                            for (Map.Entry<Integer, List<Object>> eventWatcherEntry : eventWatchers.entrySet()) {
                                                events.putEventBindingArgsValue(Constants.Event.DISAPPEAR, eventWatcherEntry.getValue());
                                                component.notifyAppearStateChange(Constants.Event.DISAPPEAR, direction);
                                            }
                                            eventWatchers.clear();
                                        }
                                    }
                                }
                            }
                            this.mDisAppearWatchList.remove(Integer.valueOf(position2));
                        } else {
                            return;
                        }
                    } else {
                        continue;
                    }
                } else {
                    position2 = i + 1;
                }
                position2++;
                i = lastVisible;
            }
        }
    }

    private Object safeGetListData(int position) {
        try {
            return this.cellDataManager.listData.get(position);
        } catch (Exception e) {
            return JSONObject.parseObject("{}");
        }
    }

    public void notifyUpdateList() {
        if (getHostView() != null && ((BounceRecyclerView) getHostView()).getInnerView() != null && this.listUpdateRunnable != null) {
            if (Looper.getMainLooper().getThread().getId() != Thread.currentThread().getId()) {
                ((BounceRecyclerView) getHostView()).removeCallbacks(this.listUpdateRunnable);
                ((BounceRecyclerView) getHostView()).post(this.listUpdateRunnable);
                return;
            }
            this.listUpdateRunnable.run();
        }
    }

    private int calcContentSize() {
        int totalHeight = 0;
        if (this.cellDataManager.listData == null) {
            return 0;
        }
        for (int i = 0; i < this.cellDataManager.listData.size(); i++) {
            WXCell child = getSourceTemplate(i);
            if (child != null) {
                totalHeight = (int) (((float) totalHeight) + child.getLayoutHeight());
            }
        }
        return totalHeight;
    }

    public int calcContentOffset(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        if (layoutManager instanceof LinearLayoutManager) {
            int firstVisibleItemPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
            int offset = 0;
            for (int i = 0; i < firstVisibleItemPosition; i++) {
                WXCell cell = getSourceTemplate(i);
                if (cell != null) {
                    offset = (int) (((float) offset) - cell.getLayoutHeight());
                }
            }
            if (layoutManager instanceof GridLayoutManager) {
                offset /= ((GridLayoutManager) layoutManager).getSpanCount();
            }
            View firstVisibleView = layoutManager.findViewByPosition(firstVisibleItemPosition);
            if (firstVisibleView != null) {
                return offset + firstVisibleView.getTop();
            }
            return offset;
        } else if (!(layoutManager instanceof StaggeredGridLayoutManager)) {
            return -1;
        } else {
            int spanCount = ((StaggeredGridLayoutManager) layoutManager).getSpanCount();
            int firstVisibleItemPosition2 = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(null)[0];
            int offset2 = 0;
            for (int i2 = 0; i2 < firstVisibleItemPosition2; i2++) {
                WXCell cell2 = getSourceTemplate(i2);
                if (cell2 != null) {
                    offset2 = (int) (((float) offset2) - cell2.getLayoutHeight());
                }
            }
            int offset3 = offset2 / spanCount;
            View firstVisibleView2 = layoutManager.findViewByPosition(firstVisibleItemPosition2);
            if (firstVisibleView2 != null) {
                return offset3 + firstVisibleView2.getTop();
            }
            return offset3;
        }
    }

    public WXComponent findParentType(WXComponent component, Class type) {
        if (type.isAssignableFrom(component.getClass())) {
            return component;
        }
        if (component.getParent() == null) {
            return null;
        }
        findTypeParent(component.getParent(), type);
        return null;
    }

    public WXComponent findChildByRef(WXComponent component, String ref) {
        if (ref.equals(component.getRef())) {
            return component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        for (int i = 0; i < container.getChildCount(); i++) {
            WXComponent child = findChildByRef(container.getChild(i), ref);
            if (child != null) {
                return child;
            }
        }
        return null;
    }

    public List<WXComponent> findChildListByRef(WXComponent component, String ref) {
        WXComponent child = findChildByRef(component, ref);
        if (child == null) {
            return null;
        }
        List<WXComponent> componentList = new ArrayList<>();
        WXVContainer container = child.getParent();
        if (container == null || (container instanceof WXRecyclerTemplateList)) {
            componentList.add(child);
        } else {
            for (int i = 0; i < container.getChildCount(); i++) {
                WXComponent element = container.getChild(i);
                if (ref.equals(element.getRef())) {
                    componentList.add(element);
                }
            }
        }
        return componentList;
    }

    public WXComponent findChildByAttrsRef(WXComponent component, String ref) {
        if (component.getAttrs() != null && ref.equals(component.getAttrs().get("ref"))) {
            return component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        for (int i = 0; i < container.getChildCount(); i++) {
            WXComponent child = findChildByAttrsRef(container.getChild(i), ref);
            if (child != null) {
                return child;
            }
        }
        return null;
    }

    private WXCell getCellTemplateFromCache(String template) {
        TemplateCache cache = this.mTemplatesCache.get(template);
        WXCell component = null;
        if (!(cache == null || cache.cells == null || cache.cells.size() <= 0)) {
            component = cache.cells.poll();
        }
        if (cache == null || !cache.isLoadIng) {
            if (cache == null) {
                cache = new TemplateCache();
                this.mTemplatesCache.put(template, cache);
            }
            cache.isLoadIng = true;
            WXCell source = this.mTemplateSources.get(template);
            if (source != null && WXUtils.getBoolean(source.getAttrs().get("preload"), true).booleanValue()) {
                new AsyncCellLoadTask(template, source, this).startTask();
            }
        }
        return component;
    }

    public WXComponent copyComponentFromSourceCell(WXCell cell) {
        renderTemplateCellWithData(cell);
        return (WXCell) Statements.copyComponentTree(cell);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0054, code lost:
        r0 = th;
     */
    private synchronized void renderTemplateCellWithData(WXCell cell) {
        if (cell.getRenderData() == null && this.cellDataManager.listData != null && this.cellDataManager.listData.size() > 0) {
            synchronized (this) {
                if (cell.getRenderData() == null) {
                    Statements.parseStatementsToken(cell);
                    int i = 0;
                    while (true) {
                        if (i >= this.cellDataManager.listData.size()) {
                            break;
                        } else if (cell == getSourceTemplate(i)) {
                            Object data = this.cellDataManager.listData.get(i);
                            doRenderTemplate(cell, i);
                            Layouts.doLayoutSync(cell, getLayoutWidth(), getLayoutHeight());
                            cell.setRenderData(data);
                            break;
                        } else {
                            i++;
                        }
                    }
                }
            }
        }
        return;
        while (true) {
        }
    }

    public static void doCreateCellViewBindData(WXCell component, String template, boolean inPreload) {
        if (component.isLazy() || component.getHostView() == null) {
            System.currentTimeMillis();
            Statements.initLazyComponent(component, null);
            WXEnvironment.isOpenDebugLog();
        }
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    public int getTemplateCacheSize() {
        return this.templateCacheSize;
    }

    public ConcurrentHashMap<String, TemplateCache> getTemplatesCache() {
        if (this.mTemplatesCache == null) {
            this.mTemplatesCache = new ConcurrentHashMap<>();
        }
        return this.mTemplatesCache;
    }

    public CellDataManager getCellDataManager() {
        return this.cellDataManager;
    }

    private JSONArray parseListDataToJSONArray(Object value) {
        try {
            if (value instanceof JSONArray) {
                return (JSONArray) value;
            }
            if (value instanceof String) {
                return JSONArray.parseArray(getAttrs().get(Constants.Name.Recycler.LIST_DATA).toString());
            }
            return new JSONArray();
        } catch (Exception e) {
            WXLogUtils.e(TAG, "parseListDataException" + e.getMessage());
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView != null) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo(0, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidthWithFloat()), getAttrs().getOrientation());
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        BounceRecyclerView bounceRecyclerView = (BounceRecyclerView) getHostView();
        if (bounceRecyclerView != null) {
            ((WXRecyclerView) bounceRecyclerView.getInnerView()).scrollTo((int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidthWithFloat()), 0, getAttrs().getOrientation());
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void setIsLayoutRTL(boolean isRTL) {
        super.setIsLayoutRTL(isRTL);
        this.mViewOnScrollListener.setLayoutRTL(isLayoutRTL());
    }
}
