package com.taobao.weex.ui.component.richtext;

import android.content.Context;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.text.SpannedString;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXText;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.richtext.node.RichTextNode;
import com.taobao.weex.ui.component.richtext.node.RichTextNodeManager;
import com.taobao.weex.ui.view.WXTextView;
import java.lang.reflect.InvocationTargetException;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class WXRichText extends WXText {
    private List<RichTextNode> nodes = new LinkedList();

    static class RichTextContentBoxMeasurement extends TextContentBoxMeasurement {
        public RichTextContentBoxMeasurement(WXComponent component) {
            super(component);
        }

        /* access modifiers changed from: protected */
        @Override // com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement
        public Spanned createSpanned(String text) {
            if (!TextUtils.isEmpty(text)) {
                boolean z = true;
                boolean z2 = this.mComponent.getInstance() != null;
                if (this.mComponent.getInstance().getUIContext() == null) {
                    z = false;
                }
                if ((!z2 || !z) || TextUtils.isEmpty(this.mComponent.getInstanceId())) {
                    return new SpannedString("");
                }
                Spannable spannable = RichTextNode.parse(this.mComponent.getInstance().getUIContext(), this.mComponent.getInstanceId(), this.mComponent.getRef(), text);
                updateSpannable(spannable, RichTextNode.createSpanFlag(0));
                return spannable;
            }
            Spannable spannable2 = ((WXRichText) this.mComponent).toSpan();
            updateSpannable(spannable2, RichTextNode.createSpanFlag(0));
            return spannable2;
        }
    }

    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXRichText(instance, parent, basicComponentData);
        }
    }

    public WXRichText(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        setContentBoxMeasurement(new RichTextContentBoxMeasurement(this));
    }

    public void AddChildNode(String ref, String nodeType, String parentRef, Map<String, String> styles, Map<String, String> attrs) {
        if (getInstance() != null && getInstance().getUIContext() != null && !TextUtils.isEmpty(getInstanceId()) && !TextUtils.isEmpty(ref) && !TextUtils.isEmpty(nodeType)) {
            RichTextNode child = RichTextNodeManager.createRichTextNode(getInstance().getUIContext(), getInstanceId(), getRef(), ref, nodeType, styles, attrs);
            if (TextUtils.isEmpty(parentRef)) {
                this.nodes.add(child);
                return;
            }
            RichTextNode parent = findRichNode(parentRef);
            if (parent != null) {
                parent.addChildNode(child);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Spannable toSpan() {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        List<RichTextNode> list = this.nodes;
        if (list != null && !list.isEmpty()) {
            for (RichTextNode node : this.nodes) {
                spannableStringBuilder.append((CharSequence) node.toSpan(1));
            }
        }
        return spannableStringBuilder;
    }

    public void removeChildNode(String parentRef, String ref) {
        List<RichTextNode> list = this.nodes;
        if (!(list == null || list.isEmpty())) {
            if (parentRef.equals("")) {
                for (RichTextNode node : this.nodes) {
                    if (TextUtils.equals(node.getRef(), ref)) {
                        this.nodes.remove(node);
                    }
                }
                return;
            }
            RichTextNode parent = findRichNode(parentRef);
            if (parent != null) {
                parent.removeChildNode(ref);
            }
        }
    }

    public void updateChildNodeStyles(String ref, Map<String, Object> styles) {
        RichTextNode node = findRichNode(ref);
        if (node != null) {
            node.updateStyles(styles);
        }
    }

    public void updateChildNodeAttrs(String ref, Map<String, Object> attrs) {
        RichTextNode node = findRichNode(ref);
        if (node != null) {
            node.updateAttrs(attrs);
        }
    }

    private RichTextNode findRichNode(String ref) {
        List<RichTextNode> list;
        if (TextUtils.isEmpty(ref) || (list = this.nodes) == null || list.isEmpty()) {
            return null;
        }
        for (RichTextNode node : this.nodes) {
            RichTextNode theNode = node.findRichNode(ref);
            if (theNode != null) {
                return theNode;
            }
        }
        return null;
    }

    /* Return type fixed from 'com.taobao.weex.ui.component.richtext.WXRichTextView' to match base method */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXText, com.taobao.weex.ui.component.WXText, com.taobao.weex.ui.component.WXComponent
    public WXTextView initComponentHostView(Context context) {
        return new WXRichTextView(context);
    }
}
