package com.taobao.weex.ui.component.richtext;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.text.Layout;
import android.text.Selection;
import android.text.Spannable;
import android.text.Spanned;
import android.text.style.ClickableSpan;
import android.view.MotionEvent;
import com.taobao.weex.ui.component.richtext.span.ImgSpan;
import com.taobao.weex.ui.view.WXTextView;

public class WXRichTextView extends WXTextView {
    public WXRichTextView(Context context) {
        super(context);
    }

    @Override // com.taobao.weex.ui.view.WXTextView
    public boolean onTouchEvent(MotionEvent event) {
        boolean superResult = super.onTouchEvent(event);
        boolean handled = false;
        if (isEnabled() && getTextLayout() != null && (getText() instanceof Spannable)) {
            handled = updateSelection(event, (Spannable) getText());
        }
        return handled || superResult;
    }

    /* access modifiers changed from: protected */
    public boolean verifyDrawable(Drawable who) {
        super.verifyDrawable(who);
        return true;
    }

    @Override // com.taobao.weex.ui.view.WXTextView
    public void setTextLayout(Layout layout) {
        super.setTextLayout(layout);
        if (layout.getText() instanceof Spanned) {
            Spanned spanned = (Spanned) layout.getText();
            ImgSpan[] imgSpan = (ImgSpan[]) spanned.getSpans(0, spanned.length(), ImgSpan.class);
            if (imgSpan != null) {
                for (ImgSpan span : imgSpan) {
                    span.setView(this);
                }
            }
        }
    }

    private boolean updateSelection(MotionEvent event, Spannable buffer) {
        int action = event.getActionMasked();
        if (action == 1 || action == 0) {
            int x = ((int) event.getX()) - getPaddingLeft();
            int y = ((int) event.getY()) - getPaddingTop();
            int x2 = x + getScrollX();
            int y2 = y + getScrollY();
            Layout layout = getTextLayout();
            int off = layout.getOffsetForHorizontal(layout.getLineForVertical(y2), (float) x2);
            ClickableSpan[] link = (ClickableSpan[]) buffer.getSpans(off, off, ClickableSpan.class);
            if (link.length != 0) {
                if (action == 1) {
                    link[0].onClick(this);
                } else {
                    Selection.setSelection(buffer, buffer.getSpanStart(link[0]), buffer.getSpanEnd(link[0]));
                }
                return true;
            }
            Selection.removeSelection(buffer);
        }
        return false;
    }
}
