package com.taobao.weex.ui.component.richtext.node;

import android.content.Context;
import android.net.Uri;
import android.text.SpannableStringBuilder;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.DrawableStrategy;
import com.taobao.weex.ui.component.richtext.span.ImgSpan;
import com.taobao.weex.ui.component.richtext.span.ItemClickSpan;
import com.taobao.weex.utils.ImgURIUtil;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

/* access modifiers changed from: package-private */
public class ImgNode extends RichTextNode {
    public static final String NODE_TYPE = "image";

    static class ImgNodeCreator implements RichTextNodeCreator<ImgNode> {
        ImgNodeCreator() {
        }

        @Override // com.taobao.weex.ui.component.richtext.node.RichTextNodeCreator
        public ImgNode createRichTextNode(Context context, String instanceId, String componentRef) {
            return new ImgNode(context, instanceId, componentRef);
        }

        @Override // com.taobao.weex.ui.component.richtext.node.RichTextNodeCreator
        public ImgNode createRichTextNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
            return new ImgNode(context, instanceId, componentRef, ref, styles, attrs);
        }
    }

    private ImgNode(Context context, String instanceId, String componentRef) {
        super(context, instanceId, componentRef);
    }

    private ImgNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
        super(context, instanceId, componentRef, ref, styles, attrs);
    }

    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    public String toString() {
        return "﻿";
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    public boolean isInternalNode() {
        return false;
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    public void updateSpans(SpannableStringBuilder spannableStringBuilder, int level) {
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(this.mInstanceId);
        if (WXSDKEngine.getDrawableLoader() == null) {
            return;
        }
        if (((this.style.containsKey("width") && this.style.containsKey("height")) || (this.attr.containsKey("width") && this.attr.containsKey("height"))) && this.attr.containsKey("src") && instance != null) {
            List<Object> spans = new LinkedList<>();
            spans.add(createImgSpan(instance));
            if (this.attr.containsKey(RichTextNode.PSEUDO_REF)) {
                spans.add(new ItemClickSpan(this.mInstanceId, this.mComponentRef, this.attr.get(RichTextNode.PSEUDO_REF).toString()));
            }
            for (Object span : spans) {
                spannableStringBuilder.setSpan(span, 0, spannableStringBuilder.length(), createSpanFlag(level));
            }
        }
    }

    private ImgSpan createImgSpan(WXSDKInstance instance) {
        Object widthStr = (this.style.containsKey("width") ? this.style : this.attr).get("width");
        Object heightStr = (this.style.containsKey("height") ? this.style : this.attr).get("height");
        int width = (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(widthStr), instance.getInstanceViewPortWidthWithFloat());
        int height = (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(heightStr), instance.getInstanceViewPortWidthWithFloat());
        ImgSpan imageSpan = new ImgSpan(width, height, this.mInstanceId, this.mComponentRef);
        Uri rewrited = instance.rewriteUri(Uri.parse(this.attr.get("src").toString()), "image");
        if ("local".equals(rewrited.getScheme())) {
            imageSpan.setDrawable(ImgURIUtil.getDrawableFromLoaclSrc(this.mContext, rewrited), false);
        } else {
            DrawableStrategy drawableStrategy = new DrawableStrategy();
            drawableStrategy.width = width;
            drawableStrategy.height = height;
            WXSDKEngine.getDrawableLoader().setDrawable(rewrited.toString(), imageSpan, drawableStrategy);
        }
        return imageSpan;
    }
}
