package com.taobao.weex.ui.config;

import android.text.TextUtils;
import android.util.Pair;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.SimpleComponentHolder;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.utils.WXLogUtils;
import com.vivo.push.PushClientConstants;
import java.lang.reflect.InvocationTargetException;
import java.util.Map;

public class ConfigComponentHolder implements IFComponentHolder {
    public static final String TAG = "WeexScanConfigRegister";
    private boolean mAppendTree;
    private Class mClass;
    private ClassLoader mClassLoader;
    private String mClassName;
    private Map<String, Invoker> mMethodInvokers;
    private Map<String, Invoker> mPropertyInvokers;
    private String mType;
    private String[] methods;

    public ConfigComponentHolder(String mType2, boolean mAppendTree2, String mClassName2, String[] methods2) {
        this.mType = mType2;
        this.mAppendTree = mAppendTree2;
        this.mClassName = mClassName2;
        this.methods = methods2;
    }

    @Override // io.dcloud.feature.uniapp.ui.AbsIComponentHolder
    public void loadIfNonLazy() {
    }

    private synchronized boolean generate() {
        if (this.mClass == null) {
            return false;
        }
        Pair<Map<String, Invoker>, Map<String, Invoker>> methodPair = SimpleComponentHolder.getMethods(this.mClass);
        this.mPropertyInvokers = (Map) methodPair.first;
        this.mMethodInvokers = (Map) methodPair.second;
        return true;
    }

    @Override // com.taobao.weex.ui.ComponentCreator
    public synchronized WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
        WXComponent component;
        if (this.mClass == null || this.mClassLoader != instance.getContext().getClassLoader()) {
            this.mClass = WXSDKManager.getInstance().getClassLoaderAdapter().getComponentClass(this.mType, this.mClassName, instance);
            this.mClassLoader = instance.getContext().getClassLoader();
        }
        component = new SimpleComponentHolder.ClazzComponentCreator(this.mClass).createInstance(instance, parent, basicComponentData);
        component.bindHolder(this);
        return component;
    }

    @Override // io.dcloud.feature.uniapp.ui.AbsIComponentHolder
    public synchronized Invoker getPropertyInvoker(String name) {
        if (this.mPropertyInvokers == null && !generate()) {
            return null;
        }
        return this.mPropertyInvokers.get(name);
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public Invoker getMethodInvoker(String name) {
        if (this.mMethodInvokers != null || generate()) {
            return this.mMethodInvokers.get(name);
        }
        return null;
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public String[] getMethods() {
        String[] strArr = this.methods;
        if (strArr == null) {
            return new String[0];
        }
        return strArr;
    }

    public static final ConfigComponentHolder fromConfig(JSONObject config) {
        if (config == null) {
            return null;
        }
        try {
            String type = config.getString("name");
            boolean appendTree = config.getBooleanValue("appendTree");
            String className = config.getString(PushClientConstants.TAG_CLASS_NAME);
            JSONArray methods2 = null;
            if (config.containsKey("methods")) {
                methods2 = config.getJSONArray("methods");
            }
            if (!TextUtils.isEmpty(type)) {
                if (!TextUtils.isEmpty(className)) {
                    String[] arrays = new String[0];
                    if (methods2 != null) {
                        arrays = new String[methods2.size()];
                        methods2.toArray(arrays);
                    }
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d("WeexScanConfigRegister", "resolve component " + type + " className " + className + " methods " + methods2);
                    }
                    return new ConfigComponentHolder(type, appendTree, className, arrays);
                }
            }
            return null;
        } catch (Exception e) {
            WXLogUtils.e("WeexScanConfigRegister", e);
            return null;
        }
    }

    public boolean isAppendTree() {
        return this.mAppendTree;
    }

    public String getType() {
        return this.mType;
    }
}
