package com.taobao.weex.ui.config;

import android.text.TextUtils;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.bridge.MethodInvoker;
import com.taobao.weex.bridge.ModuleFactory;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.common.WXModuleAnno;
import com.taobao.weex.utils.WXLogUtils;
import com.vivo.push.PushClientConstants;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.common.UniModuleAnno;
import java.lang.annotation.Annotation;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

public class ConfigModuleFactory<T extends WXModule> implements ModuleFactory<T> {
    public static final String TAG = "WeexScanConfigRegister";
    private ClassLoader mClassLoader;
    private String mClassName;
    private Class<T> mClazz;
    private Map<String, Invoker> mMethodMap;
    private String mName;
    private String[] methods;

    public ConfigModuleFactory(String mName2, String mClassName2, String[] methods2) {
        this.mName = mName2;
        this.mClassName = mClassName2;
        this.methods = methods2;
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public String[] getMethods() {
        String[] strArr = this.methods;
        if (strArr == null) {
            return new String[0];
        }
        return strArr;
    }

    @Override // com.taobao.weex.bridge.JavascriptInvokable
    public Invoker getMethodInvoker(String name) {
        if (this.mMethodMap == null) {
            generateMethodMap();
        }
        return this.mMethodMap.get(name);
    }

    @Override // com.taobao.weex.bridge.ModuleFactory
    public T buildInstance() throws IllegalAccessException, InstantiationException {
        if (this.mClazz == null) {
            this.mClazz = (Class<T>) WXSDKManager.getInstance().getClassLoaderAdapter().getModuleClass(this.mName, this.mClassName, WXEnvironment.getApplication().getApplicationContext());
        }
        return this.mClazz.newInstance();
    }

    public T buildInstance(WXSDKInstance instance) throws IllegalAccessException, InstantiationException {
        if (instance == null) {
            return buildInstance();
        }
        if (this.mClazz == null || this.mClassLoader != instance.getContext().getClassLoader()) {
            this.mClazz = (Class<T>) WXSDKManager.getInstance().getClassLoaderAdapter().getModuleClass(this.mName, this.mClassName, instance.getContext());
            this.mClassLoader = instance.getContext().getClassLoader();
        }
        return this.mClazz.newInstance();
    }

    private void generateMethodMap() {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("WeexScanConfigRegister", "extractMethodNames:" + this.mClazz.getSimpleName());
        }
        HashMap<String, Invoker> methodMap = new HashMap<>();
        try {
            Method[] methods2 = this.mClazz.getMethods();
            for (Method method : methods2) {
                Annotation[] declaredAnnotations = method.getDeclaredAnnotations();
                int length = declaredAnnotations.length;
                int i = 0;
                while (true) {
                    if (i >= length) {
                        break;
                    }
                    Annotation anno = declaredAnnotations[i];
                    if (anno != null) {
                        if (anno instanceof JSMethod) {
                            JSMethod methodAnnotation = (JSMethod) anno;
                            methodMap.put("_".equals(methodAnnotation.alias()) ? method.getName() : methodAnnotation.alias(), new MethodInvoker(method, methodAnnotation.uiThread()));
                        } else if (anno instanceof WXModuleAnno) {
                            methodMap.put(method.getName(), new MethodInvoker(method, ((WXModuleAnno) anno).runOnUIThread()));
                            break;
                        } else if (anno instanceof UniJSMethod) {
                            UniJSMethod methodAnnotation2 = (UniJSMethod) anno;
                            methodMap.put("_".equals(methodAnnotation2.alias()) ? method.getName() : methodAnnotation2.alias(), new MethodInvoker(method, methodAnnotation2.uiThread()));
                        } else if (anno instanceof UniModuleAnno) {
                            methodMap.put(method.getName(), new MethodInvoker(method, ((UniModuleAnno) anno).runOnUIThread()));
                            break;
                        }
                    }
                    i++;
                }
            }
        } catch (Throwable e) {
            WXLogUtils.e("[WXModuleManager] extractMethodNames:", e);
        }
        this.mMethodMap = methodMap;
    }

    public static ConfigModuleFactory fromConfig(JSONObject config) {
        if (config == null) {
            return null;
        }
        try {
            String name = config.getString("name");
            String className = config.getString(PushClientConstants.TAG_CLASS_NAME);
            JSONArray methods2 = config.getJSONArray("methods");
            if (!TextUtils.isEmpty(name)) {
                if (!TextUtils.isEmpty(className)) {
                    String[] arrays = new String[methods2.size()];
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d("WeexScanConfigRegister", " resolve module " + name + " className " + className + " methods " + methods2);
                    }
                    return new ConfigModuleFactory(name, className, (String[]) methods2.toArray(arrays));
                }
            }
            return null;
        } catch (Exception e) {
            WXLogUtils.e("WeexScanConfigRegister", e);
            return null;
        }
    }

    public String getName() {
        return this.mName;
    }
}
