package com.taobao.weex.ui.flat.widget;

import android.graphics.Canvas;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.view.View;
import com.taobao.weex.ui.flat.FlatGUIContext;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.WXViewUtils;

/* access modifiers changed from: package-private */
public abstract class BaseWidget implements Widget {
    private BorderDrawable backgroundBorder;
    private Rect borderBox = new Rect();
    private int bottomOffset;
    private final FlatGUIContext context;
    private int leftOffset;
    private Point offsetOfContainer = new Point();
    private int rightOffset;
    private int topOffset;

    BaseWidget(FlatGUIContext context2) {
        this.context = context2;
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public void setLayout(int width, int height, int left, int right, int top, int bottom, Point offset) {
        this.offsetOfContainer = offset;
        this.borderBox.set(left, top, left + width, top + height);
        BorderDrawable borderDrawable = this.backgroundBorder;
        if (borderDrawable != null) {
            setBackgroundAndBorder(borderDrawable);
        }
        invalidate();
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public void setContentBox(int leftOffset2, int topOffset2, int rightOffset2, int bottomOffset2) {
        this.leftOffset = leftOffset2;
        this.topOffset = topOffset2;
        this.rightOffset = rightOffset2;
        this.bottomOffset = bottomOffset2;
        invalidate();
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public void setBackgroundAndBorder(BorderDrawable backgroundBorder2) {
        this.backgroundBorder = backgroundBorder2;
        Rect backgroundBox = new Rect(this.borderBox);
        backgroundBox.offset(-this.borderBox.left, -this.borderBox.top);
        backgroundBorder2.setBounds(backgroundBox);
        setCallback(backgroundBorder2);
        invalidate();
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public final Point getLocInFlatContainer() {
        return this.offsetOfContainer;
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public final BorderDrawable getBackgroundAndBorder() {
        return this.backgroundBorder;
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public final Rect getBorderBox() {
        return this.borderBox;
    }

    @Override // com.taobao.weex.ui.flat.widget.Widget
    public final void draw(Canvas canvas) {
        canvas.save();
        WXViewUtils.clipCanvasWithinBorderBox(this, canvas);
        canvas.translate((float) this.borderBox.left, (float) this.borderBox.top);
        BorderDrawable borderDrawable = this.backgroundBorder;
        if (borderDrawable != null) {
            borderDrawable.draw(canvas);
        }
        canvas.clipRect(this.leftOffset, this.topOffset, this.borderBox.width() - this.rightOffset, this.borderBox.height() - this.bottomOffset);
        canvas.translate((float) this.leftOffset, (float) this.topOffset);
        onDraw(canvas);
        canvas.restore();
    }

    /* access modifiers changed from: protected */
    public void invalidate() {
        View widgetContainer;
        Rect dirtyRegion = new Rect(this.borderBox);
        dirtyRegion.offset(this.offsetOfContainer.x, this.offsetOfContainer.y);
        FlatGUIContext flatGUIContext = this.context;
        if (flatGUIContext != null && (widgetContainer = flatGUIContext.getWidgetContainerView(this)) != null) {
            widgetContainer.invalidate(dirtyRegion);
        }
    }

    /* access modifiers changed from: protected */
    public void setCallback(Drawable drawable) {
        View widgetContainer;
        FlatGUIContext flatGUIContext = this.context;
        if (flatGUIContext != null && (widgetContainer = flatGUIContext.getWidgetContainerView(this)) != null) {
            drawable.setCallback(widgetContainer);
        }
    }
}
