package com.taobao.weex.ui.module;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.widget.EditText;
import android.widget.Toast;
import com.alibaba.fastjson.JSONObject;
import com.dcloud.android.widget.toast.ToastCompat;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.utils.WXLogUtils;
import java.util.HashMap;
import java.util.Map;

public class WXModalUIModule extends WXSDKEngine.DestroyableModule {
    public static final String CANCEL = "Cancel";
    public static final String CANCEL_TITLE = "cancelTitle";
    public static final String DATA = "data";
    public static final String DEFAULT = "default";
    public static final String DURATION = "duration";
    public static final String GRAVITY = "gravity";
    public static final String MESSAGE = "message";
    public static final String OK = "OK";
    public static final String OK_TITLE = "okTitle";
    public static final String RESULT = "result";
    private Dialog activeDialog;
    private Toast toast;

    @JSMethod(uiThread = true)
    public void toast(JSONObject jsObj) {
        int duration;
        if (this.mWXSDKInstance.getContext() != null) {
            String message = "";
            int duration2 = 0;
            int gravity = 17;
            if (jsObj != null) {
                try {
                    message = jsObj.getString("message");
                    if (jsObj.containsKey("duration")) {
                        duration2 = jsObj.getInteger("duration").intValue();
                    }
                    if (jsObj.containsKey(GRAVITY)) {
                        String str = jsObj.getString(GRAVITY);
                        if ((str instanceof String) && str.equals("bottom")) {
                            gravity = 80;
                        }
                    }
                } catch (Exception e) {
                    WXLogUtils.e("[WXModalUIModule] alert param parse error ", e);
                }
            }
            if (TextUtils.isEmpty(message)) {
                WXLogUtils.e("[WXModalUIModule] toast param parse is null ");
                return;
            }
            if (duration2 > 3) {
                duration = 1;
            } else {
                duration = 0;
            }
            Toast toast2 = this.toast;
            if (toast2 == null) {
                this.toast = ToastCompat.makeText(this.mWXSDKInstance.getContext(), (CharSequence) message, duration);
            } else {
                toast2.setDuration(duration);
                this.toast.setText(message);
            }
            if (17 == gravity) {
                this.toast.setGravity(gravity, 0, 0);
            }
            this.toast.show();
        }
    }

    @JSMethod(uiThread = true)
    public void alert(JSONObject jsObj, final JSCallback callback) {
        if (this.mWXSDKInstance.getContext() instanceof Activity) {
            String message = "";
            String okTitle = OK;
            if (jsObj != null) {
                try {
                    message = jsObj.getString("message");
                    okTitle = jsObj.getString(OK_TITLE);
                } catch (Exception e) {
                    WXLogUtils.e("[WXModalUIModule] alert param parse error ", e);
                }
            }
            if (TextUtils.isEmpty(message)) {
                message = "";
            }
            AlertDialog.Builder builder = new AlertDialog.Builder(this.mWXSDKInstance.getContext());
            builder.setMessage(message);
            final String okTitle_f = TextUtils.isEmpty(okTitle) ? OK : okTitle;
            builder.setPositiveButton(okTitle_f, new DialogInterface.OnClickListener() {
                /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass1 */

                public void onClick(DialogInterface dialog, int which) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(okTitle_f);
                    }
                }
            });
            AlertDialog alertDialog = builder.create();
            alertDialog.setCanceledOnTouchOutside(false);
            alertDialog.show();
            tracking(alertDialog);
            return;
        }
        WXLogUtils.e("[WXModalUIModule] when call alert mWXSDKInstance.getContext() must instanceof Activity");
    }

    @JSMethod(uiThread = true)
    public void confirm(JSONObject jsObj, final JSCallback callback) {
        if (this.mWXSDKInstance.getContext() instanceof Activity) {
            String message = "";
            String okTitle = OK;
            String cancelTitle = CANCEL;
            if (jsObj != null) {
                try {
                    message = jsObj.getString("message");
                    okTitle = jsObj.getString(OK_TITLE);
                    cancelTitle = jsObj.getString(CANCEL_TITLE);
                } catch (Exception e) {
                    WXLogUtils.e("[WXModalUIModule] confirm param parse error ", e);
                }
            }
            if (TextUtils.isEmpty(message)) {
                message = "";
            }
            AlertDialog.Builder builder = new AlertDialog.Builder(this.mWXSDKInstance.getContext());
            builder.setMessage(message);
            final String okTitleFinal = TextUtils.isEmpty(okTitle) ? OK : okTitle;
            final String cancelTitleFinal = TextUtils.isEmpty(cancelTitle) ? CANCEL : cancelTitle;
            builder.setPositiveButton(okTitleFinal, new DialogInterface.OnClickListener() {
                /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass2 */

                public void onClick(DialogInterface dialog, int which) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(okTitleFinal);
                    }
                }
            });
            builder.setNegativeButton(cancelTitleFinal, new DialogInterface.OnClickListener() {
                /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass3 */

                public void onClick(DialogInterface dialog, int which) {
                    JSCallback jSCallback = callback;
                    if (jSCallback != null) {
                        jSCallback.invoke(cancelTitleFinal);
                    }
                }
            });
            AlertDialog alertDialog = builder.create();
            alertDialog.setCanceledOnTouchOutside(false);
            alertDialog.show();
            tracking(alertDialog);
            return;
        }
        WXLogUtils.e("[WXModalUIModule] when call confirm mWXSDKInstance.getContext() must instanceof Activity");
    }

    @JSMethod(uiThread = true)
    public void prompt(JSONObject jsObj, final JSCallback callback) {
        if (this.mWXSDKInstance.getContext() instanceof Activity) {
            String message = "";
            String defaultValue = "";
            String okTitle = OK;
            String cancelTitle = CANCEL;
            if (jsObj != null) {
                try {
                    message = jsObj.getString("message");
                    okTitle = jsObj.getString(OK_TITLE);
                    cancelTitle = jsObj.getString(CANCEL_TITLE);
                    defaultValue = jsObj.getString("default");
                } catch (Exception e) {
                    WXLogUtils.e("[WXModalUIModule] confirm param parse error ", e);
                }
            }
            if (TextUtils.isEmpty(message)) {
                message = "";
            }
            AlertDialog.Builder builder = new AlertDialog.Builder(this.mWXSDKInstance.getContext());
            builder.setMessage(message);
            final EditText editText = new EditText(this.mWXSDKInstance.getContext());
            editText.setText(defaultValue);
            builder.setView(editText);
            final String okTitleFinal = TextUtils.isEmpty(okTitle) ? OK : okTitle;
            final String cancelTitleFinal = TextUtils.isEmpty(cancelTitle) ? CANCEL : cancelTitle;
            builder.setPositiveButton(okTitleFinal, new DialogInterface.OnClickListener() {
                /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass5 */

                public void onClick(DialogInterface dialog, int which) {
                    if (callback != null) {
                        Map<String, Object> result = new HashMap<>();
                        result.put("result", okTitleFinal);
                        result.put("data", editText.getText().toString());
                        callback.invoke(result);
                    }
                }
            }).setNegativeButton(cancelTitleFinal, new DialogInterface.OnClickListener() {
                /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass4 */

                public void onClick(DialogInterface dialog, int which) {
                    if (callback != null) {
                        Map<String, Object> result = new HashMap<>();
                        result.put("result", cancelTitleFinal);
                        result.put("data", editText.getText().toString());
                        callback.invoke(result);
                    }
                }
            });
            AlertDialog alertDialog = builder.create();
            alertDialog.setCanceledOnTouchOutside(false);
            alertDialog.show();
            tracking(alertDialog);
            return;
        }
        WXLogUtils.e("when call prompt mWXSDKInstance.getContext() must instanceof Activity");
    }

    private void tracking(Dialog dialog) {
        this.activeDialog = dialog;
        dialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
            /* class com.taobao.weex.ui.module.WXModalUIModule.AnonymousClass6 */

            public void onDismiss(DialogInterface dialog) {
                WXModalUIModule.this.activeDialog = null;
            }
        });
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        Dialog dialog = this.activeDialog;
        if (dialog != null && dialog.isShowing()) {
            this.activeDialog.dismiss();
        }
    }
}
