package com.taobao.weex.ui.module;

import android.os.Handler;
import android.os.Message;
import android.util.SparseArray;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXHashMap;
import com.taobao.weex.bridge.WXJSObject;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.utils.WXJsonUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.HashMap;

public class WXTimerModule extends WXModule implements Destroyable, Handler.Callback {
    private static final String TAG = "timer";
    private SparseArray<Integer> antiIntAutoBoxing = new SparseArray<>();
    private Handler handler = new Handler(WXBridgeManager.getInstance().getJSLooper(), this);

    @JSMethod(uiThread = false)
    public void setTimeout(int funcId, float delay) {
        if (this.mWXSDKInstance != null) {
            postOrHoldMessage(11, funcId, (int) delay, WXUtils.parseInt(this.mWXSDKInstance.getInstanceId()));
            if (this.mWXSDKInstance.getWXPerformance() != null) {
                this.mWXSDKInstance.getWXPerformance().timerInvokeCount++;
            }
            this.mWXSDKInstance.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_TIMER_NUM, 1.0d);
        }
    }

    @JSMethod(uiThread = false)
    public void setInterval(int funcId, float interval) {
        if (this.mWXSDKInstance != null) {
            postOrHoldMessage(12, funcId, (int) interval, WXUtils.parseInt(this.mWXSDKInstance.getInstanceId()));
            if (this.mWXSDKInstance.getWXPerformance() != null) {
                this.mWXSDKInstance.getWXPerformance().timerInvokeCount++;
            }
            this.mWXSDKInstance.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_TIMER_NUM, 1.0d);
        }
    }

    @JSMethod(uiThread = false)
    public void clearTimeout(int funcId) {
        if (funcId > 0) {
            removeOrHoldMessage(11, funcId);
        }
    }

    @JSMethod(uiThread = false)
    public void clearInterval(int funcId) {
        if (funcId > 0) {
            removeOrHoldMessage(12, funcId);
        }
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        if (this.handler != null) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d(TAG, "Timer Module removeAllMessages: ");
            }
            this.handler.removeCallbacksAndMessages(null);
            this.antiIntAutoBoxing.clear();
        }
    }

    public boolean handleMessage(Message msg) {
        if (msg == null) {
            return false;
        }
        int what = msg.what;
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d(TAG, "Timer Module handleMessage : " + msg.what);
        }
        if (what != 11) {
            if (what != 12 || msg.obj == null) {
                return false;
            }
            checkIfTimerInBack(msg.arg1);
            postMessage(12, ((Integer) msg.obj).intValue(), msg.arg2, msg.arg1);
            WXBridgeManager.getInstance().invokeExecJS(String.valueOf(msg.arg1), null, WXBridgeManager.METHOD_CALL_JS, createTimerArgs(msg.arg1, ((Integer) msg.obj).intValue(), true), true);
            return true;
        } else if (msg.obj == null) {
            return false;
        } else {
            checkIfTimerInBack(msg.arg1);
            WXBridgeManager.getInstance().invokeExecJS(String.valueOf(msg.arg1), null, WXBridgeManager.METHOD_CALL_JS, createTimerArgs(msg.arg1, ((Integer) msg.obj).intValue(), false), true);
            return true;
        }
    }

    private void checkIfTimerInBack(int instanceId) {
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(String.valueOf(instanceId));
        if (instance != null && instance.isViewDisAppear()) {
            instance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_TIMER_BACK_NUM, 1.0d);
        }
    }

    /* access modifiers changed from: package-private */
    public void setHandler(Handler handler2) {
        this.handler = handler2;
    }

    private WXJSObject[] createTimerArgs(int instanceId, int funcId, boolean keepAlive) {
        ArrayList<Object> argsList = new ArrayList<>();
        argsList.add(Integer.valueOf(funcId));
        argsList.add(new HashMap());
        argsList.add(Boolean.valueOf(keepAlive));
        WXHashMap<String, Object> task = new WXHashMap<>();
        task.put("method", WXBridgeManager.METHOD_CALLBACK);
        task.put("args", argsList);
        return new WXJSObject[]{new WXJSObject(2, String.valueOf(instanceId)), new WXJSObject(3, WXJsonUtils.fromObjectToJSONString(new Object[]{task}))};
    }

    private void postOrHoldMessage(int what, int funcId, int interval, int instanceId) {
        if (this.mWXSDKInstance.isPreRenderMode()) {
            postMessage(what, funcId, interval, instanceId);
        } else {
            postMessage(what, funcId, interval, instanceId);
        }
    }

    private void removeOrHoldMessage(int what, int funcId) {
        if (this.mWXSDKInstance.isPreRenderMode()) {
            this.handler.removeMessages(what, this.antiIntAutoBoxing.get(funcId, Integer.valueOf(funcId)));
        } else {
            this.handler.removeMessages(what, this.antiIntAutoBoxing.get(funcId, Integer.valueOf(funcId)));
        }
    }

    private void postMessage(int what, int funcId, int interval, int instanceId) {
        if (interval < 0 || funcId <= 0) {
            WXLogUtils.e(TAG, "interval < 0 or funcId <=0");
            return;
        }
        if (this.antiIntAutoBoxing.get(funcId) == null) {
            this.antiIntAutoBoxing.put(funcId, Integer.valueOf(funcId));
        }
        this.handler.sendMessageDelayed(this.handler.obtainMessage(what, instanceId, interval, this.antiIntAutoBoxing.get(funcId)), (long) interval);
    }
}
