package com.taobao.weex.ui.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.FrameLayout;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXViewUtils;

public class WXBaseCircleIndicator extends FrameLayout implements WXGestureObservable {
    private float circlePadding;
    private int fillColor = -12303292;
    private WXCircleViewPager mCircleViewPager;
    private ViewPager.OnPageChangeListener mListener;
    private final Paint mPaintFill = new Paint();
    private final Paint mPaintPage = new Paint();
    private int pageColor = -3355444;
    private float radius;
    private int realCurrentItem;
    private WXGesture wxGesture;

    public WXBaseCircleIndicator(Context context) {
        super(context);
        init();
    }

    private void init() {
        this.radius = (float) WXViewUtils.dip2px(5.0f);
        this.circlePadding = (float) WXViewUtils.dip2px(5.0f);
        this.pageColor = -3355444;
        this.fillColor = -12303292;
        this.mPaintFill.setStyle(Paint.Style.FILL);
        this.mPaintFill.setAntiAlias(true);
        this.mPaintPage.setAntiAlias(true);
        this.mPaintPage.setColor(this.pageColor);
        this.mPaintFill.setStyle(Paint.Style.FILL);
        this.mPaintFill.setColor(this.fillColor);
        setWillNotDraw(false);
    }

    public WXBaseCircleIndicator(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    public void setCircleViewPager(WXCircleViewPager viewPager) {
        this.mCircleViewPager = viewPager;
        if (viewPager != null) {
            if (this.mListener == null) {
                this.mListener = new ViewPager.SimpleOnPageChangeListener() {
                    /* class com.taobao.weex.ui.view.WXBaseCircleIndicator.AnonymousClass1 */

                    @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener, androidx.viewpager.widget.ViewPager.SimpleOnPageChangeListener
                    public void onPageSelected(int position) {
                        WXBaseCircleIndicator wXBaseCircleIndicator = WXBaseCircleIndicator.this;
                        wXBaseCircleIndicator.realCurrentItem = wXBaseCircleIndicator.mCircleViewPager.getRealCurrentItem();
                        WXBaseCircleIndicator.this.invalidate();
                    }
                };
            }
            this.mCircleViewPager.addOnPageChangeListener(this.mListener);
            int realCurrentItem2 = this.mCircleViewPager.getRealCurrentItem();
            this.realCurrentItem = realCurrentItem2;
            if (realCurrentItem2 < 0) {
                this.realCurrentItem = 0;
            }
        }
        requestLayout();
    }

    public void setRadius(float radius2) {
        this.radius = radius2;
    }

    public void setFillColor(int fillColor2) {
        this.fillColor = fillColor2;
        this.mPaintFill.setColor(fillColor2);
    }

    public void setPageColor(int pageColor2) {
        this.pageColor = pageColor2;
        this.mPaintPage.setColor(pageColor2);
    }

    public int getRealCurrentItem() {
        return this.realCurrentItem;
    }

    public void setRealCurrentItem(int realCurrentItem2) {
        this.realCurrentItem = realCurrentItem2;
        invalidate();
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public boolean dispatchTouchEvent(MotionEvent event) {
        boolean result = super.dispatchTouchEvent(event);
        WXGesture wXGesture = this.wxGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, event);
        }
        return result;
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        float dotWidth = (this.circlePadding + this.radius) * 2.0f;
        float firstCenterX = ((float) (getWidth() / 2)) - ((((float) (getCount() - 1)) * dotWidth) / 2.0f);
        float firstCenterY = (float) ((getHeight() / 2) + getPaddingTop());
        for (int i = 0; i < getCount(); i++) {
            float dx = (((float) i) * dotWidth) + firstCenterX;
            if (i != this.realCurrentItem) {
                canvas.drawCircle(dx, firstCenterY, this.radius, this.mPaintPage);
            } else {
                canvas.drawCircle(dx, firstCenterY, this.radius, this.mPaintFill);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        int viewWidth;
        int viewHeight;
        int widthMode = View.MeasureSpec.getMode(widthMeasureSpec);
        int widthSize = View.MeasureSpec.getSize(widthMeasureSpec);
        int heightMode = View.MeasureSpec.getMode(heightMeasureSpec);
        int heightSize = View.MeasureSpec.getSize(heightMeasureSpec);
        if (widthMode == 1073741824) {
            viewWidth = widthSize;
        } else {
            viewWidth = ((int) (((float) getPaddingLeft()) + (this.radius * 2.0f * ((float) getCount())) + (this.circlePadding * ((float) (getCount() - 1))) + ((float) getPaddingRight()))) + 1;
        }
        if (heightMode == 1073741824) {
            viewHeight = heightSize;
        } else {
            viewHeight = ((int) (((float) getPaddingTop()) + (this.radius * 2.0f) + ((float) getPaddingBottom()))) + 1;
        }
        setMeasuredDimension(viewWidth, viewHeight);
    }

    public int getCount() {
        WXCircleViewPager wXCircleViewPager = this.mCircleViewPager;
        if (wXCircleViewPager == null || wXCircleViewPager.getAdapter() == null) {
            return 0;
        }
        return this.mCircleViewPager.getRealCount();
    }
}
