package com.taobao.weex.ui.view;

import android.view.View;
import android.view.ViewGroup;
import androidx.viewpager.widget.PagerAdapter;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public class WXCirclePageAdapter extends PagerAdapter {
    public boolean isRTL;
    private boolean needLoop;
    private List<View> originalViews;
    private List<View> shadow;
    private List<View> views;

    public WXCirclePageAdapter(List<View> views2, boolean needLoop2) {
        this.views = new ArrayList();
        this.shadow = new ArrayList();
        this.needLoop = true;
        this.isRTL = false;
        this.originalViews = new ArrayList();
        this.views = new ArrayList(views2);
        this.originalViews = new ArrayList(views2);
        this.needLoop = needLoop2;
    }

    public void setLayoutDirectionRTL(boolean isRTL2) {
        if (isRTL2 != this.isRTL) {
            this.isRTL = isRTL2;
            ArrayList arrayList = new ArrayList(this.originalViews);
            this.views = arrayList;
            if (isRTL2) {
                Collections.reverse(arrayList);
            }
            ensureShadow();
        }
    }

    public WXCirclePageAdapter() {
        this(true);
    }

    public WXCirclePageAdapter(boolean needLoop2) {
        this.views = new ArrayList();
        this.shadow = new ArrayList();
        this.needLoop = true;
        this.isRTL = false;
        this.originalViews = new ArrayList();
        this.needLoop = needLoop2;
    }

    public void addPageView(View view) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> addPageView");
        }
        this.originalViews.add(view);
        if (this.isRTL) {
            this.views.add(0, view);
        } else {
            this.views.add(view);
        }
        ensureShadow();
    }

    public void removePageView(View view) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> removePageView");
        }
        this.views.remove(view);
        this.originalViews.remove(view);
        ensureShadow();
    }

    public void replacePageView(View oldView, View newView) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> replacePageView");
        }
        int index = this.views.indexOf(oldView);
        this.views.remove(index);
        this.views.add(index, newView);
        ensureShadow();
        int index2 = this.originalViews.indexOf(oldView);
        this.originalViews.remove(index2);
        this.originalViews.add(index2, newView);
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public int getCount() {
        return this.shadow.size();
    }

    public int getRealCount() {
        return this.views.size();
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public Object instantiateItem(ViewGroup container, int position) {
        View pageView = null;
        try {
            pageView = this.shadow.get(position);
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("onPageSelected >>>> instantiateItem >>>>> position:" + position + ",position % getRealCount()" + (position % getRealCount()));
            }
            if (pageView.getParent() == null) {
                container.addView(pageView);
            } else {
                ((ViewGroup) pageView.getParent()).removeView(pageView);
                container.addView(pageView);
            }
        } catch (Exception e) {
            WXLogUtils.e("[CirclePageAdapter] instantiateItem: ", e);
        }
        return pageView;
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public void destroyItem(ViewGroup container, int position, Object object) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> destroyItem >>>>> position:" + position);
        }
        if (!this.needLoop) {
            container.removeView((View) object);
        }
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public boolean isViewFromObject(View view, Object object) {
        return view == object;
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public int getItemPosition(Object object) {
        return -2;
    }

    public int getPagePosition(View page) {
        return this.views.indexOf(page);
    }

    public int getItemIndex(Object object) {
        if (object instanceof View) {
            return this.views.indexOf(object);
        }
        return -1;
    }

    public List<View> getViews() {
        return this.views;
    }

    private void ensureShadow() {
        List<View> temp = new ArrayList<>();
        if (!this.needLoop || this.views.size() <= 2) {
            temp.addAll(this.views);
        } else {
            List<View> list = this.views;
            temp.add(0, list.get(list.size() - 1));
            for (View view : this.views) {
                if (view.getParent() != null) {
                    ((ViewGroup) view.getParent()).removeView(view);
                }
                temp.add(view);
            }
            temp.add(this.views.get(0));
        }
        this.shadow.clear();
        notifyDataSetChanged();
        this.shadow.addAll(temp);
        notifyDataSetChanged();
    }

    public int getRealPosition(int shadowPosition) {
        if (shadowPosition < 0 || shadowPosition >= this.shadow.size()) {
            return -1;
        }
        return getItemIndex(this.shadow.get(shadowPosition));
    }

    public int getFirst() {
        if (!this.needLoop || this.views.size() <= 2) {
            return 0;
        }
        return 1;
    }
}
