package com.taobao.weex.ui.view;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.animation.Interpolator;
import androidx.viewpager.widget.ViewPager;
import com.alipay.sdk.m.u.b;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXLogUtils;
import java.lang.reflect.Field;

public class WXCircleViewPager extends ViewPager implements WXGestureObservable {
    private final int SCROLL_TO_NEXT = 1;
    private long intervalTime = b.a;
    private boolean isAutoScroll;
    private Handler mAutoScrollHandler = new Handler(Looper.getMainLooper()) {
        /* class com.taobao.weex.ui.view.WXCircleViewPager.AnonymousClass1 */

        public void handleMessage(Message msg) {
            if (msg.what == 1) {
                WXLogUtils.d("[CircleViewPager] trigger auto play action");
                WXCircleViewPager.this.showNextItem();
                sendEmptyMessageDelayed(1, WXCircleViewPager.this.intervalTime);
                return;
            }
            super.handleMessage(msg);
        }
    };
    private WXSmoothScroller mScroller;
    private int mState = 0;
    private boolean needLoop = true;
    private boolean scrollable = true;
    private WXGesture wxGesture;

    public WXCircleViewPager(Context context) {
        super(context);
        init();
    }

    private void init() {
        setOverScrollMode(2);
        addOnPageChangeListener(new ViewPager.OnPageChangeListener() {
            /* class com.taobao.weex.ui.view.WXCircleViewPager.AnonymousClass2 */

            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
            }

            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageSelected(int position) {
            }

            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageScrollStateChanged(int state) {
                WXCircleViewPager.this.mState = state;
                WXCirclePageAdapter adapter = WXCircleViewPager.this.getCirclePageAdapter();
                int currentItemInternal = WXCircleViewPager.super.getCurrentItem();
                if (WXCircleViewPager.this.needLoop && state == 0 && adapter.getCount() > 1) {
                    if (currentItemInternal == adapter.getCount() - 1) {
                        WXCircleViewPager.this.superSetCurrentItem(1, false);
                        adapter.getViews().get(0).setTranslationY(0.0f);
                        adapter.getViews().get(0).setTranslationX(0.0f);
                    } else if (currentItemInternal == 0) {
                        WXCircleViewPager.this.superSetCurrentItem(adapter.getCount() - 2, false);
                        try {
                            adapter.getViews().get((adapter.getCount() - 2) - 1).setTranslationY(0.0f);
                            adapter.getViews().get((adapter.getCount() - 2) - 1).setTranslationX(0.0f);
                        } catch (Exception e) {
                        }
                    }
                }
            }
        });
        postInitViewPager();
    }

    private void postInitViewPager() {
        if (!isInEditMode()) {
            try {
                Field scroller = ViewPager.class.getDeclaredField("mScroller");
                scroller.setAccessible(true);
                Field interpolator = ViewPager.class.getDeclaredField("sInterpolator");
                interpolator.setAccessible(true);
                WXSmoothScroller wXSmoothScroller = new WXSmoothScroller(getContext(), (Interpolator) interpolator.get(null));
                this.mScroller = wXSmoothScroller;
                scroller.set(this, wXSmoothScroller);
            } catch (Exception e) {
                WXLogUtils.e("[CircleViewPager] postInitViewPager: ", e);
            }
        }
    }

    public WXSmoothScroller getmScroller() {
        return this.mScroller;
    }

    public WXCircleViewPager(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    @Override // androidx.viewpager.widget.ViewPager
    public int getCurrentItem() {
        return getRealCurrentItem();
    }

    public int superGetCurrentItem() {
        return super.getCurrentItem();
    }

    @Override // androidx.viewpager.widget.ViewPager
    public boolean onInterceptTouchEvent(MotionEvent ev) {
        try {
            return this.scrollable && super.onInterceptTouchEvent(ev);
        } catch (IllegalArgumentException e) {
            e.printStackTrace();
            return false;
        } catch (ArrayIndexOutOfBoundsException e2) {
            e2.printStackTrace();
            return false;
        }
    }

    @Override // androidx.viewpager.widget.ViewPager
    public boolean onTouchEvent(MotionEvent ev) {
        if (!this.scrollable) {
            return true;
        }
        return super.onTouchEvent(ev);
    }

    public void scrollTo(int x, int y) {
        if (this.scrollable || this.mState != 1) {
            super.scrollTo(x, y);
        }
    }

    public void startAutoScroll() {
        this.isAutoScroll = true;
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
        this.mAutoScrollHandler.sendEmptyMessageDelayed(1, this.intervalTime);
    }

    public void pauseAutoScroll() {
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    public void stopAutoScroll() {
        this.isAutoScroll = false;
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    public boolean isAutoScroll() {
        return this.isAutoScroll;
    }

    @Override // androidx.viewpager.widget.ViewPager
    public void setCurrentItem(int item) {
        setRealCurrentItem(item, true);
    }

    @Override // androidx.viewpager.widget.ViewPager
    public void setCurrentItem(int item, boolean smooth) {
        setRealCurrentItem(item, smooth);
    }

    public WXCirclePageAdapter getCirclePageAdapter() {
        return (WXCirclePageAdapter) getAdapter();
    }

    public void setCirclePageAdapter(WXCirclePageAdapter circlePageAdapter) {
        setAdapter(circlePageAdapter);
    }

    public long getIntervalTime() {
        return this.intervalTime;
    }

    public void setIntervalTime(long intervalTime2) {
        this.intervalTime = intervalTime2;
    }

    public void setCircle(boolean circle) {
        this.needLoop = circle;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:7:0x000d, code lost:
        if (r0 != 3) goto L_0x0025;
     */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x002d A[Catch:{ Exception -> 0x0035 }] */
    /* JADX WARNING: Removed duplicated region for block: B:20:? A[RETURN, SYNTHETIC] */
    public boolean dispatchTouchEvent(MotionEvent ev) {
        int action = ev.getAction();
        if (action != 0) {
            if (action != 1) {
                if (action != 2) {
                }
            }
            if (isAutoScroll()) {
                this.mAutoScrollHandler.sendEmptyMessageDelayed(1, this.intervalTime);
            }
            boolean result = super.dispatchTouchEvent(ev);
            if (this.wxGesture == null) {
                return result | this.wxGesture.onTouch(this, ev);
            }
            return result;
        }
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
        try {
            boolean result2 = super.dispatchTouchEvent(ev);
            if (this.wxGesture == null) {
            }
        } catch (Exception e) {
            return false;
        }
    }

    public void destory() {
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public int getRealCurrentItem() {
        return ((WXCirclePageAdapter) getAdapter()).getRealPosition(super.getCurrentItem());
    }

    private void setRealCurrentItem(int item, boolean smooth) {
        superSetCurrentItem(((WXCirclePageAdapter) getAdapter()).getFirst() + item, smooth);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void superSetCurrentItem(int item, boolean smooth) {
        try {
            if (Math.abs(item - getRealCurrentItem()) > 3 && this.needLoop && getRealCount() > 2 && item == getCirclePageAdapter().getCount() - 2) {
                super.setCurrentItem(item - 2, false);
            }
        } catch (Exception e) {
        }
        try {
            super.setCurrentItem(item, smooth);
        } catch (IllegalStateException e2) {
            WXLogUtils.e(e2.toString());
            if (getAdapter() != null) {
                getAdapter().notifyDataSetChanged();
                super.setCurrentItem(item, smooth);
            }
        }
    }

    public int getRealCount() {
        return ((WXCirclePageAdapter) getAdapter()).getRealCount();
    }

    /* access modifiers changed from: protected */
    @Override // androidx.viewpager.widget.ViewPager
    public void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        try {
            super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        } catch (IllegalStateException e) {
            WXLogUtils.e(e.toString());
            if (getAdapter() != null) {
                getAdapter().notifyDataSetChanged();
                super.onMeasure(widthMeasureSpec, heightMeasureSpec);
            }
        }
    }

    public boolean isScrollable() {
        return this.scrollable;
    }

    public void setScrollable(boolean scrollable2) {
        this.scrollable = scrollable2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showNextItem() {
        if (getCirclePageAdapter() == null || !getCirclePageAdapter().isRTL) {
            if (!this.needLoop && superGetCurrentItem() == getRealCount() - 1) {
                return;
            }
            if (getRealCount() == 2 && superGetCurrentItem() == 1) {
                superSetCurrentItem(0, true);
            } else {
                superSetCurrentItem(superGetCurrentItem() + 1, true);
            }
        } else if (!this.needLoop && superGetCurrentItem() == 0) {
        } else {
            if (getRealCount() == 2 && superGetCurrentItem() == 0) {
                superSetCurrentItem(1, true);
            } else {
                superSetCurrentItem(superGetCurrentItem() - 1, true);
            }
        }
    }
}
