package com.taobao.weex.ui.view;

import android.content.Context;
import android.graphics.Canvas;
import android.view.MotionEvent;
import android.view.View;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXDiv;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.adapter.util.PlatformUtil;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Map;

public class WXFrameLayout extends BaseFrameLayout implements WXGestureObservable, IRenderStatus<WXDiv>, IRenderResult<WXDiv> {
    private long downTimeMillis;
    private float downX;
    private float downY;
    private Object mOnTouchListener;
    private WeakReference<WXDiv> mWeakReference;
    private float moveX;
    private float moveY;
    private WXGesture wxGesture;

    public WXFrameLayout(Context context) {
        super(context);
    }

    @Override // com.taobao.weex.ui.view.IRenderResult
    public WXDiv getComponent() {
        WeakReference<WXDiv> weakReference = this.mWeakReference;
        if (weakReference != null) {
            return weakReference.get();
        }
        return null;
    }

    public void holdComponent(WXDiv component) {
        this.mWeakReference = new WeakReference<>(component);
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public boolean dispatchTouchEvent(MotionEvent event) {
        boolean result = super.dispatchTouchEvent(event);
        WXGesture wXGesture = this.wxGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, event);
        }
        return result;
    }

    public boolean onInterceptTouchEvent(MotionEvent event) {
        Object obj = this.mOnTouchListener;
        if (obj != null) {
            PlatformUtil.invokeMethod(obj.getClass().getName(), "onTouch", this.mOnTouchListener, new Class[]{View.class, MotionEvent.class}, new Object[]{this, event});
            int action = event.getAction();
            if (action == 0) {
                this.downTimeMillis = System.currentTimeMillis();
                this.downX = event.getRawX();
            } else if (action == 1 || action == 2 || action == 3) {
                this.moveX = event.getRawX();
            }
            if (Math.abs(this.moveX - this.downX) > 30.0f && System.currentTimeMillis() - this.downTimeMillis > 200) {
                return true;
            }
        }
        return super.onInterceptTouchEvent(event);
    }

    private void addPan(Object listener) {
        this.mOnTouchListener = listener;
    }

    private void removePan() {
        this.mOnTouchListener = null;
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.view.BaseFrameLayout
    public void dispatchDraw(Canvas canvas) {
        WXSDKInstance instance;
        try {
            super.dispatchDrawInterval(canvas);
        } catch (Throwable e) {
            if (getComponent() != null) {
                notifyLayerOverFlow();
                if (!(getComponent() == null || (instance = WXSDKManager.getInstance().getSDKInstance(getComponent().getInstanceId())) == null || instance.getApmForInstance() == null || instance.getApmForInstance().hasReportLayerOverDraw)) {
                    instance.getApmForInstance().hasReportLayerOverDraw = true;
                    reportLayerOverFlowError();
                }
            }
            WXLogUtils.e("Layer overflow limit error", WXLogUtils.getStackTrace(e));
        }
    }

    private int reportLayerOverFlowError() {
        int deep = calLayerDeep(this, 0);
        if (getComponent() != null) {
            String instanceId = getComponent().getInstanceId();
            WXErrorCode wXErrorCode = WXErrorCode.WX_RENDER_ERR_LAYER_OVERFLOW;
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "draw android view", WXErrorCode.WX_RENDER_ERR_LAYER_OVERFLOW.getErrorMsg() + "Layer overflow limit error: " + deep + " layers!", null);
        }
        return deep;
    }

    private int calLayerDeep(View view, int deep) {
        int deep2 = deep + 1;
        if (view.getParent() == null || !(view.getParent() instanceof View)) {
            return deep2;
        }
        return calLayerDeep((View) view.getParent(), deep2);
    }

    public void notifyLayerOverFlow() {
        WXSDKInstance instance;
        if (!(getComponent() == null || (instance = getComponent().getInstance()) == null || instance.getLayerOverFlowListeners() == null)) {
            for (String ref : instance.getLayerOverFlowListeners()) {
                WXComponent component = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(instance.getInstanceId(), ref);
                Map<String, Object> params = new HashMap<>();
                params.put("ref", ref);
                params.put(Constants.Weex.INSTANCEID, component.getInstanceId());
                component.fireEvent(Constants.Event.LAYEROVERFLOW, params);
            }
        }
    }
}
