package com.taobao.weex.ui.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.os.Handler;
import android.os.Message;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.ScrollView;
import androidx.core.view.NestedScrollingChild;
import androidx.core.view.NestedScrollingChildHelper;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.component.WXBaseScroller;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public class WXScrollView extends ScrollView implements Handler.Callback, IWXScroller, WXGestureObservable, NestedScrollingChild {
    private NestedScrollingChildHelper childHelper;
    private int[] consumed;
    private int mCheckTime;
    private View mCurrentStickyView;
    private boolean mHasNotDoneActionDown;
    private int mInitialPosition;
    private boolean mRedirectTouchToStickyView;
    private Rect mScrollRect;
    private List<WXScrollViewListener> mScrollViewListeners;
    int mScrollX;
    int mScrollY;
    private Handler mScrollerTask;
    private int mStickyOffset;
    private int[] mStickyP;
    private WXBaseScroller mWAScroller;
    private int[] offsetInWindow;
    private float ox;
    private float oy;
    private boolean scrollable;
    private int[] stickyScrollerP;
    private int[] stickyViewP;
    private WXGesture wxGesture;

    public interface WXScrollViewListener {
        void onScroll(WXScrollView wXScrollView, int i, int i2);

        void onScrollChanged(WXScrollView wXScrollView, int i, int i2, int i3, int i4);

        void onScrollStopped(WXScrollView wXScrollView, int i, int i2);

        void onScrollToBottom(WXScrollView wXScrollView, int i, int i2);
    }

    public WXScrollView(Context context) {
        super(context);
        this.consumed = new int[2];
        this.offsetInWindow = new int[2];
        this.mHasNotDoneActionDown = true;
        this.mCheckTime = 100;
        this.mStickyP = new int[2];
        this.stickyScrollerP = new int[2];
        this.stickyViewP = new int[2];
        this.scrollable = true;
        this.mScrollViewListeners = new ArrayList();
        init();
        try {
            WXReflectionUtils.setValue(this, "mMinimumVelocity", 5);
        } catch (Exception e) {
            WXLogUtils.e("[WXScrollView] WXScrollView: ", e);
        }
    }

    private void init() {
        setWillNotDraw(false);
        startScrollerTask();
        setOverScrollMode(2);
        NestedScrollingChildHelper nestedScrollingChildHelper = new NestedScrollingChildHelper(this);
        this.childHelper = nestedScrollingChildHelper;
        nestedScrollingChildHelper.setNestedScrollingEnabled(true);
    }

    public void startScrollerTask() {
        if (this.mScrollerTask == null) {
            this.mScrollerTask = new Handler(WXThread.secure(this));
        }
        this.mInitialPosition = getScrollY();
        this.mScrollerTask.sendEmptyMessageDelayed(0, (long) this.mCheckTime);
    }

    public WXScrollView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.consumed = new int[2];
        this.offsetInWindow = new int[2];
        this.mHasNotDoneActionDown = true;
        this.mCheckTime = 100;
        this.mStickyP = new int[2];
        this.stickyScrollerP = new int[2];
        this.stickyViewP = new int[2];
        this.scrollable = true;
        init();
    }

    public WXScrollView(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        this.consumed = new int[2];
        this.offsetInWindow = new int[2];
        this.mHasNotDoneActionDown = true;
        this.mCheckTime = 100;
        this.mStickyP = new int[2];
        this.stickyScrollerP = new int[2];
        this.stickyViewP = new int[2];
        this.scrollable = true;
        setOverScrollMode(2);
    }

    public void addScrollViewListener(WXScrollViewListener scrollViewListener) {
        if (!this.mScrollViewListeners.contains(scrollViewListener)) {
            this.mScrollViewListeners.add(scrollViewListener);
        }
    }

    public void removeScrollViewListener(WXScrollViewListener scrollViewListener) {
        this.mScrollViewListeners.remove(scrollViewListener);
    }

    public boolean dispatchTouchEvent(MotionEvent ev) {
        if (ev.getAction() == 0) {
            this.mRedirectTouchToStickyView = true;
        }
        if (this.mRedirectTouchToStickyView) {
            boolean z = false;
            boolean z2 = this.mCurrentStickyView != null;
            this.mRedirectTouchToStickyView = z2;
            if (z2) {
                if (ev.getY() <= ((float) this.mCurrentStickyView.getHeight()) && ev.getX() >= ((float) this.mCurrentStickyView.getLeft()) && ev.getX() <= ((float) this.mCurrentStickyView.getRight())) {
                    z = true;
                }
                this.mRedirectTouchToStickyView = z;
            }
        }
        if (this.mRedirectTouchToStickyView) {
            if (this.mScrollRect == null) {
                Rect rect = new Rect();
                this.mScrollRect = rect;
                getGlobalVisibleRect(rect);
            }
            this.mCurrentStickyView.getLocationOnScreen(this.stickyViewP);
            ev.offsetLocation(0.0f, (float) (this.stickyViewP[1] - this.mScrollRect.top));
        }
        boolean result = super.dispatchTouchEvent(ev);
        WXGesture wXGesture = this.wxGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, ev);
        }
        return result;
    }

    /* access modifiers changed from: protected */
    public void dispatchDraw(Canvas canvas) {
        super.dispatchDraw(canvas);
        if (this.mCurrentStickyView != null) {
            canvas.save();
            this.mCurrentStickyView.getLocationOnScreen(this.mStickyP);
            int realOffset = this.mStickyOffset;
            if (realOffset > 0) {
                realOffset = 0;
            }
            canvas.translate((float) this.mStickyP[0], (float) (getScrollY() + realOffset));
            canvas.clipRect(0, realOffset, this.mCurrentStickyView.getWidth(), this.mCurrentStickyView.getHeight());
            this.mCurrentStickyView.draw(canvas);
            canvas.restore();
        }
    }

    public boolean onTouchEvent(MotionEvent ev) {
        if (!this.scrollable) {
            return true;
        }
        if (this.mRedirectTouchToStickyView) {
            if (this.mScrollRect == null) {
                Rect rect = new Rect();
                this.mScrollRect = rect;
                getGlobalVisibleRect(rect);
            }
            this.mCurrentStickyView.getLocationOnScreen(this.stickyViewP);
            ev.offsetLocation(0.0f, (float) (-(this.stickyViewP[1] - this.mScrollRect.top)));
        }
        if (ev.getAction() == 0) {
            this.mHasNotDoneActionDown = false;
        }
        if (this.mHasNotDoneActionDown) {
            MotionEvent down = MotionEvent.obtain(ev);
            down.setAction(0);
            this.mHasNotDoneActionDown = false;
            down.recycle();
        }
        if (ev.getAction() == 0) {
            this.ox = ev.getX();
            this.oy = ev.getY();
            startNestedScroll(3);
        }
        if (ev.getAction() == 1 || ev.getAction() == 3) {
            this.mHasNotDoneActionDown = true;
            stopNestedScroll();
        }
        if (ev.getAction() == 2) {
            float clampedX = ev.getX();
            float clampedY = ev.getY();
            if (dispatchNestedPreScroll((int) (this.ox - clampedX), (int) (this.oy - clampedY), this.consumed, this.offsetInWindow)) {
                int[] iArr = this.consumed;
                ev.setLocation(((float) iArr[0]) + clampedX, ((float) iArr[1]) + clampedY);
            }
            this.ox = ev.getX();
            this.oy = ev.getY();
        }
        return super.onTouchEvent(ev);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public void setNestedScrollingEnabled(boolean enabled) {
        this.childHelper.setNestedScrollingEnabled(enabled);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean isNestedScrollingEnabled() {
        return this.childHelper.isNestedScrollingEnabled();
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean startNestedScroll(int axes) {
        return this.childHelper.startNestedScroll(axes);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public void stopNestedScroll() {
        this.childHelper.stopNestedScroll();
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean hasNestedScrollingParent() {
        return this.childHelper.hasNestedScrollingParent();
    }

    public boolean isScrollable() {
        return this.scrollable;
    }

    public void setScrollable(boolean scrollable2) {
        this.scrollable = scrollable2;
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedScroll(int dxConsumed, int dyConsumed, int dxUnconsumed, int dyUnconsumed, int[] offsetInWindow2) {
        return this.childHelper.dispatchNestedScroll(dxConsumed, dyConsumed, dxUnconsumed, dyUnconsumed, offsetInWindow2);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedPreScroll(int dx, int dy, int[] consumed2, int[] offsetInWindow2) {
        return this.childHelper.dispatchNestedPreScroll(dx, dy, consumed2, offsetInWindow2);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedFling(float velocityX, float velocityY, boolean consumed2) {
        return this.childHelper.dispatchNestedFling(velocityX, velocityY, consumed2);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedPreFling(float velocityX, float velocityY) {
        return this.childHelper.dispatchNestedPreFling(velocityX, velocityY);
    }

    public boolean onNestedPreFling(View target, float velocityX, float velocityY) {
        return dispatchNestedPreFling(velocityX, velocityY);
    }

    public boolean onNestedFling(View target, float velocityX, float velocityY, boolean consumed2) {
        return dispatchNestedFling(velocityX, velocityY, consumed2);
    }

    public void fling(int velocityY) {
        super.fling(velocityY);
        Handler handler = this.mScrollerTask;
        if (handler != null) {
            handler.removeMessages(0);
        }
        startScrollerTask();
    }

    /* access modifiers changed from: protected */
    public void onScrollChanged(int x, int y, int oldx, int oldy) {
        this.mScrollX = getScrollX();
        int scrollY = getScrollY();
        this.mScrollY = scrollY;
        onScroll(this, this.mScrollX, scrollY);
        View view = getChildAt(getChildCount() - 1);
        if (view != null) {
            int d = view.getBottom();
            int height = getHeight();
            int i = this.mScrollY;
            if (d - (height + i) == 0) {
                onScrollToBottom(this.mScrollX, i);
            }
            List<WXScrollViewListener> list = this.mScrollViewListeners;
            int count = list == null ? 0 : list.size();
            for (int i2 = 0; i2 < count; i2++) {
                this.mScrollViewListeners.get(i2).onScrollChanged(this, x, y, oldx, oldy);
            }
            showStickyView();
        }
    }

    /* access modifiers changed from: protected */
    public void onScroll(WXScrollView scrollView, int x, int y) {
        List<WXScrollViewListener> list = this.mScrollViewListeners;
        int count = list == null ? 0 : list.size();
        for (int i = 0; i < count; i++) {
            this.mScrollViewListeners.get(i).onScroll(this, x, y);
        }
    }

    /* access modifiers changed from: protected */
    public void onScrollToBottom(int x, int y) {
        List<WXScrollViewListener> list = this.mScrollViewListeners;
        int count = list == null ? 0 : list.size();
        for (int i = 0; i < count; i++) {
            this.mScrollViewListeners.get(i).onScrollToBottom(this, x, y);
        }
    }

    private void showStickyView() {
        WXBaseScroller wXBaseScroller = this.mWAScroller;
        if (wXBaseScroller != null) {
            View curStickyView = procSticky(wXBaseScroller.getStickMap());
            if (curStickyView != null) {
                this.mCurrentStickyView = curStickyView;
            } else {
                this.mCurrentStickyView = null;
            }
        }
    }

    private View procSticky(Map<String, Map<String, WXComponent>> mStickyMap) {
        Map<String, WXComponent> stickyMap;
        if (mStickyMap == null || (stickyMap = mStickyMap.get(this.mWAScroller.getRef())) == null) {
            return null;
        }
        for (Map.Entry<String, WXComponent> entry : stickyMap.entrySet()) {
            WXComponent stickyData = entry.getValue();
            getLocationOnScreen(this.stickyScrollerP);
            stickyData.getHostView().getLocationOnScreen(this.stickyViewP);
            int parentH = 0;
            if (!(stickyData.getParent() == null || stickyData.getParent().getRealView() == null)) {
                parentH = stickyData.getParent().getRealView().getHeight();
            }
            int stickyViewH = stickyData.getHostView().getHeight();
            int[] iArr = this.stickyScrollerP;
            int stickyShowPos = iArr[1];
            int stickyStartHidePos = (-parentH) + iArr[1] + stickyViewH;
            int[] iArr2 = this.stickyViewP;
            if (iArr2[1] > stickyShowPos || iArr2[1] < stickyStartHidePos - stickyViewH) {
                stickyData.setStickyOffset(0);
            } else {
                this.mStickyOffset = iArr2[1] - stickyStartHidePos;
                stickyData.setStickyOffset(iArr2[1] - iArr[1]);
                return stickyData.getHostView();
            }
        }
        return null;
    }

    public boolean handleMessage(Message msg) {
        if (msg.what != 0) {
            return true;
        }
        Handler handler = this.mScrollerTask;
        if (handler != null) {
            handler.removeMessages(0);
        }
        if (this.mInitialPosition - getScrollY() == 0) {
            onScrollStopped(this, getScrollX(), getScrollY());
            return true;
        }
        onScroll(this, getScrollX(), getScrollY());
        this.mInitialPosition = getScrollY();
        Handler handler2 = this.mScrollerTask;
        if (handler2 == null) {
            return true;
        }
        handler2.sendEmptyMessageDelayed(0, (long) this.mCheckTime);
        return true;
    }

    /* access modifiers changed from: protected */
    public void onScrollStopped(WXScrollView scrollView, int x, int y) {
        List<WXScrollViewListener> list = this.mScrollViewListeners;
        int count = list == null ? 0 : list.size();
        for (int i = 0; i < count; i++) {
            this.mScrollViewListeners.get(i).onScrollStopped(this, x, y);
        }
    }

    @Override // com.taobao.weex.ui.view.IWXScroller
    public void destroy() {
        Handler handler = this.mScrollerTask;
        if (handler != null) {
            handler.removeCallbacksAndMessages(null);
        }
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public Rect getContentFrame() {
        return new Rect(0, 0, computeHorizontalScrollRange(), computeVerticalScrollRange());
    }

    public void setWAScroller(WXBaseScroller mWAScroller2) {
        this.mWAScroller = mWAScroller2;
    }
}
