package com.taobao.weex.ui.view;

import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.graphics.Canvas;
import android.text.Layout;
import android.text.TextUtils;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import androidx.appcompat.widget.PopupMenu;
import com.taobao.weex.ui.component.WXText;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import java.lang.ref.WeakReference;

public class WXTextView extends View implements WXGestureObservable, IWXTextView, IRenderStatus<WXText>, IRenderResult<WXText> {
    private boolean mIsLabelSet = false;
    private WeakReference<WXText> mWeakReference;
    private Layout textLayout;
    private WXGesture wxGesture;

    public WXTextView(Context context) {
        super(context);
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        canvas.save();
        Layout layout = getTextLayout();
        if (layout != null) {
            canvas.translate((float) getPaddingLeft(), (float) getPaddingTop());
            layout.draw(canvas);
        }
        canvas.restore();
    }

    public boolean onTouchEvent(MotionEvent event) {
        boolean result = super.onTouchEvent(event);
        WXGesture wXGesture = this.wxGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, event);
        }
        return result;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    @Override // com.taobao.weex.ui.view.IWXTextView
    public CharSequence getText() {
        Layout layout = this.textLayout;
        if (layout != null) {
            return layout.getText();
        }
        return null;
    }

    public Layout getTextLayout() {
        return this.textLayout;
    }

    public void setTextLayout(Layout layout) {
        WXText wxText;
        this.textLayout = layout;
        if (layout != null && !this.mIsLabelSet) {
            setContentDescription(layout.getText());
        }
        WeakReference<WXText> weakReference = this.mWeakReference;
        if (weakReference != null && (wxText = weakReference.get()) != null) {
            wxText.readyToRender();
        }
    }

    public void setAriaLabel(String label) {
        if (!TextUtils.isEmpty(label)) {
            this.mIsLabelSet = true;
            setContentDescription(label);
            return;
        }
        this.mIsLabelSet = false;
        Layout layout = this.textLayout;
        if (layout != null) {
            setContentDescription(layout.getText());
        }
    }

    public void setTextColor(int color) {
        Layout layout = getTextLayout();
        if (layout != null) {
            layout.getPaint().setColor(color);
        }
    }

    public void holdComponent(WXText component) {
        this.mWeakReference = new WeakReference<>(component);
    }

    @Override // com.taobao.weex.ui.view.IRenderResult
    public WXText getComponent() {
        WeakReference<WXText> weakReference = this.mWeakReference;
        if (weakReference != null) {
            return weakReference.get();
        }
        return null;
    }

    public void enableCopy(boolean enable) {
        if (enable) {
            setOnLongClickListener(new View.OnLongClickListener() {
                /* class com.taobao.weex.ui.view.WXTextView.AnonymousClass1 */

                public boolean onLongClick(View v) {
                    PopupMenu popupMenu = new PopupMenu(WXTextView.this.getContext(), WXTextView.this);
                    final String s = "Copy";
                    try {
                        s = WXTextView.this.getContext().getResources().getString(17039361);
                    } catch (Throwable th) {
                    }
                    popupMenu.getMenu().add(s);
                    popupMenu.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
                        /* class com.taobao.weex.ui.view.WXTextView.AnonymousClass1.AnonymousClass1 */

                        @Override // androidx.appcompat.widget.PopupMenu.OnMenuItemClickListener
                        public boolean onMenuItemClick(MenuItem item) {
                            if (!s.equals(item.getTitle())) {
                                return false;
                            }
                            String data = WXTextView.this.getText().toString();
                            ClipboardManager clipboardManager = (ClipboardManager) WXTextView.this.getContext().getSystemService("clipboard");
                            if (clipboardManager == null) {
                                return true;
                            }
                            clipboardManager.setPrimaryClip(ClipData.newPlainText(data, data));
                            return true;
                        }
                    });
                    popupMenu.show();
                    return true;
                }
            });
        } else {
            setOnLongClickListener(null);
        }
    }
}
