package com.taobao.weex.ui.view;

import android.content.Context;
import android.graphics.Rect;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Build;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.MediaController;
import android.widget.ProgressBar;
import android.widget.VideoView;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXResourceUtils;

public class WXVideoView extends VideoView implements WXGestureObservable {
    private VideoPlayListener mVideoPauseListener;
    private WXGesture wxGesture;

    public interface VideoPlayListener {
        void onPause();

        void onStart();
    }

    public WXVideoView(Context context) {
        super(context);
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture2) {
        this.wxGesture = wxGesture2;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public void setOnVideoPauseListener(VideoPlayListener listener) {
        this.mVideoPauseListener = listener;
    }

    public boolean onTouchEvent(MotionEvent event) {
        boolean result = super.onTouchEvent(event);
        WXGesture wXGesture = this.wxGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, event);
        }
        return result;
    }

    public void start() {
        super.start();
        VideoPlayListener videoPlayListener = this.mVideoPauseListener;
        if (videoPlayListener != null) {
            videoPlayListener.onStart();
        }
    }

    public void pause() {
        super.pause();
        VideoPlayListener videoPlayListener = this.mVideoPauseListener;
        if (videoPlayListener != null) {
            videoPlayListener.onPause();
        }
    }

    public static class Wrapper extends FrameLayout implements ViewTreeObserver.OnGlobalLayoutListener {
        private boolean mControls = true;
        private MediaController mMediaController;
        private MediaPlayer.OnCompletionListener mOnCompletionListener;
        private MediaPlayer.OnErrorListener mOnErrorListener;
        private MediaPlayer.OnPreparedListener mOnPreparedListener;
        private ProgressBar mProgressBar;
        private Uri mUri;
        private VideoPlayListener mVideoPlayListener;
        private WXVideoView mVideoView;

        public Wrapper(Context context) {
            super(context);
            init(context);
        }

        public Wrapper(Context context, AttributeSet attrs) {
            super(context, attrs);
            init(context);
        }

        public Wrapper(Context context, AttributeSet attrs, int defStyleAttr) {
            super(context, attrs, defStyleAttr);
            init(context);
        }

        private void init(Context context) {
            setBackgroundColor(WXResourceUtils.getColor("#ee000000"));
            this.mProgressBar = new ProgressBar(context);
            FrameLayout.LayoutParams pLayoutParams = new FrameLayout.LayoutParams(-2, -2);
            this.mProgressBar.setLayoutParams(pLayoutParams);
            pLayoutParams.gravity = 17;
            addView(this.mProgressBar);
            getViewTreeObserver().addOnGlobalLayoutListener(this);
        }

        public ProgressBar getProgressBar() {
            return this.mProgressBar;
        }

        public WXVideoView getVideoView() {
            return this.mVideoView;
        }

        public WXVideoView createIfNotExist() {
            if (this.mVideoView == null) {
                createVideoView();
            }
            return this.mVideoView;
        }

        public MediaController getMediaController() {
            return this.mMediaController;
        }

        public void setVideoURI(Uri uri) {
            this.mUri = uri;
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.setVideoURI(uri);
            }
        }

        public void start() {
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.start();
            }
        }

        public void pause() {
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.pause();
            }
        }

        public void stopPlayback() {
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.stopPlayback();
            }
        }

        public void resume() {
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.resume();
            }
        }

        public void setOnErrorListener(MediaPlayer.OnErrorListener l) {
            this.mOnErrorListener = l;
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.setOnErrorListener(l);
            }
        }

        public void setOnPreparedListener(MediaPlayer.OnPreparedListener l) {
            this.mOnPreparedListener = l;
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.setOnPreparedListener(l);
            }
        }

        public void setOnCompletionListener(MediaPlayer.OnCompletionListener l) {
            this.mOnCompletionListener = l;
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.setOnCompletionListener(l);
            }
        }

        public void setOnVideoPauseListener(VideoPlayListener listener) {
            this.mVideoPlayListener = listener;
            WXVideoView wXVideoView = this.mVideoView;
            if (wXVideoView != null) {
                wXVideoView.setOnVideoPauseListener(listener);
            }
        }

        public void setControls(boolean controls) {
            MediaController mediaController;
            this.mControls = controls;
            if (this.mVideoView != null && (mediaController = this.mMediaController) != null) {
                if (!controls) {
                    mediaController.setVisibility(8);
                } else {
                    mediaController.setVisibility(0);
                }
            }
        }

        private synchronized void createVideoView() {
            if (this.mVideoView == null) {
                Context context = getContext();
                WXVideoView video = new WXVideoView(context);
                FrameLayout.LayoutParams videoLayoutParams = new FrameLayout.LayoutParams(-1, -1);
                videoLayoutParams.gravity = 17;
                video.setLayoutParams(videoLayoutParams);
                addView(video, 0);
                video.setOnErrorListener(this.mOnErrorListener);
                video.setOnPreparedListener(this.mOnPreparedListener);
                video.setOnCompletionListener(this.mOnCompletionListener);
                video.setOnVideoPauseListener(this.mVideoPlayListener);
                MediaController controller = new MediaController(context);
                controller.setAnchorView(this);
                video.setMediaController(controller);
                controller.setMediaPlayer(video);
                if (!this.mControls) {
                    controller.setVisibility(8);
                } else {
                    controller.setVisibility(0);
                }
                this.mMediaController = controller;
                this.mVideoView = video;
                video.setZOrderOnTop(true);
                if (this.mUri != null) {
                    setVideoURI(this.mUri);
                }
            }
        }

        private void removeSelfFromViewTreeObserver() {
            if (Build.VERSION.SDK_INT >= 16) {
                getViewTreeObserver().removeOnGlobalLayoutListener(this);
            } else {
                getViewTreeObserver().removeGlobalOnLayoutListener(this);
            }
        }

        public boolean createVideoViewIfVisible() {
            Rect visibleRect = new Rect();
            if (this.mVideoView != null) {
                return true;
            }
            if (!getGlobalVisibleRect(visibleRect) || visibleRect.isEmpty()) {
                return false;
            }
            createVideoView();
            return true;
        }

        public void onGlobalLayout() {
            if (createVideoViewIfVisible()) {
                removeSelfFromViewTreeObserver();
            }
        }
    }
}
