package com.taobao.weex.ui.view.border;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.RectF;
import android.os.Build;
import com.taobao.weex.base.FloatUtil;

/* access modifiers changed from: package-private */
public abstract class BorderCorner {
    static final float SWEEP_ANGLE = 45.0f;
    private boolean hasInnerCorner = false;
    private boolean hasOuterCorner = false;
    protected float mAngleBisector;
    private RectF mBorderBox;
    private float mCornerRadius = 0.0f;
    private float mOvalBottom;
    private float mOvalLeft;
    private float mOvalRight;
    private float mOvalTop;
    private float mPostBorderWidth = 0.0f;
    private float mPreBorderWidth = 0.0f;
    private float mRoundCornerEndX;
    private float mRoundCornerEndY;
    private float mRoundCornerStartX;
    private float mRoundCornerStartY;

    /* access modifiers changed from: protected */
    public abstract void prepareOval();

    /* access modifiers changed from: protected */
    public abstract void prepareRoundCorner();

    BorderCorner() {
    }

    /* access modifiers changed from: package-private */
    public final void set(float cornerRadius, float preBorderWidth, float postBorderWidth, RectF borderBox, float angleBisector) {
        RectF rectF;
        boolean z = false;
        if (!FloatUtil.floatsEqual(this.mCornerRadius, cornerRadius) || !FloatUtil.floatsEqual(this.mPreBorderWidth, preBorderWidth) || !FloatUtil.floatsEqual(this.mPostBorderWidth, postBorderWidth) || !FloatUtil.floatsEqual(this.mAngleBisector, angleBisector) || ((rectF = this.mBorderBox) != null && rectF.equals(borderBox))) {
            this.mCornerRadius = cornerRadius;
            this.mPreBorderWidth = preBorderWidth;
            this.mPostBorderWidth = postBorderWidth;
            this.mBorderBox = borderBox;
            this.mAngleBisector = angleBisector;
            boolean z2 = cornerRadius > 0.0f && !FloatUtil.floatsEqual(0.0f, cornerRadius);
            this.hasOuterCorner = z2;
            if (z2 && getPreBorderWidth() >= 0.0f && getPostBorderWidth() >= 0.0f && getOuterCornerRadius() > getPreBorderWidth() && getOuterCornerRadius() > getPostBorderWidth()) {
                z = true;
            }
            this.hasInnerCorner = z;
            if (this.hasOuterCorner) {
                prepareOval();
            }
            prepareRoundCorner();
        }
    }

    public final void drawRoundedCorner(Canvas canvas, Paint paint, float startAngle) {
        if (hasOuterCorner()) {
            Paint mPaint = new Paint(paint);
            float rectWidth = Math.abs(this.mOvalLeft - this.mOvalRight);
            if (paint.getStrokeWidth() > rectWidth) {
                mPaint.setStrokeWidth(rectWidth);
            }
            mPaint.setStrokeCap(Paint.Cap.ROUND);
            if (Build.VERSION.SDK_INT >= 21) {
                canvas.drawArc(this.mOvalLeft, this.mOvalTop, this.mOvalRight, this.mOvalBottom, startAngle, SWEEP_ANGLE, false, mPaint);
            } else {
                canvas.drawArc(new RectF(this.mOvalLeft, this.mOvalTop, this.mOvalRight, this.mOvalBottom), startAngle, SWEEP_ANGLE, false, mPaint);
            }
        } else if (getRoundCornerStartX() != getRoundCornerEndX() || getRoundCornerStartY() != getRoundCornerEndY()) {
            canvas.drawLine(getRoundCornerStartX(), getRoundCornerStartY(), getRoundCornerEndX(), getRoundCornerEndY(), paint);
        }
    }

    public final float getRoundCornerStartX() {
        return this.mRoundCornerStartX;
    }

    /* access modifiers changed from: package-private */
    public final void setRoundCornerStartX(float roundCornerStartX) {
        this.mRoundCornerStartX = roundCornerStartX;
    }

    public final float getRoundCornerStartY() {
        return this.mRoundCornerStartY;
    }

    /* access modifiers changed from: package-private */
    public final void setRoundCornerStartY(float roundCornerStartY) {
        this.mRoundCornerStartY = roundCornerStartY;
    }

    public final float getRoundCornerEndX() {
        return this.mRoundCornerEndX;
    }

    /* access modifiers changed from: package-private */
    public final void setRoundCornerEndX(float mRoundCornerEndX2) {
        this.mRoundCornerEndX = mRoundCornerEndX2;
    }

    public final float getRoundCornerEndY() {
        return this.mRoundCornerEndY;
    }

    /* access modifiers changed from: package-private */
    public final void setRoundCornerEndY(float mRoundCornerEndY2) {
        this.mRoundCornerEndY = mRoundCornerEndY2;
    }

    /* access modifiers changed from: package-private */
    public final void setOvalLeft(float mOvalLeft2) {
        this.mOvalLeft = mOvalLeft2;
    }

    /* access modifiers changed from: package-private */
    public final void setOvalTop(float mOvalTop2) {
        this.mOvalTop = mOvalTop2;
    }

    /* access modifiers changed from: package-private */
    public final void setOvalRight(float mOvalRight2) {
        this.mOvalRight = mOvalRight2;
    }

    /* access modifiers changed from: package-private */
    public final void setOvalBottom(float mOvalBottom2) {
        this.mOvalBottom = mOvalBottom2;
    }

    /* access modifiers changed from: package-private */
    public boolean hasInnerCorner() {
        return this.hasInnerCorner;
    }

    /* access modifiers changed from: package-private */
    public boolean hasOuterCorner() {
        return this.hasOuterCorner;
    }

    /* access modifiers changed from: protected */
    public final float getPreBorderWidth() {
        return this.mPreBorderWidth;
    }

    /* access modifiers changed from: protected */
    public final float getPostBorderWidth() {
        return this.mPostBorderWidth;
    }

    /* access modifiers changed from: protected */
    public final float getOuterCornerRadius() {
        return this.mCornerRadius;
    }

    /* access modifiers changed from: protected */
    public final float getAngleBisectorDegree() {
        return this.mAngleBisector;
    }

    /* access modifiers changed from: protected */
    public final RectF getBorderBox() {
        return this.mBorderBox;
    }
}
