package com.taobao.weex.ui.view.border;

import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Outline;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.SparseIntArray;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowData;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Locale;

public class BorderDrawable extends Drawable {
    public static final int BORDER_BOTTOM_LEFT_RADIUS = 3;
    public static final int BORDER_BOTTOM_RIGHT_RADIUS = 2;
    public static final int BORDER_RADIUS_ALL = 5;
    public static final int BORDER_TOP_LEFT_RADIUS = 0;
    public static final int BORDER_TOP_RIGHT_RADIUS = 1;
    static final int DEFAULT_BORDER_COLOR = -16777216;
    private static final BorderStyle DEFAULT_BORDER_STYLE = BorderStyle.SOLID;
    static final float DEFAULT_BORDER_WIDTH = 0.0f;
    private static final String TAG = "Border";
    private static BorderStyle[] sBorderStyle = BorderStyle.values();
    private int mAlpha = 255;
    private SparseIntArray mBorderColor;
    private final BorderEdge mBorderEdge = new BorderEdge();
    private CSSShorthand<CSSShorthand.CORNER> mBorderRadius;
    private SparseIntArray mBorderStyle;
    private CSSShorthand<CSSShorthand.EDGE> mBorderWidth;
    private BottomLeftCorner mBottomLeftCorner;
    private BottomRightCorner mBottomRightCorner;
    UniBoxShadowData mBoxShadowData = null;
    private int mColor = 0;
    private boolean mNeedUpdatePath = false;
    private CSSShorthand<CSSShorthand.CORNER> mOverlappingBorderRadius;
    private final Paint mPaint = new Paint(1);
    private Path mPathForBorderOutline;
    private RectF mRectBounds;
    private Shader mShader = null;
    private TopLeftCorner mTopLeftCorner;
    private TopRightCorner mTopRightCorner;

    public void draw(Canvas canvas) {
        canvas.save();
        updateBorderOutline();
        this.mPaint.setAlpha(255);
        if (this.mPathForBorderOutline != null) {
            int useColor = WXViewUtils.multiplyColorAlpha(this.mColor, this.mAlpha);
            Shader shader = this.mShader;
            if (shader != null) {
                this.mPaint.setShader(shader);
                this.mPaint.setStyle(Paint.Style.FILL);
                canvas.drawPath(this.mPathForBorderOutline, this.mPaint);
                this.mPaint.setShader(null);
            } else if ((useColor >>> 24) != 0) {
                this.mPaint.setColor(useColor);
                this.mPaint.setStyle(Paint.Style.FILL);
                canvas.drawPath(this.mPathForBorderOutline, this.mPaint);
                this.mPaint.setShader(null);
            }
        }
        this.mPaint.setStyle(Paint.Style.STROKE);
        this.mPaint.setStrokeJoin(Paint.Join.ROUND);
        drawBorders(canvas);
        this.mPaint.setShader(null);
        canvas.restore();
    }

    /* access modifiers changed from: protected */
    public void onBoundsChange(Rect bounds) {
        super.onBoundsChange(bounds);
        this.mNeedUpdatePath = true;
    }

    public void setAlpha(int alpha) {
        if (alpha != this.mAlpha) {
            this.mAlpha = alpha;
            invalidateSelf();
        }
    }

    public int getAlpha() {
        return this.mAlpha;
    }

    public void updateBoxShadowData(UniBoxShadowData data) {
        this.mBoxShadowData = data;
        invalidateSelf();
    }

    public void setColorFilter(ColorFilter cf) {
    }

    public int getOpacity() {
        if (this.mShader != null) {
            return -1;
        }
        return WXViewUtils.getOpacityFromColor(WXViewUtils.multiplyColorAlpha(this.mColor, this.mAlpha));
    }

    public void getOutline(Outline outline) {
        if (Build.VERSION.SDK_INT >= 21) {
            if (this.mPathForBorderOutline == null) {
                this.mNeedUpdatePath = true;
            }
            updateBorderOutline();
            outline.setConvexPath(this.mPathForBorderOutline);
        }
    }

    public void setBorderWidth(CSSShorthand.EDGE edge, float width) {
        if (this.mBorderWidth == null) {
            this.mBorderWidth = new CSSShorthand<>();
        }
        if (this.mBorderWidth.get(edge) != width) {
            this.mBorderWidth.set(edge, width);
            this.mNeedUpdatePath = true;
            invalidateSelf();
        }
    }

    /* access modifiers changed from: package-private */
    public float getBorderWidth(CSSShorthand.EDGE edge) {
        return this.mBorderWidth.get(edge);
    }

    public void setBorderRadius(CSSShorthand.CORNER position, float radius) {
        if (this.mBorderRadius == null) {
            this.mBorderRadius = new CSSShorthand<>();
        }
        if (this.mBorderRadius.get(position) == radius) {
            if (position != CSSShorthand.CORNER.ALL) {
                return;
            }
            if (radius == this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT) && radius == this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT) && radius == this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT) && radius == this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT)) {
                return;
            }
        }
        this.mBorderRadius.set(position, radius);
        this.mNeedUpdatePath = true;
        invalidateSelf();
    }

    public float[] getBorderRadius(RectF borderBox) {
        prepareBorderRadius(borderBox);
        if (this.mOverlappingBorderRadius == null) {
            this.mOverlappingBorderRadius = new CSSShorthand<>();
        }
        float topLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT);
        float topRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT);
        float bottomRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT);
        float bottomLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT);
        return new float[]{topLeftRadius, topLeftRadius, topRightRadius, topRightRadius, bottomRightRadius, bottomRightRadius, bottomLeftRadius, bottomLeftRadius};
    }

    public float[] getBorderInnerRadius(RectF borderBox) {
        prepareBorderRadius(borderBox);
        if (this.mOverlappingBorderRadius == null) {
            this.mOverlappingBorderRadius = new CSSShorthand<>();
        }
        float topLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT);
        float topRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT);
        float bottomRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT);
        float bottomLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT);
        CSSShorthand<CSSShorthand.EDGE> cSSShorthand = this.mBorderWidth;
        if (cSSShorthand != null) {
            topLeftRadius = Math.max(topLeftRadius - cSSShorthand.get(CSSShorthand.EDGE.TOP), 0.0f);
            topRightRadius = Math.max(topRightRadius - this.mBorderWidth.get(CSSShorthand.EDGE.TOP), 0.0f);
            bottomRightRadius = Math.max(bottomRightRadius - this.mBorderWidth.get(CSSShorthand.EDGE.BOTTOM), 0.0f);
            bottomLeftRadius = Math.max(bottomLeftRadius - this.mBorderWidth.get(CSSShorthand.EDGE.BOTTOM), 0.0f);
        }
        return new float[]{topLeftRadius, topLeftRadius, topRightRadius, topRightRadius, bottomRightRadius, bottomRightRadius, bottomLeftRadius, bottomLeftRadius};
    }

    public void setBorderColor(CSSShorthand.EDGE edge, int color) {
        if (this.mBorderColor == null) {
            SparseIntArray sparseIntArray = new SparseIntArray(5);
            this.mBorderColor = sparseIntArray;
            sparseIntArray.put(CSSShorthand.EDGE.ALL.ordinal(), -16777216);
        }
        if (getBorderColor(edge) != color) {
            BorderUtil.updateSparseArray(this.mBorderColor, edge.ordinal(), color);
            invalidateSelf();
        }
    }

    /* access modifiers changed from: package-private */
    public int getBorderColor(CSSShorthand.EDGE edge) {
        return BorderUtil.fetchFromSparseArray(this.mBorderColor, edge.ordinal(), -16777216);
    }

    public void setBorderStyle(CSSShorthand.EDGE edge, String style) {
        if (this.mBorderStyle == null) {
            SparseIntArray sparseIntArray = new SparseIntArray(5);
            this.mBorderStyle = sparseIntArray;
            sparseIntArray.put(CSSShorthand.EDGE.ALL.ordinal(), DEFAULT_BORDER_STYLE.ordinal());
        }
        try {
            int borderStyle = BorderStyle.valueOf(style.toUpperCase(Locale.US)).ordinal();
            if (getBorderStyle(edge) != borderStyle) {
                BorderUtil.updateSparseArray(this.mBorderStyle, edge.ordinal(), borderStyle);
                invalidateSelf();
            }
        } catch (IllegalArgumentException e) {
            WXLogUtils.e(TAG, WXLogUtils.getStackTrace(e));
        }
    }

    /* access modifiers changed from: package-private */
    public int getBorderStyle(CSSShorthand.EDGE edge) {
        return BorderUtil.fetchFromSparseArray(this.mBorderStyle, edge.ordinal(), BorderStyle.SOLID.ordinal());
    }

    public int getColor() {
        return this.mColor;
    }

    public void setColor(int color) {
        this.mColor = color;
        invalidateSelf();
    }

    public void setImage(Shader shader) {
        this.mShader = shader;
        invalidateSelf();
    }

    public boolean hasImage() {
        return this.mShader != null;
    }

    public boolean isRounded() {
        CSSShorthand<CSSShorthand.CORNER> cSSShorthand = this.mBorderRadius;
        return (cSSShorthand == null || (cSSShorthand.get(CSSShorthand.CORNER.BORDER_TOP_LEFT) == 0.0f && this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT) == 0.0f && this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT) == 0.0f && this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT) == 0.0f)) ? false : true;
    }

    public Path getContentPath(RectF borderBox) {
        Path contentClip = new Path();
        prepareBorderPath(0, 0, 0, 0, borderBox, contentClip);
        return contentClip;
    }

    private void updateBorderOutline() {
        if (this.mNeedUpdatePath) {
            this.mNeedUpdatePath = false;
            if (this.mPathForBorderOutline == null) {
                this.mPathForBorderOutline = new Path();
            }
            this.mPathForBorderOutline.reset();
            prepareBorderPath(0, 0, 0, 0, new RectF(getBounds()), this.mPathForBorderOutline);
        }
    }

    private void prepareBorderPath(int topPadding, int rightPadding, int bottomPadding, int leftPadding, RectF rectF, Path path) {
        UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
        if (uniBoxShadowData != null) {
            int dy = 0;
            int dx = 0;
            if (uniBoxShadowData.getNormalTop() > 0) {
                dy = this.mBoxShadowData.getNormalTop() / 2;
            }
            if (this.mBoxShadowData.getNormalLeft() > 0) {
                dx = this.mBoxShadowData.getNormalLeft() / 2;
            }
            rectF.inset((float) dx, (float) dy);
        }
        if (this.mBorderRadius != null) {
            prepareBorderRadius(rectF);
            if (this.mOverlappingBorderRadius == null) {
                this.mOverlappingBorderRadius = new CSSShorthand<>();
            }
            float topLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT);
            float topRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT);
            float bottomRightRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT);
            float bottomLeftRadius = this.mOverlappingBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT);
            path.addRoundRect(rectF, new float[]{topLeftRadius - ((float) leftPadding), topLeftRadius - ((float) topPadding), topRightRadius - ((float) rightPadding), topRightRadius - ((float) topPadding), bottomRightRadius - ((float) rightPadding), bottomRightRadius - ((float) bottomPadding), bottomLeftRadius - ((float) leftPadding), bottomLeftRadius - ((float) bottomPadding)}, Path.Direction.CW);
            return;
        }
        path.addRect(rectF, Path.Direction.CW);
    }

    private void prepareBorderRadius(RectF borderBox) {
        if (this.mBorderRadius != null) {
            float factor = getScaleFactor(borderBox);
            if (this.mOverlappingBorderRadius == null) {
                this.mOverlappingBorderRadius = new CSSShorthand<>();
            }
            if (Float.isNaN(factor) || factor >= 1.0f) {
                this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_TOP_LEFT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT));
                this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_TOP_RIGHT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT));
                this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT));
                this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT));
                return;
            }
            this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_TOP_LEFT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT) * factor);
            this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_TOP_RIGHT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT) * factor);
            this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT) * factor);
            this.mOverlappingBorderRadius.set(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT) * factor);
        }
    }

    private float getScaleFactor(RectF borderBox) {
        float topRadius = this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT) + this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT);
        float rightRadius = this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_RIGHT) + this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT);
        float bottomRadius = this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT) + this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT);
        float leftRadius = this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT) + this.mBorderRadius.get(CSSShorthand.CORNER.BORDER_TOP_LEFT);
        List<Float> factors = new ArrayList<>(4);
        updateFactor(factors, borderBox.width(), topRadius);
        updateFactor(factors, borderBox.height(), rightRadius);
        updateFactor(factors, borderBox.width(), bottomRadius);
        updateFactor(factors, borderBox.height(), leftRadius);
        if (factors.isEmpty()) {
            return Float.NaN;
        }
        return ((Float) Collections.min(factors)).floatValue();
    }

    private void updateFactor(List<Float> list, float numerator, float denominator) {
        if (denominator != 0.0f) {
            list.add(Float.valueOf(numerator / denominator));
        }
    }

    private void drawBorders(Canvas canvas) {
        RectF rectF = this.mRectBounds;
        if (rectF == null) {
            this.mRectBounds = new RectF(getBounds());
        } else {
            rectF.set(getBounds());
        }
        int dy = 0;
        int dx = 0;
        UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
        if (uniBoxShadowData != null) {
            if (uniBoxShadowData.getNormalTop() > 0) {
                dy = this.mBoxShadowData.getNormalTop() / 2;
            }
            if (this.mBoxShadowData.getNormalLeft() > 0) {
                dx = this.mBoxShadowData.getNormalLeft() / 2;
            }
            this.mRectBounds.inset((float) dx, (float) dy);
        }
        CSSShorthand<CSSShorthand.EDGE> cSSShorthand = this.mBorderWidth;
        if (cSSShorthand != null) {
            float leftBorderWidth = cSSShorthand.get(CSSShorthand.EDGE.LEFT);
            float topBorderWidth = this.mBorderWidth.get(CSSShorthand.EDGE.TOP);
            float bottomBorderWidth = this.mBorderWidth.get(CSSShorthand.EDGE.BOTTOM);
            float rightBorderWidth = this.mBorderWidth.get(CSSShorthand.EDGE.RIGHT);
            if (this.mTopLeftCorner == null) {
                this.mTopLeftCorner = new TopLeftCorner();
            }
            this.mTopLeftCorner.set(getBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT), leftBorderWidth, topBorderWidth, this.mRectBounds);
            if (this.mTopRightCorner == null) {
                this.mTopRightCorner = new TopRightCorner();
            }
            this.mTopRightCorner.set(getBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT), topBorderWidth, rightBorderWidth, this.mRectBounds);
            if (this.mBottomRightCorner == null) {
                this.mBottomRightCorner = new BottomRightCorner();
            }
            this.mBottomRightCorner.set(getBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT), rightBorderWidth, bottomBorderWidth, this.mRectBounds);
            if (this.mBottomLeftCorner == null) {
                this.mBottomLeftCorner = new BottomLeftCorner();
            }
            this.mBottomLeftCorner.set(getBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT), bottomBorderWidth, leftBorderWidth, this.mRectBounds);
            if (!isDefAllDrawRoundRect(canvas, leftBorderWidth, topBorderWidth, bottomBorderWidth, rightBorderWidth)) {
                canvas.translate((float) dx, (float) dy);
                drawOneSide(canvas, this.mBorderEdge.set(this.mTopLeftCorner, this.mTopRightCorner, topBorderWidth, CSSShorthand.EDGE.TOP));
                drawOneSide(canvas, this.mBorderEdge.set(this.mTopRightCorner, this.mBottomRightCorner, rightBorderWidth, CSSShorthand.EDGE.RIGHT));
                drawOneSide(canvas, this.mBorderEdge.set(this.mBottomRightCorner, this.mBottomLeftCorner, bottomBorderWidth, CSSShorthand.EDGE.BOTTOM));
                drawOneSide(canvas, this.mBorderEdge.set(this.mBottomLeftCorner, this.mTopLeftCorner, leftBorderWidth, CSSShorthand.EDGE.LEFT));
            }
        }
    }

    private boolean isDefAllDrawRoundRect(Canvas canvas, float leftBorderWidth, float topBorderWidth, float bottomBorderWidth, float rightBorderWidth) {
        float leftRadius = this.mTopLeftCorner.getOuterCornerRadius();
        if (leftRadius <= 0.0f || leftRadius != this.mTopRightCorner.getOuterCornerRadius() || leftRadius != this.mBottomLeftCorner.getOuterCornerRadius() || leftRadius != this.mBottomRightCorner.getOuterCornerRadius() || leftBorderWidth <= 0.0f || leftBorderWidth != topBorderWidth || leftBorderWidth != bottomBorderWidth || leftBorderWidth != rightBorderWidth) {
            return false;
        }
        int leftBorderColor = WXViewUtils.multiplyColorAlpha(getBorderColor(CSSShorthand.EDGE.LEFT), this.mAlpha);
        int topBorderColor = WXViewUtils.multiplyColorAlpha(getBorderColor(CSSShorthand.EDGE.TOP), this.mAlpha);
        int BottomRightColor = WXViewUtils.multiplyColorAlpha(getBorderColor(CSSShorthand.EDGE.BOTTOM), this.mAlpha);
        int rightBorderColor = WXViewUtils.multiplyColorAlpha(getBorderColor(CSSShorthand.EDGE.RIGHT), this.mAlpha);
        if (leftBorderColor != topBorderColor || leftBorderColor != BottomRightColor || leftBorderColor != rightBorderColor) {
            return false;
        }
        preparePaint(this.mBorderEdge.set(this.mTopLeftCorner, this.mTopRightCorner, topBorderWidth, CSSShorthand.EDGE.TOP).getEdge());
        this.mPaint.setStrokeWidth(leftBorderWidth);
        RectF rectF = new RectF();
        float w = leftBorderWidth / 2.0f;
        rectF.top = this.mRectBounds.top + w;
        rectF.bottom = this.mRectBounds.bottom - w;
        rectF.left = this.mRectBounds.left + w;
        rectF.right = this.mRectBounds.right - w;
        canvas.drawRoundRect(rectF, leftRadius, leftRadius, this.mPaint);
        return true;
    }

    private float getBorderRadius(CSSShorthand.CORNER position) {
        CSSShorthand<CSSShorthand.CORNER> cSSShorthand = this.mOverlappingBorderRadius;
        if (cSSShorthand != null) {
            return cSSShorthand.get(position);
        }
        return 0.0f;
    }

    private void drawOneSide(Canvas canvas, BorderEdge borderEdge) {
        if (0.0f != borderEdge.getBorderWidth()) {
            preparePaint(borderEdge.getEdge());
            borderEdge.drawEdge(canvas, this.mPaint);
        }
    }

    private void preparePaint(CSSShorthand.EDGE edge) {
        float borderWidth = this.mBorderWidth.get(edge);
        int color = WXViewUtils.multiplyColorAlpha(getBorderColor(edge), this.mAlpha);
        this.mPaint.setShader(sBorderStyle[getBorderStyle(edge)].getLineShader(borderWidth, color, edge));
        this.mPaint.setColor(color);
        this.mPaint.setStrokeCap(Paint.Cap.BUTT);
    }
}
