package com.taobao.weex.ui.view.gesture;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.os.Handler;
import android.os.Looper;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baidu.speech.asr.SpeechConstant;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class WXGesture extends GestureDetector.SimpleOnGestureListener implements View.OnTouchListener {
    private static final int CUR_EVENT = -1;
    public static final String DOWN = "down";
    public static final String END = "end";
    public static final String LEFT = "left";
    public static final String MOVE = "move";
    public static final String RIGHT = "right";
    public static final String START = "start";
    private static final String TAG = "Gesture";
    public static final String UNKNOWN = "unknown";
    public static final String UP = "up";
    private WXComponent component;
    private Point globalEventOffset;
    private Point globalOffset;
    private Rect globalRect;
    private PointF locEventOffset;
    private PointF locLeftTop;
    private GestureDetector mGestureDetector;
    private boolean mIsPreventMoveEvent = false;
    private boolean mIsTouchEventConsumed = false;
    private int mParentOrientation = -1;
    private WXGestureType mPendingPan = null;
    private final List<View.OnTouchListener> mTouchListeners = new LinkedList();
    private long panDownTime = -1;
    private boolean requestDisallowInterceptTouchEvent = false;
    private int shouldBubbleCallRemainTimes = 0;
    private int shouldBubbleInterval = 0;
    private boolean shouldBubbleResult = true;
    private long swipeDownTime = -1;

    public WXGesture(WXComponent wxComponent, Context context) {
        this.component = wxComponent;
        this.globalRect = new Rect();
        this.globalOffset = new Point();
        this.globalEventOffset = new Point();
        this.locEventOffset = new PointF();
        this.locLeftTop = new PointF();
        this.mGestureDetector = new GestureDetector(context, this, new GestureHandler());
        Scrollable parentScrollable = wxComponent.getParentScroller();
        if (parentScrollable != null) {
            this.mParentOrientation = parentScrollable.getOrientation();
        }
        this.shouldBubbleResult = WXUtils.getBoolean(wxComponent.getAttrs().get(Constants.Name.SHOULD_STOP_PROPAGATION_INIT_RESULT), true).booleanValue();
        this.shouldBubbleInterval = WXUtils.getNumberInt(wxComponent.getAttrs().get(Constants.Name.SHOULD_STOP_PROPAGATION_INTERVAL), 0);
    }

    private boolean isParentScrollable() {
        Scrollable parentScrollable;
        WXComponent wXComponent = this.component;
        if (wXComponent == null || (parentScrollable = wXComponent.getParentScroller()) == null || parentScrollable.isScrollable()) {
            return true;
        }
        return false;
    }

    private boolean hasSameOrientationWithParent() {
        if (this.mParentOrientation == 0 && this.component.containsGesture(WXGestureType.HighLevelGesture.HORIZONTALPAN)) {
            return true;
        }
        if (this.mParentOrientation != 1 || !this.component.containsGesture(WXGestureType.HighLevelGesture.VERTICALPAN)) {
            return false;
        }
        return true;
    }

    public void setPreventMoveEvent(boolean preventMoveEvent) {
        this.mIsPreventMoveEvent = preventMoveEvent;
    }

    public boolean isTouchEventConsumedByAdvancedGesture() {
        return this.mIsTouchEventConsumed;
    }

    public static boolean isStopPropagation(String type) {
        return Constants.Event.STOP_PROPAGATION.equals(type) || Constants.Event.STOP_PROPAGATION_RAX.equals(type);
    }

    public static boolean hasStopPropagation(WXComponent component2) {
        WXEvent event = component2.getEvents();
        if (event == null) {
            return false;
        }
        int size = event.size();
        int i = 0;
        while (i < size && i < event.size()) {
            if (isStopPropagation((String) event.get(i))) {
                return true;
            }
            i++;
        }
        return false;
    }

    private boolean shouldBubbleTouchEvent(MotionEvent event) {
        int i;
        if (!hasStopPropagation(this.component)) {
            return true;
        }
        if (this.shouldBubbleInterval <= 0 || (i = this.shouldBubbleCallRemainTimes) <= 0) {
            Map<String, Object> eventMap = createFireEventParam(event, -1, null);
            eventMap.put("type", SpeechConstant.VAD_TOUCH);
            if (event.getAction() == 0) {
                eventMap.put("action", "start");
            } else if (event.getAction() == 3 || event.getAction() == 1) {
                eventMap.put("action", "end");
            } else {
                eventMap.put("action", MOVE);
            }
            String name = Constants.Event.STOP_PROPAGATION;
            if (!this.component.getEvents().contains(Constants.Event.STOP_PROPAGATION)) {
                name = Constants.Event.STOP_PROPAGATION_RAX;
            }
            EventResult result = this.component.fireEventWait(name, eventMap);
            if (result.isSuccess() && result.getResult() != null) {
                this.shouldBubbleResult = !WXUtils.getBoolean(result.getResult(), Boolean.valueOf(true ^ this.shouldBubbleResult)).booleanValue();
            }
            this.shouldBubbleCallRemainTimes = this.shouldBubbleInterval;
            return this.shouldBubbleResult;
        }
        this.shouldBubbleCallRemainTimes = i - 1;
        return this.shouldBubbleResult;
    }

    public void addOnTouchListener(View.OnTouchListener listener) {
        if (listener != null) {
            this.mTouchListeners.add(listener);
        }
    }

    public boolean removeTouchListener(View.OnTouchListener listener) {
        if (listener != null) {
            return this.mTouchListeners.remove(listener);
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:43:0x00fc A[Catch:{ Exception -> 0x0142 }] */
    public boolean onTouch(View v, MotionEvent event) {
        ViewParent p;
        if (this.requestDisallowInterceptTouchEvent) {
            this.requestDisallowInterceptTouchEvent = false;
            return false;
        }
        try {
            boolean result = this.mGestureDetector.onTouchEvent(event);
            if (this.mTouchListeners != null && !this.mTouchListeners.isEmpty()) {
                for (View.OnTouchListener listener : this.mTouchListeners) {
                    result |= listener.onTouch(v, event);
                }
            }
            int actionMasked = event.getActionMasked();
            if (actionMasked != 0) {
                if (actionMasked != 1) {
                    if (actionMasked == 2) {
                        result |= handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_MOVE, event);
                    } else if (actionMasked == 3) {
                        finishDisallowInterceptTouchEvent(v);
                        result = result | handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_CANCEL, event) | handlePanMotionEvent(event);
                        if (this.component.isPreventGesture()) {
                            WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), true, this.component.getRef());
                        }
                    } else if (actionMasked != 5) {
                        if (actionMasked != 6) {
                        }
                    }
                    if (hasStopPropagation(this.component)) {
                        ViewGroup parent = (ViewGroup) v.getParent();
                        boolean requestDisallowInterceptTouchEvent2 = false;
                        if (parent != null) {
                            if (!shouldBubbleTouchEvent(event)) {
                                requestDisallowInterceptTouchEvent2 = true;
                            }
                            parent.requestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent2);
                        }
                        if (this.component.getParent() != null) {
                            this.component.getParent().requestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent2);
                        }
                        if (this.mIsTouchEventConsumed && WXUtils.getBoolean(this.component.getAttrs().get("cancelTouchOnConsume"), false).booleanValue()) {
                            event.setAction(3);
                        }
                    }
                    return result;
                }
                finishDisallowInterceptTouchEvent(v);
                result = result | handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_UP, event) | handlePanMotionEvent(event);
                if (this.component.isPreventGesture()) {
                    WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), true, this.component.getRef());
                }
                if (hasStopPropagation(this.component)) {
                }
                return result;
            }
            this.mIsTouchEventConsumed = false;
            if (hasSameOrientationWithParent() && !isParentScrollable() && (p = this.component.getRealView().getParent()) != null) {
                p.requestDisallowInterceptTouchEvent(true);
            }
            result |= handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_DOWN, event);
            if (this.component.isPreventGesture()) {
                WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), false, this.component.getRef());
            }
            if (hasStopPropagation(this.component)) {
            }
            return result;
        } catch (Exception e) {
            WXLogUtils.e("Gesture RunTime Error ", e);
            return false;
        }
    }

    private String getPanEventAction(MotionEvent event) {
        int action = event.getAction();
        if (action == 0) {
            return "start";
        }
        if (action == 1) {
            return "end";
        }
        if (action == 2) {
            return MOVE;
        }
        if (action != 3) {
            return "unknown";
        }
        return "end";
    }

    private void finishDisallowInterceptTouchEvent(View v) {
        if (v.getParent() != null) {
            v.getParent().requestDisallowInterceptTouchEvent(false);
        }
    }

    private boolean handlePanMotionEvent(MotionEvent motionEvent) {
        WXGestureType wXGestureType = this.mPendingPan;
        if (wXGestureType == null) {
            return false;
        }
        String state = null;
        if (wXGestureType == WXGestureType.HighLevelGesture.HORIZONTALPAN || this.mPendingPan == WXGestureType.HighLevelGesture.VERTICALPAN) {
            state = getPanEventAction(motionEvent);
        }
        if (!this.component.containsGesture(this.mPendingPan)) {
            return false;
        }
        if (this.mIsPreventMoveEvent && MOVE.equals(state)) {
            return true;
        }
        for (Map<String, Object> map : createMultipleFireEventParam(motionEvent, state)) {
            this.component.fireEvent(this.mPendingPan.toString(), map);
        }
        if (motionEvent.getAction() == 1 || motionEvent.getAction() == 3) {
            this.mPendingPan = null;
        }
        return true;
    }

    private boolean handleMotionEvent(WXGestureType WXGestureType, MotionEvent motionEvent) {
        if (this.component.getHover() != null) {
            this.component.getHover().handleMotionEvent(WXGestureType, motionEvent);
        }
        if (!this.component.containsGesture(WXGestureType)) {
            return false;
        }
        for (Map<String, Object> map : createMultipleFireEventParam(motionEvent, null)) {
            this.component.fireEvent(WXGestureType.toString(), map);
        }
        return true;
    }

    private List<Map<String, Object>> createMultipleFireEventParam(MotionEvent motionEvent, String state) {
        List<Map<String, Object>> list = new ArrayList<>(motionEvent.getHistorySize() + 1);
        list.add(createFireEventParam(motionEvent, -1, state));
        return list;
    }

    private List<Map<String, Object>> getHistoricalEvents(MotionEvent motionEvent) {
        List<Map<String, Object>> list = new ArrayList<>(motionEvent.getHistorySize());
        if (motionEvent.getActionMasked() == 2) {
            for (int i = 0; i < motionEvent.getHistorySize(); i++) {
                list.add(createFireEventParam(motionEvent, i, null));
            }
        }
        return list;
    }

    private Map<String, Object> createFireEventParam(MotionEvent motionEvent, int pos, String state) {
        JSONArray jsonArray = new JSONArray(motionEvent.getPointerCount());
        if (motionEvent.getActionMasked() == 2) {
            for (int i = 0; i < motionEvent.getPointerCount(); i++) {
                jsonArray.add(createJSONObject(motionEvent, pos, i));
            }
        } else if (isPointerNumChanged(motionEvent)) {
            jsonArray.add(createJSONObject(motionEvent, -1, motionEvent.getActionIndex()));
        }
        Map<String, Object> map = new HashMap<>();
        map.put(WXGestureType.GestureInfo.HISTORICAL_XY, jsonArray);
        if (state != null) {
            map.put("state", state);
        }
        return map;
    }

    private boolean isPointerNumChanged(MotionEvent event) {
        if (event.getActionMasked() == 0 || event.getActionMasked() == 5 || event.getActionMasked() == 1 || event.getActionMasked() == 6 || event.getActionMasked() == 3) {
            return true;
        }
        return false;
    }

    private boolean containsSimplePan() {
        return this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_START) || this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_MOVE) || this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_END);
    }

    private JSONObject createJSONObject(MotionEvent motionEvent, int pos, int pointerIndex) {
        PointF screenXY;
        PointF pageXY;
        if (pos == -1) {
            pageXY = getEventLocInPageCoordinate(motionEvent, pointerIndex);
            screenXY = getEventLocInScreenCoordinate(motionEvent, pointerIndex);
        } else {
            pageXY = getEventLocInPageCoordinate(motionEvent, pointerIndex, pos);
            screenXY = getEventLocInScreenCoordinate(motionEvent, pointerIndex, pos);
        }
        JSONObject map = createJSONObject(screenXY, pageXY, (float) motionEvent.getPointerId(pointerIndex));
        float force = motionEvent.getPressure();
        if (force > 0.0f && force < 1.0f) {
            map.put(AbsoluteConst.INSTALL_OPTIONS_FORCE, (Object) Float.valueOf(motionEvent.getPressure()));
        }
        return map;
    }

    private JSONObject createJSONObject(PointF screenXY, PointF pageXY, float pointerId) {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put(WXGestureType.GestureInfo.PAGE_X, (Object) Float.valueOf(pageXY.x));
        jsonObject.put(WXGestureType.GestureInfo.PAGE_Y, (Object) Float.valueOf(pageXY.y));
        jsonObject.put(WXGestureType.GestureInfo.SCREEN_X, (Object) Float.valueOf(screenXY.x));
        jsonObject.put(WXGestureType.GestureInfo.SCREEN_Y, (Object) Float.valueOf(screenXY.y));
        jsonObject.put(WXGestureType.GestureInfo.POINTER_ID, (Object) Float.valueOf(pointerId));
        return jsonObject;
    }

    private PointF getEventLocInScreenCoordinate(MotionEvent motionEvent, int pointerIndex) {
        return getEventLocInScreenCoordinate(motionEvent, pointerIndex, -1);
    }

    private PointF getEventLocInScreenCoordinate(MotionEvent motionEvent, int pointerIndex, int position) {
        float eventY;
        float eventX;
        if (position == -1) {
            eventX = motionEvent.getX(pointerIndex);
            eventY = motionEvent.getY(pointerIndex);
        } else {
            eventX = motionEvent.getHistoricalX(pointerIndex, position);
            eventY = motionEvent.getHistoricalY(pointerIndex, position);
        }
        return getEventLocInScreenCoordinate(eventX, eventY);
    }

    private PointF getEventLocInScreenCoordinate(float eventX, float eventY) {
        this.globalRect.set(0, 0, 0, 0);
        this.globalOffset.set(0, 0);
        this.globalEventOffset.set((int) eventX, (int) eventY);
        this.component.getRealView().getGlobalVisibleRect(this.globalRect, this.globalOffset);
        this.globalEventOffset.offset(this.globalOffset.x, this.globalOffset.y);
        return new PointF(WXViewUtils.getWebPxByWidth((float) this.globalEventOffset.x, this.component.getInstance().getInstanceViewPortWidthWithFloat()), WXViewUtils.getWebPxByWidth((float) this.globalEventOffset.y, this.component.getInstance().getInstanceViewPortWidthWithFloat()));
    }

    private PointF getEventLocInPageCoordinate(MotionEvent motionEvent, int pointerIndex) {
        return getEventLocInPageCoordinate(motionEvent, pointerIndex, -1);
    }

    private PointF getEventLocInPageCoordinate(MotionEvent motionEvent, int pointerIndex, int position) {
        float eventY;
        float eventX;
        if (position == -1) {
            eventX = motionEvent.getX(pointerIndex);
            eventY = motionEvent.getY(pointerIndex);
        } else {
            eventX = motionEvent.getHistoricalX(pointerIndex, position);
            eventY = motionEvent.getHistoricalY(pointerIndex, position);
        }
        return getEventLocInPageCoordinate(eventX, eventY);
    }

    private PointF getEventLocInPageCoordinate(float eventX, float eventY) {
        this.locEventOffset.set(eventX, eventY);
        this.locLeftTop.set(0.0f, 0.0f);
        this.component.computeVisiblePointInViewCoordinate(this.locLeftTop);
        this.locEventOffset.offset(this.locLeftTop.x, this.locLeftTop.y);
        return new PointF(WXViewUtils.getWebPxByWidth(this.locEventOffset.x, this.component.getInstance().getInstanceViewPortWidthWithFloat()), WXViewUtils.getWebPxByWidth(this.locEventOffset.y, this.component.getInstance().getInstanceViewPortWidthWithFloat()));
    }

    private static class GestureHandler extends Handler {
        public GestureHandler() {
            super(Looper.getMainLooper());
        }
    }

    public void onLongPress(MotionEvent e) {
        if (this.component.containsGesture(WXGestureType.HighLevelGesture.LONG_PRESS)) {
            List<Map<String, Object>> list = createMultipleFireEventParam(e, null);
            this.component.getInstance().fireEvent(this.component.getRef(), WXGestureType.HighLevelGesture.LONG_PRESS.toString(), list.get(list.size() - 1));
            this.mIsTouchEventConsumed = true;
        }
    }

    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        WXGestureType possiblePan;
        boolean result = false;
        boolean z = false;
        if (e1 == null || e2 == null) {
            return false;
        }
        if (Math.abs(e2.getX() - e1.getX()) > Math.abs(e2.getY() - e1.getY())) {
            possiblePan = WXGestureType.HighLevelGesture.HORIZONTALPAN;
        } else {
            possiblePan = WXGestureType.HighLevelGesture.VERTICALPAN;
        }
        if (this.mPendingPan == WXGestureType.HighLevelGesture.HORIZONTALPAN || this.mPendingPan == WXGestureType.HighLevelGesture.VERTICALPAN) {
            result = handlePanMotionEvent(e2);
        } else if (this.component.containsGesture(possiblePan)) {
            ViewParent p = this.component.getRealView().getParent();
            if (p != null) {
                p.requestDisallowInterceptTouchEvent(true);
            }
            WXGestureType wXGestureType = this.mPendingPan;
            if (wXGestureType != null) {
                handleMotionEvent(wXGestureType, e2);
            }
            this.mPendingPan = possiblePan;
            this.component.fireEvent(possiblePan.toString(), createFireEventParam(e2, -1, "start"));
            result = true;
        } else if (containsSimplePan()) {
            if (this.panDownTime != e1.getEventTime()) {
                this.panDownTime = e1.getEventTime();
                this.mPendingPan = WXGestureType.HighLevelGesture.PAN_END;
                this.component.fireEvent(WXGestureType.HighLevelGesture.PAN_START.toString(), createFireEventParam(e1, -1, null));
            } else {
                this.component.fireEvent(WXGestureType.HighLevelGesture.PAN_MOVE.toString(), createFireEventParam(e2, -1, null));
            }
            result = true;
        } else if (this.component.containsGesture(WXGestureType.HighLevelGesture.SWIPE) && this.swipeDownTime != e1.getEventTime()) {
            this.swipeDownTime = e1.getEventTime();
            List<Map<String, Object>> list = createMultipleFireEventParam(e2, null);
            Map<String, Object> param = list.get(list.size() - 1);
            if (Math.abs(distanceX) > Math.abs(distanceY)) {
                param.put("direction", distanceX > 0.0f ? "left" : "right");
            } else {
                param.put("direction", distanceY > 0.0f ? "up" : "down");
            }
            this.component.getInstance().fireEvent(this.component.getRef(), WXGestureType.HighLevelGesture.SWIPE.toString(), param);
            result = true;
        }
        if (this.mIsTouchEventConsumed || result) {
            z = true;
        }
        this.mIsTouchEventConsumed = z;
        return result;
    }

    public boolean onDown(MotionEvent e) {
        return true;
    }

    public boolean isRequestDisallowInterceptTouchEvent() {
        return this.requestDisallowInterceptTouchEvent;
    }

    public void setRequestDisallowInterceptTouchEvent(boolean requestDisallowInterceptTouchEvent2) {
        this.requestDisallowInterceptTouchEvent = requestDisallowInterceptTouchEvent2;
    }
}
