package com.taobao.weex.ui.view.listview;

import android.content.Context;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.WXListComponent;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.ui.view.listview.ExtendedLinearLayoutManager;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import io.dcloud.common.ui.blur.AppEventForBlurManager;
import io.dcloud.feature.weex.extend.DCWXSlider;
import io.dcloud.weex.FlingHelper;

public class WXRecyclerView extends RecyclerView implements WXGestureObservable {
    public static final int TYPE_GRID_LAYOUT = 2;
    public static final int TYPE_LINEAR_LAYOUT = 1;
    public static final int TYPE_STAGGERED_GRID_LAYOUT = 3;
    private JSONObject NestInfo = null;
    private boolean hasTouch = false;
    private float headerHeight = 0.0f;
    public boolean isNestParent = false;
    boolean isStartFling = false;
    private Float lastY = Float.valueOf(0.0f);
    RecyclerView.OnScrollListener mChildScrollListener;
    private int mCurrentDy = 0;
    private FlingHelper mFlingHelper;
    private WXGesture mGesture;
    private String mInstanceId;
    RecyclerView.OnScrollListener mParentScrollListener;
    private boolean scrollable = true;
    private int totalDy = 0;
    private int velocityY = 0;

    static /* synthetic */ int access$212(WXRecyclerView x0, int x1) {
        int i = x0.totalDy + x1;
        x0.totalDy = i;
        return i;
    }

    public void setNestInfo(JSONObject nestInfo) {
        this.NestInfo = nestInfo;
        if (nestInfo != null) {
            this.isNestParent = nestInfo.getBooleanValue("isNestParent");
            this.mInstanceId = nestInfo.getString("instanceId");
            if (this.mFlingHelper == null) {
                this.mFlingHelper = new FlingHelper(getContext());
            }
            if (this.isNestParent) {
                setDescendantFocusability(131072);
                if (this.mParentScrollListener == null) {
                    this.headerHeight = nestInfo.getFloat("headerHeight").floatValue();
                    AnonymousClass1 r0 = new RecyclerView.OnScrollListener() {
                        /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass1 */

                        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                        public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                            super.onScrollStateChanged(recyclerView, newState);
                            if (newState == 0) {
                                WXRecyclerView.this.mCurrentDy = 0;
                                WXRecyclerView.this.dispatchChildFling();
                            }
                        }

                        @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                        public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                            super.onScrolled(recyclerView, dx, dy);
                            WXRecyclerView.this.mCurrentDy = dy;
                            if (WXRecyclerView.this.isStartFling) {
                                WXRecyclerView.this.totalDy = 0;
                                WXRecyclerView.this.isStartFling = false;
                            }
                            WXRecyclerView.access$212(WXRecyclerView.this, dy);
                        }
                    };
                    this.mParentScrollListener = r0;
                    addOnScrollListener(r0);
                }
            } else if (this.mChildScrollListener == null) {
                AnonymousClass2 r02 = new RecyclerView.OnScrollListener() {
                    /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass2 */

                    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                    public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                        if (newState == 0) {
                            WXRecyclerView.this.mCurrentDy = 0;
                            WXRecyclerView.this.dispatchParentFling();
                        }
                        super.onScrollStateChanged(recyclerView, newState);
                    }

                    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                    public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                        super.onScrolled(recyclerView, dx, dy);
                        WXRecyclerView.this.mCurrentDy = dy;
                        if (WXRecyclerView.this.isStartFling) {
                            WXRecyclerView.this.totalDy = 0;
                            WXRecyclerView.this.isStartFling = false;
                        }
                        WXRecyclerView.access$212(WXRecyclerView.this, dy);
                    }
                };
                this.mChildScrollListener = r02;
                addOnScrollListener(r02);
            }
        }
    }

    public int getCurrentDy() {
        return this.mCurrentDy;
    }

    public void callBackNestParent(String ref, String instanceId, float headerHeight2) {
        WXRecyclerView parent = getParentRecyclerView();
        if (parent != null) {
            JSONObject nestInfo = new JSONObject();
            nestInfo.put("isNestParent", (Object) true);
            nestInfo.put("instanceId", (Object) instanceId);
            nestInfo.put("nestChildRef", (Object) ref);
            nestInfo.put("headerHeight", (Object) Float.valueOf(headerHeight2));
            parent.setNestInfo(nestInfo);
        }
    }

    public WXRecyclerView(Context context) {
        super(context);
    }

    public WXRecyclerView(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    public boolean isScrollable() {
        return this.scrollable;
    }

    public void setScrollable(boolean scrollable2) {
        this.scrollable = scrollable2;
    }

    public void initView(Context context, int type, int orientation) {
        initView(context, type, 1, 32.0f, orientation);
    }

    public void initView(Context context, int type, int columnCount, float columnGap, final int orientation) {
        if (type == 2) {
            setLayoutManager(new GridLayoutManager(context, columnCount, false, orientation) {
                /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass3 */

                @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception e) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.GridLayoutManager, androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } else if (type == 3) {
            setLayoutManager(new ExtendedStaggeredGridLayoutManager(columnCount, orientation) {
                /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass4 */

                @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.StaggeredGridLayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception e) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.StaggeredGridLayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        } else if (type == 1) {
            setLayoutManager(new LinearLayoutManager(context, false, orientation) {
                /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass5 */

                @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
                public boolean canScrollVertically() {
                    try {
                        return WXRecyclerView.this.canParentScrollVertically(orientation, super.canScrollVertically());
                    } catch (Exception e) {
                        return true;
                    }
                }

                @Override // androidx.recyclerview.widget.RecyclerView.LayoutManager, androidx.recyclerview.widget.LinearLayoutManager
                public void onLayoutChildren(RecyclerView.Recycler recycler, RecyclerView.State state) {
                    try {
                        super.onLayoutChildren(recycler, state);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean canParentScrollVertically(int orientation, boolean defV) {
        if (orientation == 1 && orientation == 1) {
            try {
                if (this.NestInfo != null && this.isNestParent) {
                    WXRecyclerView childRecyclerView = getChildRecylerView();
                    if (childRecyclerView == null) {
                        return true;
                    }
                    Rect rect = new Rect();
                    childRecyclerView.getLocalVisibleRect(rect);
                    if (childRecyclerView.getHeight() - rect.bottom != 0 || childRecyclerView.isScrollTop()) {
                        return true;
                    }
                    return false;
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return defV;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture) {
        this.mGesture = wxGesture;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.mGesture;
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean onTouchEvent(MotionEvent event) {
        View parent;
        RecyclerView childRecyclerView;
        int deltaY;
        if (!this.scrollable) {
            return true;
        }
        if (this.NestInfo != null && this.isNestParent) {
            if (this.lastY.floatValue() == 0.0f) {
                this.lastY = Float.valueOf(event.getY());
            }
            if (!(!isScrollEnd() || (childRecyclerView = getChildRecylerView()) == null || (deltaY = (int) (this.lastY.floatValue() - event.getY())) == 0)) {
                childRecyclerView.scrollBy(0, deltaY);
            }
            this.lastY = Float.valueOf(event.getY());
        }
        if (event.getAction() == 1 && (parent = (View) getParent().getParent()) != null && parent.hasOnClickListeners() && (parent instanceof BounceRecyclerView) && pointInView(event.getX(), event.getY(), 0.0f) && getScrollState() == 0) {
            parent.performClick();
        }
        return super.onTouchEvent(event);
    }

    public boolean dispatchTouchEvent(MotionEvent event) {
        this.hasTouch = true;
        if (this.NestInfo != null) {
            if (this.isNestParent) {
                if (event != null && event.getAction() == 0) {
                    this.velocityY = 0;
                    stopScroll();
                }
                if (!(event == null || event.getAction() == 2)) {
                    this.lastY = Float.valueOf(0.0f);
                }
            } else if (event != null && event.getAction() == 0) {
                this.velocityY = 0;
            }
        }
        boolean result = super.dispatchTouchEvent(event);
        WXGesture wXGesture = this.mGesture;
        if (wXGesture != null) {
            return result | wXGesture.onTouch(this, event);
        }
        return result;
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean onInterceptTouchEvent(MotionEvent e) {
        return super.onInterceptTouchEvent(e);
    }

    public void scrollTo(boolean smooth, int position, final int offset, final int orientation) {
        try {
            RecyclerView.LayoutManager layoutManager = getLayoutManager();
            stopScroll();
            if (smooth) {
                if (orientation == 1) {
                    if (layoutManager instanceof LinearLayoutManager) {
                        int firstPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
                        int lastPostition = ((LinearLayoutManager) layoutManager).findLastVisibleItemPosition();
                        if (position >= firstPosition && position <= lastPostition) {
                            smoothScrollBy(0, getChildAt(position - firstPosition).getTop() + offset);
                            return;
                        }
                    } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                        int[] firstPosition2 = ((StaggeredGridLayoutManager) layoutManager).findFirstVisibleItemPositions(null);
                        int[] lastPostition2 = ((StaggeredGridLayoutManager) layoutManager).findLastCompletelyVisibleItemPositions(null);
                        if (position >= firstPosition2[0] && position <= lastPostition2[0]) {
                            smoothScrollBy(0, getChildAt(position - firstPosition2[0]).getTop() + offset);
                            return;
                        }
                    }
                }
                smoothScrollToPosition(position);
                if (offset != 0) {
                    setOnSmoothScrollEndListener(new ExtendedLinearLayoutManager.OnSmoothScrollEndListener() {
                        /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass6 */

                        @Override // com.taobao.weex.ui.view.listview.ExtendedLinearLayoutManager.OnSmoothScrollEndListener
                        public void onStop() {
                            WXRecyclerView.this.post(WXThread.secure(new Runnable() {
                                /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass6.AnonymousClass1 */

                                public void run() {
                                    if (orientation == 1) {
                                        WXRecyclerView.this.smoothScrollBy(0, offset);
                                    } else {
                                        WXRecyclerView.this.smoothScrollBy(offset, 0);
                                    }
                                }
                            }));
                        }
                    });
                }
            } else if (layoutManager instanceof LinearLayoutManager) {
                ((LinearLayoutManager) layoutManager).scrollToPositionWithOffset(position, -offset);
            } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                ((StaggeredGridLayoutManager) layoutManager).scrollToPositionWithOffset(position, -offset);
            }
        } catch (Exception e) {
        }
    }

    public void scrollTo(final int x, final int y, final int orientation) {
        postDelayed(WXThread.secure(new Runnable() {
            /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass7 */

            public void run() {
                int offset;
                RecyclerView.LayoutManager layoutManager = WXRecyclerView.this.getLayoutManager();
                if (orientation == 1) {
                    offset = y;
                } else {
                    offset = x;
                }
                if (layoutManager instanceof LinearLayoutManager) {
                    ((LinearLayoutManager) layoutManager).scrollToPositionWithOffset(0, -offset);
                } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                    ((StaggeredGridLayoutManager) layoutManager).scrollToPositionWithOffset(0, -offset);
                }
            }
        }), 100);
    }

    public void setOnSmoothScrollEndListener(final ExtendedLinearLayoutManager.OnSmoothScrollEndListener onSmoothScrollEndListener) {
        addOnScrollListener(new RecyclerView.OnScrollListener() {
            /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass8 */

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                if (newState == 0) {
                    recyclerView.removeOnScrollListener(this);
                    ExtendedLinearLayoutManager.OnSmoothScrollEndListener onSmoothScrollEndListener = onSmoothScrollEndListener;
                    if (onSmoothScrollEndListener != null) {
                        onSmoothScrollEndListener.onStop();
                    }
                }
            }
        });
    }

    private WXRecyclerView getParentRecyclerView() {
        WXComponent component;
        WXListComponent listComponent;
        JSONObject jSONObject = this.NestInfo;
        if (jSONObject == null || this.isNestParent || (component = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(this.mInstanceId, jSONObject.getString("listParentId"))) == null || (listComponent = getListComponent(component)) == null || listComponent.getHostView() == null) {
            return null;
        }
        return (WXRecyclerView) ((BounceRecyclerView) listComponent.getHostView()).getInnerView();
    }

    private WXRecyclerView getChildRecylerView() {
        WXComponent component;
        WXListComponent listComponent;
        JSONObject jSONObject = this.NestInfo;
        if (jSONObject == null || !this.isNestParent) {
            return null;
        }
        if (jSONObject.getBooleanValue("isSwipelist")) {
            component = WXSDKManager.getInstance().getWXRenderManager().getWXComponentById(this.mInstanceId, this.NestInfo.getString("swipeId"));
            if (!(component == null || (component = getDCWXSliderComponent(component)) == null || !(component instanceof DCWXSlider))) {
                component = ((DCWXSlider) component).getChild(((DCWXSlider) component).getCurrentIndex());
            }
        } else {
            component = WXSDKManager.getInstance().getWXRenderManager().getWXComponent(this.mInstanceId, this.NestInfo.getString("nestChildRef"));
        }
        if (component == null || (listComponent = getListComponent(component)) == null || listComponent.getHostView() == null) {
            return null;
        }
        return (WXRecyclerView) ((BounceRecyclerView) listComponent.getHostView()).getInnerView();
    }

    public WXListComponent getListComponent(WXComponent component) {
        if (component instanceof WXListComponent) {
            return (WXListComponent) component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        if (container.getChildCount() <= 0) {
            return null;
        }
        for (int i = 0; i < container.getChildCount(); i++) {
            WXListComponent listComponent = getListComponent(container.getChild(i));
            if (listComponent != null) {
                return listComponent;
            }
        }
        return null;
    }

    public DCWXSlider getDCWXSliderComponent(WXComponent component) {
        if (component instanceof DCWXSlider) {
            return (DCWXSlider) component;
        }
        if (!(component instanceof WXVContainer)) {
            return null;
        }
        WXVContainer container = (WXVContainer) component;
        if (container.getChildCount() <= 0) {
            return null;
        }
        for (int i = 0; i < container.getChildCount(); i++) {
            DCWXSlider ve = getDCWXSliderComponent(container.getChild(i));
            if (ve != null) {
                return ve;
            }
        }
        return null;
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public boolean fling(int velX, int velY) {
        if (!isAttachedToWindow()) {
            return false;
        }
        boolean fling = super.fling(velX, velY);
        if (this.NestInfo != null) {
            if (this.isNestParent) {
                if (!fling || velY <= 0) {
                    this.velocityY = 0;
                } else {
                    this.isStartFling = true;
                    this.velocityY = velY;
                }
            } else if (!fling || velY >= 0) {
                this.velocityY = 0;
            } else {
                this.isStartFling = true;
                this.velocityY = velY;
            }
        }
        return fling;
    }

    public boolean isNestScroll() {
        return this.NestInfo != null;
    }

    public boolean isScrollTop() {
        return !canScrollVertically(-1);
    }

    private boolean isScrollEnd() {
        return true ^ canScrollVertically(1);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchChildFling() {
        int i;
        if (isScrollEnd() && (i = this.velocityY) != 0) {
            double splineFlingDistance = this.mFlingHelper.getSplineFlingDistance(i);
            int i2 = this.totalDy;
            if (splineFlingDistance > ((double) i2)) {
                childFling(this.mFlingHelper.getVelocityByDistance(splineFlingDistance - ((double) i2)));
            }
        }
        this.totalDy = 0;
        this.velocityY = 0;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchParentFling() {
        int i;
        WXRecyclerView parentRecyclerView = getParentRecyclerView();
        if (parentRecyclerView != null && isScrollTop() && (i = this.velocityY) != 0) {
            double flingDistance = this.mFlingHelper.getSplineFlingDistance(i);
            if (flingDistance > ((double) Math.abs(this.totalDy))) {
                parentRecyclerView.fling(0, -this.mFlingHelper.getVelocityByDistance(((double) this.totalDy) + flingDistance));
            }
            this.totalDy = 0;
            this.velocityY = 0;
        }
    }

    private void childFling(int velY) {
        RecyclerView childRecyclerView = getChildRecylerView();
        if (childRecyclerView != null) {
            childRecyclerView.fling(0, velY);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView
    public void scrollToPosition(final int position) {
        if (!this.isNestParent || this.NestInfo == null) {
            super.scrollToPosition(position);
            return;
        }
        RecyclerView childRecyclerView = getChildRecylerView();
        if (childRecyclerView != null) {
            childRecyclerView.scrollToPosition(position);
        }
        postDelayed(new Runnable() {
            /* class com.taobao.weex.ui.view.listview.WXRecyclerView.AnonymousClass9 */

            public void run() {
                WXRecyclerView.super.scrollToPosition(position);
            }
        }, 50);
    }

    public boolean onStartNestedScroll(View child, View target, int nestedScrollAxes) {
        if (!this.isNestParent || this.NestInfo == null || target == null || !(target instanceof WXRecyclerView) || ((WXRecyclerView) target).isNestParent) {
            return super.onStartNestedScroll(child, target, nestedScrollAxes);
        }
        return true;
    }

    public void onNestedPreScroll(View target, int dx, int dy, int[] consumed) {
        if (this.isNestParent && this.NestInfo != null) {
            WXRecyclerView childRecyclerView = getChildRecylerView();
            boolean isParentCanScroll = dy > 0 && !isScrollEnd();
            boolean isChildCanNotScroll = dy < 0 && childRecyclerView != null && childRecyclerView.isScrollTop();
            if (isParentCanScroll || isChildCanNotScroll) {
                scrollBy(0, dy);
                consumed[1] = dy;
            }
        }
    }

    public boolean onNestedFling(View target, float velocityX, float velocityY2, boolean consumed) {
        if (!this.isNestParent || this.NestInfo == null) {
            return super.onNestedFling(target, velocityX, velocityY2, consumed);
        }
        return true;
    }

    public boolean onNestedPreFling(View target, float velocityX, float velocityY2) {
        if (!this.isNestParent || this.NestInfo == null) {
            return super.onNestedPreFling(target, velocityX, velocityY2);
        }
        WXRecyclerView childRecyclerView = getChildRecylerView();
        boolean isParentCanFling = velocityY2 > 0.0f && !isScrollEnd();
        boolean isChildCanNotFling = velocityY2 < 0.0f && childRecyclerView != null && childRecyclerView.isScrollTop();
        if (!isParentCanFling && !isChildCanNotFling) {
            return false;
        }
        fling(0, (int) velocityY2);
        return true;
    }

    public boolean pointInView(float localX, float localY, float slop) {
        return localX >= (-slop) && localY >= (-slop) && localX < ((float) (getRight() - getLeft())) + slop && localY < ((float) (getBottom() - getTop())) + slop;
    }

    /* access modifiers changed from: protected */
    public void onScrollChanged(int l, int t, int oldl, int oldt) {
        super.onScrollChanged(l, t, oldl, oldt);
        AppEventForBlurManager.onScrollChanged(l, t);
    }
}
