package com.taobao.weex.ui.view.listview.adapter;

import android.view.ViewGroup;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.taobao.weex.ui.view.listview.adapter.ListBaseViewHolder;

public class RecyclerViewBaseAdapter<T extends ListBaseViewHolder> extends RecyclerView.Adapter<T> {
    private IRecyclerAdapterListener iRecyclerAdapterListener;

    public RecyclerViewBaseAdapter(IRecyclerAdapterListener Listener) {
        this.iRecyclerAdapterListener = Listener;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public T onCreateViewHolder(ViewGroup parent, int viewType) {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            return (T) ((ListBaseViewHolder) iRecyclerAdapterListener2.onCreateViewHolder(parent, viewType));
        }
        return null;
    }

    public void onViewAttachedToWindow(T holder) {
        ViewGroup.LayoutParams lp;
        super.onViewAttachedToWindow((RecyclerView.ViewHolder) holder);
        if (holder != null && holder.isFullSpan() && (lp = ((ListBaseViewHolder) holder).itemView.getLayoutParams()) != null && (lp instanceof StaggeredGridLayoutManager.LayoutParams)) {
            ((StaggeredGridLayoutManager.LayoutParams) lp).setFullSpan(true);
        }
    }

    public void onViewDetachedFromWindow(T holder) {
        super.onViewDetachedFromWindow((RecyclerView.ViewHolder) holder);
        if (holder != null) {
            holder.setComponentUsing(false);
        }
    }

    public void onBindViewHolder(T viewHolder, int i) {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            iRecyclerAdapterListener2.onBindViewHolder(viewHolder, i);
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemViewType(int position) {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            return iRecyclerAdapterListener2.getItemViewType(position);
        }
        return position;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public long getItemId(int position) {
        return this.iRecyclerAdapterListener.getItemId(position);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            return iRecyclerAdapterListener2.getItemCount();
        }
        return 0;
    }

    public void onViewRecycled(T holder) {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            iRecyclerAdapterListener2.onViewRecycled(holder);
        }
        super.onViewRecycled((RecyclerView.ViewHolder) holder);
    }

    public boolean onFailedToRecycleView(T holder) {
        IRecyclerAdapterListener iRecyclerAdapterListener2 = this.iRecyclerAdapterListener;
        if (iRecyclerAdapterListener2 != null) {
            return iRecyclerAdapterListener2.onFailedToRecycleView(holder);
        }
        return super.onFailedToRecycleView((RecyclerView.ViewHolder) holder);
    }
}
