package com.taobao.weex.ui.view.listview.adapter;

import android.graphics.Canvas;
import android.view.View;
import androidx.recyclerview.widget.RecyclerView;

public class TransformItemDecoration extends RecyclerView.ItemDecoration {
    float mAlpha = -1.0f;
    boolean mIsVertical = true;
    int mRotation = 0;
    float mScaleX = 0.0f;
    float mScaleY = 0.0f;
    int mXTranslate = 0;
    int mYTranslate = 0;

    public TransformItemDecoration(boolean isVertical, float alpha, int translateX, int translateY, int rotation, float scaleX, float scaleY) {
        this.mIsVertical = isVertical;
        this.mAlpha = alpha;
        this.mXTranslate = translateX;
        this.mYTranslate = translateY;
        this.mRotation = rotation;
        this.mScaleX = scaleX;
        this.mScaleY = scaleY;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.ItemDecoration
    public void onDrawOver(Canvas c, RecyclerView parent, RecyclerView.State state) {
        super.onDrawOver(c, parent, state);
        int width = parent.getWidth();
        int height = parent.getHeight();
        int count = parent.getChildCount();
        for (int i = 0; i < count; i++) {
            updateItem(parent.getChildAt(i), width, height);
        }
    }

    private void updateItem(View child, int width, int height) {
        int childCenter;
        int size;
        int containerSize;
        if (this.mIsVertical) {
            containerSize = height;
            size = child.getHeight();
            childCenter = child.getTop() + (size / 2);
        } else {
            containerSize = width;
            size = child.getWidth();
            childCenter = child.getLeft() + (size / 2);
        }
        float effectsAmount = Math.min(1.0f, Math.max(-1.0f, (1.0f / ((float) ((containerSize + size) / 2))) * ((float) (childCenter - (containerSize / 2)))));
        float f = this.mAlpha;
        if (f > 0.0f) {
            child.setAlpha(1.0f - (f * Math.abs(effectsAmount)));
        }
        if (this.mScaleX > 0.0f || this.mScaleY > 0.0f) {
            child.setScaleX(1.0f - (this.mScaleX * Math.abs(effectsAmount)));
            child.setScaleY(1.0f - (this.mScaleY * Math.abs(effectsAmount)));
        }
        int i = this.mRotation;
        if (i != 0) {
            child.setRotation(((float) i) * effectsAmount);
        }
        int i2 = this.mXTranslate;
        if (i2 != 0) {
            child.setTranslationX(((float) i2) * Math.abs(effectsAmount));
        }
        int i3 = this.mYTranslate;
        if (i3 != 0) {
            child.setTranslationY(((float) i3) * Math.abs(effectsAmount));
        }
    }
}
