package com.taobao.weex.ui.view.listview.adapter;

import android.view.View;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.taobao.weex.utils.WXLogUtils;
import java.lang.ref.WeakReference;

public class WXRecyclerViewOnScrollListener extends RecyclerView.OnScrollListener {
    private boolean isLayoutRTL = false;
    protected LAYOUT_MANAGER_TYPE layoutManagerType;
    private WeakReference<IOnLoadMoreListener> listener;
    private int mCurrentScrollState = 0;
    private int mDy = 0;
    private int[] mFirstPositions;
    private int mFirstVisibleItemPosition;
    private int[] mLastPositions;
    private int mLastVisibleItemPosition;

    public enum LAYOUT_MANAGER_TYPE {
        LINEAR,
        GRID,
        STAGGERED_GRID
    }

    public void setLayoutRTL(boolean layoutRTL) {
        this.isLayoutRTL = layoutRTL;
    }

    public WXRecyclerViewOnScrollListener(IOnLoadMoreListener listener2) {
        this.listener = new WeakReference<>(listener2);
    }

    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
    public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
        WeakReference<IOnLoadMoreListener> weakReference;
        WeakReference<IOnLoadMoreListener> weakReference2;
        super.onScrollStateChanged(recyclerView, newState);
        this.mCurrentScrollState = newState;
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        int visibleItemCount = layoutManager.getChildCount();
        int totalItemCount = layoutManager.getItemCount();
        if (visibleItemCount != 0) {
            int bottomOffset = (((totalItemCount - this.mLastVisibleItemPosition) - 1) * recyclerView.getHeight()) / visibleItemCount;
            if (visibleItemCount > 0 && this.mCurrentScrollState == 0) {
                if (recyclerView.isHorizontalScrollBarEnabled()) {
                    View lastChildView = recyclerView.getLayoutManager().getChildAt(visibleItemCount - 1);
                    int lastPosition = recyclerView.getLayoutManager().getPosition(lastChildView);
                    if (lastChildView != null && lastPosition == totalItemCount - 1) {
                        if (this.isLayoutRTL) {
                            if (layoutManager.getDecoratedLeft(lastChildView) >= -50 && (weakReference2 = this.listener) != null && weakReference2.get() != null) {
                                this.listener.get().onLoadMore(bottomOffset);
                            }
                        } else if (layoutManager.getDecoratedRight(lastChildView) <= recyclerView.getWidth() && (weakReference = this.listener) != null && weakReference.get() != null) {
                            this.listener.get().onLoadMore(bottomOffset);
                        }
                    }
                } else {
                    View view = layoutManager.getChildAt(this.mLastVisibleItemPosition);
                    if (view != null) {
                        int lastBottom = layoutManager.getDecoratedBottom(view);
                        int recyclerViewHeight = recyclerView.getHeight();
                        if (lastBottom + 50 < recyclerViewHeight || lastBottom > recyclerViewHeight) {
                            return;
                        }
                    } else {
                        int i = this.mDy;
                        if (i == 0 || i < 0) {
                            return;
                        }
                    }
                    WeakReference<IOnLoadMoreListener> weakReference3 = this.listener;
                    if (!(weakReference3 == null || weakReference3.get() == null)) {
                        this.listener.get().onLoadMore(bottomOffset);
                    }
                    this.mDy = 0;
                }
            }
        }
    }

    @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
    public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
        IOnLoadMoreListener iOnLoadMoreListener;
        super.onScrolled(recyclerView, dx, dy);
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        WeakReference<IOnLoadMoreListener> weakReference = this.listener;
        if (weakReference != null && (iOnLoadMoreListener = weakReference.get()) != null) {
            iOnLoadMoreListener.onBeforeScroll(dx, dy);
            this.mDy = dy;
            if (layoutManager instanceof LinearLayoutManager) {
                this.layoutManagerType = LAYOUT_MANAGER_TYPE.LINEAR;
                LinearLayoutManager linearLayoutManager = (LinearLayoutManager) layoutManager;
                this.mLastVisibleItemPosition = linearLayoutManager.findLastVisibleItemPosition();
                iOnLoadMoreListener.notifyAppearStateChange(linearLayoutManager.findFirstVisibleItemPosition(), this.mLastVisibleItemPosition, dx, dy);
            } else if (layoutManager instanceof GridLayoutManager) {
                this.layoutManagerType = LAYOUT_MANAGER_TYPE.GRID;
                GridLayoutManager gridLayoutManager = (GridLayoutManager) layoutManager;
                this.mLastVisibleItemPosition = gridLayoutManager.findLastVisibleItemPosition();
                iOnLoadMoreListener.notifyAppearStateChange(gridLayoutManager.findFirstVisibleItemPosition(), this.mLastVisibleItemPosition, dx, dy);
            } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                this.layoutManagerType = LAYOUT_MANAGER_TYPE.STAGGERED_GRID;
                StaggeredGridLayoutManager staggeredGridLayoutManager = (StaggeredGridLayoutManager) layoutManager;
                int newSpanCount = staggeredGridLayoutManager.getSpanCount();
                int[] iArr = this.mLastPositions;
                if (iArr == null || newSpanCount != iArr.length) {
                    this.mLastPositions = new int[newSpanCount];
                }
                int[] iArr2 = this.mFirstPositions;
                if (iArr2 == null || newSpanCount != iArr2.length) {
                    this.mFirstPositions = new int[newSpanCount];
                }
                try {
                    staggeredGridLayoutManager.findFirstVisibleItemPositions(this.mFirstPositions);
                    this.mFirstVisibleItemPosition = findMin(this.mFirstPositions);
                    staggeredGridLayoutManager.findLastVisibleItemPositions(this.mLastPositions);
                    int findMax = findMax(this.mLastPositions);
                    this.mLastVisibleItemPosition = findMax;
                    iOnLoadMoreListener.notifyAppearStateChange(this.mFirstVisibleItemPosition, findMax, dx, dy);
                } catch (Exception e) {
                    e.printStackTrace();
                    WXLogUtils.e(e.toString());
                }
            } else {
                throw new RuntimeException("Unsupported LayoutManager used. Valid ones are LinearLayoutManager, GridLayoutManager and StaggeredGridLayoutManager");
            }
        }
    }

    private int findMax(int[] lastPositions) {
        int max = lastPositions[0];
        for (int value : lastPositions) {
            if (value > max) {
                max = value;
            }
        }
        return max;
    }

    private int findMin(int[] firstPositions) {
        int min = firstPositions[0];
        for (int value : firstPositions) {
            if (value < min) {
                min = value;
            }
        }
        return min;
    }
}
