package com.taobao.weex.ui.view.refresh.core;

import android.animation.Animator;
import android.animation.ValueAnimator;
import android.content.Context;
import android.os.Build;
import android.util.AttributeSet;
import android.util.TypedValue;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.AbsListView;
import android.widget.FrameLayout;
import android.widget.ListAdapter;
import androidx.core.view.NestedScrollingChild;
import androidx.core.view.NestedScrollingChildHelper;
import androidx.core.view.NestedScrollingParent;
import androidx.core.view.NestedScrollingParentHelper;
import androidx.core.view.ViewCompat;
import androidx.core.view.ViewParentCompat;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import java.util.LinkedList;
import java.util.List;

public class WXSwipeLayout extends FrameLayout implements NestedScrollingParent, NestedScrollingChild {
    private static final float DAMPING = 0.4f;
    private static final int INVALID = -1;
    private static final int LOAD_MORE = 1;
    private static final int PULL_REFRESH = 0;
    private static final float overFlow = 1.0f;
    private WXRefreshView footerView;
    private WXRefreshView headerView;
    private boolean isConfirm;
    private volatile float loadingViewFlowHeight;
    private volatile float loadingViewHeight;
    private int mCurrentAction;
    private ViewParent mNestedScrollAcceptedParent;
    private boolean mNestedScrollInProgress;
    private NestedScrollingChildHelper mNestedScrollingChildHelper;
    private NestedScrollingParentHelper mNestedScrollingParentHelper;
    private final int[] mParentOffsetInWindow;
    private final int[] mParentScrollConsumed;
    private int mProgressBgColor;
    private int mProgressColor;
    private boolean mPullLoadEnable;
    private boolean mPullRefreshEnable;
    private final List<OnRefreshOffsetChangedListener> mRefreshOffsetChangedListeners;
    private int mRefreshViewBgColor;
    private volatile boolean mRefreshing;
    private View mTargetView;
    private WXOnLoadingListener onLoadingListener;
    private WXOnRefreshListener onRefreshListener;
    private volatile float refreshViewFlowHeight;
    private volatile float refreshViewHeight;

    public interface OnRefreshOffsetChangedListener {
        void onOffsetChanged(int i);
    }

    public interface WXOnLoadingListener {
        void onLoading();

        void onPullingUp(float f, int i, float f2);
    }

    public interface WXOnRefreshListener {
        void onPullingDown(float f, int i, float f2);

        void onRefresh();
    }

    static class WXRefreshAnimatorListener implements Animator.AnimatorListener {
        WXRefreshAnimatorListener() {
        }

        public void onAnimationStart(Animator animation) {
        }

        public void onAnimationEnd(Animator animation) {
        }

        public void onAnimationCancel(Animator animation) {
        }

        public void onAnimationRepeat(Animator animation) {
        }
    }

    public WXSwipeLayout(Context context) {
        super(context);
        this.mParentScrollConsumed = new int[2];
        this.mParentOffsetInWindow = new int[2];
        this.mRefreshOffsetChangedListeners = new LinkedList();
        this.mPullRefreshEnable = false;
        this.mPullLoadEnable = false;
        this.mRefreshing = false;
        this.refreshViewHeight = 0.0f;
        this.loadingViewHeight = 0.0f;
        this.refreshViewFlowHeight = 0.0f;
        this.loadingViewFlowHeight = 0.0f;
        this.mCurrentAction = -1;
        this.isConfirm = false;
        initAttrs(context, null);
    }

    public WXSwipeLayout(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.mParentScrollConsumed = new int[2];
        this.mParentOffsetInWindow = new int[2];
        this.mRefreshOffsetChangedListeners = new LinkedList();
        this.mPullRefreshEnable = false;
        this.mPullLoadEnable = false;
        this.mRefreshing = false;
        this.refreshViewHeight = 0.0f;
        this.loadingViewHeight = 0.0f;
        this.refreshViewFlowHeight = 0.0f;
        this.loadingViewFlowHeight = 0.0f;
        this.mCurrentAction = -1;
        this.isConfirm = false;
        initAttrs(context, attrs);
    }

    public WXSwipeLayout(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.mParentScrollConsumed = new int[2];
        this.mParentOffsetInWindow = new int[2];
        this.mRefreshOffsetChangedListeners = new LinkedList();
        this.mPullRefreshEnable = false;
        this.mPullLoadEnable = false;
        this.mRefreshing = false;
        this.refreshViewHeight = 0.0f;
        this.loadingViewHeight = 0.0f;
        this.refreshViewFlowHeight = 0.0f;
        this.loadingViewFlowHeight = 0.0f;
        this.mCurrentAction = -1;
        this.isConfirm = false;
        initAttrs(context, attrs);
    }

    public WXSwipeLayout(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        this.mParentScrollConsumed = new int[2];
        this.mParentOffsetInWindow = new int[2];
        this.mRefreshOffsetChangedListeners = new LinkedList();
        this.mPullRefreshEnable = false;
        this.mPullLoadEnable = false;
        this.mRefreshing = false;
        this.refreshViewHeight = 0.0f;
        this.loadingViewHeight = 0.0f;
        this.refreshViewFlowHeight = 0.0f;
        this.loadingViewFlowHeight = 0.0f;
        this.mCurrentAction = -1;
        this.isConfirm = false;
        initAttrs(context, attrs);
    }

    private void initAttrs(Context context, AttributeSet attrs) {
        if (getChildCount() <= 1) {
            this.mNestedScrollingParentHelper = new NestedScrollingParentHelper(this);
            this.mNestedScrollingChildHelper = new NestedScrollingChildHelper(this);
            setNestedScrollingEnabled(false);
            if (!isInEditMode() || attrs != null) {
                this.mRefreshViewBgColor = 0;
                this.mProgressBgColor = 0;
                this.mProgressColor = -65536;
                return;
            }
            return;
        }
        throw new RuntimeException("WXSwipeLayout should not have more than one child");
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        if (this.mTargetView == null && getChildCount() > 0) {
            this.mTargetView = getChildAt(0);
        }
        if (this.mTargetView == null) {
            return;
        }
        if (this.headerView == null || this.footerView == null) {
            setRefreshView();
        }
    }

    public void addTargetView(View mInnerView) {
        addView(mInnerView, new FrameLayout.LayoutParams(-1, -1));
        setRefreshView();
    }

    private void setRefreshView() {
        FrameLayout.LayoutParams lp = new FrameLayout.LayoutParams(-1, 0);
        WXRefreshView wXRefreshView = new WXRefreshView(getContext());
        this.headerView = wXRefreshView;
        wXRefreshView.setStartEndTrim(0.0f, 0.75f);
        this.headerView.setBackgroundColor(this.mRefreshViewBgColor);
        this.headerView.setProgressBgColor(this.mProgressBgColor);
        this.headerView.setProgressColor(this.mProgressColor);
        this.headerView.setContentGravity(80);
        addView(this.headerView, lp);
        FrameLayout.LayoutParams lp2 = new FrameLayout.LayoutParams(-1, 0);
        lp2.gravity = 80;
        WXRefreshView wXRefreshView2 = new WXRefreshView(getContext());
        this.footerView = wXRefreshView2;
        wXRefreshView2.setStartEndTrim(0.5f, 1.25f);
        this.footerView.setBackgroundColor(this.mRefreshViewBgColor);
        this.footerView.setProgressBgColor(this.mProgressBgColor);
        this.footerView.setProgressColor(this.mProgressColor);
        this.footerView.setContentGravity(48);
        addView(this.footerView, lp2);
    }

    public boolean onInterceptTouchEvent(MotionEvent ev) {
        if ((this.mPullRefreshEnable || this.mPullLoadEnable) && isEnabled() && !canChildScrollUp() && !this.mRefreshing && !this.mNestedScrollInProgress) {
            return super.onInterceptTouchEvent(ev);
        }
        return false;
    }

    @Override // androidx.core.view.NestedScrollingChild
    public void setNestedScrollingEnabled(boolean enabled) {
        this.mNestedScrollingChildHelper.setNestedScrollingEnabled(enabled);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean isNestedScrollingEnabled() {
        return this.mNestedScrollingChildHelper.isNestedScrollingEnabled();
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:17:0x0023 */
    @Override // androidx.core.view.NestedScrollingChild
    public boolean startNestedScroll(int axes) {
        boolean result = this.mNestedScrollingChildHelper.startNestedScroll(axes);
        if (result && this.mNestedScrollAcceptedParent == null) {
            ViewParent parent = getParent();
            View child = this;
            while (true) {
                if (parent == null) {
                    break;
                } else if (ViewParentCompat.onStartNestedScroll(parent, child, this, axes)) {
                    this.mNestedScrollAcceptedParent = parent;
                    break;
                } else {
                    if (parent instanceof View) {
                        child = (View) parent;
                    }
                    parent = parent.getParent();
                    child = child;
                }
            }
        }
        return result;
    }

    @Override // androidx.core.view.NestedScrollingChild
    public void stopNestedScroll() {
        this.mNestedScrollingChildHelper.stopNestedScroll();
        if (this.mNestedScrollAcceptedParent != null) {
            this.mNestedScrollAcceptedParent = null;
        }
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean hasNestedScrollingParent() {
        return this.mNestedScrollingChildHelper.hasNestedScrollingParent();
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedScroll(int dxConsumed, int dyConsumed, int dxUnconsumed, int dyUnconsumed, int[] offsetInWindow) {
        return this.mNestedScrollingChildHelper.dispatchNestedScroll(dxConsumed, dyConsumed, dxUnconsumed, dyUnconsumed, offsetInWindow);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedPreScroll(int dx, int dy, int[] consumed, int[] offsetInWindow) {
        return this.mNestedScrollingChildHelper.dispatchNestedPreScroll(dx, dy, consumed, offsetInWindow);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedFling(float velocityX, float velocityY, boolean consumed) {
        return this.mNestedScrollingChildHelper.dispatchNestedFling(velocityX, velocityY, consumed);
    }

    @Override // androidx.core.view.NestedScrollingChild
    public boolean dispatchNestedPreFling(float velocityX, float velocityY) {
        return this.mNestedScrollingChildHelper.dispatchNestedPreFling(velocityX, velocityY);
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onNestedPreFling(View target, float velocityX, float velocityY) {
        if (isNestedScrollingEnabled()) {
            return dispatchNestedPreFling(velocityX, velocityY);
        }
        return false;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onNestedFling(View target, float velocityX, float velocityY, boolean consumed) {
        if (isNestedScrollingEnabled()) {
            return dispatchNestedFling(velocityX, velocityY, consumed);
        }
        return false;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public boolean onStartNestedScroll(View child, View target, int nestedScrollAxes) {
        boolean result = true;
        boolean result2 = isEnabled() && !this.mRefreshing && (nestedScrollAxes & 2) != 0;
        if (!(target instanceof WXRecyclerView) || !((WXRecyclerView) target).isNestScroll()) {
            return result2;
        }
        if (!result2 || !((WXRecyclerView) target).isScrollTop()) {
            result = false;
        }
        return result;
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedScrollAccepted(View child, View target, int axes) {
        this.mNestedScrollingParentHelper.onNestedScrollAccepted(child, target, axes);
        if (isNestedScrollingEnabled()) {
            startNestedScroll(axes & 2);
            this.mNestedScrollInProgress = true;
        }
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedPreScroll(View target, int dx, int dy, int[] consumed) {
        ViewParent viewParent;
        int[] parentConsumed = this.mParentScrollConsumed;
        if (isNestedScrollingEnabled() && dispatchNestedPreScroll(dx - consumed[0], dy - consumed[1], parentConsumed, null)) {
            consumed[0] = consumed[0] + parentConsumed[0];
            consumed[1] = consumed[1] + parentConsumed[1];
        } else if (this.mPullRefreshEnable || this.mPullLoadEnable) {
            if (!canChildScrollUp() && isNestedScrollingEnabled() && (viewParent = this.mNestedScrollAcceptedParent) != null && viewParent != this.mTargetView) {
                ViewGroup group = (ViewGroup) viewParent;
                if (group.getChildCount() > 0) {
                    int count = group.getChildCount();
                    int i = 0;
                    while (true) {
                        if (i >= count) {
                            break;
                        }
                        View view = group.getChildAt(i);
                        if (view.getVisibility() == 8 || view.getMeasuredHeight() <= 0) {
                            i++;
                        } else if (view.getTop() < 0) {
                            return;
                        }
                    }
                }
            }
            int spinnerDy = (int) calculateDistanceY(target, dy);
            this.mRefreshing = false;
            if (!this.isConfirm) {
                if (spinnerDy < 0 && !canChildScrollUp()) {
                    this.mCurrentAction = 0;
                    this.isConfirm = true;
                } else if (spinnerDy > 0 && !canChildScrollDown() && !this.mRefreshing) {
                    this.mCurrentAction = 1;
                    this.isConfirm = true;
                }
            }
            if (!moveSpinner((float) (-spinnerDy))) {
                return;
            }
            if (!canChildScrollUp() && this.mPullRefreshEnable && this.mTargetView.getTranslationY() > 0.0f && dy > 0) {
                consumed[1] = consumed[1] + dy;
            } else if (canChildScrollDown() || !this.mPullLoadEnable || this.mTargetView.getTranslationY() >= 0.0f || dy >= 0) {
                consumed[1] = consumed[1] + spinnerDy;
            } else {
                consumed[1] = consumed[1] + dy;
            }
        }
    }

    @Override // androidx.core.view.NestedScrollingParent
    public int getNestedScrollAxes() {
        return this.mNestedScrollingParentHelper.getNestedScrollAxes();
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onStopNestedScroll(View child) {
        this.mNestedScrollingParentHelper.onStopNestedScroll(child);
        handlerAction();
        if (isNestedScrollingEnabled()) {
            this.mNestedScrollInProgress = true;
            stopNestedScroll();
        }
    }

    @Override // androidx.core.view.NestedScrollingParent
    public void onNestedScroll(View target, int dxConsumed, int dyConsumed, int dxUnconsumed, int dyUnconsumed) {
        if (isNestedScrollingEnabled()) {
            dispatchNestedScroll(dxConsumed, dyConsumed, dxUnconsumed, dyUnconsumed, this.mParentOffsetInWindow);
        }
    }

    private double calculateDistanceY(View target, int dy) {
        int viewHeight = target.getMeasuredHeight();
        double ratio = ((((double) (((float) viewHeight) - Math.abs(target.getY()))) / 1.0d) / ((double) viewHeight)) * 0.4000000059604645d;
        if (ratio <= 0.01d) {
            ratio = 0.01d;
        }
        return ((double) dy) * ratio;
    }

    private boolean moveSpinner(float distanceY) {
        if (this.mRefreshing) {
            return false;
        }
        if (!canChildScrollUp() && this.mPullRefreshEnable && this.mCurrentAction == 0) {
            FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) this.headerView.getLayoutParams();
            lp.height = (int) (((float) lp.height) + distanceY);
            if (lp.height < 0) {
                lp.height = 0;
            }
            if (lp.height == 0) {
                this.isConfirm = false;
                this.mCurrentAction = -1;
            }
            this.headerView.setLayoutParams(lp);
            this.onRefreshListener.onPullingDown(distanceY, lp.height, this.refreshViewFlowHeight);
            notifyOnRefreshOffsetChangedListener(lp.height);
            this.headerView.setProgressRotation(((float) lp.height) / this.refreshViewFlowHeight);
            moveTargetView((float) lp.height);
            return true;
        } else if (canChildScrollDown() || !this.mPullLoadEnable || this.mCurrentAction != 1) {
            return false;
        } else {
            FrameLayout.LayoutParams lp2 = (FrameLayout.LayoutParams) this.footerView.getLayoutParams();
            lp2.height = (int) (((float) lp2.height) - distanceY);
            if (lp2.height < 0) {
                lp2.height = 0;
            }
            if (lp2.height == 0) {
                this.isConfirm = false;
                this.mCurrentAction = -1;
            }
            this.footerView.setLayoutParams(lp2);
            this.onLoadingListener.onPullingUp(distanceY, lp2.height, this.loadingViewFlowHeight);
            this.footerView.setProgressRotation(((float) lp2.height) / this.loadingViewFlowHeight);
            moveTargetView((float) (-lp2.height));
            return true;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void moveTargetView(float h) {
        this.mTargetView.setTranslationY(h);
    }

    private void handlerAction() {
        if (!isRefreshing()) {
            this.isConfirm = false;
            if (this.mPullRefreshEnable && this.mCurrentAction == 0) {
                FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) this.headerView.getLayoutParams();
                if (((float) lp.height) >= this.refreshViewHeight) {
                    startRefresh(lp.height);
                } else if (lp.height > 0) {
                    resetHeaderView(lp.height);
                } else {
                    resetRefreshState();
                }
            }
            if (this.mPullLoadEnable && this.mCurrentAction == 1) {
                FrameLayout.LayoutParams lp2 = (FrameLayout.LayoutParams) this.footerView.getLayoutParams();
                if (((float) lp2.height) >= this.loadingViewHeight) {
                    startLoadmore(lp2.height);
                } else if (lp2.height > 0) {
                    resetFootView(lp2.height);
                } else {
                    resetLoadmoreState();
                }
            }
        }
    }

    private void startRefresh(int headerViewHeight) {
        this.mRefreshing = true;
        ValueAnimator animator = ValueAnimator.ofFloat((float) headerViewHeight, this.refreshViewHeight);
        animator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass1 */

            public void onAnimationUpdate(ValueAnimator animation) {
                FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) WXSwipeLayout.this.headerView.getLayoutParams();
                lp.height = (int) ((Float) animation.getAnimatedValue()).floatValue();
                WXSwipeLayout.this.notifyOnRefreshOffsetChangedListener(lp.height);
                WXSwipeLayout.this.headerView.setLayoutParams(lp);
                WXSwipeLayout.this.moveTargetView((float) lp.height);
            }
        });
        animator.addListener(new WXRefreshAnimatorListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass2 */

            @Override // com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.WXRefreshAnimatorListener
            public void onAnimationEnd(Animator animation) {
                WXSwipeLayout.this.headerView.startAnimation();
                if (WXSwipeLayout.this.onRefreshListener != null) {
                    WXSwipeLayout.this.onRefreshListener.onRefresh();
                }
            }
        });
        animator.setDuration(300L);
        animator.start();
    }

    private void resetHeaderView(int headerViewHeight) {
        this.headerView.stopAnimation();
        this.headerView.setStartEndTrim(0.0f, 0.75f);
        ValueAnimator animator = ValueAnimator.ofFloat((float) headerViewHeight, 0.0f);
        animator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass3 */

            public void onAnimationUpdate(ValueAnimator animation) {
                FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) WXSwipeLayout.this.headerView.getLayoutParams();
                lp.height = (int) ((Float) animation.getAnimatedValue()).floatValue();
                WXSwipeLayout.this.notifyOnRefreshOffsetChangedListener(lp.height);
                WXSwipeLayout.this.headerView.setLayoutParams(lp);
                WXSwipeLayout.this.moveTargetView((float) lp.height);
            }
        });
        animator.addListener(new WXRefreshAnimatorListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass4 */

            @Override // com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.WXRefreshAnimatorListener
            public void onAnimationEnd(Animator animation) {
                WXSwipeLayout.this.resetRefreshState();
            }
        });
        animator.setDuration(300L);
        animator.start();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void resetRefreshState() {
        this.mRefreshing = false;
        this.isConfirm = false;
        this.mCurrentAction = -1;
    }

    private void startLoadmore(int headerViewHeight) {
        this.mRefreshing = true;
        ValueAnimator animator = ValueAnimator.ofFloat((float) headerViewHeight, this.loadingViewHeight);
        animator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass5 */

            public void onAnimationUpdate(ValueAnimator animation) {
                FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) WXSwipeLayout.this.footerView.getLayoutParams();
                lp.height = (int) ((Float) animation.getAnimatedValue()).floatValue();
                WXSwipeLayout.this.footerView.setLayoutParams(lp);
                WXSwipeLayout.this.moveTargetView((float) (-lp.height));
            }
        });
        animator.addListener(new WXRefreshAnimatorListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass6 */

            @Override // com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.WXRefreshAnimatorListener
            public void onAnimationEnd(Animator animation) {
                WXSwipeLayout.this.footerView.startAnimation();
                if (WXSwipeLayout.this.onLoadingListener != null) {
                    WXSwipeLayout.this.onLoadingListener.onLoading();
                }
            }
        });
        animator.setDuration(300L);
        animator.start();
    }

    private void resetFootView(int headerViewHeight) {
        this.footerView.stopAnimation();
        this.footerView.setStartEndTrim(0.5f, 1.25f);
        ValueAnimator animator = ValueAnimator.ofFloat((float) headerViewHeight, 0.0f);
        animator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass7 */

            public void onAnimationUpdate(ValueAnimator animation) {
                FrameLayout.LayoutParams lp = (FrameLayout.LayoutParams) WXSwipeLayout.this.footerView.getLayoutParams();
                lp.height = (int) ((Float) animation.getAnimatedValue()).floatValue();
                WXSwipeLayout.this.footerView.setLayoutParams(lp);
                WXSwipeLayout.this.moveTargetView((float) (-lp.height));
            }
        });
        animator.addListener(new WXRefreshAnimatorListener() {
            /* class com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.AnonymousClass8 */

            @Override // com.taobao.weex.ui.view.refresh.core.WXSwipeLayout.WXRefreshAnimatorListener
            public void onAnimationEnd(Animator animation) {
                WXSwipeLayout.this.resetLoadmoreState();
            }
        });
        animator.setDuration(300L);
        animator.start();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void resetLoadmoreState() {
        this.mRefreshing = false;
        this.isConfirm = false;
        this.mCurrentAction = -1;
    }

    public boolean canChildScrollUp() {
        if (this.mTargetView == null) {
            return false;
        }
        if (Build.VERSION.SDK_INT >= 14) {
            return ViewCompat.canScrollVertically(this.mTargetView, -1);
        }
        View view = this.mTargetView;
        if (view instanceof AbsListView) {
            AbsListView absListView = (AbsListView) view;
            if (absListView.getChildCount() <= 0) {
                return false;
            }
            if (absListView.getFirstVisiblePosition() > 0 || absListView.getChildAt(0).getTop() < absListView.getPaddingTop()) {
                return true;
            }
            return false;
        } else if (ViewCompat.canScrollVertically(view, -1) || this.mTargetView.getScrollY() > 0) {
            return true;
        } else {
            return false;
        }
    }

    public boolean canChildScrollDown() {
        if (this.mTargetView == null) {
            return false;
        }
        if (Build.VERSION.SDK_INT >= 14) {
            return ViewCompat.canScrollVertically(this.mTargetView, 1);
        }
        View view = this.mTargetView;
        if (view instanceof AbsListView) {
            AbsListView absListView = (AbsListView) view;
            if (absListView.getChildCount() <= 0) {
                return false;
            }
            int lastChildBottom = absListView.getChildAt(absListView.getChildCount() - 1).getBottom();
            if (absListView.getLastVisiblePosition() != ((ListAdapter) absListView.getAdapter()).getCount() - 1 || lastChildBottom > absListView.getMeasuredHeight()) {
                return false;
            }
            return true;
        } else if (ViewCompat.canScrollVertically(view, 1) || this.mTargetView.getScrollY() > 0) {
            return true;
        } else {
            return false;
        }
    }

    public float dipToPx(Context context, float value) {
        return TypedValue.applyDimension(1, value, context.getResources().getDisplayMetrics());
    }

    public void setOnLoadingListener(WXOnLoadingListener onLoadingListener2) {
        this.onLoadingListener = onLoadingListener2;
    }

    public void setOnRefreshListener(WXOnRefreshListener onRefreshListener2) {
        this.onRefreshListener = onRefreshListener2;
    }

    public void addOnRefreshOffsetChangedListener(OnRefreshOffsetChangedListener listener) {
        if (listener != null && !this.mRefreshOffsetChangedListeners.contains(listener)) {
            this.mRefreshOffsetChangedListeners.add(listener);
        }
    }

    public boolean removeOnRefreshOffsetChangedListener(OnRefreshOffsetChangedListener listener) {
        if (listener != null) {
            return this.mRefreshOffsetChangedListeners.remove(listener);
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyOnRefreshOffsetChangedListener(int verticalOffset) {
        int size = this.mRefreshOffsetChangedListeners.size();
        int i = 0;
        while (i < size && i < this.mRefreshOffsetChangedListeners.size()) {
            OnRefreshOffsetChangedListener listener = this.mRefreshOffsetChangedListeners.get(i);
            if (listener != null) {
                listener.onOffsetChanged(verticalOffset);
            }
            i++;
        }
    }

    public void finishPullRefresh() {
        if (this.mCurrentAction == 0) {
            WXRefreshView wXRefreshView = this.headerView;
            resetHeaderView(wXRefreshView == null ? 0 : wXRefreshView.getMeasuredHeight());
        }
    }

    public void finishPullLoad() {
        if (this.mCurrentAction == 1) {
            WXRefreshView wXRefreshView = this.footerView;
            resetFootView(wXRefreshView == null ? 0 : wXRefreshView.getMeasuredHeight());
        }
    }

    public WXRefreshView getHeaderView() {
        return this.headerView;
    }

    public WXRefreshView getFooterView() {
        return this.footerView;
    }

    public boolean isPullLoadEnable() {
        return this.mPullLoadEnable;
    }

    public void setPullLoadEnable(boolean mPullLoadEnable2) {
        this.mPullLoadEnable = mPullLoadEnable2;
    }

    public boolean isPullRefreshEnable() {
        return this.mPullRefreshEnable;
    }

    public void setPullRefreshEnable(boolean mPullRefreshEnable2) {
        this.mPullRefreshEnable = mPullRefreshEnable2;
    }

    public boolean isRefreshing() {
        return this.mRefreshing;
    }

    public void setRefreshHeight(int height) {
        this.refreshViewHeight = (float) height;
        this.refreshViewFlowHeight = this.refreshViewHeight * 1.0f;
    }

    public void setLoadingHeight(int height) {
        this.loadingViewHeight = (float) height;
        this.loadingViewFlowHeight = this.loadingViewHeight * 1.0f;
    }

    public void setRefreshBgColor(int color) {
        this.headerView.setBackgroundColor(color);
    }

    public void setLoadingBgColor(int color) {
        this.footerView.setBackgroundColor(color);
    }
}
