package com.taobao.weex.ui.view.refresh.wrapper;

import android.content.Context;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.WXLoadingLayout;
import com.taobao.weex.ui.view.WXRefreshLayout;
import com.taobao.weex.ui.view.refresh.core.WXRefreshView;
import com.taobao.weex.ui.view.refresh.core.WXSwipeLayout;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;

public abstract class BaseBounceView<T extends View> extends FrameLayout {
    private T mInnerView;
    private int mOrientation;
    protected WXSwipeLayout swipeLayout;

    public abstract void onLoadmoreComplete();

    public abstract void onRefreshingComplete();

    public abstract T setInnerView(Context context);

    public BaseBounceView(Context context, int orientation) {
        this(context, null, orientation);
    }

    public BaseBounceView(Context context, AttributeSet attrs, int orientation) {
        super(context, attrs);
        this.mOrientation = 1;
        this.mOrientation = orientation;
    }

    public int getOrientation() {
        return this.mOrientation;
    }

    public void init(Context context) {
        createBounceView(context);
    }

    /* access modifiers changed from: package-private */
    public boolean isVertical() {
        return this.mOrientation == 1;
    }

    public void setOnRefreshListener(WXSwipeLayout.WXOnRefreshListener onRefreshListener) {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.setOnRefreshListener(onRefreshListener);
        }
    }

    public void setOnLoadingListener(WXSwipeLayout.WXOnLoadingListener onLoadingListener) {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.setOnLoadingListener(onLoadingListener);
        }
    }

    public void finishPullRefresh() {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.finishPullRefresh();
        }
    }

    public void finishPullLoad() {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.finishPullLoad();
        }
    }

    private WXSwipeLayout createBounceView(Context context) {
        WXSwipeLayout wXSwipeLayout = new WXSwipeLayout(context);
        this.swipeLayout = wXSwipeLayout;
        wXSwipeLayout.setLayoutParams(new FrameLayout.LayoutParams(-1, -1));
        T innerView = setInnerView(context);
        this.mInnerView = innerView;
        if (innerView == null) {
            return null;
        }
        this.swipeLayout.addTargetView(innerView);
        addView(this.swipeLayout, -1, -1);
        return this.swipeLayout;
    }

    public T getInnerView() {
        return this.mInnerView;
    }

    public void setHeaderView(WXComponent refresh) {
        WXRefreshView refreshView;
        int colorInt;
        setRefreshEnable(true);
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null && (refreshView = wXSwipeLayout.getHeaderView()) != null) {
            if (refreshView.getParent() == null) {
                this.swipeLayout.addView(refreshView, new FrameLayout.LayoutParams(-1, 0));
            }
            if (refresh != null) {
                this.swipeLayout.setRefreshHeight((int) refresh.getLayoutHeight());
                String bgColor = WXUtils.getString((String) refresh.getStyles().get("backgroundColor"), null);
                if (!(bgColor == null || TextUtils.isEmpty(bgColor) || (colorInt = WXResourceUtils.getColor(bgColor)) == 0)) {
                    this.swipeLayout.setRefreshBgColor(colorInt);
                }
                refreshView.setRefreshView(refresh.getHostView());
            }
        }
    }

    public void setFooterView(WXComponent loading) {
        WXRefreshView refreshView;
        int colorInt;
        setLoadmoreEnable(true);
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null && (refreshView = wXSwipeLayout.getFooterView()) != null) {
            if (refreshView.getParent() == null) {
                FrameLayout.LayoutParams lp = new FrameLayout.LayoutParams(-1, 0);
                lp.gravity = 80;
                this.swipeLayout.addView(refreshView, lp);
            }
            if (loading != null) {
                this.swipeLayout.setLoadingHeight((int) loading.getLayoutHeight());
                String bgColor = WXUtils.getString((String) loading.getStyles().get("backgroundColor"), null);
                if (!(bgColor == null || TextUtils.isEmpty(bgColor) || (colorInt = WXResourceUtils.getColor(bgColor)) == 0)) {
                    this.swipeLayout.setLoadingBgColor(colorInt);
                }
                refreshView.setRefreshView(loading.getHostView());
            }
        }
    }

    public void removeFooterView(WXComponent loading) {
        setLoadmoreEnable(false);
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null && wXSwipeLayout.getFooterView() != null) {
            this.swipeLayout.setLoadingHeight(0);
            this.swipeLayout.getFooterView().removeView(loading.getHostView());
            this.swipeLayout.finishPullLoad();
        }
    }

    public void removeHeaderView(WXComponent refresh) {
        setRefreshEnable(false);
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null && wXSwipeLayout.getHeaderView() != null) {
            this.swipeLayout.setRefreshHeight(0);
            this.swipeLayout.getHeaderView().removeView(refresh.getHostView());
            this.swipeLayout.finishPullRefresh();
        }
    }

    public void setRefreshEnable(boolean enable) {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.setPullRefreshEnable(enable);
        }
    }

    public void setLoadmoreEnable(boolean enable) {
        WXSwipeLayout wXSwipeLayout = this.swipeLayout;
        if (wXSwipeLayout != null) {
            wXSwipeLayout.setPullLoadEnable(enable);
        }
    }

    public void removeView(View view) {
        if (view instanceof WXLoadingLayout) {
            finishPullLoad();
            setLoadmoreEnable(false);
            WXSwipeLayout wXSwipeLayout = this.swipeLayout;
            if (wXSwipeLayout != null) {
                wXSwipeLayout.removeView(wXSwipeLayout.getFooterView());
            }
        } else if (view instanceof WXRefreshLayout) {
            finishPullRefresh();
            setRefreshEnable(false);
            WXSwipeLayout wXSwipeLayout2 = this.swipeLayout;
            if (wXSwipeLayout2 != null) {
                wXSwipeLayout2.removeView(wXSwipeLayout2.getHeaderView());
            }
        } else {
            super.removeView(view);
        }
    }

    public WXSwipeLayout getSwipeLayout() {
        return this.swipeLayout;
    }
}
