package com.taobao.weex.ui.view.refresh.wrapper;

import android.content.Context;
import android.content.res.TypedArray;
import android.util.AttributeSet;
import android.util.Xml;
import android.view.MotionEvent;
import android.view.View;
import com.taobao.weex.R;
import com.taobao.weex.ui.component.list.ListComponentView;
import com.taobao.weex.ui.component.list.StickyHeaderHelper;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.listview.adapter.RecyclerViewBaseAdapter;
import java.lang.reflect.Method;
import org.xmlpull.v1.XmlPullParser;

public class BounceRecyclerView extends BaseBounceView<WXRecyclerView> implements ListComponentView, WXGestureObservable {
    public static final int DEFAULT_COLUMN_COUNT = 1;
    public static final int DEFAULT_COLUMN_GAP = 1;
    private RecyclerViewBaseAdapter adapter;
    private int mColumnCount;
    private float mColumnGap;
    private int mLayoutType;
    private int mOrientation;
    private StickyHeaderHelper mStickyHeaderHelper;

    @Override // com.taobao.weex.ui.component.list.ListComponentView, com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView
    public /* bridge */ /* synthetic */ WXRecyclerView getInnerView() {
        return (WXRecyclerView) super.getInnerView();
    }

    public BounceRecyclerView(Context context, int type, int columnCount, float columnGap, int orientation) {
        super(context, orientation);
        this.adapter = null;
        this.mLayoutType = 1;
        this.mColumnCount = 1;
        this.mColumnGap = 1.0f;
        this.mOrientation = 0;
        this.mLayoutType = type;
        this.mColumnCount = columnCount;
        this.mColumnGap = columnGap;
        this.mOrientation = orientation;
        init(context);
        this.mStickyHeaderHelper = new StickyHeaderHelper(this);
    }

    public BounceRecyclerView(Context context, int type, int orientation) {
        this(context, type, 1, 1.0f, orientation);
    }

    @Override // com.taobao.weex.ui.component.list.ListComponentView
    public void setRecyclerViewBaseAdapter(RecyclerViewBaseAdapter adapter2) {
        this.adapter = adapter2;
        if (getInnerView() != null) {
            ((WXRecyclerView) getInnerView()).setAdapter(adapter2);
        }
    }

    @Override // com.taobao.weex.ui.component.list.ListComponentView
    public RecyclerViewBaseAdapter getRecyclerViewBaseAdapter() {
        return this.adapter;
    }

    public boolean dispatchTouchEvent(MotionEvent event) {
        return super.dispatchTouchEvent(event);
    }

    @Override // com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView
    public WXRecyclerView setInnerView(Context context) {
        WXRecyclerView wxRecyclerView;
        int type;
        if (R.layout.weex_recycler_layout != 0) {
            XmlPullParser parser = getResources().getXml(R.layout.weex_recycler_layout);
            AttributeSet attributes = Xml.asAttributeSet(parser);
            do {
                try {
                    type = parser.next();
                    if (type == 2) {
                        break;
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            } while (type != 1);
            wxRecyclerView = new WXRecyclerView(context, attributes);
            wxRecyclerView.setScrollBarStyle(33554432);
            try {
                Method method = View.class.getDeclaredMethod("initializeScrollbars", TypedArray.class);
                method.setAccessible(true);
                method.invoke(wxRecyclerView, null);
            } catch (Exception e2) {
                e2.printStackTrace();
            }
            if (this.mOrientation == 1) {
                wxRecyclerView.setVerticalScrollBarEnabled(true);
            } else {
                wxRecyclerView.setHorizontalScrollBarEnabled(true);
            }
        } else {
            wxRecyclerView = new WXRecyclerView(context);
        }
        wxRecyclerView.setOverScrollMode(0);
        wxRecyclerView.initView(context, this.mLayoutType, this.mColumnCount, this.mColumnGap, getOrientation());
        return wxRecyclerView;
    }

    @Override // com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView
    public void onRefreshingComplete() {
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = this.adapter;
        if (recyclerViewBaseAdapter != null) {
            recyclerViewBaseAdapter.notifyDataSetChanged();
        }
    }

    @Override // com.taobao.weex.ui.view.refresh.wrapper.BaseBounceView
    public void onLoadmoreComplete() {
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = this.adapter;
        if (recyclerViewBaseAdapter != null) {
            recyclerViewBaseAdapter.notifyDataSetChanged();
        }
    }

    @Override // com.taobao.weex.ui.component.list.ListComponentView
    public void notifyStickyShow(WXCell component) {
        this.mStickyHeaderHelper.notifyStickyShow(component);
    }

    @Override // com.taobao.weex.ui.component.list.ListComponentView
    public void updateStickyView(int currentStickyPos) {
        this.mStickyHeaderHelper.updateStickyView(currentStickyPos);
    }

    @Override // com.taobao.weex.ui.component.list.ListComponentView
    public void notifyStickyRemove(WXCell compToRemove) {
        this.mStickyHeaderHelper.notifyStickyRemove(compToRemove);
    }

    public StickyHeaderHelper getStickyHeaderHelper() {
        return this.mStickyHeaderHelper;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture) {
        ((WXRecyclerView) getInnerView()).registerGestureListener(wxGesture);
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return ((WXRecyclerView) getInnerView()).getGestureListener();
    }
}
