package com.taobao.weex.utils;

import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

public class FunctionParser<K, V> {
    public static final char SPACE = ' ';
    private Lexer lexer;
    private Mapper<K, V> mapper;

    public interface Mapper<K, V> {
        Map<K, V> map(String str, List<String> list);
    }

    /* access modifiers changed from: private */
    public enum Token {
        FUNC_NAME,
        PARAM_VALUE,
        LEFT_PARENT,
        RIGHT_PARENT,
        COMMA
    }

    public FunctionParser(String source, Mapper<K, V> mapper2) {
        this.lexer = new Lexer(source);
        this.mapper = mapper2;
    }

    public LinkedHashMap<K, V> parse() {
        this.lexer.moveOn();
        return definition();
    }

    private LinkedHashMap<K, V> definition() {
        LinkedHashMap<K, V> result = new LinkedHashMap<>();
        do {
            result.putAll(function());
        } while (this.lexer.getCurrentToken() == Token.FUNC_NAME);
        return result;
    }

    private Map<K, V> function() {
        List<String> list = new LinkedList<>();
        String functionName = match(Token.FUNC_NAME);
        match(Token.LEFT_PARENT);
        list.add(match(Token.PARAM_VALUE));
        while (this.lexer.getCurrentToken() == Token.COMMA) {
            match(Token.COMMA);
            list.add(match(Token.PARAM_VALUE));
        }
        match(Token.RIGHT_PARENT);
        return this.mapper.map(functionName, list);
    }

    private String match(Token token) {
        try {
            if (token != this.lexer.getCurrentToken()) {
                return "";
            }
            String value = this.lexer.getCurrentTokenValue();
            this.lexer.moveOn();
            return value;
        } catch (Exception e) {
            WXLogUtils.e(token + "Token doesn't match" + this.lexer.source);
            return "";
        }
    }

    private static class WXInterpretationException extends RuntimeException {
        private WXInterpretationException(String msg) {
            super(msg);
        }
    }

    /* access modifiers changed from: private */
    public static class Lexer {
        private static final char A_LOWER = 'a';
        private static final char A_UPPER = 'A';
        private static final String COMMA = ",";
        private static final char DOT = '.';
        private static final String LEFT_PARENT = "(";
        private static final char MINUS = '-';
        private static final char NINE = '9';
        private static final char PLUS = '+';
        private static final String RIGHT_PARENT = ")";
        private static final char ZERO = '0';
        private static final char Z_LOWER = 'z';
        private static final char Z_UPPER = 'Z';
        private Token current;
        private int pointer;
        private String source;
        private String value;

        private Lexer(String source2) {
            this.pointer = 0;
            this.source = source2;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private Token getCurrentToken() {
            return this.current;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String getCurrentTokenValue() {
            return this.value;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean moveOn() {
            int start = this.pointer;
            while (true) {
                if (this.pointer >= this.source.length()) {
                    break;
                }
                char curChar = this.source.charAt(this.pointer);
                if (curChar == ' ') {
                    int i = this.pointer;
                    this.pointer = i + 1;
                    if (start != i) {
                        break;
                    }
                    start++;
                } else if (isCharacterOrDigit(curChar) || curChar == '.' || curChar == '%' || curChar == '-' || curChar == '+') {
                    this.pointer++;
                } else {
                    int i2 = this.pointer;
                    if (start == i2) {
                        this.pointer = i2 + 1;
                    }
                }
            }
            int i3 = this.pointer;
            if (start != i3) {
                moveOn(this.source.substring(start, i3));
                return true;
            }
            this.current = null;
            this.value = null;
            return false;
        }

        private void moveOn(String token) {
            if ("(".equals(token)) {
                this.current = Token.LEFT_PARENT;
                this.value = "(";
            } else if (")".equals(token)) {
                this.current = Token.RIGHT_PARENT;
                this.value = ")";
            } else if (",".equals(token)) {
                this.current = Token.COMMA;
                this.value = ",";
            } else if (isFuncName(token)) {
                this.current = Token.FUNC_NAME;
                this.value = token;
            } else {
                this.current = Token.PARAM_VALUE;
                this.value = token;
            }
        }

        private boolean isFuncName(CharSequence funcName) {
            for (int i = 0; i < funcName.length(); i++) {
                char letter = funcName.charAt(i);
                if (('a' > letter || letter > 'z') && (('A' > letter || letter > 'Z') && letter != '-')) {
                    return false;
                }
            }
            return true;
        }

        private boolean isCharacterOrDigit(char letter) {
            return ('0' <= letter && letter <= '9') || ('a' <= letter && letter <= 'z') || ('A' <= letter && letter <= 'Z');
        }
    }
}
