package com.taobao.weex.utils;

import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.PaintDrawable;
import android.graphics.drawable.shapes.Shape;
import android.os.Build;
import android.widget.ImageView;

public class ImageDrawable extends PaintDrawable {
    private int bitmapHeight;
    private int bitmapWidth;
    private float[] radii;

    public static Drawable createImageDrawable(Drawable original, ImageView.ScaleType scaleType, float[] borderRadius, int vWidth, int vHeight, boolean gif) {
        Bitmap bm;
        if (!gif && vWidth > 0 && vHeight > 0) {
            if ((original instanceof BitmapDrawable) && (bm = ((BitmapDrawable) original).getBitmap()) != null) {
                ImageDrawable imageDrawable = new ImageDrawable();
                imageDrawable.getPaint().setFilterBitmap(true);
                imageDrawable.bitmapWidth = bm.getWidth();
                imageDrawable.bitmapHeight = bm.getHeight();
                BitmapShader bitmapShader = new BitmapShader(bm, Shader.TileMode.CLAMP, Shader.TileMode.CLAMP);
                updateShaderAndSize(scaleType, vWidth, vHeight, imageDrawable, bitmapShader);
                imageDrawable.getPaint().setShader(bitmapShader);
                return imageDrawable;
            } else if (original instanceof ImageDrawable) {
                ImageDrawable imageDrawable2 = (ImageDrawable) original;
                if (imageDrawable2.getPaint() != null && (imageDrawable2.getPaint().getShader() instanceof BitmapShader)) {
                    updateShaderAndSize(scaleType, vWidth, vHeight, imageDrawable2, (BitmapShader) imageDrawable2.getPaint().getShader());
                    return imageDrawable2;
                }
            }
        }
        return original;
    }

    private static void updateShaderAndSize(ImageView.ScaleType scaleType, int vWidth, int vHeight, ImageDrawable imageDrawable, BitmapShader bitmapShader) {
        Matrix matrix = createShaderMatrix(scaleType, vWidth, vHeight, imageDrawable.bitmapWidth, imageDrawable.bitmapHeight);
        int intrinsicWidth = vWidth;
        int intrinsicHeight = vHeight;
        if (scaleType == ImageView.ScaleType.FIT_CENTER) {
            RectF bitmapRect = new RectF(0.0f, 0.0f, (float) imageDrawable.bitmapWidth, (float) imageDrawable.bitmapHeight);
            RectF contentRect = new RectF();
            matrix.mapRect(contentRect, bitmapRect);
            intrinsicWidth = (int) contentRect.width();
            intrinsicHeight = (int) contentRect.height();
            matrix = createShaderMatrix(scaleType, intrinsicWidth, intrinsicHeight, imageDrawable.bitmapWidth, imageDrawable.bitmapHeight);
        }
        imageDrawable.setIntrinsicWidth(intrinsicWidth);
        imageDrawable.setIntrinsicHeight(intrinsicHeight);
        bitmapShader.setLocalMatrix(matrix);
    }

    private static Matrix createShaderMatrix(ImageView.ScaleType scaleType, int vWidth, int vHeight, int bmWidth, int bmHeight) {
        float scale;
        float translateX = 0.0f;
        float translateY = 0.0f;
        if (bmWidth * vHeight > bmHeight * vWidth) {
            scale = ((float) vHeight) / ((float) bmHeight);
            translateX = (((float) vWidth) - (((float) bmWidth) * scale)) * 0.5f;
        } else {
            scale = ((float) vWidth) / ((float) bmWidth);
            translateY = (((float) vHeight) - (((float) bmHeight) * scale)) * 0.5f;
        }
        Matrix mMatrix = new Matrix();
        if (scaleType == ImageView.ScaleType.FIT_XY) {
            mMatrix.setScale(((float) vWidth) / ((float) bmWidth), ((float) vHeight) / ((float) bmHeight));
        } else if (scaleType == ImageView.ScaleType.FIT_CENTER) {
            mMatrix.setRectToRect(new RectF(0.0f, 0.0f, (float) bmWidth, (float) bmHeight), new RectF(0.0f, 0.0f, (float) vWidth, (float) vHeight), Matrix.ScaleToFit.CENTER);
        } else if (scaleType == ImageView.ScaleType.CENTER_CROP) {
            mMatrix.setScale(scale, scale);
            mMatrix.postTranslate(translateX + 0.5f, 0.5f + translateY);
        }
        return mMatrix;
    }

    private ImageDrawable() {
    }

    public void setCornerRadii(float[] radii2) {
        this.radii = radii2;
        super.setCornerRadii(radii2);
    }

    /* access modifiers changed from: protected */
    public void onDraw(Shape shape, Canvas canvas, Paint paint) {
        if (Build.VERSION.SDK_INT == 21) {
            paint.setAntiAlias(false);
        }
        super.onDraw(shape, canvas, paint);
    }

    public float[] getCornerRadii() {
        return this.radii;
    }

    public int getBitmapHeight() {
        return this.bitmapHeight;
    }

    public int getBitmapWidth() {
        return this.bitmapWidth;
    }
}
