package com.taobao.weex.utils;

import android.content.Intent;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.net.Uri;
import android.text.TextUtils;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.font.FontAdapter;
import com.tencent.connect.common.Constants;
import com.tencent.smtt.sdk.TbsReaderView;
import java.io.File;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class TypefaceUtil {
    public static final String ACTION_TYPE_FACE_AVAILABLE = "type_face_available";
    public static final String FONT_CACHE_DIR_NAME = "font-family";
    private static final String TAG = "TypefaceUtil";
    private static final Map<String, FontDO> sCacheMap = new HashMap();

    public static void putFontDO(FontDO fontDO) {
        if (fontDO != null && !TextUtils.isEmpty(fontDO.getFontFamilyName())) {
            sCacheMap.put(fontDO.getFontFamilyName(), fontDO);
        }
    }

    public static void registerNativeFont(Map<String, Typeface> fonts) {
        if (fonts != null && fonts.size() > 0) {
            for (Map.Entry<String, Typeface> font : fonts.entrySet()) {
                putFontDO(new FontDO(font.getKey(), font.getValue()));
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d(TAG, "register new typeface: " + font.getKey());
                }
            }
        }
    }

    public static FontDO getFontDO(String fontFamilyName) {
        return sCacheMap.get(fontFamilyName);
    }

    public static void removeFontDO(String fontFamilyName) {
        sCacheMap.remove(fontFamilyName);
    }

    public static void applyFontStyle(Paint paint, int style, int weight, String family) {
        int oldStyle;
        Typeface typeface = paint.getTypeface();
        if (typeface == null) {
            oldStyle = 0;
        } else {
            oldStyle = typeface.getStyle();
        }
        int want = 0;
        if (weight == 1 || ((oldStyle & 1) != 0 && weight == -1)) {
            want = 0 | 1;
        }
        if (style == 2 || ((oldStyle & 2) != 0 && style == -1)) {
            want |= 2;
        }
        if (family != null) {
            typeface = getOrCreateTypeface(family, want);
        }
        if (typeface != null) {
            paint.setTypeface(Typeface.create(typeface, want));
        } else {
            paint.setTypeface(Typeface.defaultFromStyle(want));
        }
        if (style >= 0) {
            paint.setTextSkewX((((~(paint.getTypeface() != null ? paint.getTypeface().getStyle() : 0)) & style) & 2) != 0 ? -0.2f : 0.0f);
        }
    }

    public static Typeface getOrCreateTypeface(String family, int style) {
        FontDO fontDo = sCacheMap.get(family);
        if (fontDo == null || fontDo.getTypeface() == null) {
            return Typeface.create(family, style);
        }
        return fontDo.getTypeface();
    }

    private static void loadFromAsset(FontDO fontDo, String path) {
        try {
            Typeface typeface = Typeface.createFromAsset(WXEnvironment.getApplication().getAssets(), path);
            if (typeface != null) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d(TAG, "load asset file success");
                }
                fontDo.setState(2);
                fontDo.setTypeface(typeface);
                return;
            }
            WXLogUtils.e(TAG, "Font asset file not found " + fontDo.getUrl());
        } catch (Exception e) {
            WXLogUtils.e(TAG, e.toString());
        }
    }

    public static void loadTypeface(FontDO fontDo, boolean notify) {
        if (fontDo != null && fontDo.getTypeface() == null && (fontDo.getState() == 3 || fontDo.getState() == 0)) {
            fontDo.setState(1);
            if (fontDo.getType() == 3) {
                loadFromAsset(fontDo, Uri.parse(fontDo.getUrl()).getPath().substring(1));
            } else if (fontDo.getType() == 1) {
                String url = fontDo.getUrl();
                String fontFamily = fontDo.getFontFamilyName();
                String fileName = WXFileUtils.md5(url);
                File dir = new File(getFontCacheDir());
                if (!dir.exists()) {
                    dir.mkdirs();
                }
                String fullPath = dir.getAbsolutePath() + File.separator + fileName;
                if (!loadLocalFontFile(fullPath, fontFamily, false)) {
                    downloadFontByNetwork(url, fullPath, fontFamily);
                }
            } else if ((fontDo.getType() == 2 || fontDo.getType() == 5) && !loadLocalFontFile(fontDo.getUrl(), fontDo.getFontFamilyName(), false)) {
                fontDo.setState(3);
            }
        } else if (notify) {
            notifyFontAvailable(false, fontDo);
        }
    }

    private static void downloadFontByNetwork(final String url, final String fullPath, final String fontFamily) {
        IWXHttpAdapter adapter = WXSDKManager.getInstance().getIWXHttpAdapter();
        if (adapter == null) {
            WXLogUtils.e(TAG, "downloadFontByNetwork() IWXHttpAdapter == null");
            return;
        }
        WXRequest request = new WXRequest();
        request.url = url;
        request.method = Constants.HTTP_GET;
        adapter.sendRequest(request, new IWXHttpAdapter.OnHttpListener() {
            /* class com.taobao.weex.utils.TypefaceUtil.AnonymousClass1 */

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpStart() {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d(TypefaceUtil.TAG, "downloadFontByNetwork begin url:" + url);
                }
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHeadersReceived(int statusCode, Map<String, List<String>> map) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpUploadProgress(int uploadProgress) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpResponseProgress(int loadedLength) {
            }

            @Override // com.taobao.weex.adapter.IWXHttpAdapter.OnHttpListener
            public void onHttpFinish(WXResponse response) {
                boolean result;
                FontDO fontDO;
                int statusCode = 0;
                if (!TextUtils.isEmpty(response.statusCode)) {
                    try {
                        statusCode = Integer.parseInt(response.statusCode);
                    } catch (NumberFormatException e) {
                        statusCode = 0;
                        WXLogUtils.e(TypefaceUtil.TAG, "IWXHttpAdapter onHttpFinish statusCode:" + response.statusCode);
                    }
                }
                if (statusCode < 200 || statusCode > 299 || response.originalData == null) {
                    result = false;
                } else {
                    result = WXFileUtils.saveFile(fullPath, response.originalData, WXEnvironment.getApplication());
                    if (result) {
                        result = TypefaceUtil.loadLocalFontFile(fullPath, fontFamily, true);
                    } else if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d(TypefaceUtil.TAG, "downloadFontByNetwork() onHttpFinish success, but save file failed.");
                    }
                }
                if (!result && (fontDO = (FontDO) TypefaceUtil.sCacheMap.get(fontFamily)) != null) {
                    fontDO.setState(3);
                }
            }
        });
    }

    /* access modifiers changed from: private */
    public static boolean loadLocalFontFile(String path, String fontFamily, boolean hasNetworkDowload) {
        if (TextUtils.isEmpty(path) || TextUtils.isEmpty(fontFamily)) {
            return false;
        }
        try {
            if (!new File(path).exists()) {
                return false;
            }
            Typeface typeface = Typeface.createFromFile(path);
            if (typeface != null) {
                final FontDO fontDo = sCacheMap.get(fontFamily);
                if (fontDo != null) {
                    fontDo.setState(2);
                    fontDo.setTypeface(typeface);
                    fontDo.setFilePath(path);
                    if (WXEnvironment.isApkDebugable()) {
                        WXLogUtils.d(TAG, "load local font file success");
                    }
                    if (hasNetworkDowload) {
                        WXSDKManager.getInstance().getWXRenderManager().postOnUiThread(new Runnable() {
                            /* class com.taobao.weex.utils.TypefaceUtil.AnonymousClass2 */

                            public void run() {
                                TypefaceUtil.notifyFontAvailable(true, FontDO.this);
                            }
                        }, 100);
                    } else {
                        notifyFontAvailable(true, fontDo);
                    }
                    return true;
                }
            } else {
                WXLogUtils.e(TAG, "load local font file failed, can't create font.");
            }
            return false;
        } catch (Exception e) {
            WXLogUtils.e(TAG, e.toString());
        }
    }

    /* access modifiers changed from: private */
    public static void notifyFontAvailable(boolean sendBroadcast, FontDO fontDO) {
        if (sendBroadcast) {
            Intent intent = new Intent(ACTION_TYPE_FACE_AVAILABLE);
            intent.putExtra(Constants.Name.FONT_FAMILY, fontDO.getFontFamilyName());
            intent.putExtra(TbsReaderView.KEY_FILE_PATH, fontDO.getFilePath());
            intent.putExtra("fontUrl", fontDO.getUrl());
            LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).sendBroadcast(intent);
        }
        FontAdapter fontAdapter = WXSDKManager.getInstance().getFontAdapter();
        if (fontAdapter != null) {
            fontAdapter.onFontLoad(fontDO.getFontFamilyName(), fontDO.getUrl(), fontDO.getFilePath());
        }
    }

    private static String getFontCacheDir() {
        return WXEnvironment.getApplication().getCacheDir() + "/" + FONT_CACHE_DIR_NAME;
    }
}
