package com.taobao.weex.utils;

import android.text.TextUtils;
import com.amap.api.maps.model.MyLocationStyle;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.adapter.IWXJSExceptionAdapter;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXJSExceptionInfo;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.CopyOnWriteArraySet;

public class WXExceptionUtils {
    public static String degradeUrl = "BundleUrlDefaultDegradeUrl";
    private static Set<String> sGlobalExceptionRecord = new CopyOnWriteArraySet();

    private static boolean checkNeedReportCauseRepeat(String instanceId, WXErrorCode errCode, String exception) {
        Set<String> recordExceptionHistory;
        if (TextUtils.isEmpty(exception)) {
            return true;
        }
        if (errCode != null && errCode.getErrorGroup() != WXErrorCode.ErrorGroup.JS) {
            return true;
        }
        if (TextUtils.isEmpty(instanceId)) {
            instanceId = "instanceIdNull";
        }
        String targetException = exception.length() > 200 ? exception.substring(0, 200) : exception;
        WXSDKInstance instance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
        if (instance == null) {
            recordExceptionHistory = sGlobalExceptionRecord;
        } else {
            recordExceptionHistory = instance.getApmForInstance().exceptionRecord;
        }
        if (recordExceptionHistory == null) {
            return true;
        }
        if (recordExceptionHistory.contains(targetException)) {
            return false;
        }
        recordExceptionHistory.add(targetException);
        return true;
    }

    public static void commitCriticalExceptionRT(String instanceId, WXErrorCode errCode, String function, String exception, Map<String, String> extParams) {
        try {
            WXLogUtils.e("weex", "commitCriticalExceptionRT :" + errCode + "exception" + exception);
            WXStateRecord.getInstance().recordException(instanceId, exception);
            IWXConfigAdapter configAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
            boolean doCheck = true;
            if (configAdapter != null) {
                doCheck = AbsoluteConst.TRUE.equalsIgnoreCase(configAdapter.getConfig("wxapm", "check_repeat_report", AbsoluteConst.TRUE));
            }
            boolean doReport = true;
            if (doCheck) {
                doReport = checkNeedReportCauseRepeat(instanceId, errCode, exception);
            }
            if (!doReport) {
                return;
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
        commitCriticalExceptionWithDefaultUrl("BundleUrlDefault", instanceId, errCode, function, exception, extParams);
    }

    public static void commitCriticalExceptionWithDefaultUrl(String defaultUrl, String instanceId, WXErrorCode errCode, String function, String exception, Map<String, String> extParams) {
        Map<String, String> commitMap;
        String str;
        String bundleTemplate;
        IWXJSExceptionAdapter adapter = WXSDKManager.getInstance().getIWXJSExceptionAdapter();
        String bundleUrlCommit = TextUtils.isEmpty(defaultUrl) ? "BundleUrlDefault" : defaultUrl;
        String instanceIdCommit = "InstanceIdDefalut";
        if (extParams == null) {
            commitMap = new HashMap<>();
        } else {
            commitMap = extParams;
        }
        commitMap.put("wxSdkInitStartTime", String.valueOf(WXEnvironment.sSDKInitStart));
        commitMap.put("wxSDKInitCostTime", String.valueOf(WXEnvironment.sSDKInitTime));
        commitMap.put("wxSDKCurExceptionTime", String.valueOf(System.currentTimeMillis()));
        commitMap.put("wxUseRuntimeApi", String.valueOf(WXEnvironment.sUseRunTimeApi));
        if (!TextUtils.isEmpty(instanceId)) {
            instanceIdCommit = instanceId;
            WXSDKInstance instance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId);
            if (instance != null) {
                bundleUrlCommit = instance.getApmForInstance().reportPageName;
                Object loadLength = instance.getApmForInstance().extInfo.get(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH);
                commitMap.put(WXInstanceApm.VALUE_BUNDLE_LOAD_LENGTH, loadLength instanceof Integer ? String.valueOf(loadLength) : "unknownLength");
                commitMap.put("templateInfo", instance.getTemplateInfo());
                if (TextUtils.isEmpty(bundleUrlCommit) || bundleUrlCommit.equals("default")) {
                    if (!TextUtils.equals(degradeUrl, "BundleUrlDefaultDegradeUrl")) {
                        bundleUrlCommit = degradeUrl;
                    } else {
                        bundleUrlCommit = WXSDKInstance.requestUrl;
                    }
                }
                for (Map.Entry<String, String> entry : instance.getContainerInfo().entrySet()) {
                    commitMap.put(entry.getKey(), entry.getValue());
                }
                commitMap.put("wxStageList", convertStageToStr(instance));
                String bundleTemplate2 = instance.getTemplate();
                if (bundleTemplate2 == null) {
                    bundleTemplate = "has recycle by gc";
                } else {
                    bundleTemplate = bundleTemplate2.substring(0, Math.min(bundleTemplate2.length(), 300));
                }
                commitMap.put("wxTemplateOfBundle", bundleTemplate);
                Long pageStartTime = instance.getApmForInstance().stageMap.get(WXInstanceApm.KEY_PAGE_STAGES_DOWN_BUNDLE_START);
                if (pageStartTime == null) {
                    pageStartTime = instance.getApmForInstance().stageMap.get(WXInstanceApm.KEY_PAGE_STAGES_RENDER_ORGIGIN);
                }
                if (pageStartTime != null) {
                    commitMap.put("wxUseTime", String.valueOf(WXUtils.getFixUnixTime() - pageStartTime.longValue()));
                }
            }
        } else if (commitMap.size() > 0) {
            if (TextUtils.isEmpty(commitMap.get("weexUrl"))) {
                str = commitMap.get("weexUrl");
            } else {
                str = commitMap.get("bundleUrl");
            }
            bundleUrlCommit = str;
        }
        String illegalValue = commitMap.get(MyLocationStyle.ERROR_CODE);
        if (illegalValue != null && illegalValue.length() > 200) {
            commitMap.remove(MyLocationStyle.ERROR_CODE);
        }
        WXJSExceptionInfo exceptionCommit = new WXJSExceptionInfo(instanceIdCommit, bundleUrlCommit, errCode, function, exception, commitMap);
        if (adapter != null) {
            adapter.onJSException(exceptionCommit);
        }
        WXAnalyzerDataTransfer.transferError(exceptionCommit, instanceId);
    }

    private static String convertStageToStr(WXSDKInstance instance) {
        if (instance == null || instance.getApmForInstance() == null || instance.getApmForInstance().stageMap.isEmpty()) {
            return "noStageRecord";
        }
        List<Map.Entry<String, Long>> list = new ArrayList<>(instance.getApmForInstance().stageMap.entrySet());
        Collections.sort(list, new Comparator<Map.Entry<String, Long>>() {
            /* class com.taobao.weex.utils.WXExceptionUtils.AnonymousClass1 */

            public int compare(Map.Entry<String, Long> o1, Map.Entry<String, Long> o2) {
                return (int) (o1.getValue().longValue() - o2.getValue().longValue());
            }
        });
        StringBuilder builder = new StringBuilder();
        for (Map.Entry<String, Long> entry : list) {
            builder.append(entry.getKey());
            builder.append(Operators.CONDITION_IF_MIDDLE);
            builder.append(entry.getValue());
            builder.append("->");
        }
        return builder.toString();
    }
}
