package com.taobao.weex.utils;

import android.content.Context;
import android.os.Build;
import android.text.TextUtils;
import android.util.Base64;
import io.dcloud.common.util.Md5Utils;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.weex.DCFileUtils;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.Closeable;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.zip.ZipEntry;
import java.util.zip.ZipFile;
import java.util.zip.ZipInputStream;

public class WXFileUtils {
    public static String loadFileOrAsset(String path, Context context) {
        if (TextUtils.isEmpty(path)) {
            return "";
        }
        File file = new File(path);
        if (!file.exists()) {
            return loadAsset(path, context);
        }
        try {
            return readStreamToString(new FileInputStream(file));
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return "";
        }
    }

    public static String loadAsset(String path, Context context) {
        if (context == null || TextUtils.isEmpty(path)) {
            return null;
        }
        try {
            String path2 = DCFileUtils.getAssetPath(path);
            InputStream inputStream = DCFileUtils.loadWeexAsset(path2, context);
            if (inputStream == null) {
                inputStream = context.getAssets().open(path2);
            }
            return readStreamToString(inputStream);
        } catch (IOException e) {
            return "";
        }
    }

    private static String readStreamToString(InputStream inputStream) {
        BufferedReader bufferedReader = null;
        try {
            StringBuilder builder = new StringBuilder(inputStream.available() + 10);
            BufferedReader bufferedReader2 = new BufferedReader(new InputStreamReader(inputStream));
            char[] data = new char[4096];
            while (true) {
                int len = bufferedReader2.read(data);
                if (len <= 0) {
                    break;
                }
                builder.append(data, 0, len);
            }
            String sb = builder.toString();
            try {
                bufferedReader2.close();
            } catch (IOException e) {
                WXLogUtils.e("WXFileUtils loadAsset: ", e);
            }
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e2) {
                    WXLogUtils.e("WXFileUtils loadAsset: ", e2);
                }
            }
            return sb;
        } catch (IOException e3) {
            WXLogUtils.e("", e3);
            if (0 != 0) {
                try {
                    bufferedReader.close();
                } catch (IOException e4) {
                    WXLogUtils.e("WXFileUtils loadAsset: ", e4);
                }
            }
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e5) {
                    WXLogUtils.e("WXFileUtils loadAsset: ", e5);
                }
            }
            return "";
        } catch (Throwable th) {
            if (0 != 0) {
                try {
                    bufferedReader.close();
                } catch (IOException e6) {
                    WXLogUtils.e("WXFileUtils loadAsset: ", e6);
                }
            }
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (IOException e7) {
                    WXLogUtils.e("WXFileUtils loadAsset: ", e7);
                }
            }
            throw th;
        }
    }

    public static byte[] readBytesFromAssets(String path, Context context) {
        if (context == null || TextUtils.isEmpty(path)) {
            return null;
        }
        try {
            byte[] data = new byte[4096];
            int length = context.getAssets().open(path).read(data);
            byte[] result = new byte[length];
            System.arraycopy(data, 0, result, 0, length);
            return result;
        } catch (IOException e) {
            WXLogUtils.e("", e);
            return null;
        }
    }

    public static boolean saveFile(String path, byte[] content, Context context) {
        if (TextUtils.isEmpty(path) || content == null || context == null) {
            return false;
        }
        FileOutputStream outStream = null;
        try {
            outStream = new FileOutputStream(path);
            outStream.write(content);
            try {
                outStream.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
            return true;
        } catch (Exception e2) {
            WXLogUtils.e("WXFileUtils saveFile: " + WXLogUtils.getStackTrace(e2));
            if (outStream != null) {
                try {
                    outStream.close();
                } catch (IOException e3) {
                    e3.printStackTrace();
                }
            }
            return false;
        } catch (Throwable th) {
            if (outStream != null) {
                try {
                    outStream.close();
                } catch (IOException e4) {
                    e4.printStackTrace();
                }
            }
            throw th;
        }
    }

    public static String md5(String template) {
        if (template == null) {
            return "";
        }
        try {
            return md5(template.getBytes("UTF-8"));
        } catch (UnsupportedEncodingException e) {
            return "";
        }
    }

    public static String md5(byte[] bts) {
        try {
            MessageDigest digest = MessageDigest.getInstance(Md5Utils.ALGORITHM);
            digest.update(bts);
            return new BigInteger(1, digest.digest()).toString(16);
        } catch (NoSuchAlgorithmException e) {
            return "";
        }
    }

    public static String base64Md5(String template) {
        if (template == null) {
            return "";
        }
        try {
            return base64Md5(template.getBytes("UTF-8"));
        } catch (UnsupportedEncodingException e) {
            return "";
        }
    }

    public static String base64Md5(byte[] bts) {
        try {
            MessageDigest digest = MessageDigest.getInstance(Md5Utils.ALGORITHM);
            digest.update(bts);
            return Base64.encodeToString(digest.digest(), 2);
        } catch (NoSuchAlgorithmException e) {
            return "";
        }
    }

    private static String[] validCPUABIS() {
        String[] supportedAbis = null;
        if (Build.VERSION.SDK_INT >= 21) {
            supportedAbis = Build.SUPPORTED_ABIS;
        }
        if (supportedAbis != null && supportedAbis.length != 0) {
            return supportedAbis;
        }
        return new String[]{Build.CPU_ABI};
    }

    private static boolean validLibPath(String path) {
        for (String item : validCPUABIS()) {
            if (path.contains(item)) {
                return true;
            }
        }
        return false;
    }

    private static boolean replaceLib(String replaceLibAbi, String currentLibAbi) {
        if (replaceLibAbi == null || currentLibAbi == null) {
            return true;
        }
        boolean replaceFind = false;
        String[] supportedAbis = validCPUABIS();
        for (String item : supportedAbis) {
            if (currentLibAbi.contains(item) && replaceFind) {
                return true;
            }
            if (replaceLibAbi.contains(item)) {
                replaceFind = true;
            }
        }
        return false;
    }

    public static boolean extractSo(String apkFile, String path) throws IOException {
        HashMap<String, String> currentABIMap;
        boolean exist = false;
        if (!PdrUtil.isSafeEntryName(apkFile)) {
            return false;
        }
        if (!PdrUtil.isSafeEntryName(path)) {
            return false;
        }
        HashMap<String, String> currentABIMap2 = new HashMap<>();
        ZipFile zip = new ZipFile(apkFile);
        ZipInputStream zin = new ZipInputStream(new BufferedInputStream(new FileInputStream(apkFile)));
        Enumeration<? extends ZipEntry> entries = zip.entries();
        while (entries.hasMoreElements()) {
            ZipEntry zipEntry = (ZipEntry) entries.nextElement();
            if (!zipEntry.getName().contains("../") && !zipEntry.isDirectory()) {
                if (!validLibPath(zipEntry.getName())) {
                    currentABIMap = currentABIMap2;
                } else if (zipEntry.getName().contains("weex") || zipEntry.getName().equals("libjsc.so") || zipEntry.getName().equals("libJavaScriptCore.so")) {
                    exist = true;
                    String[] fileNames = zipEntry.getName().split("/");
                    String fileName = fileNames[fileNames.length - 1];
                    File zipFile = new File(path + "/" + fileName);
                    if (replaceLib(zipEntry.getName(), currentABIMap2.get(fileName))) {
                        currentABIMap2.put(fileName, zipEntry.getName());
                        if (zipFile.exists()) {
                            zipFile.delete();
                        }
                        InputStream inputStream = zip.getInputStream(zipEntry);
                        byte[] data = new byte[1024];
                        zipFile.createNewFile();
                        FileOutputStream outputStream = new FileOutputStream(zipFile);
                        while (true) {
                            currentABIMap = currentABIMap2;
                            if (inputStream.read(data) == -1) {
                                break;
                            }
                            outputStream.write(data);
                            exist = exist;
                            currentABIMap2 = currentABIMap;
                        }
                        outputStream.close();
                        exist = exist;
                    }
                } else {
                    currentABIMap = currentABIMap2;
                }
                currentABIMap2 = currentABIMap;
            }
        }
        zin.closeEntry();
        return exist;
    }

    public static void copyFile(File oldFile, File newFile) {
        FileInputStream inputStream = null;
        FileOutputStream outputStream = null;
        try {
            FileInputStream inputStream2 = new FileInputStream(oldFile);
            byte[] data = new byte[1024];
            FileOutputStream outputStream2 = new FileOutputStream(newFile);
            while (inputStream2.read(data) != -1) {
                outputStream2.write(data);
            }
            inputStream2.close();
            outputStream2.close();
        } catch (Exception e) {
            WXLogUtils.e("copyFile " + e.getMessage() + ": " + oldFile.getAbsolutePath() + ": " + newFile.getAbsolutePath());
            if (0 != 0) {
                try {
                    inputStream.close();
                } catch (IOException e1) {
                    e1.printStackTrace();
                }
            }
            if (0 != 0) {
                try {
                    outputStream.close();
                } catch (IOException e12) {
                    e12.printStackTrace();
                }
            }
        }
    }

    public static void copyFileWithException(File oldFile, File newFile) throws Exception {
        try {
            FileInputStream inputStream = new FileInputStream(oldFile);
            byte[] data = new byte[1024];
            FileOutputStream outputStream = new FileOutputStream(newFile);
            while (inputStream.read(data) != -1) {
                outputStream.write(data);
            }
            closeIo(inputStream);
            closeIo(outputStream);
        } catch (Exception e) {
            throw e;
        } catch (Throwable th) {
            closeIo(null);
            closeIo(null);
            throw th;
        }
    }

    public static void closeIo(Closeable c) {
        if (c != null) {
            try {
                c.close();
            } catch (Throwable e) {
                e.printStackTrace();
            }
        }
    }
}
