package com.taobao.weex.utils;

import android.text.TextUtils;
import android.util.Log;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.performance.WXStateRecord;
import io.dcloud.feature.uniapp.utils.AbsLogLevel;
import io.dcloud.weex.ConsoleLogUtils;
import java.io.IOException;
import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class WXLogUtils {
    private static final String CLAZZ_NAME_LOG_UTIL = "com.taobao.weex.devtools.common.LogUtil";
    public static final String WEEX_PERF_TAG = "weex_perf";
    public static final String WEEX_TAG = "weex";
    private static StringBuilder builder = new StringBuilder(50);
    private static HashMap<String, Class> clazzMaps;
    private static boolean isDebug = true;
    private static List<JsLogWatcher> jsLogWatcherList = new ArrayList();
    private static LogWatcher sLogWatcher;

    public interface JsLogWatcher {
        void onJsLog(int i, String str);
    }

    public interface LogWatcher {
        void onLog(String str, String str2, String str3);
    }

    static {
        HashMap<String, Class> hashMap = new HashMap<>(2);
        clazzMaps = hashMap;
        hashMap.put(CLAZZ_NAME_LOG_UTIL, loadClass(CLAZZ_NAME_LOG_UTIL));
    }

    public static void setIsDebug(boolean isDebug2) {
        isDebug = isDebug2;
    }

    private static Class loadClass(String clazzName) {
        Class<?> clazz = null;
        try {
            clazz = Class.forName(clazzName);
            if (clazz != null) {
                clazzMaps.put(clazzName, clazz);
            }
        } catch (ClassNotFoundException e) {
        }
        return clazz;
    }

    public static void renderPerformanceLog(String type, long time) {
        if (!WXEnvironment.isApkDebugable()) {
            WXEnvironment.isPerf();
        }
    }

    private static void log(String tag, String msg, AbsLogLevel level) {
        if (!TextUtils.isEmpty(msg) && !TextUtils.isEmpty(tag) && level != null && !TextUtils.isEmpty(level.getName()) && isDebug) {
            if (level == LogLevel.ERROR && !TextUtils.isEmpty(msg) && msg.contains("IPCException")) {
                WXStateRecord.getInstance().recordIPCException("ipc", msg);
            }
            ConsoleLogUtils.consoleLog(tag, msg, level);
            LogWatcher logWatcher = sLogWatcher;
            if (logWatcher != null) {
                logWatcher.onLog(level.getName(), tag, msg);
            }
            if (WXEnvironment.isApkDebugable()) {
                if (level.getValue() - WXEnvironment.sLogLevel.getValue() >= 0) {
                    Log.println(level.getPriority(), tag, msg);
                    writeConsoleLog(level.getName(), msg);
                }
            } else if (level.getValue() - LogLevel.WARN.getValue() >= 0 && level.getValue() - WXEnvironment.sLogLevel.getValue() >= 0) {
                Log.println(level.getPriority(), tag, msg);
            }
        }
    }

    public static void v(String msg) {
        v("weex", msg);
    }

    public static void d(String msg) {
        d("weex", msg);
    }

    public static void d(String tag, byte[] msg) {
        d(tag, new String(msg));
    }

    public static void i(String msg) {
        i("weex", msg);
    }

    public static void i(String tag, byte[] msg) {
        i(tag, new String(msg));
    }

    public static void info(String msg) {
        i("weex", msg);
    }

    public static void w(String msg) {
        w("weex", msg);
    }

    public static void w(String tag, byte[] msg) {
        w(tag, new String(msg));
    }

    public static void e(String msg) {
        e("weex", msg);
    }

    public static void e(String tag, byte[] msg) {
        e(tag, new String(msg));
    }

    public static void performance(String instanceId, byte[] msg) {
    }

    public static void wtf(String msg) {
        wtf("weex", msg);
    }

    public static void d(String tag, String msg) {
        List<JsLogWatcher> list;
        if (!(TextUtils.isEmpty(tag) || TextUtils.isEmpty(msg))) {
            log(tag, msg, LogLevel.DEBUG);
            if (WXEnvironment.isApkDebugable() && "jsLog".equals(tag) && (list = jsLogWatcherList) != null && list.size() > 0) {
                for (JsLogWatcher jsLogWatcher : jsLogWatcherList) {
                    if (msg.endsWith("__DEBUG")) {
                        jsLogWatcher.onJsLog(3, msg.replace("__DEBUG", ""));
                    } else if (msg.endsWith("__INFO")) {
                        jsLogWatcher.onJsLog(3, msg.replace("__INFO", ""));
                    } else if (msg.endsWith("__WARN")) {
                        jsLogWatcher.onJsLog(3, msg.replace("__WARN", ""));
                    } else if (msg.endsWith("__ERROR")) {
                        jsLogWatcher.onJsLog(3, msg.replace("__ERROR", ""));
                    } else {
                        jsLogWatcher.onJsLog(3, msg);
                    }
                }
            }
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private static LogLevel getLogLevel(String level) {
        char c;
        String trim = level.trim();
        switch (trim.hashCode()) {
            case -1485211506:
                if (trim.equals("__INFO")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1484806554:
                if (trim.equals("__WARN")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 90640196:
                if (trim.equals("__LOG")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 1198194259:
                if (trim.equals("__DEBUG")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 1199520264:
                if (trim.equals("__ERROR")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (c == 0) {
            return LogLevel.ERROR;
        }
        if (c == 1) {
            return LogLevel.WARN;
        }
        if (c == 2) {
            return LogLevel.INFO;
        }
        if (c == 3) {
            return LogLevel.INFO;
        }
        if (c != 4) {
            return LogLevel.DEBUG;
        }
        return LogLevel.DEBUG;
    }

    public static void i(String tag, String msg) {
        log(tag, msg, LogLevel.INFO);
    }

    public static void v(String tag, String msg) {
        log(tag, msg, LogLevel.VERBOSE);
    }

    public static void w(String tag, String msg) {
        log(tag, msg, LogLevel.WARN);
    }

    public static void e(String tag, String msg) {
        log(tag, msg, LogLevel.ERROR);
    }

    public static void wtf(String tag, String msg) {
        log(tag, msg, LogLevel.WTF);
    }

    public static void p(String msg) {
        d(WEEX_PERF_TAG, msg);
    }

    public static void d(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            d(prefix + getStackTrace(e));
        }
    }

    public static void i(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            info(prefix + getStackTrace(e));
        }
    }

    public static void v(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            v(prefix + getStackTrace(e));
        }
    }

    public static void w(String prefix, Throwable e) {
        w(prefix + getStackTrace(e));
    }

    public static void e(String prefix, Throwable e) {
        e(prefix + getStackTrace(e));
    }

    public static void wtf(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            wtf(prefix + getStackTrace(e));
        }
    }

    public static void p(String prefix, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            p(prefix + getStackTrace(e));
        }
    }

    public static void eTag(String tag, Throwable e) {
        if (WXEnvironment.isApkDebugable()) {
            e(tag, getStackTrace(e));
        }
    }

    public static String getStackTrace(Throwable e) {
        if (e == null) {
            return "";
        }
        StringWriter sw = null;
        PrintWriter pw = null;
        try {
            sw = new StringWriter();
            pw = new PrintWriter(sw);
            e.printStackTrace(pw);
            pw.flush();
            sw.flush();
            try {
                sw.close();
            } catch (IOException e1) {
                e1.printStackTrace();
            }
            pw.close();
            return sw.toString();
        } catch (Throwable th) {
            if (sw != null) {
                try {
                    sw.close();
                } catch (IOException e12) {
                    e12.printStackTrace();
                }
            }
            if (pw != null) {
                pw.close();
            }
            throw th;
        }
    }

    private static void writeConsoleLog(String level, String message) {
        if (WXEnvironment.isApkDebugable()) {
            try {
                Class<?> clazz = clazzMaps.get(CLAZZ_NAME_LOG_UTIL);
                if (clazz != null) {
                    clazz.getMethod("log", String.class, String.class).invoke(clazz, level, message);
                }
            } catch (Exception e) {
                Log.d("weex", "LogUtil not found!");
            }
        }
    }

    public static void setJsLogWatcher(JsLogWatcher watcher) {
        if (!jsLogWatcherList.contains(watcher)) {
            jsLogWatcherList.add(watcher);
        }
    }

    public static void setLogWatcher(LogWatcher watcher) {
        sLogWatcher = watcher;
    }
}
