package com.taobao.weex.utils;

import android.app.Application;
import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.os.Build;
import android.text.TextUtils;
import com.taobao.weex.IWXStatisticsListener;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.adapter.IWXSoLoaderAdapter;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.WXErrorCode;
import dalvik.system.PathClassLoader;
import io.dcloud.common.util.PdrUtil;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.util.Enumeration;
import java.util.Locale;
import java.util.zip.ZipEntry;
import java.util.zip.ZipException;
import java.util.zip.ZipFile;

public class WXSoInstallMgrSdk {
    private static final String ARMEABI = "armeabi";
    static final String LOGTAG = "INIT_SO";
    private static final String MIPS = "mips";
    private static final String STARTUPSO = "/libweexjsb.so";
    private static final String STARTUPSOANDROID15 = "/libweexjst.so";
    private static final String X86 = "x86";
    private static String mAbi = null;
    static Application mContext = null;
    private static IWXSoLoaderAdapter mSoLoader = null;
    private static IWXStatisticsListener mStatisticsListener = null;

    public static void init(Application c, IWXSoLoaderAdapter loader, IWXStatisticsListener listener) {
        mContext = c;
        mSoLoader = loader;
        mStatisticsListener = listener;
    }

    public static boolean isX86() {
        return _cpuType().equalsIgnoreCase("x86");
    }

    public static boolean isCPUSupport() {
        return !_cpuType().equalsIgnoreCase("mips");
    }

    public static boolean initSo(String libName, int version, IWXUserTrackAdapter utAdapter) {
        String cpuType = _cpuType();
        if (cpuType.equalsIgnoreCase("mips")) {
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT, "initSo", "[WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT] for android cpuType is MIPS", null);
            return false;
        }
        if (WXEnvironment.CORE_SO_NAME.equals(libName)) {
            copyStartUpSo();
        }
        try {
            if (mSoLoader != null) {
                mSoLoader.doLoadLibrary("c++_shared");
            } else {
                System.loadLibrary("c++_shared");
            }
        } catch (Error | Exception e) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT;
            WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, "initSo", "load c++_shared failed Detail Error is: " + e.getMessage(), null);
            if (WXEnvironment.isApkDebugable()) {
                throw e;
            }
        }
        try {
            if (mSoLoader != null) {
                mSoLoader.doLoadLibrary(libName);
            } else {
                System.loadLibrary(libName);
            }
            return true;
        } catch (Error | Exception e2) {
            if (cpuType.contains(ARMEABI) || cpuType.contains("x86")) {
                WXErrorCode wXErrorCode2 = WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT;
                WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode2, "initSo", libName + "[WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT] for android cpuType is " + cpuType + "\n Detail Error is: " + e2.getMessage(), null);
            }
            if (!WXEnvironment.isApkDebugable()) {
                return false;
            }
            throw e2;
        }
    }

    private static File _desSoCopyFile(String soName) {
        String cpuType = _cpuType();
        String copyPath = WXEnvironment.copySoDesDir();
        if (TextUtils.isEmpty(copyPath)) {
            return null;
        }
        return new File(copyPath, soName + "/" + cpuType);
    }

    public static void copyStartUpSo() {
        File oldfile;
        try {
            String pkgName = WXEnvironment.getApplication().getPackageName();
            String cacheFile = WXEnvironment.getApplication().getApplicationContext().getCacheDir().getPath();
            boolean pieSupport = true;
            String startSoName = WXEnvironment.CORE_JSB_SO_NAME;
            String startSoPath = STARTUPSO;
            if (Build.VERSION.SDK_INT < 16) {
                pieSupport = false;
                startSoName = WXEnvironment.CORE_JST_SO_NAME;
                startSoPath = STARTUPSOANDROID15;
            }
            File copyPath = _desSoCopyFile(startSoName);
            if (!copyPath.exists()) {
                copyPath.mkdirs();
            }
            File newfile = new File(copyPath, startSoPath);
            WXEnvironment.CORE_JSB_SO_PATH = newfile.getAbsolutePath();
            String jsb = WXEnvironment.getDefaultSettingValue(startSoName, "-1");
            if (!newfile.exists() || !TextUtils.equals(WXEnvironment.getAppVersionName(), jsb)) {
                String path = "/data/data/" + pkgName + "/lib";
                if (cacheFile != null && cacheFile.indexOf("/cache") > 0) {
                    path = cacheFile.replace("/cache", "/lib");
                }
                if (pieSupport) {
                    oldfile = new File(path, STARTUPSO);
                } else {
                    oldfile = new File(path, STARTUPSOANDROID15);
                }
                if (!oldfile.exists()) {
                    try {
                        oldfile = new File(((PathClassLoader) WXSoInstallMgrSdk.class.getClassLoader()).findLibrary(startSoName));
                    } catch (Throwable th) {
                    }
                }
                if (!oldfile.exists()) {
                    WXEnvironment.extractSo();
                    oldfile = new File(WXEnvironment.copySoDesDir(), STARTUPSO);
                }
                if (oldfile.exists()) {
                    WXFileUtils.copyFile(oldfile, newfile);
                }
                WXEnvironment.writeDefaultSettingsValue(startSoName, WXEnvironment.getAppVersionName());
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static void copyJssRuntimeSo() {
        boolean tryUseRunTimeApi = WXUtils.checkGreyConfig("wxapm", "use_runtime_api", "0");
        WXLogUtils.e("weex", "tryUseRunTimeApi ? " + tryUseRunTimeApi);
        if (tryUseRunTimeApi) {
            try {
                WXLogUtils.e("weex", "copyJssRuntimeSo: ");
                File toPath = _desSoCopyFile(WXEnvironment.CORE_JSS_SO_NAME);
                if (!toPath.exists()) {
                    toPath.mkdirs();
                }
                File targetFile = new File(toPath, "libweexjss.so");
                String defaultSettingValue = WXEnvironment.getDefaultSettingValue("app_version_code_weex", "-1");
                if (targetFile.exists()) {
                    if (!TextUtils.equals(WXEnvironment.getAppVersionName(), defaultSettingValue)) {
                        targetFile.delete();
                    } else {
                        WXEnvironment.CORE_JSS_RUNTIME_SO_PATH = targetFile.getAbsolutePath();
                        WXEnvironment.sUseRunTimeApi = true;
                        WXLogUtils.e("weex", "copyJssRuntimeSo exist:  return");
                        return;
                    }
                }
                String fromPath = ((PathClassLoader) WXSoInstallMgrSdk.class.getClassLoader()).findLibrary("weexjssr");
                if (!TextUtils.isEmpty(fromPath)) {
                    targetFile.createNewFile();
                    WXFileUtils.copyFileWithException(new File(fromPath), targetFile);
                    WXEnvironment.CORE_JSS_RUNTIME_SO_PATH = targetFile.getAbsolutePath();
                    WXEnvironment.writeDefaultSettingsValue("app_version_code_weex", WXEnvironment.getAppVersionName());
                    WXEnvironment.sUseRunTimeApi = true;
                    WXLogUtils.e("weex", "copyJssRuntimeSo: cp end and return ");
                }
            } catch (Throwable e) {
                e.printStackTrace();
                WXEnvironment.sUseRunTimeApi = false;
                WXLogUtils.e("weex", "copyJssRuntimeSo:  exception" + e);
            }
        }
    }

    private static String _getFieldReflectively(Build build, String fieldName) {
        try {
            return Build.class.getField(fieldName).get(build).toString();
        } catch (Exception e) {
            return "Unknown";
        }
    }

    private static String _cpuType() {
        if (TextUtils.isEmpty(mAbi)) {
            try {
                mAbi = Build.CPU_ABI;
            } catch (Throwable e) {
                e.printStackTrace();
                mAbi = ARMEABI;
            }
            if (TextUtils.isEmpty(mAbi)) {
                mAbi = ARMEABI;
            }
            mAbi = mAbi.toLowerCase(Locale.ROOT);
        }
        return mAbi;
    }

    static boolean checkSoIsValid(String libName, long size) {
        if (mContext == null) {
            return false;
        }
        try {
            long start = System.currentTimeMillis();
            if (WXSoInstallMgrSdk.class.getClassLoader() instanceof PathClassLoader) {
                String path = ((PathClassLoader) WXSoInstallMgrSdk.class.getClassLoader()).findLibrary(libName);
                if (TextUtils.isEmpty(path)) {
                    return false;
                }
                File file = new File(path);
                if (file.exists()) {
                    if (size != file.length()) {
                        return false;
                    }
                }
                WXLogUtils.w("weex so size check path :" + path + "   " + (System.currentTimeMillis() - start));
                return true;
            }
        } catch (Throwable e) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT;
            WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, "checkSoIsValid", "[WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT] for weex so size check fail exception :" + e.getMessage(), null);
            WXLogUtils.e("weex so size check fail exception :" + e.getMessage());
        }
        return true;
    }

    static String _targetSoFile(String libName, int version) {
        Context context = mContext;
        if (context == null) {
            return "";
        }
        String path = "/data/data/" + context.getPackageName() + "/files";
        File f = context.getFilesDir();
        if (f != null) {
            path = f.getPath();
        }
        return path + "/lib" + libName + "bk" + version + ".so";
    }

    static void removeSoIfExit(String libName, int version) {
        File a = new File(_targetSoFile(libName, version));
        if (a.exists()) {
            a.delete();
        }
    }

    static boolean isExist(String libName, int version) {
        return new File(_targetSoFile(libName, version)).exists();
    }

    static boolean _loadUnzipSo(String libName, int version, IWXUserTrackAdapter utAdapter) {
        try {
            if (isExist(libName, version)) {
                if (mSoLoader != null) {
                    mSoLoader.doLoad(_targetSoFile(libName, version));
                } else {
                    System.load(_targetSoFile(libName, version));
                }
            }
            return true;
        } catch (Throwable e) {
            WXErrorCode wXErrorCode = WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT;
            WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, "_loadUnzipSo", "[WX_KEY_EXCEPTION_SDK_INIT_WX_ERR_COPY_FROM_APK] \n Detail Msg is : " + e.getMessage(), null);
            WXLogUtils.e("", e);
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:59:0x00e9 A[SYNTHETIC, Splitter:B:59:0x00e9] */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x00f7 A[SYNTHETIC, Splitter:B:65:0x00f7] */
    /* JADX WARNING: Removed duplicated region for block: B:70:0x0103 A[SYNTHETIC, Splitter:B:70:0x0103] */
    /* JADX WARNING: Removed duplicated region for block: B:86:0x014d  */
    /* JADX WARNING: Removed duplicated region for block: B:90:0x0152  */
    static boolean unZipSelectedFiles(String libName, int version, IWXUserTrackAdapter utAdapter) throws ZipException, IOException {
        Context context;
        String zipPath;
        Throwable th;
        IOException e;
        Throwable th2;
        String str = libName;
        String sourcePath = "lib/armeabi/lib" + str + ".so";
        if (!PdrUtil.isSafeEntryName(sourcePath) || (context = mContext) == null) {
            return false;
        }
        ApplicationInfo aInfo = context.getApplicationInfo();
        if (aInfo != null) {
            zipPath = aInfo.sourceDir;
        } else {
            zipPath = "";
        }
        ZipFile zf = new ZipFile(zipPath);
        try {
            Enumeration<?> entries = zf.entries();
            while (entries.hasMoreElements()) {
                ZipEntry entry = (ZipEntry) entries.nextElement();
                if (entry.getName().startsWith(sourcePath)) {
                    InputStream in = null;
                    FileOutputStream os = null;
                    FileChannel channel = null;
                    int total = 0;
                    try {
                        removeSoIfExit(libName, version);
                        in = zf.getInputStream(entry);
                        StringBuilder sb = new StringBuilder();
                        sb.append("lib");
                        sb.append(str);
                        sb.append("bk");
                        try {
                            sb.append(version);
                            sb.append(".so");
                            FileOutputStream os2 = context.openFileOutput(sb.toString(), 0);
                            FileChannel channel2 = os2.getChannel();
                            byte[] buffers = new byte[1024];
                            while (true) {
                                int realLength = in.read(buffers);
                                if (realLength <= 0) {
                                    break;
                                }
                                channel2.write(ByteBuffer.wrap(buffers, 0, realLength));
                                total += realLength;
                            }
                            if (in != null) {
                                try {
                                    in.close();
                                } catch (Exception e2) {
                                    try {
                                        e2.printStackTrace();
                                    } catch (IOException e3) {
                                        e = e3;
                                        try {
                                            e.printStackTrace();
                                            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT, "unZipSelectedFiles", "[WX_KEY_EXCEPTION_SDK_INIT_unZipSelectedFiles] \n Detail msg is: " + e.getMessage(), null);
                                            if (zf == null) {
                                            }
                                            zf.close();
                                            return false;
                                        } catch (Throwable th3) {
                                            th = th3;
                                            if (zf != null) {
                                            }
                                            throw th;
                                        }
                                    }
                                }
                            }
                            if (channel2 != null) {
                                try {
                                    channel2.close();
                                } catch (Exception e4) {
                                    e4.printStackTrace();
                                }
                            }
                            if (os2 != null) {
                                try {
                                    os2.close();
                                } catch (Exception e5) {
                                    e5.printStackTrace();
                                }
                            }
                            zf.close();
                            ZipFile zf2 = null;
                            if (total > 0) {
                                boolean _loadUnzipSo = _loadUnzipSo(libName, version, utAdapter);
                                if (0 != 0) {
                                    zf2.close();
                                }
                                return _loadUnzipSo;
                            }
                            if (0 != 0) {
                                zf2.close();
                            }
                            return false;
                        } catch (Throwable th4) {
                            th2 = th4;
                            if (in != null) {
                                try {
                                    in.close();
                                } catch (Exception e6) {
                                    e6.printStackTrace();
                                }
                            }
                            if (0 != 0) {
                                try {
                                    channel.close();
                                } catch (Exception e7) {
                                    e7.printStackTrace();
                                }
                            }
                            if (0 != 0) {
                                try {
                                    os.close();
                                } catch (Exception e8) {
                                    e8.printStackTrace();
                                }
                            }
                            zf.close();
                            throw th2;
                        }
                    } catch (Throwable th5) {
                        th2 = th5;
                        if (in != null) {
                        }
                        if (0 != 0) {
                        }
                        if (0 != 0) {
                        }
                        zf.close();
                        throw th2;
                    }
                } else {
                    str = libName;
                }
            }
        } catch (IOException e9) {
            e = e9;
            e.printStackTrace();
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_KEY_EXCEPTION_SDK_INIT_CPU_NOT_SUPPORT, "unZipSelectedFiles", "[WX_KEY_EXCEPTION_SDK_INIT_unZipSelectedFiles] \n Detail msg is: " + e.getMessage(), null);
            if (zf == null) {
                return false;
            }
            zf.close();
            return false;
        } catch (Throwable th6) {
            th = th6;
            if (zf != null) {
                zf.close();
            }
            throw th;
        }
        zf.close();
        return false;
    }
}
