package com.taobao.weex.utils;

import android.app.ActivityManager;
import android.content.Context;
import android.os.Looper;
import android.os.SystemClock;
import android.text.TextUtils;
import androidx.collection.LruCache;
import com.igexin.push.core.b;
import com.meizu.cloud.pushsdk.constants.PushConstants;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;

public class WXUtils {
    private static final int HUNDRED = 100;
    public static final char PERCENT = '%';
    static final LruCache<String, Integer> sCache = new LruCache<>(64);
    private static final long sInterval = (System.currentTimeMillis() - SystemClock.uptimeMillis());

    public static LruCache getCache() {
        return sCache;
    }

    public static boolean isUiThread() {
        return Thread.currentThread().getId() == Looper.getMainLooper().getThread().getId();
    }

    public static boolean isUndefined(float value) {
        return Float.isNaN(value);
    }

    public static float getFloatByViewport(Object value, float viewport) {
        return floatByViewport(value, viewport);
    }

    public static float getFloatByViewport(Object value, int viewport) {
        return floatByViewport(value, (float) viewport);
    }

    private static float floatByViewport(Object value, float viewport) {
        if (value == null) {
            return Float.NaN;
        }
        String temp = value.toString().trim();
        if ("auto".equals(temp) || Constants.Name.UNDEFINED.equals(temp) || TextUtils.isEmpty(temp)) {
            WXLogUtils.e("Argument Warning ! value is " + temp + "And default Value:" + Float.NaN);
            return Float.NaN;
        } else if (temp.endsWith("wx")) {
            try {
                return transferWx(temp, viewport);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
                return Float.NaN;
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
                return Float.NaN;
            }
        } else if (!temp.endsWith("px")) {
            try {
                return Float.parseFloat(temp);
            } catch (NumberFormatException nfe) {
                WXLogUtils.e("Argument format error! value is " + value, nfe);
                return Float.NaN;
            } catch (Exception e3) {
                WXLogUtils.e("Argument error! value is " + value, e3);
                return Float.NaN;
            }
        } else if (temp.length() <= 3 || (!temp.endsWith("rpx") && !temp.endsWith("upx"))) {
            try {
                return Float.parseFloat(temp.substring(0, temp.indexOf("px")));
            } catch (NumberFormatException nfe2) {
                WXLogUtils.e("Argument format error! value is " + value, nfe2);
                return Float.NaN;
            } catch (Exception e4) {
                WXLogUtils.e("Argument error! value is " + value, e4);
                return Float.NaN;
            }
        } else {
            try {
                return transferRpxAndUpx(temp.substring(0, temp.length() - 3), 750.0f);
            } catch (NumberFormatException nfe3) {
                WXLogUtils.e("Argument format error! value is " + value, nfe3);
                return Float.NaN;
            } catch (Exception e5) {
                WXLogUtils.e("Argument error! value is " + value, e5);
                return Float.NaN;
            }
        }
    }

    public static float getFloat(Object value) {
        return getFloat(value, Float.valueOf(Float.NaN)).floatValue();
    }

    public static Float getFloat(Object value, Float df) {
        if (value == null) {
            return df;
        }
        String temp = value.toString().trim();
        if ("auto".equals(temp) || Constants.Name.UNDEFINED.equals(temp) || TextUtils.isEmpty(temp)) {
            WXLogUtils.e("Argument Warning ! value is " + temp + "And default Value:" + Float.NaN);
            return df;
        } else if (temp.endsWith("wx")) {
            try {
                return Float.valueOf(transferWx(temp, 750.0f));
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
                return df;
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
                return df;
            }
        } else if (!temp.endsWith("px")) {
            try {
                return Float.valueOf(Float.parseFloat(temp));
            } catch (NumberFormatException nfe) {
                WXLogUtils.e("Argument format error! value is " + value, nfe);
                return df;
            } catch (Exception e3) {
                WXLogUtils.e("Argument error! value is " + value, e3);
                return df;
            }
        } else if (temp.length() <= 3 || (!temp.endsWith("rpx") && !temp.endsWith("upx"))) {
            try {
                return Float.valueOf(Float.parseFloat(temp.substring(0, temp.indexOf("px"))));
            } catch (NumberFormatException nfe2) {
                WXLogUtils.e("Argument format error! value is " + value, nfe2);
                return df;
            } catch (Exception e4) {
                WXLogUtils.e("Argument error! value is " + value, e4);
                return df;
            }
        } else {
            try {
                return Float.valueOf(transferRpxAndUpx(temp.substring(0, temp.length() - 3), 750.0f));
            } catch (NumberFormatException nfe3) {
                WXLogUtils.e("Argument format error! value is " + value, nfe3);
                return df;
            } catch (Exception e5) {
                WXLogUtils.e("Argument error! value is " + value, e5);
                return df;
            }
        }
    }

    private static float transferWx(String stringWithWXPostfix, float viewport) {
        if (stringWithWXPostfix == null) {
            return 0.0f;
        }
        String temp = stringWithWXPostfix;
        if (stringWithWXPostfix.endsWith("wx")) {
            temp = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("wx"));
        }
        Float f = Float.valueOf(Float.parseFloat(temp));
        return ((f.floatValue() * WXEnvironment.sApplication.getResources().getDisplayMetrics().density) * viewport) / ((float) WXViewUtils.getScreenWidth());
    }

    private static float transferRpxAndUpx(String stringWithWXPostfix, float viewport) {
        if (stringWithWXPostfix == null) {
            return 0.0f;
        }
        String temp = stringWithWXPostfix;
        if (stringWithWXPostfix.endsWith("rpx")) {
            temp = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("rpx"));
        } else if (stringWithWXPostfix.endsWith("upx")) {
            temp = stringWithWXPostfix.substring(0, stringWithWXPostfix.indexOf("upx"));
        }
        return Float.valueOf(Float.parseFloat(temp)).floatValue() * (WXEnvironment.getViewProt() / viewport);
    }

    public static float fastGetFloat(String raw, float precision) {
        char digit;
        char digit2;
        if (TextUtils.isEmpty(raw)) {
            return 0.0f;
        }
        boolean positive = true;
        int loc = 0;
        if (raw.charAt(0) == '-') {
            positive = false;
            loc = 0 + 1;
        } else if (raw.charAt(0) == '+') {
            loc = 0 + 1;
        }
        float result = 0.0f;
        while (loc < raw.length() && (digit2 = raw.charAt(loc)) >= '0' && digit2 <= '9') {
            result = ((10.0f * result) + ((float) digit2)) - 48.0f;
            loc++;
        }
        if (loc < raw.length() && raw.charAt(loc) == '.') {
            int loc2 = loc + 1;
            int remainderLength = 10;
            int counter = 0;
            while (loc2 < raw.length() && ((float) counter) < precision && (digit = raw.charAt(loc2)) >= '0' && digit <= '9') {
                result += ((float) (digit - '0')) / ((float) remainderLength);
                remainderLength *= 10;
                loc2++;
                counter++;
            }
        }
        if (!positive) {
            return result * -1.0f;
        }
        return result;
    }

    public static float fastGetFloat(String raw) {
        return fastGetFloat(raw, 2.14748365E9f);
    }

    public static int parseInt(String value) {
        try {
            if (TextUtils.isEmpty(value) || value.contains(Operators.DOT_STR)) {
                return 0;
            }
            return Integer.parseInt(value);
        } catch (NumberFormatException e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 0;
            }
            WXLogUtils.e(WXLogUtils.getStackTrace(e));
            return 0;
        }
    }

    public static int parseInt(Object value) {
        return parseInt(String.valueOf(value));
    }

    public static float parseFloat(Object value) {
        return parseFloat(String.valueOf(value));
    }

    public static float parseFloat(String value) {
        try {
            if (!TextUtils.isEmpty(value) && !TextUtils.equals(value, b.m)) {
                return Float.parseFloat(value);
            }
            if (!WXEnvironment.isApkDebugable()) {
                return 0.0f;
            }
            WXLogUtils.e("WXUtils parseFloat illegal value is " + value);
            return 0.0f;
        } catch (NumberFormatException e) {
            if (!WXEnvironment.isApkDebugable()) {
                return 0.0f;
            }
            WXLogUtils.e(WXLogUtils.getStackTrace(e));
            return 0.0f;
        }
    }

    public static int getInt(Object value) {
        return getInteger(value, 0).intValue();
    }

    public static Integer getInteger(Object value, Integer df) {
        if (value == null) {
            return df;
        }
        String temp = value.toString().trim();
        Integer cache = sCache.get(temp);
        if (cache != null) {
            return cache;
        }
        Integer ret = df;
        String suffix = "";
        if (temp.length() >= 2) {
            suffix = temp.substring(temp.length() - 2, temp.length());
        }
        if (TextUtils.equals("wx", suffix)) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                ret = Integer.valueOf((int) transferWx(temp, 750.0f));
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
            }
        } else if (!TextUtils.equals("px", suffix)) {
            try {
                if (!TextUtils.isEmpty(temp)) {
                    ret = temp.contains(Operators.DOT_STR) ? Integer.valueOf((int) parseFloat(temp)) : Integer.valueOf(Integer.parseInt(temp));
                } else if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.e("Argument value is null, df is" + df);
                }
            } catch (NumberFormatException nfe) {
                WXLogUtils.e("Argument format error! value is " + value, nfe);
            } catch (Exception e3) {
                WXLogUtils.e("Argument error! value is " + value, e3);
            }
        } else if (temp.length() <= 3 || (!temp.endsWith("rpx") && !temp.endsWith("upx"))) {
            try {
                String temp2 = temp.substring(0, temp.length() - 2);
                ret = (TextUtils.isEmpty(temp2) || !temp2.contains(Operators.DOT_STR)) ? Integer.valueOf(Integer.parseInt(temp2)) : Integer.valueOf((int) parseFloat(temp2));
            } catch (NumberFormatException nfe2) {
                WXLogUtils.e("Argument format error! value is " + value, nfe2);
            } catch (Exception e4) {
                WXLogUtils.e("Argument error! value is " + value, e4);
            }
        } else {
            try {
                ret = Integer.valueOf((int) transferRpxAndUpx(temp.substring(0, temp.length() - 3), 750.0f));
            } catch (NumberFormatException nfe3) {
                WXLogUtils.e("Argument format error! value is " + value, nfe3);
            } catch (Exception e5) {
                WXLogUtils.e("Argument error! value is " + value, e5);
            }
        }
        if (ret != null && !ret.equals(df)) {
            sCache.put(temp, ret);
        }
        return ret;
    }

    @Deprecated
    public static long getLong(Object value) {
        if (value == null) {
            return 0;
        }
        String temp = value.toString().trim();
        if (temp.endsWith("wx")) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                return (long) transferWx(temp, 750.0f);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
                return 0;
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
                return 0;
            }
        } else if (!temp.endsWith("px")) {
            try {
                return Long.parseLong(temp);
            } catch (NumberFormatException nfe) {
                WXLogUtils.e("Argument format error! value is " + value, nfe);
                return 0;
            } catch (Exception e3) {
                WXLogUtils.e("Argument error! value is " + value, e3);
                return 0;
            }
        } else if (temp.length() <= 3 || (!temp.endsWith("rpx") && !temp.endsWith("upx"))) {
            try {
                return Long.parseLong(temp.substring(0, temp.indexOf("px")));
            } catch (NumberFormatException nfe2) {
                WXLogUtils.e("Argument format error! value is " + value, nfe2);
                return 0;
            } catch (Exception e4) {
                WXLogUtils.e("Argument error! value is " + value, e4);
                return 0;
            }
        } else {
            try {
                return (long) transferRpxAndUpx(temp.substring(0, temp.length() - 3), 750.0f);
            } catch (NumberFormatException nfe3) {
                WXLogUtils.e("Argument format error! value is " + value, nfe3);
                return 0;
            } catch (Exception e5) {
                WXLogUtils.e("Argument error! value is " + value, e5);
                return 0;
            }
        }
    }

    @Deprecated
    public static double getDouble(Object value) {
        if (value == null) {
            return 0.0d;
        }
        String temp = value.toString().trim();
        if (temp.endsWith("wx")) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.w("the value of " + value + " use wx unit, which will be not supported soon after.");
            }
            try {
                return (double) transferWx(temp, 750.0f);
            } catch (NumberFormatException e) {
                WXLogUtils.e("Argument format error! value is " + value, e);
                return 0.0d;
            } catch (Exception e2) {
                WXLogUtils.e("Argument error! value is " + value, e2);
                return 0.0d;
            }
        } else if (!temp.endsWith("px")) {
            try {
                return Double.parseDouble(temp);
            } catch (NumberFormatException nfe) {
                WXLogUtils.e("Argument format error! value is " + value, nfe);
                return 0.0d;
            } catch (Exception e3) {
                WXLogUtils.e("Argument error! value is " + value, e3);
                return 0.0d;
            }
        } else if (temp.length() <= 3 || (!temp.endsWith("rpx") && !temp.endsWith("upx"))) {
            try {
                return Double.parseDouble(temp.substring(0, temp.indexOf("px")));
            } catch (NumberFormatException nfe2) {
                WXLogUtils.e("Argument format error! value is " + value, nfe2);
                return 0.0d;
            } catch (Exception e4) {
                WXLogUtils.e("Argument error! value is " + value, e4);
                return 0.0d;
            }
        } else {
            try {
                return (double) transferRpxAndUpx(temp.substring(0, temp.length() - 3), 750.0f);
            } catch (NumberFormatException nfe3) {
                WXLogUtils.e("Argument format error! value is " + value, nfe3);
                return 0.0d;
            } catch (Exception e5) {
                WXLogUtils.e("Argument error! value is " + value, e5);
                return 0.0d;
            }
        }
    }

    @Deprecated
    public static boolean isTabletDevice() {
        try {
            return (WXEnvironment.getApplication().getResources().getConfiguration().screenLayout & 15) >= 3;
        } catch (Exception e) {
            return false;
        }
    }

    public static Boolean getBoolean(Object value, Boolean df) {
        if (value == null) {
            return df;
        }
        if (TextUtils.equals(AbsoluteConst.FALSE, value.toString())) {
            return false;
        }
        if (TextUtils.equals(AbsoluteConst.TRUE, value.toString())) {
            return true;
        }
        return df;
    }

    public static long getAvailMemory(Context context) {
        ActivityManager.MemoryInfo mi = new ActivityManager.MemoryInfo();
        ((ActivityManager) context.getSystemService(PushConstants.INTENT_ACTIVITY_NAME)).getMemoryInfo(mi);
        WXLogUtils.w("app AvailMemory ---->>>" + (mi.availMem / 1048576));
        return mi.availMem / 1048576;
    }

    public static String getString(Object value, String df) {
        if (value == null) {
            return df;
        }
        if (value instanceof String) {
            return (String) value;
        }
        return value.toString();
    }

    public static int parseUnitOrPercent(String raw, int unit) {
        int suffix = raw.lastIndexOf(37);
        if (suffix != -1) {
            return parsePercent(raw.substring(0, suffix), unit);
        }
        return parseInt(raw);
    }

    private static int parsePercent(String raw, int unit) {
        return (int) ((Float.parseFloat(raw) / 100.0f) * ((float) unit));
    }

    public static String getBundleBanner(String content) {
        int offsetCountBegin;
        int offsetCountEnd;
        String commentBegin = "/*!";
        int offsetCountBegin2 = content.indexOf("/*!");
        if (offsetCountBegin2 == -1 || (offsetCountEnd = indexLineBreak(content, (offsetCountBegin = offsetCountBegin2 + "/*!".length()))) == -1) {
            return null;
        }
        String commentBody = content.substring(offsetCountEnd + 1, offsetCountEnd + 1 + Integer.parseInt(content.substring(offsetCountBegin, offsetCountEnd)));
        int offsetBodyEnd = commentBody.lastIndexOf("!*/");
        if (offsetBodyEnd == -1) {
            return null;
        }
        int i = 0;
        String commentBody2 = commentBody.substring(0, offsetBodyEnd);
        StringBuilder commentBodyBuilder = new StringBuilder();
        String[] items = splitLineBreak(commentBody2);
        int length = items.length;
        while (i < length) {
            commentBodyBuilder.append(items[i].replaceFirst("\\*", ""));
            i++;
            commentBegin = commentBegin;
        }
        return commentBodyBuilder.toString();
    }

    private static int indexLineBreak(String str, int fromIndex) {
        int index = str.indexOf("\r", fromIndex);
        if (index == -1) {
            index = str.indexOf("\n", fromIndex);
        }
        if (index == -1) {
            return str.indexOf("\r\n", fromIndex);
        }
        return index;
    }

    private static String[] splitLineBreak(String str) {
        String[] items = str.split("\r");
        if (items.length == 1) {
            items = str.split("\n");
        }
        if (items.length == 1) {
            return str.split("\r\n");
        }
        return items;
    }

    public static int getNumberInt(Object value, int defaultValue) {
        if (value == null) {
            return defaultValue;
        }
        if (value instanceof Number) {
            return ((Number) value).intValue();
        }
        try {
            String number = value.toString();
            if (number.indexOf(46) >= 0) {
                return (int) Float.parseFloat(value.toString());
            }
            return Integer.parseInt(number);
        } catch (Exception e) {
            return defaultValue;
        }
    }

    public static boolean checkGreyConfig(String group, String key, String defaultValue) {
        IWXConfigAdapter configAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (configAdapter == null) {
            return false;
        }
        double randomValue = Math.random() * 100.0d;
        double max = 100.0d;
        try {
            max = Double.valueOf(configAdapter.getConfig(group, key, defaultValue)).doubleValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (randomValue < max) {
            return true;
        }
        return false;
    }

    public static long getFixUnixTime() {
        return sInterval + SystemClock.uptimeMillis();
    }
}
