package com.taobao.weex.utils;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.provider.MediaStore;
import android.view.View;
import com.taobao.weex.WXSDKManager;
import com.tencent.mm.opensdk.modelmsg.WXVideoFileObject;
import io.dcloud.common.adapter.util.DeviceInfo;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

public class WXViewToImageUtil {
    public static int mBackgroundColor = 0;

    public interface OnImageSavedCallback {
        void onSaveFailed(String str);

        void onSaveSucceed(String str);
    }

    public static void generateImage(final View imageView, final int width, int backgroundColor, final OnImageSavedCallback mOnImageSavedCallback) {
        mBackgroundColor = backgroundColor;
        WXSDKManager.getInstance().getWXWorkThreadManager().post(new Thread(new Runnable() {
            /* class com.taobao.weex.utils.WXViewToImageUtil.AnonymousClass1 */

            public void run() {
                Bitmap bitmap = WXViewToImageUtil.getBitmapFromImageView(imageView, width);
                if (bitmap == null) {
                    OnImageSavedCallback onImageSavedCallback = mOnImageSavedCallback;
                    if (onImageSavedCallback != null) {
                        onImageSavedCallback.onSaveFailed("Image is empty");
                        return;
                    }
                    return;
                }
                final String destPath = WXViewToImageUtil.saveBitmapToGallery(imageView.getContext(), bitmap, mOnImageSavedCallback);
                new Handler(Looper.getMainLooper()).post(new Runnable() {
                    /* class com.taobao.weex.utils.WXViewToImageUtil.AnonymousClass1.AnonymousClass1 */

                    public void run() {
                        if (mOnImageSavedCallback != null) {
                            mOnImageSavedCallback.onSaveSucceed(destPath);
                            imageView.getContext().sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.parse(destPath)));
                        }
                    }
                });
            }
        }));
    }

    public static String saveBitmapToGallery(Context context, Bitmap bitmap, OnImageSavedCallback mOnImageSavedCallback) {
        File appDir = new File(Environment.getExternalStorageDirectory(), "Weex");
        if (!appDir.exists()) {
            appDir.mkdir();
        }
        String fileName = System.currentTimeMillis() + ".jpg";
        File file = new File(appDir, fileName);
        try {
            FileOutputStream fos = new FileOutputStream(file);
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, fos);
            fos.flush();
            fos.close();
        } catch (FileNotFoundException e) {
            if (mOnImageSavedCallback != null) {
                mOnImageSavedCallback.onSaveFailed("Image creation failed due to system reason");
            }
            e.printStackTrace();
        } catch (IOException e2) {
            if (mOnImageSavedCallback != null) {
                mOnImageSavedCallback.onSaveFailed("Android IOException");
            }
            e2.printStackTrace();
        }
        try {
            MediaStore.Images.Media.insertImage(context.getContentResolver(), file.getAbsolutePath(), fileName, (String) null);
        } catch (FileNotFoundException e3) {
            e3.printStackTrace();
        }
        context.sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.parse(DeviceInfo.FILE_PROTOCOL + appDir.getAbsolutePath() + "/" + fileName)));
        return file.getAbsolutePath();
    }

    public static Bitmap getBitmapFromImageView(View view, int width) {
        if (view.getWidth() <= 0 || view.getHeight() <= 0) {
            view.measure(View.MeasureSpec.makeMeasureSpec(width, WXVideoFileObject.FILE_SIZE_LIMIT), View.MeasureSpec.makeMeasureSpec(0, 0));
            view.layout(0, 0, view.getMeasuredWidth(), view.getMeasuredHeight());
        }
        view.setDrawingCacheEnabled(true);
        return view.getDrawingCache();
    }
}
