package com.taobao.weex.utils;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Canvas;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.os.Build;
import android.util.DisplayMetrics;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.flat.widget.Widget;
import com.taobao.weex.ui.flat.widget.WidgetGroup;
import com.taobao.weex.ui.view.WXFrameLayout;
import com.taobao.weex.ui.view.border.BorderDrawable;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.concurrent.atomic.AtomicInteger;

public class WXViewUtils {
    public static final int DIMENSION_UNSET = -1;
    @Deprecated
    public static final int OPAQUE = -1;
    @Deprecated
    public static final int TRANSLUCENT = -3;
    @Deprecated
    public static final int TRANSPARENT = -2;
    private static int mScreenHeight = 0;
    private static int mScreenWidth = 0;
    private static final boolean mUseWebPx = false;
    private static final AtomicInteger sNextGeneratedId = new AtomicInteger(1);

    @Retention(RetentionPolicy.SOURCE)
    public @interface Opacity {
    }

    public static int generateViewId() {
        int result;
        int newValue;
        if (Build.VERSION.SDK_INT >= 17) {
            return View.generateViewId();
        }
        do {
            result = sNextGeneratedId.get();
            newValue = result + 1;
            if (newValue > 16777215) {
                newValue = 1;
            }
        } while (!sNextGeneratedId.compareAndSet(result, newValue));
        return result;
    }

    public static int getWeexHeight(String instanceId) {
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (instance == null) {
            return -3;
        }
        int weexHeight = instance.getWeexHeight();
        if (weexHeight >= 0 || weexHeight == -2) {
            return weexHeight;
        }
        return getScreenHeight(WXEnvironment.sApplication);
    }

    public static int getWeexWidth(String instanceId) {
        WXSDKInstance instance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (instance == null) {
            return -3;
        }
        int weexWidth = instance.getWeexWidth();
        if (weexWidth >= 0 || weexWidth == -2) {
            return weexWidth;
        }
        return getScreenWidth(WXEnvironment.sApplication);
    }

    @Deprecated
    public static int getScreenWidth() {
        return getScreenWidth(WXEnvironment.sApplication);
    }

    @Deprecated
    public static int setScreenWidth(int screenWidth) {
        mScreenWidth = screenWidth;
        return screenWidth;
    }

    public static float getScreenDensity(Context ctx) {
        if (ctx == null) {
            return 3.0f;
        }
        try {
            return ctx.getResources().getDisplayMetrics().density;
        } catch (Exception e) {
            WXLogUtils.e("getScreenDensityDpi exception:" + e.getMessage());
            return 3.0f;
        }
    }

    public static void updateApplicationScreen(Context context) {
        if (context != null && WXEnvironment.sApplication != null) {
            DisplayMetrics metrics = context.getResources().getDisplayMetrics();
            DisplayMetrics displayMetrics = WXEnvironment.sApplication.getResources().getDisplayMetrics();
            displayMetrics.heightPixels = metrics.heightPixels;
            displayMetrics.widthPixels = metrics.widthPixels;
            displayMetrics.density = metrics.density;
            displayMetrics.densityDpi = metrics.densityDpi;
            displayMetrics.scaledDensity = metrics.scaledDensity;
            displayMetrics.xdpi = metrics.xdpi;
        }
    }

    public static int getScreenWidth(Context ctx) {
        if (ctx != null) {
            Resources res = ctx.getResources();
            mScreenWidth = res.getDisplayMetrics().widthPixels;
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = res.getDisplayMetrics().heightPixels;
                mScreenHeight = i;
                int i2 = mScreenWidth;
                if (i > i2) {
                    i = i2;
                }
                mScreenWidth = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenWidth;
    }

    public static int getStatusBarHeight(Context context) {
        Resources resources = context.getResources();
        int resourceId = resources.getIdentifier("status_bar_height", "dimen", WXEnvironment.OS);
        if (resourceId > 0) {
            return resources.getDimensionPixelSize(resourceId);
        }
        return -1;
    }

    @Deprecated
    public static int getScreenHeight() {
        return getScreenHeight(WXEnvironment.sApplication);
    }

    public static int getScreenHeight(String instanceId) {
        return WXSDKManager.getInstance().getSDKInstance(instanceId).isFullScreenHeightEnabled() ? getFullScreenHeight(WXEnvironment.sApplication) : getScreenHeight(WXEnvironment.sApplication);
    }

    public static int getFullScreenHeight(Context cxt) {
        WindowManager wm;
        if (cxt != null) {
            Resources res = cxt.getResources();
            if (Build.VERSION.SDK_INT < 17 || (wm = (WindowManager) cxt.getSystemService("window")) == null || wm.getDefaultDisplay() == null) {
                mScreenHeight = cxt.getResources().getDisplayMetrics().heightPixels;
            } else {
                Point size = new Point();
                wm.getDefaultDisplay().getRealSize(size);
                mScreenHeight = size.y;
            }
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = res.getDisplayMetrics().widthPixels;
                mScreenWidth = i;
                int i2 = mScreenHeight;
                if (i2 > i) {
                    i = i2;
                }
                mScreenHeight = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenHeight;
    }

    public static int getScreenHeight(Context cxt) {
        if (cxt != null) {
            Resources res = cxt.getResources();
            mScreenHeight = res.getDisplayMetrics().heightPixels;
            if (WXEnvironment.SETTING_FORCE_VERTICAL_SCREEN) {
                int i = res.getDisplayMetrics().widthPixels;
                mScreenWidth = i;
                int i2 = mScreenHeight;
                if (i2 > i) {
                    i = i2;
                }
                mScreenHeight = i;
            }
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("Error Context is null When getScreenHeight");
        }
        return mScreenHeight;
    }

    @Deprecated
    public static float getRealPxByWidth(float pxValue) {
        return realPxByWidth(pxValue, 750.0f);
    }

    public static float getRealPxByWidth(float pxValue, float customViewport) {
        return realPxByWidth(pxValue, customViewport);
    }

    public static float getRealPxByWidth(float pxValue, int customViewport) {
        return realPxByWidth(pxValue, (float) customViewport);
    }

    private static float realPxByWidth(float pxValue, float customViewport) {
        if (Float.isNaN(pxValue)) {
            return pxValue;
        }
        float realPx = (((float) getScreenWidth()) * pxValue) / customViewport;
        if (((double) realPx) <= 0.005d || realPx >= 1.0f) {
            return (float) Math.rint((double) realPx);
        }
        return 1.0f;
    }

    @Deprecated
    public static float getRealSubPxByWidth(float pxValue) {
        return realSubPxByWidth(pxValue, 750.0f);
    }

    public static float getRealSubPxByWidth(float pxValue, float customViewport) {
        return realSubPxByWidth(pxValue, customViewport);
    }

    public static float getRealSubPxByWidth(float pxValue, int customViewport) {
        return realSubPxByWidth(pxValue, (float) customViewport);
    }

    private static float realSubPxByWidth(float pxValue, float customViewport) {
        if (Float.isNaN(pxValue)) {
            return pxValue;
        }
        float realPx = (((float) getScreenWidth()) * pxValue) / customViewport;
        if (((double) realPx) <= 0.005d || realPx >= 1.0f) {
            return realPx;
        }
        return 1.0f;
    }

    @Deprecated
    public static float getWeexPxByReal(float pxValue) {
        return weexPxByReal(pxValue, 750.0f);
    }

    public static float getWeexPxByReal(float pxValue, float customViewport) {
        return weexPxByReal(pxValue, customViewport);
    }

    public static float getWeexPxByReal(float pxValue, int customViewport) {
        return weexPxByReal(pxValue, (float) customViewport);
    }

    private static float weexPxByReal(float pxValue, float customViewport) {
        if (Float.isNaN(pxValue)) {
            return pxValue;
        }
        return (pxValue * customViewport) / ((float) getScreenWidth());
    }

    @Deprecated
    public static float getRealPxByWidth2(float pxValue) {
        return (float) realPxByWidth2(pxValue, 750.0f);
    }

    public static int getRealPxByWidth2(float pxValue, float customViewport) {
        return realPxByWidth2(pxValue, customViewport);
    }

    public static int getRealPxByWidth2(float pxValue, int customViewport) {
        return realPxByWidth2(pxValue, (float) customViewport);
    }

    private static int realPxByWidth2(float pxValue, float customViewport) {
        float realPx = (((float) getScreenWidth()) * pxValue) / customViewport;
        if (((double) realPx) <= 0.005d || realPx >= 1.0f) {
            return ((int) realPx) - 1;
        }
        return 1;
    }

    @Deprecated
    public static float getWebPxByWidth(float pxValue) {
        return webPxByWidth(pxValue, 750.0f);
    }

    public static float getWebPxByWidth(float pxValue, float customViewport) {
        return webPxByWidth(pxValue, customViewport);
    }

    public static float getWebPxByWidth(float pxValue, int customViewport) {
        return webPxByWidth(pxValue, (float) customViewport);
    }

    private static float webPxByWidth(float pxValue, float customViewport) {
        if (((double) pxValue) < -1.9999d && ((double) pxValue) > -2.005d) {
            return Float.NaN;
        }
        float realPx = (pxValue * customViewport) / ((float) getScreenWidth());
        if (((double) realPx) <= 0.005d || realPx >= 1.0f) {
            return realPx;
        }
        return 1.0f;
    }

    public static int dip2px(float dpValue) {
        float scale = 2.0f;
        try {
            scale = WXEnvironment.getApplication().getResources().getDisplayMetrics().density;
        } catch (Exception e) {
            WXLogUtils.e("[WXViewUtils] dip2px:", e);
        }
        float finalPx = (dpValue * scale) + 0.5f;
        if (finalPx <= 0.0f || finalPx >= 1.0f) {
            return (int) finalPx;
        }
        return 1;
    }

    public static boolean onScreenArea(View view) {
        int viewH;
        if (view == null || view.getVisibility() != 0) {
            return false;
        }
        int[] p = new int[2];
        view.getLocationOnScreen(p);
        ViewGroup.LayoutParams lp = view.getLayoutParams();
        if (lp != null) {
            viewH = lp.height;
        } else {
            viewH = view.getHeight();
        }
        if ((p[1] <= 0 || p[1] - getScreenHeight(WXEnvironment.sApplication) >= 0) && (p[1] + viewH <= 0 || p[1] > 0)) {
            return false;
        }
        return true;
    }

    public static int multiplyColorAlpha(int color, int alpha) {
        if (alpha == 255) {
            return color;
        }
        if (alpha == 0) {
            return 16777215 & color;
        }
        return (16777215 & color) | ((((color >>> 24) * (alpha + (alpha >> 7))) >> 8) << 24);
    }

    public static int getOpacityFromColor(int color) {
        int colorAlpha = color >>> 24;
        if (colorAlpha == 255) {
            return -1;
        }
        if (colorAlpha == 0) {
            return -2;
        }
        return -3;
    }

    public static void setBackGround(View view, Drawable drawable, WXComponent component) {
        if (Build.VERSION.SDK_INT < 16) {
            view.setBackgroundDrawable(drawable);
            return;
        }
        try {
            view.setBackground(drawable);
        } catch (Exception e) {
            if (component != null) {
                WXExceptionUtils.commitCriticalExceptionRT(component.getInstanceId(), WXErrorCode.WX_RENDER_ERR_TEXTURE_SETBACKGROUND, component.getComponentType() + " setBackGround for android view", WXErrorCode.WX_RENDER_ERR_TEXTURE_SETBACKGROUND.getErrorMsg() + ": TextureView doesn't support displaying a background drawable!", null);
            }
        }
    }

    public static BorderDrawable getBorderDrawable(View view) {
        Drawable drawable = view.getBackground();
        if (drawable instanceof BorderDrawable) {
            return (BorderDrawable) drawable;
        }
        if (!(drawable instanceof LayerDrawable)) {
            return null;
        }
        LayerDrawable layerDrawable = (LayerDrawable) drawable;
        if (layerDrawable.getNumberOfLayers() <= 1) {
            return null;
        }
        for (int i = 0; i < layerDrawable.getNumberOfLayers(); i++) {
            Drawable innerDrawable = layerDrawable.getDrawable(i);
            if (innerDrawable instanceof BorderDrawable) {
                return (BorderDrawable) innerDrawable;
            }
        }
        return null;
    }

    public static void clipCanvasWithinBorderBox(View targetView, Canvas canvas) {
        if (clipCanvasDueToAndroidVersion(canvas) && clipCanvasIfAnimationExist(targetView)) {
            Drawable drawable = getBorderDrawable(targetView);
            if (drawable instanceof BorderDrawable) {
                BorderDrawable borderDrawable = (BorderDrawable) drawable;
                if (borderDrawable.isRounded() && clipCanvasIfBackgroundImageExist(targetView, borderDrawable)) {
                    RectF f = new RectF(0.0f, 0.0f, (float) targetView.getWidth(), (float) targetView.getHeight());
                    Path path = borderDrawable.getContentPath(f);
                    if (targetView instanceof WXFrameLayout) {
                        WXComponent component = ((WXFrameLayout) targetView).getComponent();
                        if (component != null) {
                            Object rotateFix = component.getAttrs().get(Constants.Name.ROTATE_FIX);
                            if (rotateFix != null && rotateFix.toString().equals(AbsoluteConst.TRUE)) {
                                canvas.clipRect(f);
                            } else if ((component.getStyles() != null && "hidden".equals(component.getStyles().getOverflow())) || Build.VERSION.SDK_INT < 24) {
                                canvas.clipPath(path);
                            }
                        }
                    } else {
                        canvas.clipPath(path);
                    }
                }
            }
        }
    }

    public static void clipCanvasWithinBorderBox(Widget widget, Canvas canvas) {
        BorderDrawable borderDrawable;
        if (clipCanvasDueToAndroidVersion(canvas) && clipCanvasIfAnimationExist(null) && (borderDrawable = widget.getBackgroundAndBorder()) != null) {
            if (!borderDrawable.isRounded() || !clipCanvasIfBackgroundImageExist(widget, borderDrawable)) {
                canvas.clipRect(widget.getBorderBox());
            } else {
                canvas.clipPath(borderDrawable.getContentPath(new RectF(0.0f, 0.0f, (float) widget.getBorderBox().width(), (float) widget.getBorderBox().height())));
            }
        }
    }

    private static boolean clipCanvasDueToAndroidVersion(Canvas canvas) {
        return Build.VERSION.SDK_INT >= 18 || !canvas.isHardwareAccelerated();
    }

    private static boolean clipCanvasIfAnimationExist(View targetView) {
        if (Build.VERSION.SDK_INT < 24) {
            return true;
        }
        return false;
    }

    private static boolean clipCanvasIfBackgroundImageExist(View targetView, BorderDrawable borderDrawable) {
        if (!(targetView instanceof ViewGroup)) {
            return true;
        }
        ViewGroup parent = (ViewGroup) targetView;
        int count = parent.getChildCount();
        for (int i = 0; i < count; i++) {
            BorderDrawable drawable = getBorderDrawable(parent.getChildAt(i));
            if (drawable != null && drawable.hasImage() && Build.VERSION.SDK_INT < 21) {
                return false;
            }
        }
        return true;
    }

    private static boolean clipCanvasIfBackgroundImageExist(Widget widget, BorderDrawable borderDrawable) {
        if (!(widget instanceof WidgetGroup)) {
            return true;
        }
        for (Widget child : ((WidgetGroup) widget).getChildren()) {
            if (child.getBackgroundAndBorder().hasImage() && Build.VERSION.SDK_INT < 21) {
                return false;
            }
        }
        return true;
    }
}
