package com.taobao.weex.utils.cache;

import com.taobao.weex.bridge.ModuleFactory;
import com.taobao.weex.bridge.WXModuleManager;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.WXComponentRegistry;
import com.taobao.weex.ui.config.AutoScanConfigRegister;
import com.taobao.weex.utils.WXLogUtils;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class RegisterCache {
    private static Map<String, ComponentCache> componentCacheMap = new ConcurrentHashMap();
    private static Map<String, ModuleCache> moduleCacheMap = new ConcurrentHashMap();
    private static RegisterCache registerCache;
    private volatile int doNotCacheSize = Integer.MAX_VALUE;
    private boolean enable = false;
    private boolean enableAutoScan = true;
    private volatile boolean finished = false;

    public static RegisterCache getInstance() {
        if (registerCache == null) {
            synchronized (RegisterCache.class) {
                if (registerCache == null) {
                    registerCache = new RegisterCache();
                }
            }
        }
        return registerCache;
    }

    private RegisterCache() {
    }

    public void setEnable(boolean enable2) {
        this.enable = enable2;
    }

    private boolean enableCache() {
        return this.enable;
    }

    private boolean canCache() {
        if (!enableCache() || this.finished || getDoNotCacheSize() >= 1) {
            return false;
        }
        return true;
    }

    public boolean enableAutoScan() {
        return this.enableAutoScan;
    }

    public void setEnableAutoScan(boolean enableAutoScan2) {
        if (this.enableAutoScan != enableAutoScan2) {
            if (enableAutoScan2) {
                AutoScanConfigRegister.doScanConfig();
            }
            this.enableAutoScan = enableAutoScan2;
        }
    }

    private int getDoNotCacheSize() {
        int i = this.doNotCacheSize;
        this.doNotCacheSize = i - 1;
        return i;
    }

    public void setDoNotCacheSize(int doNotCacheSize2) {
        this.doNotCacheSize = doNotCacheSize2;
    }

    public boolean idle(boolean atCreateInstance) {
        String message;
        if (this.finished) {
            return true;
        }
        if (atCreateInstance) {
            message = "idle from create instance";
        } else {
            message = "idle from external";
        }
        WXLogUtils.e(message + " cache size is " + (moduleCacheMap.size() + componentCacheMap.size()));
        this.finished = true;
        CacheComponentRegister();
        CacheModuleRegister();
        return true;
    }

    public boolean cacheModule(String moduleName, ModuleFactory factory, boolean global) {
        if (!canCache()) {
            return false;
        }
        try {
            moduleCacheMap.put(moduleName, new ModuleCache(moduleName, factory, global));
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public boolean cacheComponent(String type, IFComponentHolder holder, Map<String, Object> componentInfo) {
        if (!canCache()) {
            return false;
        }
        try {
            componentCacheMap.put(type, new ComponentCache(type, holder, componentInfo));
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    private void CacheComponentRegister() {
        if (!componentCacheMap.isEmpty()) {
            WXComponentRegistry.registerComponent(componentCacheMap);
        }
    }

    private void CacheModuleRegister() {
        if (!moduleCacheMap.isEmpty()) {
            WXModuleManager.registerModule(moduleCacheMap);
        }
    }

    public class ModuleCache {
        public final ModuleFactory factory;
        public final boolean global;
        public final String name;

        ModuleCache(String moduleName, ModuleFactory factory2, boolean global2) {
            this.name = moduleName;
            this.factory = factory2;
            this.global = global2;
        }
    }

    public class ComponentCache {
        public final Map<String, Object> componentInfo;
        public final IFComponentHolder holder;
        public final String type;

        ComponentCache(String type2, IFComponentHolder holder2, Map<String, Object> componentInfo2) {
            this.type = type2;
            this.componentInfo = componentInfo2;
            this.holder = holder2;
        }
    }
}
