package com.tencent.ijk.media.exo.demo;

import android.os.SystemClock;
import android.util.Log;
import android.view.Surface;
import com.google.android.exoplayer2.a.d;
import com.google.android.exoplayer2.f;
import com.google.android.exoplayer2.f.a;
import com.google.android.exoplayer2.f.b.h;
import com.google.android.exoplayer2.f.b.k;
import com.google.android.exoplayer2.f.f;
import com.google.android.exoplayer2.h.e;
import com.google.android.exoplayer2.h.g;
import com.google.android.exoplayer2.i.i;
import com.google.android.exoplayer2.j;
import com.google.android.exoplayer2.o;
import com.google.android.exoplayer2.source.a;
import com.google.android.exoplayer2.source.f;
import com.google.android.exoplayer2.source.l;
import com.google.android.exoplayer2.source.m;
import com.google.android.exoplayer2.v;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.text.NumberFormat;
import java.util.Locale;

public class EventLogger implements d, f.a, f.a, com.google.android.exoplayer2.k.f, a, f.a {
    private static final int MAX_TIMELINE_ITEM_LINES = 3;
    private static final String TAG = "EventLogger";
    private static final NumberFormat TIME_FORMAT;
    private long mBytesLoaded = 0;
    private long mBytesLoadedSeconds = 0;
    private long mLastBytesLoadedTime = 0;
    private final v.a period;
    private final long startTimeMs;
    private final e trackSelector;
    private final v.b window;

    static {
        NumberFormat instance = NumberFormat.getInstance(Locale.US);
        TIME_FORMAT = instance;
        instance.setMinimumFractionDigits(2);
        TIME_FORMAT.setMaximumFractionDigits(2);
        TIME_FORMAT.setGroupingUsed(false);
    }

    public EventLogger(e eVar) {
        this.trackSelector = eVar;
        this.window = new v.b();
        this.period = new v.a();
        this.startTimeMs = SystemClock.elapsedRealtime();
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onLoadingChanged(boolean z) {
        Log.d(TAG, "loading [" + z + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onPlayerStateChanged(boolean z, int i) {
        Log.d(TAG, "state [" + getSessionTimeString() + ", " + z + ", " + getStateString(i) + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onPositionDiscontinuity() {
        Log.d(TAG, "positionDiscontinuity");
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onPlaybackParametersChanged(o oVar) {
        Log.d(TAG, "playbackParameters " + String.format("[speed=%.2f, pitch=%.2f]", Float.valueOf(oVar.b), Float.valueOf(oVar.c)));
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onTimelineChanged(v vVar, Object obj) {
        int c = vVar.c();
        int b = vVar.b();
        Log.d(TAG, "sourceInfo [periodCount=" + c + ", windowCount=" + b);
        for (int i = 0; i < Math.min(c, 3); i++) {
            vVar.a(i, this.period);
            Log.d(TAG, "  period [" + getTimeString(this.period.a()) + Operators.ARRAY_END_STR);
        }
        if (c > 3) {
            Log.d(TAG, "  ...");
        }
        for (int i2 = 0; i2 < Math.min(b, 3); i2++) {
            vVar.a(i2, this.window);
            Log.d(TAG, "  window [" + getTimeString(this.window.b()) + ", " + this.window.d + ", " + this.window.e + Operators.ARRAY_END_STR);
        }
        if (b > 3) {
            Log.d(TAG, "  ...");
        }
        Log.d(TAG, Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onPlayerError(com.google.android.exoplayer2.e eVar) {
        Log.e(TAG, "playerFailed [" + getSessionTimeString() + Operators.ARRAY_END_STR, eVar);
    }

    @Override // com.google.android.exoplayer2.f.a
    public void onTracksChanged(m mVar, g gVar) {
        String str;
        String str2;
        EventLogger eventLogger;
        EventLogger eventLogger2 = this;
        e.a a = eventLogger2.trackSelector.a();
        if (a == null) {
            Log.d(TAG, "Tracks []");
            return;
        }
        Log.d(TAG, "Tracks [");
        int i = 0;
        while (true) {
            str = "  ]";
            str2 = " [";
            if (i >= a.a) {
                break;
            }
            m a2 = a.a(i);
            com.google.android.exoplayer2.h.f a3 = gVar.a(i);
            if (a2.b > 0) {
                Log.d(TAG, "  Renderer:" + i + str2);
                int i2 = 0;
                while (i2 < a2.b) {
                    l a4 = a2.a(i2);
                    String adaptiveSupportString = getAdaptiveSupportString(a4.a, a.a(i, i2, false));
                    Log.d(TAG, "    Group:" + i2 + ", adaptive_supported=" + adaptiveSupportString + str2);
                    int i3 = 0;
                    while (i3 < a4.a) {
                        String trackStatusString = getTrackStatusString(a3, a4, i3);
                        String formatSupportString = getFormatSupportString(a.a(i, i2, i3));
                        Log.d(TAG, "      " + trackStatusString + " Track:" + i3 + ", " + j.b(a4.a(i3)) + ", supported=" + formatSupportString);
                        i3++;
                        str2 = str2;
                    }
                    Log.d(TAG, "    ]");
                    i2++;
                    a2 = a2;
                    str = str;
                }
                if (a3 != null) {
                    int i4 = 0;
                    while (true) {
                        if (i4 >= a3.e()) {
                            eventLogger = this;
                            break;
                        }
                        com.google.android.exoplayer2.f.a aVar = a3.a(i4).d;
                        if (aVar != null) {
                            Log.d(TAG, "    Metadata [");
                            eventLogger = this;
                            eventLogger.printMetadata(aVar, "      ");
                            Log.d(TAG, "    ]");
                            break;
                        }
                        i4++;
                    }
                } else {
                    eventLogger = this;
                }
                Log.d(TAG, str);
            } else {
                eventLogger = eventLogger2;
            }
            i++;
            eventLogger2 = eventLogger;
        }
        String str3 = str2;
        m a5 = a.a();
        if (a5.b > 0) {
            Log.d(TAG, "  Renderer:None [");
            int i5 = 0;
            while (i5 < a5.b) {
                Log.d(TAG, "    Group:" + i5 + str3);
                l a6 = a5.a(i5);
                int i6 = 0;
                while (i6 < a6.a) {
                    String trackStatusString2 = getTrackStatusString(false);
                    String formatSupportString2 = getFormatSupportString(0);
                    Log.d(TAG, "      " + trackStatusString2 + " Track:" + i6 + ", " + j.b(a6.a(i6)) + ", supported=" + formatSupportString2);
                    i6++;
                    a5 = a5;
                }
                Log.d(TAG, "    ]");
                i5++;
                str3 = str3;
            }
            Log.d(TAG, str);
        }
        Log.d(TAG, Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.f.f.a
    public void onMetadata(com.google.android.exoplayer2.f.a aVar) {
        Log.d(TAG, "onMetadata [");
        printMetadata(aVar, "  ");
        Log.d(TAG, Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioEnabled(com.google.android.exoplayer2.b.d dVar) {
        Log.d(TAG, "audioEnabled [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioSessionId(int i) {
        Log.d(TAG, "audioSessionId [" + i + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioDecoderInitialized(String str, long j, long j2) {
        Log.d(TAG, "audioDecoderInitialized [" + getSessionTimeString() + ", " + str + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioInputFormatChanged(j jVar) {
        Log.d(TAG, "audioFormatChanged [" + getSessionTimeString() + ", " + j.b(jVar) + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioDisabled(com.google.android.exoplayer2.b.d dVar) {
        Log.d(TAG, "audioDisabled [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.a.d
    public void onAudioTrackUnderrun(int i, long j, long j2) {
        printInternalError("audioTrackUnderrun [" + i + ", " + j + ", " + j2 + Operators.ARRAY_END_STR, null);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onVideoEnabled(com.google.android.exoplayer2.b.d dVar) {
        Log.d(TAG, "videoEnabled [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onVideoDecoderInitialized(String str, long j, long j2) {
        Log.d(TAG, "videoDecoderInitialized [" + getSessionTimeString() + ", " + str + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onVideoInputFormatChanged(j jVar) {
        Log.d(TAG, "videoFormatChanged [" + getSessionTimeString() + ", " + j.b(jVar) + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onVideoDisabled(com.google.android.exoplayer2.b.d dVar) {
        Log.d(TAG, "videoDisabled [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onDroppedFrames(int i, long j) {
        Log.d(TAG, "droppedFrames [" + getSessionTimeString() + ", " + i + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onVideoSizeChanged(int i, int i2, int i3, float f) {
    }

    @Override // com.google.android.exoplayer2.k.f
    public void onRenderedFirstFrame(Surface surface) {
        Log.d(TAG, "renderedFirstFrame [" + surface + Operators.ARRAY_END_STR);
    }

    public void onDrmSessionManagerError(Exception exc) {
        printInternalError("drmSessionManagerError", exc);
    }

    public void onDrmKeysRestored() {
        Log.d(TAG, "drmKeysRestored [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    public void onDrmKeysRemoved() {
        Log.d(TAG, "drmKeysRemoved [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    public void onDrmKeysLoaded() {
        Log.d(TAG, "drmKeysLoaded [" + getSessionTimeString() + Operators.ARRAY_END_STR);
    }

    @Override // com.google.android.exoplayer2.source.f.a
    public void onLoadError(IOException iOException) {
        printInternalError("loadError", iOException);
    }

    @Override // com.google.android.exoplayer2.source.a
    public void onLoadStarted(i iVar, int i, int i2, j jVar, int i3, Object obj, long j, long j2, long j3) {
        if (this.mLastBytesLoadedTime == 0) {
            this.mLastBytesLoadedTime = System.currentTimeMillis();
        }
    }

    @Override // com.google.android.exoplayer2.source.a
    public void onLoadError(i iVar, int i, int i2, j jVar, int i3, Object obj, long j, long j2, long j3, long j4, long j5, IOException iOException, boolean z) {
        printInternalError("loadError", iOException);
    }

    @Override // com.google.android.exoplayer2.source.a
    public void onLoadCanceled(i iVar, int i, int i2, j jVar, int i3, Object obj, long j, long j2, long j3, long j4, long j5) {
    }

    @Override // com.google.android.exoplayer2.source.a
    public void onLoadCompleted(i iVar, int i, int i2, j jVar, int i3, Object obj, long j, long j2, long j3, long j4, long j5) {
        long currentTimeMillis = System.currentTimeMillis();
        long j6 = this.mLastBytesLoadedTime;
        if (j6 != 0) {
            logBytesLoadedInSeconds(j5, (float) ((currentTimeMillis - j6) / 1000));
            this.mLastBytesLoadedTime = currentTimeMillis;
        }
    }

    private void logBytesLoadedInSeconds(long j, float f) {
        this.mBytesLoaded += j;
        this.mBytesLoadedSeconds = (long) (((float) this.mBytesLoadedSeconds) + f);
    }

    public int getObservedBitrate() {
        long j = this.mBytesLoadedSeconds;
        if (j == 0) {
            return 0;
        }
        StringBuilder sb = new StringBuilder();
        sb.append(" mBytesLoaded ");
        sb.append(this.mBytesLoaded);
        sb.append(" in ");
        sb.append(this.mBytesLoadedSeconds);
        sb.append(" seconds (");
        int i = (int) (((double) (this.mBytesLoaded / j)) * 8.0d);
        sb.append(i);
        sb.append(" b/s indicated ");
        Log.d(TAG, sb.toString());
        return i;
    }

    public void onUpstreamDiscarded(int i, long j, long j2) {
    }

    @Override // com.google.android.exoplayer2.source.a
    public void onDownstreamFormatChanged(int i, j jVar, int i2, Object obj, long j) {
    }

    private void printInternalError(String str, Exception exc) {
        Log.e(TAG, "internalError [" + getSessionTimeString() + ", " + str + Operators.ARRAY_END_STR, exc);
    }

    private void printMetadata(com.google.android.exoplayer2.f.a aVar, String str) {
        for (int i = 0; i < aVar.a(); i++) {
            a.AbstractC0065a a = aVar.a(i);
            if (a instanceof com.google.android.exoplayer2.f.b.j) {
                com.google.android.exoplayer2.f.b.j jVar = (com.google.android.exoplayer2.f.b.j) a;
                Log.d(TAG, str + String.format("%s: value=%s", jVar.f, jVar.b));
            } else if (a instanceof k) {
                k kVar = (k) a;
                Log.d(TAG, str + String.format("%s: url=%s", kVar.f, kVar.b));
            } else if (a instanceof com.google.android.exoplayer2.f.b.i) {
                com.google.android.exoplayer2.f.b.i iVar = (com.google.android.exoplayer2.f.b.i) a;
                Log.d(TAG, str + String.format("%s: owner=%s", iVar.f, iVar.a));
            } else if (a instanceof com.google.android.exoplayer2.f.b.f) {
                com.google.android.exoplayer2.f.b.f fVar = (com.google.android.exoplayer2.f.b.f) a;
                Log.d(TAG, str + String.format("%s: mimeType=%s, filename=%s, description=%s", fVar.f, fVar.a, fVar.b, fVar.c));
            } else if (a instanceof com.google.android.exoplayer2.f.b.a) {
                com.google.android.exoplayer2.f.b.a aVar2 = (com.google.android.exoplayer2.f.b.a) a;
                Log.d(TAG, str + String.format("%s: mimeType=%s, description=%s", aVar2.f, aVar2.a, aVar2.b));
            } else if (a instanceof com.google.android.exoplayer2.f.b.e) {
                com.google.android.exoplayer2.f.b.e eVar = (com.google.android.exoplayer2.f.b.e) a;
                Log.d(TAG, str + String.format("%s: language=%s, description=%s", eVar.f, eVar.a, eVar.b));
            } else if (a instanceof h) {
                Log.d(TAG, str + String.format("%s", ((h) a).f));
            } else if (a instanceof com.google.android.exoplayer2.f.a.a) {
                com.google.android.exoplayer2.f.a.a aVar3 = (com.google.android.exoplayer2.f.a.a) a;
                Log.d(TAG, str + String.format("EMSG: scheme=%s, id=%d, value=%s", aVar3.a, Long.valueOf(aVar3.d), aVar3.b));
            }
        }
    }

    private String getSessionTimeString() {
        return getTimeString(SystemClock.elapsedRealtime() - this.startTimeMs);
    }

    private static String getTimeString(long j) {
        return j == -9223372036854775807L ? Operators.CONDITION_IF_STRING : TIME_FORMAT.format((double) (((float) j) / 1000.0f));
    }

    private static String getStateString(int i) {
        if (i == 1) {
            return "I";
        }
        if (i == 2) {
            return "B";
        }
        if (i == 3) {
            return "R";
        }
        if (i != 4) {
            return Operators.CONDITION_IF_STRING;
        }
        return "E";
    }

    private static String getFormatSupportString(int i) {
        if (i == 0) {
            return "NO";
        }
        if (i == 1) {
            return "NO_UNSUPPORTED_TYPE";
        }
        if (i == 2) {
            return "NO_EXCEEDS_CAPABILITIES";
        }
        if (i != 3) {
            return Operators.CONDITION_IF_STRING;
        }
        return "YES";
    }

    private static String getAdaptiveSupportString(int i, int i2) {
        if (i < 2) {
            return "N/A";
        }
        if (i2 == 0) {
            return "NO";
        }
        if (i2 == 4) {
            return "YES_NOT_SEAMLESS";
        }
        if (i2 != 8) {
            return Operators.CONDITION_IF_STRING;
        }
        return "YES";
    }

    private static String getTrackStatusString(com.google.android.exoplayer2.h.f fVar, l lVar, int i) {
        return getTrackStatusString((fVar == null || fVar.d() != lVar || fVar.c(i) == -1) ? false : true);
    }

    private static String getTrackStatusString(boolean z) {
        return z ? "[X]" : "[ ]";
    }
}
