package com.tencent.liteav.audio;

import android.content.Context;
import android.media.AudioTrack;
import android.os.Handler;
import android.os.Looper;
import com.tencent.liteav.audio.impl.TXCTraeJNI;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.b;
import io.dcloud.common.constant.AbsoluteConst;
import java.lang.ref.WeakReference;

public class TXCLiveBGMPlayer implements Runnable {
    private static final int PLAY_ERR_AUDIO_TRACK = -3;
    private static final int PLAY_ERR_AUDIO_TRACK_PLAY = -4;
    private static final int PLAY_ERR_FILE_NOTFOUND = -2;
    private static final int PLAY_ERR_OPEN = -1;
    private static final int PLAY_SUCCESS = 0;
    private static final String TAG = ("AudioCenter:" + TXCLiveBGMPlayer.class.getSimpleName());
    private static TXCLiveBGMPlayer instance;
    private int mAECType = 0;
    private Context mContext = null;
    private String mFilePath = null;
    private boolean mIsPause = false;
    private boolean mIsRunning = false;
    private float mPitch = 0.0f;
    private Thread mThread = null;
    private WeakReference<e> mWeakListener = null;

    private native int nativeGetBitsPerChannel();

    private native int nativeGetChannels();

    private native long nativeGetCurDurationMS();

    private native long nativeGetCurPtsMS();

    private native long nativeGetDurationMS(String str);

    private native int nativeGetSampleRate();

    private native void nativePause();

    private native int nativeRead(byte[] bArr, int i);

    private native void nativeResume();

    private native void nativeSetPitch(float f);

    private native void nativeSetVolume(float f);

    private native boolean nativeStartPlay(String str, TXCLiveBGMPlayer tXCLiveBGMPlayer);

    private native void nativeStopPlay();

    static {
        b.f();
    }

    public static TXCLiveBGMPlayer getInstance() {
        if (instance == null) {
            synchronized (TXCLiveBGMPlayer.class) {
                if (instance == null) {
                    instance = new TXCLiveBGMPlayer();
                }
            }
        }
        return instance;
    }

    private TXCLiveBGMPlayer() {
    }

    public synchronized void setOnPlayListener(e eVar) {
        if (eVar == null) {
            this.mWeakListener = null;
        }
        this.mWeakListener = new WeakReference<>(eVar);
    }

    public void setContext(Context context) {
        this.mContext = context;
    }

    public boolean startPlay(String str, int i) {
        if (str == null || str.isEmpty()) {
            TXCLog.e(TAG, "start live bgm failed! invalid params!");
            return false;
        }
        stopPlay();
        this.mAECType = i;
        this.mFilePath = str;
        this.mIsRunning = true;
        onPlayStart();
        if (!nativeStartPlay(this.mFilePath, this)) {
            onPlayEnd(-1);
            return false;
        }
        if (this.mAECType == 2) {
            TXCTraeJNI.traeStartPlay(this.mContext);
        } else if (this.mThread == null) {
            Thread thread = new Thread(this, "BGMPlayer");
            this.mThread = thread;
            thread.start();
        }
        String str2 = TAG;
        TXCLog.i(str2, "startPlay filePath = " + str);
        return true;
    }

    public void stopPlay() {
        this.mIsRunning = false;
        long currentTimeMillis = System.currentTimeMillis();
        Thread thread = this.mThread;
        if (!(thread == null || !thread.isAlive() || Thread.currentThread().getId() == this.mThread.getId())) {
            try {
                this.mThread.join();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        this.mThread = null;
        nativeStopPlay();
        TXCTraeJNI.traeStopPlay();
        this.mIsPause = false;
        String str = TAG;
        TXCLog.i(str, "stopBGMPlay cost(MS): " + (System.currentTimeMillis() - currentTimeMillis));
    }

    public boolean isRunning() {
        return this.mIsRunning && !this.mIsPause;
    }

    public boolean isPlaying() {
        return this.mIsRunning;
    }

    public void switchAecType(int i) {
        if (!this.mIsRunning) {
            TXCLog.w(TAG, "未开始播放BGM，不能切换AEC Type");
        } else if (this.mAECType == i) {
            String str = TAG;
            TXCLog.i(str, "无需切换AEC Type. aecType = " + this.mAECType);
        } else {
            String str2 = TAG;
            TXCLog.i(str2, "切换AEC Type为 " + i);
            this.mAECType = i;
            if (i == 2) {
                Thread thread = this.mThread;
                if (!(thread == null || !thread.isAlive() || Thread.currentThread().getId() == this.mThread.getId())) {
                    try {
                        this.mThread.join();
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }
                this.mThread = null;
            } else if (this.mThread == null) {
                Thread thread2 = new Thread(this, "BGMPlayer");
                this.mThread = thread2;
                thread2.start();
            }
        }
    }

    public void pause() {
        TXCLog.i(TAG, "pause");
        this.mIsPause = true;
        nativePause();
    }

    public void resume() {
        TXCLog.i(TAG, AbsoluteConst.EVENTS_RESUME);
        this.mIsPause = false;
        nativeResume();
    }

    public void setVolume(float f) {
        nativeSetVolume(f);
    }

    public long getMusicDuration(String str) {
        return nativeGetDurationMS(str);
    }

    public void setPitch(float f) {
        this.mPitch = f;
        nativeSetPitch(f);
    }

    private void onPlayStart() {
        final e eVar;
        synchronized (this) {
            if (this.mWeakListener != null) {
                eVar = this.mWeakListener.get();
            } else {
                eVar = null;
            }
        }
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class com.tencent.liteav.audio.TXCLiveBGMPlayer.AnonymousClass1 */

            public void run() {
                e eVar = eVar;
                if (eVar != null) {
                    eVar.onPlayStart();
                }
            }
        });
    }

    private void onPlayEnd(final int i) {
        final e eVar;
        synchronized (this) {
            if (this.mWeakListener != null) {
                eVar = this.mWeakListener.get();
            } else {
                eVar = null;
            }
        }
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class com.tencent.liteav.audio.TXCLiveBGMPlayer.AnonymousClass2 */

            public void run() {
                e eVar = eVar;
                if (eVar != null) {
                    eVar.onPlayEnd(i);
                }
            }
        });
    }

    private void onPlayProgress(long j, long j2) {
        e eVar;
        synchronized (this) {
            if (this.mWeakListener != null) {
                eVar = this.mWeakListener.get();
            } else {
                eVar = null;
            }
        }
        if (eVar != null) {
            eVar.onPlayProgress(j, j2);
        }
    }

    private void nativeOPlayProgress(long j, long j2) {
        onPlayProgress(j, j2);
        if (j == j2) {
            onPlayEnd(0);
        }
    }

    public void run() {
        int i;
        int i2;
        long currentTimeMillis = System.currentTimeMillis();
        String str = this.mFilePath;
        int i3 = 0;
        AudioTrack audioTrack = null;
        if (str == null || str.isEmpty()) {
            i3 = -2;
        } else {
            int nativeGetSampleRate = nativeGetSampleRate();
            int nativeGetChannels = nativeGetChannels();
            int nativeGetBitsPerChannel = nativeGetBitsPerChannel();
            if (nativeGetChannels == 1) {
                i = 2;
            } else {
                i = 3;
            }
            if (nativeGetBitsPerChannel == 8) {
                i2 = 3;
            } else {
                i2 = 2;
            }
            try {
                AudioTrack audioTrack2 = new AudioTrack(3, nativeGetSampleRate, i, i2, AudioTrack.getMinBufferSize(nativeGetSampleRate, i, i2), 1);
                try {
                    audioTrack2.play();
                    int i4 = nativeGetChannels * 2048;
                    byte[] bArr = new byte[i4];
                    while (true) {
                        if (!this.mIsRunning || Thread.interrupted() || this.mAECType == 2) {
                            break;
                        }
                        int nativeRead = nativeRead(bArr, i4);
                        if (nativeRead < 0) {
                            onPlayProgress(nativeGetCurDurationMS(), nativeGetCurDurationMS());
                            break;
                        } else if (nativeRead != 0) {
                            audioTrack2.write(bArr, 0, nativeRead);
                            onPlayProgress(nativeGetCurPtsMS(), nativeGetCurDurationMS());
                        } else if (this.mIsPause) {
                            try {
                                Thread.sleep(100);
                            } catch (InterruptedException e) {
                                e.printStackTrace();
                            }
                        }
                    }
                    audioTrack = audioTrack2;
                } catch (Exception e2) {
                    e2.printStackTrace();
                    String str2 = TAG;
                    TXCLog.e(str2, "AudioTrack play Exception: " + e2.getMessage());
                    i3 = -4;
                    audioTrack = audioTrack2;
                }
            } catch (Exception e3) {
                e3.printStackTrace();
                String str3 = TAG;
                TXCLog.e(str3, "new AudioTrack Exception: " + e3.getMessage());
                i3 = -3;
            }
        }
        if (audioTrack != null) {
            try {
                audioTrack.pause();
                audioTrack.flush();
                audioTrack.stop();
                audioTrack.release();
            } catch (Exception e4) {
                e4.printStackTrace();
            }
        }
        String str4 = TAG;
        TXCLog.i(str4, "Live BGM player play time: " + (System.currentTimeMillis() - currentTimeMillis));
        if (this.mIsRunning) {
            onPlayEnd(i3);
        }
    }
}
