package com.tencent.liteav.audio.impl.Play;

import android.content.Context;
import android.os.Environment;
import com.tencent.liteav.audio.TXEAudioDef;
import com.tencent.liteav.audio.a;
import com.tencent.liteav.audio.c;
import com.tencent.liteav.basic.e.b;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.structs.TXSAVModuleSyncInfo;
import io.dcloud.common.DHInterface.IFeature;
import java.lang.ref.WeakReference;

public class TXCAudioBasePlayController implements c {
    private static final String TAG = ("AudioCenter:" + TXCAudioBasePlayController.class.getSimpleName());
    private static WeakReference<c> mAudioCoreListener = null;
    protected float mAutoAdjustMaxCache = a.c;
    protected float mAutoAdjustMinCache = a.d;
    protected float mCacheTime = a.a;
    protected Context mContext;
    protected boolean mIsAutoAdjustCache = a.b;
    protected boolean mIsHWAcceleration = false;
    protected boolean mIsMute = a.e;
    protected volatile boolean mIsPlaying = false;
    protected boolean mIsRealTimePlay = false;
    protected long mJitterBuffer = 0;
    protected c mListener;
    protected int mSmoothMode = 0;
    protected int mStreamFormat = 0;
    protected String mUserID = null;

    public static native byte[] nativeGetMixedTracksData(int i);

    public static native boolean nativeIsTracksEmpty();

    public static native void nativeSetTempPath(String str);

    /* access modifiers changed from: protected */
    public native long nativeCreateJitterBuffer(boolean z, TXCAudioBasePlayController tXCAudioBasePlayController, int i);

    /* access modifiers changed from: protected */
    public native void nativeDestoryJitterBuffer(long j);

    /* access modifiers changed from: protected */
    public native void nativeEnableAutoAdjustCache(long j, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeEnableRealTimePlay(long j, boolean z);

    /* access modifiers changed from: protected */
    public native TXSAVModuleSyncInfo nativeGetAudioSyncInfo(long j);

    /* access modifiers changed from: protected */
    public native float nativeGetCacheThreshold(long j);

    /* access modifiers changed from: protected */
    public native int nativeGetChannel(long j);

    /* access modifiers changed from: protected */
    public native long nativeGetCurPts(long j);

    /* access modifiers changed from: protected */
    public native int nativeGetExpiredFrames(long j);

    /* access modifiers changed from: protected */
    public native TXAudioJitterBufferReportInfo nativeGetLoadingInfo(long j);

    /* access modifiers changed from: protected */
    public native long nativeGetNetRecvTS(long j);

    /* access modifiers changed from: protected */
    public native int nativeGetRecvJitter(long j);

    /* access modifiers changed from: protected */
    public native int nativeGetSamplerate(long j);

    /* access modifiers changed from: protected */
    public native void nativeSetAutoAdjustMaxCache(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetAutoAdjustMinCache(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetCacheTime(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetJitterCycle(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetLoadingThreshold(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetMinPlayoutDelay(long j, int i);

    /* access modifiers changed from: protected */
    public native void nativeSetMute(long j, boolean z);

    /* access modifiers changed from: protected */
    public native void nativeSetRTCPlayHungryTimeThreshold(long j, int i);

    /* access modifiers changed from: protected */
    public native void nativeSetRealtimeJitterCycle(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetSmoothAdjust(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetSmoothMode(long j, long j2);

    /* access modifiers changed from: protected */
    public native void nativeSetSmoothSpeed(long j, float f);

    /* access modifiers changed from: protected */
    public native void nativeSetUserID(long j, String str);

    static {
        nativeSetTempPath(Environment.getExternalStorageDirectory().getAbsolutePath());
    }

    public TXCAudioBasePlayController(Context context) {
        this.mContext = context;
    }

    public static void setAudioMode(Context context, int i) {
        b.a(context, i);
        c.a(context, i);
    }

    public static void setAudioCorePlayListener(c cVar) {
        mAudioCoreListener = new WeakReference<>(cVar);
    }

    public static void onCorePlayPcmData(byte[] bArr, long j, int i, int i2) {
        c cVar;
        WeakReference<c> weakReference = mAudioCoreListener;
        if (weakReference != null && (cVar = weakReference.get()) != null) {
            cVar.onPlayPcmData(bArr, j, i, i2);
        }
    }

    public synchronized void setListener(c cVar) {
        this.mListener = cVar;
    }

    public void setCacheTime(float f) {
        String str = TAG;
        TXCLog.i(str, "set cache time to " + f);
        nativeSetCacheTime(this.mJitterBuffer, f);
        this.mCacheTime = f;
    }

    public void enableAutojustCache(boolean z) {
        String str = TAG;
        TXCLog.i(str, "set auto adjust cache to " + z);
        nativeEnableAutoAdjustCache(this.mJitterBuffer, z);
        this.mIsAutoAdjustCache = z;
    }

    public void setAutoAdjustMaxCache(float f) {
        String str = TAG;
        TXCLog.i(str, "set auto adjust max cache to " + f);
        nativeSetAutoAdjustMaxCache(this.mJitterBuffer, f);
        this.mAutoAdjustMaxCache = f;
    }

    public void setAutoAdjustMinCache(float f) {
        String str = TAG;
        TXCLog.i(str, "set auto adjust min cache to " + f);
        nativeSetAutoAdjustMinCache(this.mJitterBuffer, f);
        this.mAutoAdjustMinCache = f;
    }

    public void enableHWAcceleration(boolean z) {
        String str = TAG;
        TXCLog.i(str, "set hw acceleration to " + z);
        this.mIsHWAcceleration = z;
    }

    public void setSmootheMode(int i) {
        String str = TAG;
        TXCLog.i(str, "set careful mode to " + i);
        this.mSmoothMode = i;
    }

    public void enableRealTimePlay(boolean z) {
        if (z != this.mIsRealTimePlay) {
            String str = TAG;
            TXCLog.i(str, "set real-time play to " + z);
            nativeEnableRealTimePlay(this.mJitterBuffer, z);
            this.mIsRealTimePlay = z;
        }
    }

    public void setMinPlayoutDelay(int i) {
        nativeSetMinPlayoutDelay(this.mJitterBuffer, i);
    }

    public void setUserID(String str) {
        this.mUserID = str;
        if (str != null) {
            nativeSetUserID(this.mJitterBuffer, str);
        }
    }

    public TXAudioJitterBufferReportInfo getReportInfo() {
        if (!this.mIsPlaying) {
            return null;
        }
        long j = this.mJitterBuffer;
        if (j != 0) {
            return nativeGetLoadingInfo(j);
        }
        return null;
    }

    public long getCurPts() {
        return nativeGetCurPts(this.mJitterBuffer);
    }

    public int getRecvJitter() {
        return nativeGetRecvJitter(this.mJitterBuffer);
    }

    public long getCurRecvTS() {
        return nativeGetNetRecvTS(this.mJitterBuffer);
    }

    public float getCacheThreshold() {
        return nativeGetCacheThreshold(this.mJitterBuffer);
    }

    public boolean isPlaying() {
        return this.mIsPlaying;
    }

    public int getExpiredFrames() {
        return nativeGetExpiredFrames(this.mJitterBuffer);
    }

    public TXSAVModuleSyncInfo getAudioSyncInfo() {
        return nativeGetAudioSyncInfo(this.mJitterBuffer);
    }

    public int startPlay() {
        this.mIsPlaying = true;
        return 0;
    }

    public int setStreamFormat(int i) {
        if (i == this.mStreamFormat) {
            return TXEAudioDef.TXE_AUDIO_PLAY_ERR_REPEAT_OPTION;
        }
        this.mStreamFormat = i;
        if (this.mJitterBuffer == 0) {
            long nativeCreateJitterBuffer = nativeCreateJitterBuffer(false, this, i);
            this.mJitterBuffer = nativeCreateJitterBuffer;
            if (nativeCreateJitterBuffer != 0) {
                nativeSetSmoothMode(nativeCreateJitterBuffer, (long) this.mSmoothMode);
                nativeSetSmoothAdjust(this.mJitterBuffer, b.a().a(IFeature.F_AUDIO, "SmoothAdjust"));
                nativeSetCacheTime(this.mJitterBuffer, this.mCacheTime);
                nativeSetMute(this.mJitterBuffer, this.mIsMute);
                nativeEnableRealTimePlay(this.mJitterBuffer, this.mIsRealTimePlay);
                nativeEnableAutoAdjustCache(this.mJitterBuffer, this.mIsAutoAdjustCache);
                nativeSetAutoAdjustMaxCache(this.mJitterBuffer, this.mAutoAdjustMaxCache);
                nativeSetAutoAdjustMinCache(this.mJitterBuffer, this.mAutoAdjustMinCache);
                setUserID(this.mUserID);
                nativeSetSmoothSpeed(this.mJitterBuffer, b.a().b(IFeature.F_AUDIO, "SmoothSpeed"));
                nativeSetJitterCycle(this.mJitterBuffer, b.a().a(IFeature.F_AUDIO, "LIVE_JitterCycle"));
                nativeSetRealtimeJitterCycle(this.mJitterBuffer, b.a().a(IFeature.F_AUDIO, "RTC_JitterCycle"));
                nativeSetLoadingThreshold(this.mJitterBuffer, b.a().a(IFeature.F_AUDIO, "LoadingThreshold"));
                nativeSetRTCPlayHungryTimeThreshold(this.mJitterBuffer, (int) b.a().a(IFeature.F_AUDIO, "RtcPlayHungryTimeThreshold"));
            } else {
                TXCLog.e(TAG, "soft dec, create jitterbuffer failed!!");
            }
            String str = TAG;
            TXCLog.e(str, "soft dec, create jitterbuffer with id " + this.mJitterBuffer);
        }
        return 0;
    }

    public int stopPlay() {
        this.mIsPlaying = false;
        this.mCacheTime = a.a;
        this.mIsAutoAdjustCache = a.b;
        this.mAutoAdjustMaxCache = a.c;
        this.mAutoAdjustMinCache = a.d;
        this.mIsRealTimePlay = false;
        this.mIsHWAcceleration = false;
        this.mIsMute = a.e;
        this.mSmoothMode = 0;
        return 0;
    }

    public void setMute(boolean z) {
        if (z != this.mIsMute) {
            nativeSetMute(this.mJitterBuffer, z);
        }
        String str = TAG;
        TXCLog.i(str, "set mute to " + z);
        this.mIsMute = z;
    }

    @Override // com.tencent.liteav.audio.c
    public void onPlayPcmData(byte[] bArr, long j, int i, int i2) {
        c cVar = this.mListener;
        if (cVar != null) {
            cVar.onPlayPcmData(bArr, j, i, i2);
        }
    }

    @Override // com.tencent.liteav.audio.c
    public synchronized void onPlayError(int i, String str) {
        if (this.mListener != null) {
            this.mListener.onPlayError(i, str);
        }
    }

    @Override // com.tencent.liteav.audio.c
    public synchronized void onPlayJitterStateNotify(int i) {
        String str = TAG;
        TXCLog.e(str, "onPlayJitterStateNotify  cur state " + i);
        if (this.mListener != null) {
            this.mListener.onPlayJitterStateNotify(i);
        }
    }
}
