package com.tencent.liteav.audio.impl;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import com.tencent.liteav.audio.TXCLiveBGMPlayer;
import com.tencent.liteav.audio.d;
import com.tencent.liteav.audio.impl.Play.TXCAudioBasePlayController;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.TXCTimeUtil;
import com.tencent.liteav.basic.util.b;
import java.io.File;
import java.lang.ref.WeakReference;

public class TXCTraeJNI {
    private static Context mContext;
    private static WeakReference<d> mTraeRecordListener;

    public static native void nativeAppendLibraryPath(String str);

    public static native void nativeCacheClassForNative();

    public static native void nativeSetAudioMode(int i);

    public static native void nativeSetEncBitRate(int i);

    public static native void nativeSetEncFrameLenMs(int i);

    public static native void nativeSetEncInfo(int i, int i2);

    public static native void nativeSetFecRatio(float f);

    public static native void nativeSetTraeConfig(String str);

    public static native boolean nativeTraeIsPlaying();

    public static native boolean nativeTraeIsRecording();

    public static native void nativeTraeSetChangerType(int i, int i2);

    public static native void nativeTraeSetRecordMute(boolean z);

    public static native void nativeTraeSetRecordReverb(int i);

    public static native void nativeTraeSetVolume(float f);

    private static native void nativeTraeStartPlay(Context context);

    public static native void nativeTraeStartRecord(Context context, int i, int i2, int i3, int i4, int i5);

    private static native void nativeTraeStopPlay();

    public static native void nativeTraeStopRecord(boolean z);

    static {
        b.f();
        nativeCacheClassForNative();
    }

    public static void setContext(Context context) {
        mContext = context;
    }

    public static void setTraeRecordListener(WeakReference<d> weakReference) {
        mTraeRecordListener = weakReference;
    }

    public static void onRecordRawPcmData(byte[] bArr, int i, int i2, int i3) {
        WeakReference<d> weakReference = mTraeRecordListener;
        if (weakReference != null && weakReference.get() != null) {
            mTraeRecordListener.get().a(bArr, TXCTimeUtil.getTimeTick(), i, i2, i3, false);
        }
    }

    public static void onRecordPcmData(byte[] bArr, int i, int i2, int i3) {
        WeakReference<d> weakReference = mTraeRecordListener;
        if (weakReference != null && weakReference.get() != null) {
            mTraeRecordListener.get().a(bArr, TXCTimeUtil.getTimeTick(), i, i2, i3);
        }
    }

    public static void onRecordEncData(byte[] bArr, long j, int i, int i2, int i3) {
        WeakReference<d> weakReference = mTraeRecordListener;
        if (weakReference != null && weakReference.get() != null) {
            mTraeRecordListener.get().b(bArr, j, i, i2, i3);
        }
    }

    public static void onRecordError(int i, String str) {
        WeakReference<d> weakReference = mTraeRecordListener;
        if (weakReference != null && weakReference.get() != null) {
            mTraeRecordListener.get().a(i, str);
        }
    }

    public static void SetAudioMode(int i) {
        a.a().b(i);
    }

    public static void InitTraeEngineLibrary(Context context) {
        if (context == null) {
            TXCLog.e("TXCAudioJNI", "nativeInitTraeEngine failed, context is null!");
            return;
        }
        try {
            ApplicationInfo applicationInfo = context.getApplicationInfo();
            String str = applicationInfo.nativeLibraryDir;
            String str2 = applicationInfo.dataDir + "/lib";
            nativeAppendLibraryPath("add_libpath:" + str);
            nativeAppendLibraryPath("add_libpath:" + str2);
            nativeAppendLibraryPath("add_libpath:" + ("/data/data/" + applicationInfo.packageName + "/lib"));
        } catch (UnsatisfiedLinkError e) {
            e.printStackTrace();
        }
    }

    public static boolean nativeCheckTraeEngine(Context context) {
        boolean z;
        boolean z2;
        if (context == null) {
            TXCLog.e("TXCAudioJNI", "nativeCheckTraeEngine failed, context is null!");
            return false;
        }
        ApplicationInfo applicationInfo = context.getApplicationInfo();
        String str = applicationInfo.nativeLibraryDir;
        String str2 = applicationInfo.dataDir + "/lib";
        String str3 = "/data/data/" + applicationInfo.packageName + "/lib";
        String g = b.g();
        if (g == null) {
            g = "";
        }
        if (new File(str + "/libTRAECodec.so").exists()) {
            z = true;
        } else {
            if (new File(str2 + "/libTRAECodec.so").exists()) {
                z = true;
            } else {
                if (new File(str3 + "/libTRAECodec.so").exists()) {
                    z = true;
                } else {
                    if (new File(g + "/libTRAECodec.so").exists()) {
                        z = true;
                    } else {
                        z = false;
                    }
                }
            }
        }
        if (new File(str + "/libtraeimp-rtmp.so").exists()) {
            z2 = true;
        } else {
            if (new File(str2 + "/libtraeimp-rtmp.so").exists()) {
                z2 = true;
            } else {
                if (new File(str3 + "/libtraeimp-rtmp.so").exists()) {
                    z2 = true;
                } else {
                    if (new File(g + "/libtraeimp-rtmp.so").exists()) {
                        z2 = true;
                    } else {
                        z2 = false;
                    }
                }
            }
        }
        if (z && z2) {
            return true;
        }
        TXCLog.e("TXCAudioJNI", "nativeCheckTraeEngine failed, can not find trae libs !");
        return false;
    }

    public static boolean traeStartPlay(Context context) {
        if (TXCAudioBasePlayController.nativeIsTracksEmpty() && !TXCLiveBGMPlayer.getInstance().isPlaying()) {
            return false;
        }
        InitTraeEngineLibrary(context);
        nativeTraeStartPlay(context);
        return true;
    }

    public static boolean traeStopPlay() {
        if (!TXCAudioBasePlayController.nativeIsTracksEmpty() || TXCLiveBGMPlayer.getInstance().isPlaying()) {
            return false;
        }
        nativeTraeStopPlay();
        return true;
    }
}
