package com.tencent.liteav.videoencoder;

import android.opengl.GLES20;
import com.amap.api.maps.utils.SpatialRelationUtil;
import com.taobao.weex.common.Constants;
import com.tencent.liteav.basic.d.g;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.util.b;
import com.tencent.liteav.beauty.b.o;
import java.lang.ref.WeakReference;

public class TXCSWVideoEncoder extends c {
    private static final boolean DEBUG = false;
    private static final String TAG = TXCSWVideoEncoder.class.getSimpleName();
    private int mBitrate = 0;
    private long mNativeEncoder = 0;
    private long mPTS = 0;
    private int mPopIdx = 0;
    private int mPushIdx = 0;
    private g mRawFrameFilter;
    private int mRendIdx = 0;
    private g mResizeFilter;

    private static native void nativeClassInit();

    private native void nativeEnableNearestRPS(long j, int i);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native int nativeEncode(long j, int i, int i2, int i3, long j2);

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private native int nativeEncodeSync(long j, int i, int i2, int i3, long j2);

    private static native long nativeGetAndIncreaseGopIndex();

    private static native long nativeGetAndIncreaseSeq();

    private native long nativeGetRealFPS(long j);

    private native long nativeInit(WeakReference<TXCSWVideoEncoder> weakReference);

    private native void nativeRelease(long j);

    private native void nativeRestartIDR(long j);

    private native void nativeSetBitrate(long j, int i);

    private native void nativeSetBitrateFromQos(long j, int i, int i2);

    private native void nativeSetEncodeIdrFpsFromQos(long j, int i);

    private native void nativeSetFPS(long j, int i);

    private native void nativeSetID(long j, String str);

    private native void nativeSetRPSRefBitmap(long j, int i, int i2, long j2);

    private native void nativeSignalEOSAndFlush(long j);

    private native int nativeStart(long j, TXSVideoEncoderParam tXSVideoEncoderParam);

    private native void nativeStop(long j);

    private native long nativegetRealBitrate(long j);

    @Override // com.tencent.liteav.videoencoder.c
    public int start(TXSVideoEncoderParam tXSVideoEncoderParam) {
        super.start(tXSVideoEncoderParam);
        int i = ((tXSVideoEncoderParam.width + 7) / 8) * 8;
        int i2 = ((tXSVideoEncoderParam.height + 1) / 2) * 2;
        if (!(i == tXSVideoEncoderParam.width && i2 == tXSVideoEncoderParam.height)) {
            TXCLog.w(TAG, "Encode Resolution not supportted, transforming...");
            String str = TAG;
            TXCLog.w(str, tXSVideoEncoderParam.width + Constants.Name.X + tXSVideoEncoderParam.height + "-> " + i + Constants.Name.X + i2);
        }
        tXSVideoEncoderParam.width = i;
        tXSVideoEncoderParam.height = i2;
        this.mOutputWidth = i;
        this.mOutputHeight = i2;
        this.mInputWidth = i;
        this.mInputHeight = i2;
        long nativeInit = nativeInit(new WeakReference<>(this));
        this.mNativeEncoder = nativeInit;
        nativeSetBitrate(nativeInit, this.mBitrate);
        nativeSetID(this.mNativeEncoder, getID());
        nativeStart(this.mNativeEncoder, tXSVideoEncoderParam);
        return 0;
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void stop() {
        String str = TAG;
        TXCLog.i(str, "stop->enter with mRawFrameFilter:" + this.mRawFrameFilter);
        this.mGLContextExternal = null;
        nativeStop(this.mNativeEncoder);
        nativeRelease(this.mNativeEncoder);
        this.mNativeEncoder = 0;
        g gVar = this.mRawFrameFilter;
        if (gVar != null) {
            gVar.d();
            this.mRawFrameFilter = null;
        }
        g gVar2 = this.mResizeFilter;
        if (gVar2 != null) {
            gVar2.d();
            this.mResizeFilter = null;
        }
        super.stop();
    }

    @Override // com.tencent.liteav.basic.module.a
    public void setID(String str) {
        super.setID(str);
        nativeSetID(this.mNativeEncoder, str);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void setFPS(int i) {
        nativeSetFPS(this.mNativeEncoder, i);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void enableNearestRPS(int i) {
        nativeEnableNearestRPS(this.mNativeEncoder, i);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void setBitrate(int i) {
        this.mBitrate = i;
        nativeSetBitrate(this.mNativeEncoder, i);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void setBitrateFromQos(int i, int i2) {
        this.mBitrate = i;
        nativeSetBitrateFromQos(this.mNativeEncoder, i, i2);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void setEncodeIdrFpsFromQos(int i) {
        nativeSetEncodeIdrFpsFromQos(this.mNativeEncoder, i);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public double getRealFPS() {
        return (double) nativeGetRealFPS(this.mNativeEncoder);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public long getRealBitrate() {
        return nativegetRealBitrate(this.mNativeEncoder);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public long pushVideoFrame(int i, int i2, int i3, long j) {
        return pushVideoFrameInternal(i, i2, i3, j, false);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public long pushVideoFrameSync(int i, int i2, int i3, long j) {
        return pushVideoFrameInternal(i, i2, i3, j, true);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void signalEOSAndFlush() {
        nativeSignalEOSAndFlush(this.mNativeEncoder);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void setRPSRefBitmap(int i, int i2, long j) {
        nativeSetRPSRefBitmap(this.mNativeEncoder, i, i2, j);
    }

    @Override // com.tencent.liteav.videoencoder.c
    public void restartIDR() {
        nativeRestartIDR(this.mNativeEncoder);
    }

    public static long getAndIncreateSeq() {
        return nativeGetAndIncreaseSeq();
    }

    public static long getAndIncreaseGopIndex() {
        return nativeGetAndIncreaseGopIndex();
    }

    private static void postEventFromNative(WeakReference<TXCSWVideoEncoder> weakReference, byte[] bArr, int i, long j, long j2, long j3, long j4, long j5, long j6, int i2) {
        TXCSWVideoEncoder tXCSWVideoEncoder = weakReference.get();
        if (tXCSWVideoEncoder != null) {
            tXCSWVideoEncoder.callDelegate(bArr, i, j, j2, j3, j4, j5, j6, i2, null, null);
        }
    }

    private static void onEncodeFinishedFromNative(WeakReference<TXCSWVideoEncoder> weakReference, long j, long j2, long j3) {
        TXCSWVideoEncoder tXCSWVideoEncoder = weakReference.get();
        if (tXCSWVideoEncoder != null) {
            tXCSWVideoEncoder.onEncodeFinished(j, j2, j3);
        }
    }

    private long pushVideoFrameInternal(int i, int i2, int i3, long j, final boolean z) {
        int i4;
        if (this.mGLContextExternal == null) {
            return 0;
        }
        this.mInputWidth = i2;
        this.mInputHeight = i3;
        if (this.mResizeFilter == null) {
            g gVar = new g();
            this.mResizeFilter = gVar;
            gVar.a();
            this.mResizeFilter.a(true);
        }
        this.mResizeFilter.a(this.mOutputWidth, this.mOutputHeight);
        GLES20.glViewport(0, 0, this.mOutputWidth, this.mOutputHeight);
        if (this.mResizeFilter != null) {
            float[] a = this.mResizeFilter.a(i2, i3, null, b.a(i2, i3, this.mOutputWidth, this.mOutputHeight), 0);
            int i5 = (720 - this.mRotation) % SpatialRelationUtil.A_CIRCLE_DEGREE;
            this.mResizeFilter.a(i2, i3, i5, a, ((float) ((i5 == 90 || i5 == 270) ? this.mOutputHeight : this.mOutputWidth)) / ((float) ((i5 == 90 || i5 == 270) ? this.mOutputWidth : this.mOutputHeight)), false, false);
            i4 = i;
            this.mResizeFilter.b(i);
        } else {
            i4 = i;
        }
        g gVar2 = this.mResizeFilter;
        final int l = gVar2 != null ? gVar2.l() : i4;
        int[] iArr = new int[1];
        this.mPTS = j;
        if (this.mRawFrameFilter == null) {
            TXCLog.i(TAG, "pushVideoFrameInternal->create mRawFrameFilter");
            o oVar = new o(1);
            this.mRawFrameFilter = oVar;
            oVar.a(true);
            if (!this.mRawFrameFilter.a()) {
                TXCLog.i(TAG, "pushVideoFrameInternal->destroy mRawFrameFilter, init failed!");
                this.mRawFrameFilter = null;
                return 10000004;
            }
            this.mRawFrameFilter.a(this.mOutputWidth, this.mOutputHeight);
            this.mRawFrameFilter.a(new g.a() {
                /* class com.tencent.liteav.videoencoder.TXCSWVideoEncoder.AnonymousClass1 */

                @Override // com.tencent.liteav.basic.d.g.a
                public void a(int i) {
                    if (z) {
                        TXCSWVideoEncoder tXCSWVideoEncoder = TXCSWVideoEncoder.this;
                        tXCSWVideoEncoder.nativeEncodeSync(tXCSWVideoEncoder.mNativeEncoder, l, TXCSWVideoEncoder.this.mOutputWidth, TXCSWVideoEncoder.this.mOutputHeight, TXCSWVideoEncoder.this.mPTS);
                        return;
                    }
                    TXCSWVideoEncoder tXCSWVideoEncoder2 = TXCSWVideoEncoder.this;
                    tXCSWVideoEncoder2.nativeEncode(tXCSWVideoEncoder2.mNativeEncoder, l, TXCSWVideoEncoder.this.mOutputWidth, TXCSWVideoEncoder.this.mOutputHeight, TXCSWVideoEncoder.this.mPTS);
                }
            });
        }
        if (this.mRawFrameFilter == null) {
            return 10000004;
        }
        GLES20.glViewport(0, 0, this.mOutputWidth, this.mOutputHeight);
        this.mRawFrameFilter.b(l);
        int i6 = iArr[0];
        if (i6 == 0) {
            return 0;
        }
        callDelegate(i6);
        return 0;
    }

    static {
        b.f();
        nativeClassInit();
    }
}
