package com.tencent.rtmp;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.Surface;
import android.view.TextureView;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import com.tencent.liteav.basic.c.a;
import com.tencent.liteav.basic.datareport.TXCDRApi;
import com.tencent.liteav.basic.log.TXCLog;
import com.tencent.liteav.basic.structs.TXSVideoFrame;
import com.tencent.liteav.basic.util.TXCCommonUtil;
import com.tencent.liteav.g;
import com.tencent.liteav.i;
import com.tencent.liteav.p;
import com.tencent.liteav.q;
import com.tencent.liteav.r;
import com.tencent.rtmp.ui.TXCloudVideoView;
import com.tencent.ugc.TXRecordCommon;

public class TXLivePlayer implements a {
    public static final int PLAY_TYPE_LIVE_FLV = 1;
    public static final int PLAY_TYPE_LIVE_RTMP = 0;
    public static final int PLAY_TYPE_LIVE_RTMP_ACC = 5;
    public static final int PLAY_TYPE_LOCAL_VIDEO = 6;
    public static final int PLAY_TYPE_VOD_FLV = 2;
    public static final int PLAY_TYPE_VOD_HLS = 3;
    public static final int PLAY_TYPE_VOD_MP4 = 4;
    public static final String TAG = "TXLivePlayer";
    private ITXAudioRawDataListener mAudioRawDataListener;
    private int mAudioRoute = 0;
    private boolean mAutoPlay = true;
    private TXLivePlayConfig mConfig;
    private Context mContext;
    private int mCurrentPlayType = -1;
    private boolean mEnableHWDec = false;
    private boolean mIsNeedClearLastImg = true;
    private boolean mIsShiftPlaying;
    private ITXLivePlayListener mListener;
    private String mLivePlayUrl;
    private boolean mMute = false;
    private String mPlayUrl = "";
    private p mPlayer;
    private long mProgressStartTime;
    private float mRate = 1.0f;
    private int mRenderMode;
    private int mRenderRotation;
    private boolean mSnapshotRunning = false;
    private Surface mSurface;
    private int mSurfaceHeight;
    private int mSurfaceWidth;
    private TXCloudVideoView mTXCloudVideoView;
    private i mTimeShiftUtil;
    private byte[] mVideoRawBuf = null;
    private ITXVideoRawDataListener mVideoRawDataListener = null;

    public interface ITXAudioRawDataListener {
        void onAudioInfoChanged(int i, int i2, int i3);

        void onPcmDataAvailable(byte[] bArr, long j);
    }

    public interface ITXSnapshotListener {
        void onSnapshot(Bitmap bitmap);
    }

    public interface ITXVideoRawDataListener {
        void onVideoRawDataAvailable(byte[] bArr, int i, int i2, int i3);
    }

    public TXLivePlayer(Context context) {
        TXCLog.init();
        this.mListener = null;
        this.mContext = context.getApplicationContext();
    }

    public void setConfig(TXLivePlayConfig tXLivePlayConfig) {
        TXCLog.d(TAG, "liteav_api setConfig " + this);
        this.mConfig = tXLivePlayConfig;
        if (tXLivePlayConfig == null) {
            this.mConfig = new TXLivePlayConfig();
        }
        p pVar = this.mPlayer;
        if (pVar != null) {
            g p = pVar.p();
            if (p == null) {
                p = new g();
            }
            p.a = this.mConfig.mCacheTime;
            p.g = this.mConfig.mAutoAdjustCacheTime;
            p.c = this.mConfig.mMinAutoAdjustCacheTime;
            p.b = this.mConfig.mMaxAutoAdjustCacheTime;
            p.d = this.mConfig.mVideoBlockThreshold;
            p.e = this.mConfig.mConnectRetryCount;
            p.f = this.mConfig.mConnectRetryInterval;
            p.h = this.mConfig.mEnableAec;
            p.j = this.mConfig.mEnableNearestIP;
            p.l = this.mConfig.mRtmpChannelType;
            p.i = this.mEnableHWDec;
            p.m = this.mConfig.mCacheFolderPath;
            p.n = this.mConfig.mMaxCacheItems;
            p.k = this.mConfig.mEnableMessage;
            p.p = this.mConfig.mHeaders;
            this.mPlayer.a(p);
        }
    }

    public void setPlayerView(TXCloudVideoView tXCloudVideoView) {
        TXCLog.d(TAG, "liteav_api setPlayerView old view : " + this.mTXCloudVideoView + ", new view : " + tXCloudVideoView + ", " + this);
        this.mTXCloudVideoView = tXCloudVideoView;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(tXCloudVideoView);
        }
    }

    public void setSurface(Surface surface) {
        TXCLog.d(TAG, "liteav_api setSurface old : " + this.mSurface + ", new : " + surface + ", " + this);
        this.mSurface = surface;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(surface);
        }
    }

    public void setSurfaceSize(int i, int i2) {
        TXCLog.d(TAG, "liteav_api setSurfaceSize " + i + Constants.Name.X + i2 + ", " + this);
        this.mSurfaceWidth = i;
        this.mSurfaceHeight = i2;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(i, i2);
        }
    }

    public int startPlay(String str, int i) {
        TXCLog.d(TAG, "liteav_api startPlay " + this);
        if (TextUtils.isEmpty(str)) {
            TXCLog.e(TAG, "start play error when url is empty " + this);
            return -1;
        }
        if (!TextUtils.isEmpty(this.mPlayUrl) && isPlaying()) {
            if (this.mPlayUrl.equalsIgnoreCase(str)) {
                TXCLog.e(TAG, "start play error when new url is the same with old url  " + this);
                return -1;
            }
            TXCLog.w(TAG, " stop old play when new url is not the same with old url  " + this);
            p pVar = this.mPlayer;
            if (pVar != null) {
                pVar.a(false);
            }
            this.mPlayUrl = "";
        }
        TXCDRApi.initCrashReport(this.mContext);
        TXCLog.d(TAG, "===========================================================================================================================================================");
        TXCLog.d(TAG, "===========================================================================================================================================================");
        TXCLog.d(TAG, "=====  StartPlay url = " + str + " playType = " + i + " SDKVersion = " + TXCCommonUtil.getSDKID() + " , " + TXCCommonUtil.getSDKVersionStr() + "    ======");
        TXCLog.d(TAG, "===========================================================================================================================================================");
        TXCLog.d(TAG, "===========================================================================================================================================================");
        int i2 = this.mCurrentPlayType;
        if (i2 == -1 || i2 != i) {
            this.mPlayer = r.a(this.mContext, i);
        }
        this.mCurrentPlayType = i;
        if (this.mPlayer == null) {
            return -2;
        }
        this.mPlayUrl = checkPlayUrl(str, i);
        setConfig(this.mConfig);
        TXCloudVideoView tXCloudVideoView = this.mTXCloudVideoView;
        if (tXCloudVideoView != null) {
            tXCloudVideoView.clearLog();
            this.mTXCloudVideoView.setVisibility(0);
        }
        this.mPlayer.a(this.mTXCloudVideoView);
        this.mPlayer.a(this);
        this.mPlayer.c(this.mAutoPlay);
        Surface surface = this.mSurface;
        if (surface != null) {
            this.mPlayer.a(surface);
            this.mPlayer.a(this.mSurfaceWidth, this.mSurfaceHeight);
        }
        this.mPlayer.a(this.mPlayUrl, i);
        this.mPlayer.b(this.mMute);
        this.mPlayer.b(this.mRate);
        this.mPlayer.b(this.mRenderRotation);
        this.mPlayer.a(this.mRenderMode);
        setAudioRoute(this.mAudioRoute);
        this.mPlayer.a(this.mAudioRawDataListener);
        setVideoRawDataListener(this.mVideoRawDataListener);
        if (this.mPlayer.f()) {
            this.mLivePlayUrl = this.mPlayUrl;
            i iVar = this.mTimeShiftUtil;
            long a = iVar != null ? iVar.a() : 0;
            this.mProgressStartTime = a;
            if (a > 0) {
                this.mPlayer.g();
            }
        }
        return 0;
    }

    public int switchStream(String str) {
        p pVar = this.mPlayer;
        if (pVar != null) {
            return pVar.a(str);
        }
        return -1;
    }

    public int stopPlay(boolean z) {
        TXCloudVideoView tXCloudVideoView;
        TXCLog.d(TAG, "liteav_api stopPlay " + z + ", " + this);
        if (z && (tXCloudVideoView = this.mTXCloudVideoView) != null) {
            tXCloudVideoView.setVisibility(8);
        }
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a((q) null);
            this.mPlayer.a(z);
        }
        this.mPlayUrl = "";
        this.mProgressStartTime = 0;
        this.mTimeShiftUtil = null;
        this.mIsShiftPlaying = false;
        return 0;
    }

    public boolean isPlaying() {
        p pVar = this.mPlayer;
        if (pVar != null) {
            return pVar.c();
        }
        return false;
    }

    public void pause() {
        TXCLog.d(TAG, "liteav_api pause " + this);
        if (this.mPlayer != null) {
            TXCLog.w(TAG, "pause play");
            this.mPlayer.a();
        }
    }

    public void resume() {
        TXCLog.d(TAG, "liteav_api resume " + this);
        if (this.mPlayer != null) {
            TXCLog.w(TAG, "resume play");
            this.mPlayer.b();
            setAudioRoute(this.mAudioRoute);
        }
    }

    public void seek(int i) {
        TXCLog.d(TAG, "liteav_api ");
        p pVar = this.mPlayer;
        if (pVar == null) {
            return;
        }
        if (pVar.f() || this.mIsShiftPlaying) {
            i iVar = this.mTimeShiftUtil;
            String a = iVar != null ? iVar.a((long) i) : "";
            if (!TextUtils.isEmpty(a)) {
                boolean z = startPlay(a, 3) == 0;
                this.mIsShiftPlaying = z;
                if (z) {
                    this.mProgressStartTime = (long) (i * 1000);
                    return;
                }
                return;
            }
            ITXLivePlayListener iTXLivePlayListener = this.mListener;
            if (iTXLivePlayListener != null) {
                iTXLivePlayListener.onPlayEvent(-2301, new Bundle());
                return;
            }
            return;
        }
        this.mPlayer.d(i);
    }

    public int prepareLiveSeek(String str, int i) {
        TXCLog.d(TAG, "liteav_api prepareLiveSeek " + this);
        if (this.mTimeShiftUtil == null) {
            this.mTimeShiftUtil = new i(this.mContext);
        }
        i iVar = this.mTimeShiftUtil;
        if (iVar != null) {
            return iVar.a(this.mPlayUrl, str, i, new i.a() {
                /* class com.tencent.rtmp.TXLivePlayer.AnonymousClass1 */

                @Override // com.tencent.liteav.i.a
                public void onLiveTime(long j) {
                    TXLivePlayer.this.mProgressStartTime = j;
                    if (TXLivePlayer.this.mPlayer != null) {
                        TXLivePlayer.this.mPlayer.g();
                    }
                }
            });
        }
        return -1;
    }

    public int resumeLive() {
        TXCLog.d(TAG, "liteav_api resumeLive " + this);
        if (!this.mIsShiftPlaying) {
            return -1;
        }
        this.mIsShiftPlaying = false;
        return startPlay(this.mLivePlayUrl, 1);
    }

    public void setPlayListener(ITXLivePlayListener iTXLivePlayListener) {
        TXCLog.d(TAG, "liteav_api setPlayListener " + this);
        this.mListener = iTXLivePlayListener;
    }

    public void setVideoRecordListener(TXRecordCommon.ITXVideoRecordListener iTXVideoRecordListener) {
        TXCLog.d(TAG, "liteav_api setVideoRecordListener");
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(iTXVideoRecordListener);
        }
    }

    public int startRecord(int i) {
        TXCLog.d(TAG, "liteav_api startRecord " + this);
        if (Build.VERSION.SDK_INT < 18) {
            TXCLog.e(TAG, "API levl is too low (record need 18, current is" + Build.VERSION.SDK_INT + Operators.BRACKET_END_STR);
            return -3;
        } else if (!isPlaying()) {
            TXCLog.e(TAG, "startRecord: there is no playing stream");
            return -1;
        } else {
            p pVar = this.mPlayer;
            if (pVar != null) {
                return pVar.c(i);
            }
            return -1;
        }
    }

    public int stopRecord() {
        TXCLog.d(TAG, "liteav_api stopRecord " + this);
        p pVar = this.mPlayer;
        if (pVar != null) {
            return pVar.e();
        }
        return -1;
    }

    public void setRenderMode(int i) {
        TXCLog.d(TAG, "liteav_api setRenderMode " + i);
        this.mRenderMode = i;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(i);
        }
    }

    public void setRenderRotation(int i) {
        TXCLog.d(TAG, "liteav_api setRenderRotation " + i);
        this.mRenderRotation = i;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.b(i);
        }
    }

    public boolean enableHardwareDecode(boolean z) {
        TXCLog.d(TAG, "liteav_api enableHardwareDecode " + z);
        if (z) {
            if (Build.VERSION.SDK_INT < 18) {
                TXCLog.e("HardwareDecode", "enableHardwareDecode failed, android system build.version = " + Build.VERSION.SDK_INT + ", the minimum build.version should be 18(android 4.3 or later)");
                return false;
            } else if (isAVCDecBlacklistDevices()) {
                TXCLog.e("HardwareDecode", "enableHardwareDecode failed, MANUFACTURER = " + Build.MANUFACTURER + ", MODEL" + Build.MODEL);
                return false;
            }
        }
        this.mEnableHWDec = z;
        p pVar = this.mPlayer;
        if (pVar == null) {
            return true;
        }
        g p = pVar.p();
        if (p == null) {
            p = new g();
        }
        p.i = this.mEnableHWDec;
        this.mPlayer.a(p);
        return true;
    }

    public void setMute(boolean z) {
        TXCLog.d(TAG, "liteav_api setMute " + z);
        this.mMute = z;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.b(z);
        }
    }

    public void setAutoPlay(boolean z) {
        TXCLog.d(TAG, "liteav_api setAutoPlay " + z);
        this.mAutoPlay = z;
    }

    public void setRate(float f) {
        TXCLog.d(TAG, "liteav_api setRate " + f);
        this.mRate = f;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.b(f);
        }
    }

    public void setAudioRoute(int i) {
        TXCLog.d(TAG, "liteav_api setAudioRoute " + i);
        this.mAudioRoute = i;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(this.mContext, i);
        }
    }

    @Override // com.tencent.liteav.basic.c.a
    public void onNotifyEvent(int i, Bundle bundle) {
        int i2 = i;
        if (i2 == 15001) {
            TXCloudVideoView tXCloudVideoView = this.mTXCloudVideoView;
            if (tXCloudVideoView != null) {
                tXCloudVideoView.setLogText(bundle, null, 0);
            }
            ITXLivePlayListener iTXLivePlayListener = this.mListener;
            if (iTXLivePlayListener != null) {
                iTXLivePlayListener.onNetStatus(bundle);
            }
        } else if (i2 == 2005) {
            long j = ((long) bundle.getInt(TXLiveConstants.EVT_PLAY_PROGRESS_MS)) + this.mProgressStartTime;
            if (j > 0) {
                bundle.putInt(TXLiveConstants.EVT_PLAY_PROGRESS, (int) (j / 1000));
                bundle.putInt(TXLiveConstants.EVT_PLAY_PROGRESS_MS, (int) j);
                ITXLivePlayListener iTXLivePlayListener2 = this.mListener;
                if (iTXLivePlayListener2 != null) {
                    iTXLivePlayListener2.onPlayEvent(i2, bundle);
                }
            }
        } else if (i2 != 2026) {
            if (i2 == -2309) {
                i2 = -2301;
            } else if (i2 == -2307) {
                i2 = -2307;
            } else if (i2 == -2304) {
                i2 = -2304;
            } else if (i2 == 2012) {
                i2 = 2012;
            } else if (i2 == 2015) {
                i2 = 2015;
            } else if (i2 == 2101) {
                i2 = 2101;
            } else if (i2 == 2103) {
                i2 = 2103;
            } else if (i2 == 3003) {
                i2 = 3003;
            } else if (i2 == -2302) {
                i2 = -2302;
            } else if (i2 != -2301) {
                if (!(i2 == 2021 || i2 == 2022)) {
                    if (i2 != 2105) {
                        if (i2 == 2106) {
                            i2 = 2106;
                        } else if (i2 == 3006 || i2 == 3007) {
                            i2 = 3005;
                        } else if (i2 == 3009) {
                            i2 = 3002;
                        } else if (i2 != 3010) {
                            switch (i2) {
                                case 2001:
                                    i2 = 2001;
                                    break;
                                case 2002:
                                    i2 = 2002;
                                    break;
                                case 2003:
                                    break;
                                case 2004:
                                    i2 = 2004;
                                    break;
                                case 2005:
                                    i2 = 2005;
                                    break;
                                default:
                                    switch (i2) {
                                        case 2007:
                                            i2 = 2007;
                                            break;
                                        case 2008:
                                            break;
                                        case 2009:
                                            i2 = 2009;
                                            break;
                                        default:
                                            return;
                                    }
                            }
                        } else {
                            i2 = 3002;
                        }
                    }
                }
                i2 = 2008;
            } else {
                i2 = -2301;
            }
            TXCloudVideoView tXCloudVideoView2 = this.mTXCloudVideoView;
            if (tXCloudVideoView2 != null) {
                tXCloudVideoView2.setLogText(null, bundle, i2);
            }
            ITXLivePlayListener iTXLivePlayListener3 = this.mListener;
            if (iTXLivePlayListener3 != null) {
                iTXLivePlayListener3.onPlayEvent(i2, bundle);
            }
        }
    }

    public boolean addVideoRawData(byte[] bArr) {
        String str = this.mPlayUrl;
        if (str == null || str.isEmpty()) {
            return false;
        }
        if (this.mEnableHWDec) {
            TXLog.e(TAG, "can not addVideoRawData because of hw decode has set!");
            return false;
        } else if (this.mPlayer == null) {
            TXCLog.e(TAG, "player hasn't created or not instanceof live player");
            return false;
        } else {
            this.mVideoRawBuf = bArr;
            return true;
        }
    }

    public void setVideoRawDataListener(ITXVideoRawDataListener iTXVideoRawDataListener) {
        TXCLog.d(TAG, "liteav_api setVideoRawDataListener " + iTXVideoRawDataListener);
        this.mVideoRawDataListener = iTXVideoRawDataListener;
        p pVar = this.mPlayer;
        if (pVar != null) {
            if (iTXVideoRawDataListener != null) {
                pVar.a(new q() {
                    /* class com.tencent.rtmp.TXLivePlayer.AnonymousClass2 */

                    @Override // com.tencent.liteav.q
                    public void onRenderVideoFrame(String str, int i, TXSVideoFrame tXSVideoFrame) {
                        if (tXSVideoFrame != null && tXSVideoFrame.width > 0 && tXSVideoFrame.height > 0) {
                            byte[] bArr = TXLivePlayer.this.mVideoRawBuf;
                            TXLivePlayer.this.mVideoRawBuf = null;
                            ITXVideoRawDataListener iTXVideoRawDataListener = TXLivePlayer.this.mVideoRawDataListener;
                            if (iTXVideoRawDataListener != null && bArr != null) {
                                if (bArr.length >= ((tXSVideoFrame.width * tXSVideoFrame.height) * 3) / 2) {
                                    tXSVideoFrame.loadI420Array(bArr);
                                    iTXVideoRawDataListener.onVideoRawDataAvailable(bArr, tXSVideoFrame.width, tXSVideoFrame.height, (int) tXSVideoFrame.pts);
                                    tXSVideoFrame.release();
                                    return;
                                }
                                TXCLog.e(TXLivePlayer.TAG, "raw data buffer length is too large");
                            }
                        }
                    }
                });
            } else {
                pVar.a((q) null);
            }
        }
    }

    public void snapshot(ITXSnapshotListener iTXSnapshotListener) {
        TextureView textureView;
        Bitmap bitmap;
        TXCLog.d(TAG, "liteav_api snapshot " + iTXSnapshotListener);
        if (!this.mSnapshotRunning && iTXSnapshotListener != null) {
            this.mSnapshotRunning = true;
            p pVar = this.mPlayer;
            if (pVar != null) {
                textureView = pVar.d();
            } else {
                textureView = null;
            }
            if (textureView != null) {
                try {
                    bitmap = textureView.getBitmap();
                } catch (OutOfMemoryError e) {
                    bitmap = null;
                }
                if (bitmap != null) {
                    Bitmap createBitmap = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), textureView.getTransform(null), true);
                    bitmap.recycle();
                    bitmap = createBitmap;
                }
                postBitmapToMainThread(iTXSnapshotListener, bitmap);
                return;
            }
            this.mSnapshotRunning = false;
        }
    }

    public void setAudioRawDataListener(ITXAudioRawDataListener iTXAudioRawDataListener) {
        TXCLog.d(TAG, "liteav_api setAudioRawDataListener " + iTXAudioRawDataListener);
        this.mAudioRawDataListener = iTXAudioRawDataListener;
        p pVar = this.mPlayer;
        if (pVar != null) {
            pVar.a(iTXAudioRawDataListener);
        }
    }

    private boolean isAVCDecBlacklistDevices() {
        if (!Build.MANUFACTURER.equalsIgnoreCase("HUAWEI") || !Build.MODEL.equalsIgnoreCase("Che2-TL00")) {
            return false;
        }
        return true;
    }

    private String checkPlayUrl(String str, int i) {
        if (i != 6) {
            try {
                byte[] bytes = str.getBytes("UTF-8");
                StringBuilder sb = new StringBuilder(bytes.length);
                for (int i2 = 0; i2 < bytes.length; i2++) {
                    int i3 = bytes[i2] < 0 ? bytes[i2] + 256 : bytes[i2];
                    if (!(i3 <= 32 || i3 >= 127 || i3 == 34 || i3 == 37 || i3 == 60 || i3 == 62 || i3 == 91 || i3 == 125 || i3 == 92 || i3 == 93 || i3 == 94 || i3 == 96 || i3 == 123)) {
                        if (i3 != 124) {
                            sb.append((char) i3);
                        }
                    }
                    sb.append(String.format("%%%02X", Integer.valueOf(i3 == 1 ? 1 : 0)));
                }
                str = sb.toString();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return str.trim();
    }

    private void postBitmapToMainThread(final ITXSnapshotListener iTXSnapshotListener, final Bitmap bitmap) {
        if (iTXSnapshotListener != null) {
            new Handler(Looper.getMainLooper()).post(new Runnable() {
                /* class com.tencent.rtmp.TXLivePlayer.AnonymousClass3 */

                public void run() {
                    ITXSnapshotListener iTXSnapshotListener = iTXSnapshotListener;
                    if (iTXSnapshotListener != null) {
                        iTXSnapshotListener.onSnapshot(bitmap);
                    }
                    TXLivePlayer.this.mSnapshotRunning = false;
                }
            });
        }
    }
}
