package com.tencent.rtmp.sharp.jni;

import android.content.Context;
import android.hardware.SensorManager;
import android.media.AudioManager;
import android.media.AudioRecord;
import android.media.AudioTrack;
import android.media.MediaCodecInfo;
import android.media.MediaCodecList;
import android.os.Build;
import android.os.Environment;
import android.os.Process;
import android.os.SystemClock;
import com.taobao.weex.el.parse.Operators;
import com.tencent.qphone.base.util.QLog;
import com.tencent.rtmp.sharp.jni.TraeAudioCodecList;
import com.tencent.rtmp.sharp.jni.TraeAudioSession;
import com.tencent.ugc.TXRecordCommon;
import com.umeng.analytics.pro.bg;
import java.io.File;
import java.io.FileFilter;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Condition;
import java.util.concurrent.locks.ReentrantLock;

public class AudioDeviceInterface {
    private static final FileFilter CPU_FILTER = new FileFilter() {
        /* class com.tencent.rtmp.sharp.jni.AudioDeviceInterface.AnonymousClass4 */

        public boolean accept(File file) {
            String name = file.getName();
            if (!name.startsWith(bg.w)) {
                return false;
            }
            for (int i = 3; i < name.length(); i++) {
                if (name.charAt(i) < '0' || name.charAt(i) > '9') {
                    return false;
                }
            }
            return true;
        }
    };
    public static final int OUTPUT_MODE_HEADSET = 0;
    public static final int OUTPUT_MODE_SPEAKER = 1;
    private static boolean _dumpEnable = false;
    private static boolean _logEnable = true;
    private static boolean isSupportVivoKTVHelper = false;
    private static String[] mDeviceList = null;
    private static VivoKTVHelper mVivoKTVHelper = null;
    private TraeAudioSession _as = null;
    private TraeAudioSession _asAudioManager;
    private AudioManager _audioManager = null;
    private AudioRecord _audioRecord = null;
    private boolean _audioRouteChanged = false;
    private int _audioSource = 0;
    private int _audioSourcePolicy = -1;
    private int _audioStreamTypePolicy = -1;
    private AudioTrack _audioTrack = null;
    private int _bufferedPlaySamples = 0;
    private int _bufferedRecSamples = 0;
    private int _channelOutType = 4;
    private String _connectedDev = TraeAudioManager.DEVICE_NONE;
    private Context _context = null;
    private ByteBuffer _decBuffer0;
    private ByteBuffer _decBuffer1;
    private ByteBuffer _decBuffer10;
    private ByteBuffer _decBuffer2;
    private ByteBuffer _decBuffer3;
    private ByteBuffer _decBuffer4;
    private ByteBuffer _decBuffer5;
    private ByteBuffer _decBuffer6;
    private ByteBuffer _decBuffer7;
    private ByteBuffer _decBuffer8;
    private ByteBuffer _decBuffer9;
    private int _deviceStat = 0;
    private boolean _doPlayInit = true;
    private boolean _doRecInit = true;
    private boolean _isPlaying = false;
    private boolean _isRecording = false;
    private int _modePolicy = -1;
    private ByteBuffer _playBuffer;
    private int _playPosition = 0;
    private int _playSamplerate = TXRecordCommon.AUDIO_SAMPLERATE_8000;
    private File _play_dump = null;
    private FileOutputStream _play_out = null;
    private boolean _preDone;
    private Condition _precon;
    private ReentrantLock _prelock;
    private ByteBuffer _recBuffer;
    private File _rec_dump = null;
    private FileOutputStream _rec_out = null;
    private int _sceneMode = 0;
    private int _sessionId = 0;
    private int _streamType = 0;
    private byte[] _tempBufPlay;
    private byte[] _tempBufRec;
    private TraeAudioCodecList _traeAudioCodecList = null;
    private int nPlayLengthMs = 0;
    private int nRecordLengthMs = 0;
    private int switchState;
    private boolean usingJava;

    public AudioDeviceInterface() {
        ReentrantLock reentrantLock = new ReentrantLock();
        this._prelock = reentrantLock;
        this._precon = reentrantLock.newCondition();
        this._preDone = false;
        this.usingJava = true;
        this.switchState = 0;
        this._asAudioManager = null;
        try {
            this._playBuffer = ByteBuffer.allocateDirect(1920);
            this._recBuffer = ByteBuffer.allocateDirect(1920);
            this._decBuffer0 = ByteBuffer.allocateDirect(3840);
            this._decBuffer1 = ByteBuffer.allocateDirect(3840);
            this._decBuffer2 = ByteBuffer.allocateDirect(3840);
            this._decBuffer3 = ByteBuffer.allocateDirect(3840);
            this._decBuffer4 = ByteBuffer.allocateDirect(3840);
            this._decBuffer5 = ByteBuffer.allocateDirect(3840);
            this._decBuffer6 = ByteBuffer.allocateDirect(3840);
            this._decBuffer7 = ByteBuffer.allocateDirect(3840);
            this._decBuffer8 = ByteBuffer.allocateDirect(3840);
            this._decBuffer9 = ByteBuffer.allocateDirect(3840);
            this._decBuffer10 = ByteBuffer.allocateDirect(3840);
        } catch (Exception e) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, e.getMessage());
            }
        }
        this._tempBufPlay = new byte[1920];
        this._tempBufRec = new byte[1920];
        this._traeAudioCodecList = new TraeAudioCodecList();
        int i = Build.VERSION.SDK_INT;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "AudioDeviceInterface apiLevel:" + i);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, " SDK_INT:" + Build.VERSION.SDK_INT);
        }
        if (i <= 0) {
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "manufacture:" + Build.MANUFACTURER);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "MODEL:" + Build.MODEL);
        }
    }

    public void setContext(Context context) {
        this._context = context;
    }

    private int getLowlatencySamplerate() {
        if (this._context == null || Build.VERSION.SDK_INT < 9) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "getLowlatencySamplerate err, _context:" + this._context + " api:" + Build.VERSION.SDK_INT);
            }
            return 0;
        }
        boolean hasSystemFeature = this._context.getPackageManager().hasSystemFeature("android.hardware.audio.low_latency");
        if (QLog.isColorLevel()) {
            StringBuilder sb = new StringBuilder();
            sb.append("LOW_LATENCY:");
            sb.append(hasSystemFeature ? "Y" : "N");
            QLog.w("TRAE", 2, sb.toString());
        }
        if (Build.VERSION.SDK_INT < 17) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "API Level too low not support PROPERTY_OUTPUT_SAMPLE_RATE");
            }
            return 0;
        }
        if (QLog.isColorLevel()) {
            QLog.e("TRAE", 2, "getLowlatencySamplerate not support right now!");
        }
        return 0;
    }

    private int getLowlatencyFramesPerBuffer() {
        if (this._context == null || Build.VERSION.SDK_INT < 9) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "getLowlatencySamplerate err, _context:" + this._context + " api:" + Build.VERSION.SDK_INT);
            }
            return 0;
        }
        boolean hasSystemFeature = this._context.getPackageManager().hasSystemFeature("android.hardware.audio.low_latency");
        if (QLog.isColorLevel()) {
            StringBuilder sb = new StringBuilder();
            sb.append("LOW_LATENCY:");
            sb.append(hasSystemFeature ? "Y" : "N");
            QLog.w("TRAE", 2, sb.toString());
        }
        if (Build.VERSION.SDK_INT < 17 && QLog.isColorLevel()) {
            QLog.e("TRAE", 2, "API Level too low not support PROPERTY_OUTPUT_SAMPLE_RATE");
        }
        return 0;
    }

    private int getAudioSessionId(AudioRecord audioRecord) {
        return 0;
    }

    private int InitSetting(int i, int i2, int i3, int i4, int i5) {
        this._audioSourcePolicy = i;
        this._audioStreamTypePolicy = i2;
        this._modePolicy = i3;
        this._deviceStat = i4;
        this._sceneMode = i5;
        if (i4 == 1 || i4 == 5 || i4 == 2 || i4 == 3) {
            TraeAudioManager.IsMusicScene = true;
        } else {
            TraeAudioManager.IsMusicScene = false;
        }
        int i6 = this._sceneMode;
        if (i6 == 0 || i6 == 4) {
            TraeAudioManager.IsEarPhoneSupported = true;
        } else {
            TraeAudioManager.IsEarPhoneSupported = false;
        }
        TraeAudioManager.IsUpdateSceneFlag = true;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitSetting: _audioSourcePolicy:" + this._audioSourcePolicy + " _audioStreamTypePolicy:" + this._audioStreamTypePolicy + " _modePolicy:" + this._modePolicy + " DeviceStat:" + i4 + " isSupportVivoKTVHelper:" + isSupportVivoKTVHelper);
        }
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:51:0x016a  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x018c  */
    private int InitRecording(int i, int i2) {
        int i3;
        int i4;
        int i5;
        int[] iArr;
        AudioRecord audioRecord;
        String str;
        AudioRecord audioRecord2;
        String str2;
        int i6;
        Exception e;
        AudioRecord audioRecord3;
        int i7 = 2;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitRecording entry:" + i);
        }
        if (!this._isRecording && this._audioRecord == null && i2 <= 2) {
            if (i2 == 2) {
                i3 = 12;
            } else {
                i3 = 16;
            }
            int minBufferSize = AudioRecord.getMinBufferSize(i, i3, 2);
            int i8 = (((i * 20) * i2) * 2) / 1000;
            String str3 = " sr:";
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitRecording: min rec buf size is " + minBufferSize + str3 + getLowlatencySamplerate() + " fp" + getLowlatencyFramesPerBuffer() + " 20msFZ:" + i8);
            }
            this._bufferedRecSamples = (i * 5) / 200;
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "  rough rec delay set to " + this._bufferedRecSamples);
            }
            AudioRecord audioRecord4 = this._audioRecord;
            AudioRecord audioRecord5 = null;
            if (audioRecord4 != null) {
                audioRecord4.release();
                this._audioRecord = null;
            }
            int i9 = 4;
            int[] iArr2 = {0, 1, 5, 0};
            iArr2[0] = TraeAudioManager.getAudioSource(this._audioSourcePolicy);
            int i10 = minBufferSize;
            int i11 = 0;
            while (i11 < i9 && this._audioRecord == null) {
                this._audioSource = iArr2[i11];
                int i12 = 1;
                while (true) {
                    if (i12 > i7) {
                        i5 = i11;
                        iArr = iArr2;
                        audioRecord = audioRecord5;
                        str = str3;
                        break;
                    }
                    int i13 = minBufferSize * i12;
                    if (i13 >= i8 * 4 || i12 >= i7) {
                        try {
                            this.nRecordLengthMs = (i13 * 500) / (i * i2);
                            i5 = i11;
                            iArr = iArr2;
                            try {
                                AudioRecord audioRecord6 = new AudioRecord(this._audioSource, i, i3, 2, i13);
                                this._audioRecord = audioRecord6;
                                if (audioRecord6.getState() == 1) {
                                    str = str3;
                                    audioRecord = null;
                                    i10 = i13;
                                    break;
                                }
                                if (QLog.isColorLevel()) {
                                    StringBuilder sb = new StringBuilder();
                                    sb.append("InitRecording:  rec not initialized,try agine,  minbufsize:");
                                    i6 = i13;
                                    sb.append(i6);
                                    str2 = str3;
                                    sb.append(str2);
                                    sb.append(i);
                                    sb.append(" as:");
                                    sb.append(this._audioSource);
                                    QLog.w("TRAE", 2, sb.toString());
                                } else {
                                    i6 = i13;
                                    str2 = str3;
                                }
                                this._audioRecord.release();
                                audioRecord2 = null;
                                this._audioRecord = null;
                            } catch (Exception e2) {
                                e = e2;
                                i6 = i13;
                                str2 = str3;
                                audioRecord2 = null;
                                if (QLog.isColorLevel()) {
                                    QLog.w("TRAE", 2, e.getMessage() + " _audioRecord:" + this._audioRecord);
                                }
                                audioRecord3 = this._audioRecord;
                                if (audioRecord3 != null) {
                                    audioRecord3.release();
                                }
                                this._audioRecord = audioRecord2;
                                i12++;
                                i10 = i6;
                                str3 = str2;
                                audioRecord5 = audioRecord2;
                                i11 = i5;
                                iArr2 = iArr;
                                i7 = 2;
                            }
                        } catch (Exception e3) {
                            e = e3;
                            i5 = i11;
                            iArr = iArr2;
                            i6 = i13;
                            str2 = str3;
                            audioRecord2 = null;
                            if (QLog.isColorLevel()) {
                            }
                            audioRecord3 = this._audioRecord;
                            if (audioRecord3 != null) {
                            }
                            this._audioRecord = audioRecord2;
                            i12++;
                            i10 = i6;
                            str3 = str2;
                            audioRecord5 = audioRecord2;
                            i11 = i5;
                            iArr2 = iArr;
                            i7 = 2;
                        }
                    } else {
                        i5 = i11;
                        iArr = iArr2;
                        i6 = i13;
                        str2 = str3;
                        audioRecord2 = null;
                    }
                    i12++;
                    i10 = i6;
                    str3 = str2;
                    audioRecord5 = audioRecord2;
                    i11 = i5;
                    iArr2 = iArr;
                    i7 = 2;
                }
                str3 = str;
                audioRecord5 = audioRecord;
                iArr2 = iArr;
                i9 = 4;
                i7 = 2;
                i11 = i5 + 1;
            }
            if (this._audioRecord != null) {
                if (QLog.isColorLevel()) {
                    i4 = 2;
                    QLog.w("TRAE", 2, " [Config] InitRecording: audioSession:" + this._sessionId + " audioSource:" + this._audioSource + " rec sample rate set to " + i + " recBufSize:" + i10 + " nRecordLengthMs:" + this.nRecordLengthMs);
                } else {
                    i4 = 2;
                }
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", i4, "InitRecording exit");
                }
                return this._bufferedRecSamples;
            } else if (!QLog.isColorLevel()) {
                return -1;
            } else {
                QLog.w("TRAE", 2, "InitRecording fail!!!");
                return -1;
            }
        } else if (!QLog.isColorLevel()) {
            return -1;
        } else {
            QLog.e("TRAE", 2, "InitRecording _isRecording:" + this._isRecording);
            return -1;
        }
    }

    private int InitPlayback(int i, int i2) {
        AudioManager audioManager;
        Object obj;
        Object obj2;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "InitPlayback entry: sampleRate " + i);
        }
        if (!this._isPlaying && this._audioTrack == null && i2 <= 2) {
            if (this._audioManager == null) {
                try {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                } catch (Exception e) {
                    if (QLog.isColorLevel()) {
                        QLog.w("TRAE", 2, e.getMessage());
                    }
                    return -1;
                }
            }
            if (i2 == 2) {
                this._channelOutType = 12;
            } else {
                this._channelOutType = 4;
            }
            this._playSamplerate = i;
            int minBufferSize = AudioTrack.getMinBufferSize(i, this._channelOutType, 2);
            if (this._channelOutType == 12) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "InitPlayback, _channelOutType stero");
                } else if (this._channelOutType == 4 && QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "InitPlayback, _channelOutType Mono");
                }
            }
            int i3 = (((i * 20) * 1) * 2) / 1000;
            if (this._channelOutType == 12) {
                i3 *= 2;
            }
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "InitPlayback: minPlayBufSize:" + minBufferSize + " 20msFz:" + i3);
            }
            this._bufferedPlaySamples = 0;
            AudioTrack audioTrack = this._audioTrack;
            Object obj3 = null;
            if (audioTrack != null) {
                audioTrack.release();
                this._audioTrack = null;
            }
            int[] iArr = {0, 0, 3, 1};
            this._streamType = TraeAudioManager.getAudioStreamType(this._audioStreamTypePolicy);
            if (this._audioRouteChanged) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "_audioRouteChanged:" + this._audioRouteChanged + " _streamType:" + this._streamType);
                }
                if (this._audioManager.getMode() != 0 || !this._connectedDev.equals(TraeAudioManager.DEVICE_SPEAKERPHONE)) {
                    this._streamType = 0;
                } else {
                    this._streamType = 3;
                }
                this._audioRouteChanged = false;
            }
            iArr[0] = this._streamType;
            int i4 = minBufferSize;
            int i5 = 0;
            for (int i6 = 4; i5 < i6 && this._audioTrack == null; i6 = 4) {
                this._streamType = iArr[i5];
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "InitPlayback: min play buf size is " + minBufferSize + " hw_sr:" + AudioTrack.getNativeOutputSampleRate(this._streamType));
                }
                int i7 = 1;
                while (true) {
                    if (i7 > 2) {
                        obj = obj3;
                        break;
                    }
                    int i8 = minBufferSize * i7;
                    if (i8 >= i3 * 4 || i7 >= 2) {
                        try {
                            this.nPlayLengthMs = (i8 * 500) / (i * i2);
                            AudioTrack audioTrack2 = new AudioTrack(this._streamType, this._playSamplerate, this._channelOutType, 2, i8, 1);
                            this._audioTrack = audioTrack2;
                            if (audioTrack2.getState() == 1) {
                                i4 = i8;
                                obj = null;
                                break;
                            }
                            if (QLog.isColorLevel()) {
                                QLog.w("TRAE", 2, "InitPlayback: play not initialized playBufSize:" + i8 + " sr:" + this._playSamplerate);
                            }
                            this._audioTrack.release();
                            obj2 = null;
                            this._audioTrack = null;
                        } catch (Exception e2) {
                            if (QLog.isColorLevel()) {
                                QLog.w("TRAE", 2, e2.getMessage() + " _audioTrack:" + this._audioTrack);
                            }
                            AudioTrack audioTrack3 = this._audioTrack;
                            if (audioTrack3 != null) {
                                audioTrack3.release();
                            }
                            obj2 = null;
                            this._audioTrack = null;
                        }
                    } else {
                        obj2 = obj3;
                    }
                    i7++;
                    obj3 = obj2;
                    i4 = i8;
                }
                i5++;
                obj3 = obj;
            }
            if (this._audioTrack != null) {
                TraeAudioSession traeAudioSession = this._as;
                if (!(traeAudioSession == null || (audioManager = this._audioManager) == null)) {
                    traeAudioSession.voiceCallAudioParamChanged(audioManager.getMode(), this._streamType);
                }
                this._playPosition = this._audioTrack.getPlaybackHeadPosition();
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "InitPlayback exit: streamType:" + this._streamType + " samplerate:" + this._playSamplerate + " _playPosition:" + this._playPosition + " playBufSize:" + i4 + " nPlayLengthMs:" + this.nPlayLengthMs);
                }
                TraeAudioManager.forceVolumeControlStream(this._audioManager, this._connectedDev.equals(TraeAudioManager.DEVICE_BLUETOOTHHEADSET) ? 6 : this._audioTrack.getStreamType());
                return 0;
            } else if (!QLog.isColorLevel()) {
                return -1;
            } else {
                QLog.w("TRAE", 2, "InitPlayback fail!!!");
                return -1;
            }
        } else if (!QLog.isColorLevel()) {
            return -1;
        } else {
            QLog.e("TRAE", 2, "InitPlayback _isPlaying:" + this._isPlaying);
            return -1;
        }
    }

    private int getPlayRecordSysBufferMs() {
        return (this.nRecordLengthMs + this.nPlayLengthMs) * 2;
    }

    private String getDumpFilePath(String str, int i) {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "manufacture:" + Build.MANUFACTURER);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "MODEL:" + Build.MODEL);
        }
        String str2 = Environment.getExternalStorageDirectory().getPath() + "/MF-" + Build.MANUFACTURER + "-M-" + Build.MODEL + "-as-" + TraeAudioManager.getAudioSource(this._audioSourcePolicy) + "-st-" + this._streamType + "-m-" + i + "-" + str;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "dump:" + str2);
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "dump replace:" + str2.replace(Operators.SPACE_STR, "_"));
        }
        return str2.replace(Operators.SPACE_STR, "_");
    }

    private int StartRecording() {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StartRecording entry");
        }
        int i = -1;
        if (this._isRecording) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartRecording _isRecording:" + this._isRecording);
            }
            return -1;
        }
        AudioRecord audioRecord = this._audioRecord;
        if (audioRecord == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartRecording _audioRecord:" + this._audioRecord);
            }
            return -1;
        }
        try {
            audioRecord.startRecording();
            if (_dumpEnable) {
                AudioManager audioManager = this._audioManager;
                if (audioManager != null) {
                    i = audioManager.getMode();
                }
                this._rec_dump = new File(getDumpFilePath("jnirecord.pcm", i));
                try {
                    this._rec_out = new FileOutputStream(this._rec_dump);
                } catch (FileNotFoundException e) {
                    e.printStackTrace();
                }
            }
            this._isRecording = true;
            if (!QLog.isColorLevel()) {
                return 0;
            }
            QLog.w("TRAE", 2, "StartRecording ok");
            return 0;
        } catch (IllegalStateException e2) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartRecording fail");
            }
            e2.printStackTrace();
            return -1;
        }
    }

    private int StartPlayback() {
        int i = -1;
        if (this._isPlaying) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartPlayback _isPlaying");
            }
            return -1;
        }
        AudioTrack audioTrack = this._audioTrack;
        if (audioTrack == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartPlayback _audioTrack:" + this._audioTrack);
            }
            return -1;
        }
        try {
            audioTrack.play();
            if (_dumpEnable) {
                AudioManager audioManager = this._audioManager;
                if (audioManager != null) {
                    i = audioManager.getMode();
                }
                this._play_dump = new File(getDumpFilePath("jniplay.pcm", i));
                try {
                    this._play_out = new FileOutputStream(this._play_dump);
                } catch (FileNotFoundException e) {
                    e.printStackTrace();
                }
            }
            this._isPlaying = true;
            if (!QLog.isColorLevel()) {
                return 0;
            }
            QLog.w("TRAE", 2, "StartPlayback ok");
            return 0;
        } catch (IllegalStateException e2) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StartPlayback fail");
            }
            e2.printStackTrace();
            return -1;
        }
    }

    private int StopRecording() {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopRecording entry");
        }
        AudioRecord audioRecord = this._audioRecord;
        if (audioRecord == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "UnintRecord:" + this._audioRecord);
            }
            return -1;
        }
        if (audioRecord.getRecordingState() == 3) {
            try {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopRecording stop... state:" + this._audioRecord.getRecordingState());
                }
                this._audioRecord.stop();
            } catch (IllegalStateException e) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "StopRecording  err");
                }
                e.printStackTrace();
                return -1;
            }
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopRecording releaseing... state:" + this._audioRecord.getRecordingState());
        }
        this._audioRecord.release();
        this._audioRecord = null;
        this._isRecording = false;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopRecording exit ok");
        }
        return 0;
    }

    private int StopPlayback() {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopPlayback entry _isPlaying:" + this._isPlaying);
        }
        AudioTrack audioTrack = this._audioTrack;
        if (audioTrack == null) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "StopPlayback _isPlaying:" + this._isPlaying + Operators.SPACE_STR + this._audioTrack);
            }
            return -1;
        }
        if (audioTrack.getPlayState() == 3) {
            try {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopPlayback stoping...");
                }
                this._audioTrack.stop();
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "StopPlayback flushing... state:" + this._audioTrack.getPlayState());
                }
                this._audioTrack.flush();
            } catch (IllegalStateException e) {
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "StopPlayback err");
                }
                e.printStackTrace();
                return -1;
            }
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopPlayback releaseing... state:" + this._audioTrack.getPlayState());
        }
        this._audioTrack.release();
        this._audioTrack = null;
        this._isPlaying = false;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "StopPlayback exit ok");
        }
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:115:0x0276  */
    /* JADX WARNING: Removed duplicated region for block: B:118:0x0296  */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x03a2  */
    /* JADX WARNING: Removed duplicated region for block: B:178:? A[RETURN, SYNTHETIC] */
    private int PlayAudio(int i) {
        Exception exc;
        Exception e;
        boolean z;
        int i2;
        Exception e2;
        int i3 = i;
        int i4 = 2;
        if ((!this._isPlaying) || (this._audioTrack == null)) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "PlayAudio: _isPlaying " + this._isPlaying + Operators.SPACE_STR + this._audioTrack);
            }
            return -1;
        }
        try {
            if (this._audioTrack == null) {
                return -2;
            }
            if (this._doPlayInit) {
                try {
                    Process.setThreadPriority(-19);
                    Thread.currentThread().setName("TRAEAudioPlay");
                } catch (Exception e3) {
                    try {
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", 2, "Set play thread priority failed: " + e3.getMessage());
                        }
                    } catch (Exception e4) {
                        e = e4;
                        exc = e;
                        i3 = 0;
                        if (QLog.isColorLevel()) {
                            return i3;
                        }
                        QLog.e("TRAE", 2, "PlayAudio Exception: " + exc.getMessage());
                        return i3;
                    }
                }
                this._doPlayInit = false;
            }
            if (_dumpEnable && this._play_out != null) {
                try {
                    this._play_out.write(this._tempBufPlay, 0, 0);
                } catch (IOException e5) {
                    e5.printStackTrace();
                }
            }
            if (!this._audioRouteChanged) {
                z = false;
            } else {
                if (this._audioManager == null && this._context != null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (this._audioManager == null || this._audioManager.getMode() != 0 || !this._connectedDev.equals(TraeAudioManager.DEVICE_SPEAKERPHONE)) {
                    this._streamType = 0;
                } else {
                    this._streamType = 3;
                }
                z = this._streamType != this._audioTrack.getStreamType();
                this._audioRouteChanged = false;
            }
            this._playBuffer.get(this._tempBufPlay);
            if (z) {
                try {
                    this._playBuffer.rewind();
                    long elapsedRealtime = SystemClock.elapsedRealtime();
                    if (QLog.isColorLevel()) {
                        QLog.w("TRAE", 2, " track resting: _streamType:" + this._streamType + " at.st:" + this._audioTrack.getStreamType());
                    }
                    if (this._audioTrack.getPlayState() == 3) {
                        try {
                            if (QLog.isColorLevel()) {
                                QLog.w("TRAE", 2, "StopPlayback stoping...");
                            }
                            this._audioTrack.stop();
                            this._audioTrack.flush();
                            if (QLog.isColorLevel()) {
                                QLog.w("TRAE", 2, "StopPlayback flushing... state:" + this._audioTrack.getPlayState());
                            }
                            this._audioTrack.release();
                            if (QLog.isColorLevel()) {
                                QLog.w("TRAE", 2, "StopPlayback releaseing... state:" + this._audioTrack.getPlayState());
                            }
                            this._audioTrack = null;
                        } catch (IllegalStateException e6) {
                            if (QLog.isColorLevel()) {
                                QLog.e("TRAE", 2, "StopPlayback err");
                            }
                        }
                    }
                    int minBufferSize = AudioTrack.getMinBufferSize(this._playSamplerate, this._channelOutType, 2);
                    int[] iArr = {0, 0, 3, 1};
                    iArr[0] = this._streamType;
                    int i5 = (((this._playSamplerate * 20) * 1) * 2) / 1000;
                    if (this._channelOutType == 12) {
                        i5 *= 2;
                    }
                    int i6 = 0;
                    for (int i7 = 4; i6 < i7 && this._audioTrack == null; i7 = 4) {
                        this._streamType = iArr[i6];
                        if (QLog.isColorLevel()) {
                            QLog.w("TRAE", i4, "InitPlayback: min play buf size is " + minBufferSize + " hw_sr:" + AudioTrack.getNativeOutputSampleRate(this._streamType));
                        }
                        int i8 = 1;
                        while (true) {
                            if (i8 > i4) {
                                i2 = minBufferSize;
                                break;
                            }
                            int i9 = minBufferSize * i8;
                            if (i9 >= i5 * 4 || i8 >= i4) {
                                try {
                                    i2 = minBufferSize;
                                    try {
                                        this._audioTrack = new AudioTrack(this._streamType, this._playSamplerate, this._channelOutType, 2, i9, 1);
                                        if (QLog.isColorLevel()) {
                                            QLog.w("TRAE", 2, " _audioTrack:" + this._audioTrack);
                                        }
                                        if (this._audioTrack.getState() == 1) {
                                            break;
                                        }
                                        if (QLog.isColorLevel()) {
                                            QLog.w("TRAE", 2, "InitPlayback: play not initialized playBufSize:" + i9 + " sr:" + this._playSamplerate);
                                        }
                                        this._audioTrack.release();
                                        this._audioTrack = null;
                                    } catch (Exception e7) {
                                        e2 = e7;
                                        if (QLog.isColorLevel()) {
                                        }
                                        if (this._audioTrack != null) {
                                        }
                                        this._audioTrack = null;
                                        i8++;
                                        minBufferSize = i2;
                                        i4 = 2;
                                    }
                                } catch (Exception e8) {
                                    e2 = e8;
                                    i2 = minBufferSize;
                                    if (QLog.isColorLevel()) {
                                        QLog.w("TRAE", 2, e2.getMessage() + " _audioTrack:" + this._audioTrack);
                                    }
                                    if (this._audioTrack != null) {
                                        this._audioTrack.release();
                                    }
                                    this._audioTrack = null;
                                    i8++;
                                    minBufferSize = i2;
                                    i4 = 2;
                                }
                            } else {
                                i2 = minBufferSize;
                            }
                            i8++;
                            minBufferSize = i2;
                            i4 = 2;
                        }
                        i6++;
                        minBufferSize = i2;
                        i4 = 2;
                    }
                    if (this._audioTrack != null) {
                        try {
                            this._audioTrack.play();
                            this._as.voiceCallAudioParamChanged(this._audioManager.getMode(), this._streamType);
                            TraeAudioManager.forceVolumeControlStream(this._audioManager, this._connectedDev.equals(TraeAudioManager.DEVICE_BLUETOOTHHEADSET) ? 6 : this._audioTrack.getStreamType());
                        } catch (Exception e9) {
                        }
                    }
                    if (!QLog.isColorLevel()) {
                        return i3;
                    }
                    QLog.e("TRAE", 2, "  track reset used:" + (SystemClock.elapsedRealtime() - elapsedRealtime) + "ms");
                    return i3;
                } catch (Exception e10) {
                    e = e10;
                    exc = e;
                    if (QLog.isColorLevel()) {
                    }
                }
            } else {
                int write = this._audioTrack.write(this._tempBufPlay, 0, i3);
                try {
                    this._playBuffer.rewind();
                    if (write < 0) {
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "Could not write data from sc (write = " + write + ", length = " + i3 + Operators.BRACKET_END_STR);
                        }
                        return -1;
                    }
                    if (write != i3 && QLog.isColorLevel()) {
                        QLog.e("TRAE", 2, "Could not write all data from sc (write = " + write + ", length = " + i3 + Operators.BRACKET_END_STR);
                    }
                    this._bufferedPlaySamples += write >> 1;
                    int playbackHeadPosition = this._audioTrack.getPlaybackHeadPosition();
                    if (playbackHeadPosition < this._playPosition) {
                        this._playPosition = 0;
                    }
                    this._bufferedPlaySamples -= playbackHeadPosition - this._playPosition;
                    this._playPosition = playbackHeadPosition;
                    if (!this._isRecording) {
                    }
                    return write;
                } catch (Exception e11) {
                    e = e11;
                    i3 = write;
                    exc = e;
                    if (QLog.isColorLevel()) {
                    }
                }
            }
        } catch (Exception e12) {
            e = e12;
            exc = e;
            i3 = 0;
            if (QLog.isColorLevel()) {
            }
        }
    }

    private int OpenslesNeedResetAudioTrack(boolean z) {
        try {
            if (!TraeAudioManager.isCloseSystemAPM(this._modePolicy)) {
                return -1;
            }
            if (this._audioRouteChanged || z) {
                if (this._audioManager == null && this._context != null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (this._audioManager == null) {
                    return 0;
                }
                if (this._audioManager.getMode() != 0 || !this._connectedDev.equals(TraeAudioManager.DEVICE_SPEAKERPHONE)) {
                    this._audioStreamTypePolicy = 0;
                } else {
                    this._audioStreamTypePolicy = 3;
                }
                this._audioRouteChanged = false;
            }
            return this._audioStreamTypePolicy;
        } catch (Exception e) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "PlayAudio Exception: " + e.getMessage());
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:49:0x00e7  */
    private int RecordAudio(int i) {
        Exception e;
        if (!this._isRecording) {
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "RecordAudio: _isRecording " + this._isRecording);
            }
            return -1;
        }
        int i2 = 0;
        try {
            if (this._audioRecord == null) {
                return -2;
            }
            if (this._doRecInit) {
                try {
                    Process.setThreadPriority(-19);
                    Thread.currentThread().setName("TRAEAudioRecord");
                } catch (Exception e2) {
                    if (QLog.isColorLevel()) {
                        QLog.w("TRAE", 2, "Set rec thread priority failed: " + e2.getMessage());
                    }
                }
                this._doRecInit = false;
            }
            this._recBuffer.rewind();
            int read = this._audioRecord.read(this._tempBufRec, 0, i);
            if (read < 0) {
                try {
                    if (QLog.isColorLevel()) {
                        QLog.e("TRAE", 2, "Could not read data from sc (read = " + read + ", length = " + i + Operators.BRACKET_END_STR);
                    }
                    return -1;
                } catch (Exception e3) {
                    e = e3;
                    i2 = read;
                    if (QLog.isColorLevel()) {
                    }
                    return i2;
                }
            } else {
                this._recBuffer.put(this._tempBufRec, 0, read);
                if (_dumpEnable && this._rec_out != null) {
                    try {
                        this._rec_out.write(this._tempBufRec, 0, read);
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                }
                if (read == i) {
                    return read;
                }
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "Could not read all data from sc (read = " + read + ", length = " + i + Operators.BRACKET_END_STR);
                }
                return -1;
            }
        } catch (Exception e5) {
            e = e5;
            if (QLog.isColorLevel()) {
                QLog.e("TRAE", 2, "RecordAudio Exception: " + e.getMessage());
            }
            return i2;
        }
    }

    private int SetPlayoutVolume(int i) {
        Context context;
        if (this._audioManager == null && (context = this._context) != null) {
            this._audioManager = (AudioManager) context.getSystemService("audio");
        }
        AudioManager audioManager = this._audioManager;
        if (audioManager == null) {
            return -1;
        }
        audioManager.setStreamVolume(0, i, 0);
        return 0;
    }

    private int GetPlayoutVolume() {
        Context context;
        if (this._audioManager == null && (context = this._context) != null) {
            this._audioManager = (AudioManager) context.getSystemService("audio");
        }
        AudioManager audioManager = this._audioManager;
        if (audioManager != null) {
            return audioManager.getStreamVolume(0);
        }
        return -1;
    }

    public static String getTraceInfo() {
        StringBuffer stringBuffer = new StringBuffer();
        StackTraceElement[] stackTrace = new Throwable().getStackTrace();
        int length = stackTrace.length;
        stringBuffer.append("");
        stringBuffer.append(stackTrace[2].getClassName());
        stringBuffer.append(Operators.DOT_STR);
        stringBuffer.append(stackTrace[2].getMethodName());
        stringBuffer.append(": ");
        stringBuffer.append(stackTrace[2].getLineNumber());
        return stringBuffer.toString();
    }

    public static final void LogTraceEntry(String str) {
        if (_logEnable) {
            String str2 = getTraceInfo() + " entry:" + str;
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, str2);
            }
        }
    }

    public static final void LogTraceExit() {
        if (_logEnable) {
            String str = getTraceInfo() + " exit";
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, str);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onOutputChanage(String str) {
        int i;
        String str2;
        String str3;
        String str4;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, " onOutputChanage:" + str);
        }
        setAudioRouteSwitchState(str);
        if (TraeAudioManager.isCloseSystemAPM(this._modePolicy) && (i = this._deviceStat) != 1 && i != 5 && i != 2 && i != 3) {
            this._connectedDev = str;
            if (QLog.isColorLevel()) {
                StringBuilder sb = new StringBuilder();
                sb.append(" onOutputChanage:");
                sb.append(str);
                if (this._audioManager == null) {
                    str3 = " am==null";
                } else {
                    str3 = " mode:" + this._audioManager.getMode();
                }
                sb.append(str3);
                sb.append(" st:");
                sb.append(this._streamType);
                if (this._audioTrack == null) {
                    str4 = "_audioTrack==null";
                } else {
                    str4 = " at.st:" + this._audioTrack.getStreamType();
                }
                sb.append(str4);
                QLog.w("TRAE", 2, sb.toString());
            }
            try {
                if (this._audioManager == null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (QLog.isColorLevel()) {
                    StringBuilder sb2 = new StringBuilder();
                    sb2.append(" curr mode:");
                    sb2.append(str);
                    if (this._audioManager == null) {
                        str2 = "am==null";
                    } else {
                        str2 = " mode:" + this._audioManager.getMode();
                    }
                    sb2.append(str2);
                    QLog.w("TRAE", 2, sb2.toString());
                }
                if (this._audioManager != null && this._connectedDev.equals(TraeAudioManager.DEVICE_SPEAKERPHONE)) {
                    this._audioManager.setMode(0);
                }
            } catch (Exception e) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, e.getMessage());
                }
            }
            this._audioRouteChanged = true;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:44:0x00e9, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:45:0x00ea, code lost:
        r8._prelock.unlock();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:46:0x00ef, code lost:
        throw r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00e9 A[ExcHandler: all (r0v2 'th' java.lang.Throwable A[CUSTOM_DECLARE]), Splitter:B:6:0x002d] */
    public int call_preprocess() {
        LogTraceEntry("");
        this.switchState = 0;
        this._streamType = TraeAudioManager.getAudioStreamType(this._audioStreamTypePolicy);
        if (this._as == null) {
            this._as = new TraeAudioSession(this._context, new TraeAudioSession.a() {
                /* class com.tencent.rtmp.sharp.jni.AudioDeviceInterface.AnonymousClass1 */

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(boolean z) {
                    if (!z) {
                        try {
                            AudioDeviceInterface.this._prelock.lock();
                            AudioDeviceInterface.this._preDone = true;
                            if (QLog.isColorLevel()) {
                                QLog.e("TRAE", 2, "onServiceStateUpdate signalAll");
                            }
                            AudioDeviceInterface.this._precon.signalAll();
                            AudioDeviceInterface.this._prelock.unlock();
                        } catch (Exception e) {
                        }
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String[] strArr, String str, String str2, String str3) {
                    String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                    if (AudioDeviceInterface.this.usingJava) {
                        AudioDeviceInterface.this.onOutputChanage(str);
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String[] strArr, String str, String str2, String str3) {
                    String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String str, boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String str) {
                    if (i == 0) {
                        AudioDeviceInterface.this.onOutputChanage(str);
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(int i, String str) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void c(int i, String str) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, int i2) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(int i) {
                    try {
                        AudioDeviceInterface.this._prelock.lock();
                        AudioDeviceInterface.this._preDone = true;
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "onVoicecallPreprocessRes signalAll");
                        }
                        AudioDeviceInterface.this._precon.signalAll();
                        AudioDeviceInterface.this._prelock.unlock();
                    } catch (Exception e) {
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String str, String str2) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String str, long j) {
                }
            });
        }
        this._preDone = false;
        if (this._as != null) {
            this._prelock.lock();
            try {
                if (this._audioManager == null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (this._audioManager != null) {
                    if (this._audioManager.getMode() == 2) {
                        int i = 5;
                        while (true) {
                            int i2 = i - 1;
                            if (i <= 0 || this._audioManager.getMode() != 2) {
                                break;
                            }
                            if (QLog.isColorLevel()) {
                                QLog.e("TRAE", 2, "call_preprocess waiting...  mode:" + this._audioManager.getMode());
                            }
                            Thread.sleep(500);
                            i = i2;
                        }
                    }
                    if (this._audioManager.isMicrophoneMute()) {
                        this._audioManager.setMicrophoneMute(false);
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "media call_preprocess setMicrophoneMute false");
                        }
                    }
                }
                this._as.voiceCallPreprocess(this._modePolicy, this._streamType);
                this._as.connectHighestPriorityDevice();
                int i3 = 7;
                while (true) {
                    int i4 = i3 - 1;
                    if (i3 > 0) {
                        if (this._preDone) {
                            break;
                        }
                        this._precon.await(1, TimeUnit.SECONDS);
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "call_preprocess waiting...  as:" + this._as);
                        }
                        i3 = i4;
                    } else {
                        break;
                    }
                }
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "call_preprocess done!");
                }
            } catch (InterruptedException e) {
            } catch (Throwable th) {
            }
            this._as.getConnectedDevice();
            this._prelock.unlock();
        }
        LogTraceExit();
        return 0;
    }

    public int call_postprocess() {
        LogTraceEntry("");
        this.switchState = 0;
        TraeAudioSession traeAudioSession = this._as;
        if (traeAudioSession != null) {
            traeAudioSession.voiceCallPostprocess();
            this._as.release();
            this._as = null;
        }
        TraeAudioManager.IsUpdateSceneFlag = false;
        LogTraceExit();
        return 0;
    }

    public int call_preprocess_media() {
        LogTraceEntry("");
        this.switchState = 0;
        VivoKTVHelper vivoKTVHelper = mVivoKTVHelper;
        if (vivoKTVHelper != null && isSupportVivoKTVHelper) {
            vivoKTVHelper.openKTVDevice();
            mVivoKTVHelper.setPreModeParam(1);
            mVivoKTVHelper.setPlayFeedbackParam(1);
            mVivoKTVHelper.setPlayFeedbackParam(0);
        }
        if (this._as == null) {
            this._as = new TraeAudioSession(this._context, new TraeAudioSession.a() {
                /* class com.tencent.rtmp.sharp.jni.AudioDeviceInterface.AnonymousClass2 */

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String[] strArr, String str, String str2, String str3) {
                    String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                    if (AudioDeviceInterface.this.usingJava) {
                        AudioDeviceInterface.this.onOutputChanage(str);
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String[] strArr, String str, String str2, String str3) {
                    String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String str, boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, boolean z) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, String str) {
                    if (i == 0) {
                        AudioDeviceInterface.this.onOutputChanage(str);
                    }
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(int i, String str) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void c(int i, String str) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(int i, int i2) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void b(int i) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String str, String str2) {
                }

                @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                public void a(String str, long j) {
                }
            });
        }
        if (this._as != null) {
            try {
                if (this._audioManager == null) {
                    this._audioManager = (AudioManager) this._context.getSystemService("audio");
                }
                if (this._audioManager != null) {
                    if (this._audioManager.getMode() == 2) {
                        int i = 5;
                        while (true) {
                            int i2 = i - 1;
                            if (i <= 0 || this._audioManager.getMode() != 2) {
                                break;
                            }
                            if (QLog.isColorLevel()) {
                                QLog.e("TRAE", 2, "media call_preprocess_media waiting...  mode:" + this._audioManager.getMode());
                            }
                            Thread.sleep(500);
                            i = i2;
                        }
                    }
                    if (this._audioManager.getMode() != 0) {
                        this._audioManager.setMode(0);
                    }
                    if (this._audioManager.isMicrophoneMute()) {
                        this._audioManager.setMicrophoneMute(false);
                        if (QLog.isColorLevel()) {
                            QLog.e("TRAE", 2, "media call_preprocess_media setMicrophoneMute false");
                        }
                    }
                }
                this._as.connectHighestPriorityDevice();
                this._as.getConnectedDevice();
                if (QLog.isColorLevel()) {
                    QLog.e("TRAE", 2, "call_preprocess_media done!");
                }
            } catch (InterruptedException e) {
            }
        }
        LogTraceExit();
        return 0;
    }

    public int call_postprocess_media() {
        LogTraceEntry("");
        this.switchState = 0;
        TraeAudioSession traeAudioSession = this._as;
        if (traeAudioSession != null) {
            traeAudioSession.release();
            this._as = null;
        }
        TraeAudioManager.IsUpdateSceneFlag = false;
        VivoKTVHelper vivoKTVHelper = mVivoKTVHelper;
        if (vivoKTVHelper != null && isSupportVivoKTVHelper) {
            vivoKTVHelper.closeKTVDevice();
        }
        LogTraceExit();
        return 0;
    }

    public void setJavaInterface(int i) {
        if (i == 0) {
            this.usingJava = false;
        } else {
            this.usingJava = true;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "setJavaInterface flg:" + i);
        }
    }

    private void setAudioRouteSwitchState(String str) {
        if (str.equals(TraeAudioManager.DEVICE_EARPHONE)) {
            this.switchState = 1;
        } else if (str.equals(TraeAudioManager.DEVICE_SPEAKERPHONE)) {
            this.switchState = 2;
        } else if (str.equals(TraeAudioManager.DEVICE_WIREDHEADSET)) {
            this.switchState = 3;
        } else if (str.equals(TraeAudioManager.DEVICE_BLUETOOTHHEADSET)) {
            this.switchState = 4;
        } else {
            this.switchState = 0;
        }
    }

    public int getAudioRouteSwitchState() {
        return this.switchState;
    }

    private void initTRAEAudioManager() {
        Context context = this._context;
        if (context != null) {
            TraeAudioManager.init(context);
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "initTRAEAudioManager , TraeAudioSession create");
            }
            if (this._asAudioManager == null) {
                this._asAudioManager = new TraeAudioSession(this._context, new TraeAudioSession.a() {
                    /* class com.tencent.rtmp.sharp.jni.AudioDeviceInterface.AnonymousClass3 */

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(boolean z) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(String[] strArr, String str, String str2, String str3) {
                        String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                        if (AudioDeviceInterface.this.usingJava) {
                            AudioDeviceInterface.this.onOutputChanage(str);
                        }
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void b(boolean z) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i, String[] strArr, String str, String str2, String str3) {
                        String[] unused = AudioDeviceInterface.mDeviceList = strArr;
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i, String str, boolean z) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i, boolean z) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i, String str) {
                        if (i == 0) {
                            AudioDeviceInterface.this.onOutputChanage(str);
                        }
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void b(int i, String str) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void c(int i, String str) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(int i, int i2) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void b(int i) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(String str, String str2) {
                    }

                    @Override // com.tencent.rtmp.sharp.jni.TraeAudioSession.a
                    public void a(String str, long j) {
                    }
                });
            }
            this._asAudioManager.startService(TraeAudioManager.VIDEO_CONFIG);
        }
    }

    private int startService(String str) {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "initTRAEAudioManager , TraeAudioSession startService: " + this._asAudioManager + " deviceConfig:" + str);
        }
        TraeAudioSession traeAudioSession = this._asAudioManager;
        if (traeAudioSession != null) {
            return traeAudioSession.startService(str);
        }
        return -1;
    }

    private int stopService() {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "initTRAEAudioManager , TraeAudioSession stopService: " + this._asAudioManager);
        }
        TraeAudioSession traeAudioSession = this._asAudioManager;
        if (traeAudioSession != null) {
            return traeAudioSession.stopService();
        }
        return -1;
    }

    private int SetAudioOutputMode(int i) {
        TraeAudioSession traeAudioSession;
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "TraeAudioSession SetAudioOutputMode: " + i);
        }
        if (i == 0) {
            if (mDeviceList == null || this._asAudioManager == null) {
                return -1;
            }
            boolean z = false;
            do {
                int i2 = 0;
                while (true) {
                    String[] strArr = mDeviceList;
                    if (i2 >= strArr.length || z) {
                        break;
                    } else if (TraeAudioManager.DEVICE_WIREDHEADSET.equals(strArr[i2])) {
                        this._asAudioManager.connectDevice(TraeAudioManager.DEVICE_WIREDHEADSET);
                        z = true;
                        break;
                    } else {
                        i2++;
                    }
                }
                int i3 = 0;
                while (true) {
                    String[] strArr2 = mDeviceList;
                    if (i3 >= strArr2.length || z) {
                        break;
                    } else if (TraeAudioManager.DEVICE_BLUETOOTHHEADSET.equals(strArr2[i3])) {
                        this._asAudioManager.connectDevice(TraeAudioManager.DEVICE_BLUETOOTHHEADSET);
                        z = true;
                        break;
                    } else {
                        i3++;
                    }
                }
                int i4 = 0;
                while (true) {
                    String[] strArr3 = mDeviceList;
                    if (i4 >= strArr3.length || z) {
                        break;
                    } else if (TraeAudioManager.DEVICE_EARPHONE.equals(strArr3[i4])) {
                        this._asAudioManager.connectDevice(TraeAudioManager.DEVICE_EARPHONE);
                        z = true;
                        continue;
                        break;
                    } else {
                        i4++;
                    }
                }
            } while (!z);
            return 0;
        } else if (1 != i || (traeAudioSession = this._asAudioManager) == null) {
            return -1;
        } else {
            traeAudioSession.connectDevice(TraeAudioManager.DEVICE_SPEAKERPHONE);
            return 0;
        }
    }

    private int getAndroidSdkVersion() {
        return Build.VERSION.SDK_INT;
    }

    public int hasLightSensorManager() {
        Context context = this._context;
        if (context == null) {
            return 1;
        }
        try {
            if (((SensorManager) context.getSystemService(bg.ac)).getDefaultSensor(5) != null) {
                if (QLog.isColorLevel()) {
                    QLog.w("TRAE", 2, "hasLightSensorManager");
                }
                return 1;
            } else if (!QLog.isColorLevel()) {
                return 0;
            } else {
                QLog.w("TRAE", 2, "not hasLightSensorManager null == sensor8");
                return 0;
            }
        } catch (Exception e) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, e.getMessage());
            }
            return 1;
        }
    }

    static boolean isHardcodeOpenSles() {
        if (Build.MANUFACTURER.equals("Xiaomi")) {
            if (!Build.MODEL.equals("MI 5") && !Build.MODEL.equals("MI 5s") && !Build.MODEL.equals("MI 5s Plus")) {
                return false;
            }
            return true;
        } else if (!Build.MANUFACTURER.equals("samsung") || !Build.MODEL.equals("SM-G9350")) {
            return false;
        } else {
            return true;
        }
    }

    public int getNumberOfCPUCores() {
        if (Build.VERSION.SDK_INT <= 10) {
            return 1;
        }
        try {
            return new File("/sys/devices/system/cpu/").listFiles(CPU_FILTER).length;
        } catch (NullPointerException | SecurityException e) {
            return -1;
        }
    }

    private int isSupportLowLatency() {
        if (!isHardcodeOpenSles()) {
            return 0;
        }
        if (!QLog.isColorLevel()) {
            return 1;
        }
        QLog.w("TRAE", 2, "hardcode FEATURE_AUDIO_LOW_LATENCY: " + Build.MANUFACTURER + "_" + Build.MODEL);
        return 1;
    }

    private int isSupportVivoKTVHelper() {
        Context context = this._context;
        if (context != null) {
            VivoKTVHelper instance = VivoKTVHelper.getInstance(context);
            mVivoKTVHelper = instance;
            if (instance != null) {
                isSupportVivoKTVHelper = instance.isDeviceSupportKaraoke();
            }
        }
        return isSupportVivoKTVHelper ? 1 : 0;
    }

    private int EnableVivoKTVLoopback(int i) {
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "EnableVivoKTVLoopback: " + i + " isSupportVivoKTVHelper:" + isSupportVivoKTVHelper + " mVivoKTVHelper:" + mVivoKTVHelper);
        }
        VivoKTVHelper vivoKTVHelper = mVivoKTVHelper;
        if (vivoKTVHelper == null || !isSupportVivoKTVHelper) {
            return -1;
        }
        vivoKTVHelper.setPlayFeedbackParam(i);
        return 0;
    }

    private int isVivoKTVLoopback() {
        VivoKTVHelper vivoKTVHelper = mVivoKTVHelper;
        if (vivoKTVHelper == null || !isSupportVivoKTVHelper) {
            return 0;
        }
        return vivoKTVHelper.getPlayFeedbackParam();
    }

    private void uninitTRAEAudioManager() {
        if (this._context != null) {
            if (QLog.isColorLevel()) {
                QLog.w("TRAE", 2, "uninitTRAEAudioManager , stopService");
            }
            TraeAudioSession traeAudioSession = this._asAudioManager;
            if (traeAudioSession != null) {
                traeAudioSession.stopService();
                this._asAudioManager.release();
                this._asAudioManager = null;
            }
        } else if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "uninitTRAEAudioManager , context null");
        }
    }

    private int OpenMp3File(String str, int i, int i2) {
        long j = (long) i;
        if (this._traeAudioCodecList.find(j) != null) {
            return -1;
        }
        TraeAudioCodecList.a add = this._traeAudioCodecList.add(j);
        add.b.setIOPath(str);
        add.b.setIndex(i);
        int prepare = add.b.prepare(i2);
        if (prepare == 0) {
            return 0;
        }
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "openFile mp3 Failed!!!");
        }
        add.b.release();
        add.b = null;
        this._traeAudioCodecList.remove(j);
        return prepare;
    }

    private ByteBuffer getDecBuffer(int i) {
        switch (i) {
            case 0:
                return this._decBuffer0;
            case 1:
                return this._decBuffer1;
            case 2:
                return this._decBuffer2;
            case 3:
                return this._decBuffer3;
            case 4:
                return this._decBuffer4;
            case 5:
                return this._decBuffer5;
            case 6:
                return this._decBuffer6;
            case 7:
                return this._decBuffer7;
            case 8:
                return this._decBuffer8;
            case 9:
                return this._decBuffer9;
            case 10:
                return this._decBuffer10;
            default:
                QLog.w("TRAE", 2, "getDecBuffer failed!! index:" + i);
                return null;
        }
    }

    private int ReadMp3File(int i) {
        ByteBuffer decBuffer;
        TraeAudioCodecList.a find = this._traeAudioCodecList.find((long) i);
        if (find == null || (decBuffer = getDecBuffer(i)) == null) {
            return -1;
        }
        decBuffer.rewind();
        int frameSize = find.b.getFrameSize();
        int ReadOneFrame = find.b.ReadOneFrame(find.c, frameSize);
        decBuffer.put(find.c, 0, frameSize);
        return ReadOneFrame;
    }

    private int CloseMp3File(int i) {
        long j = (long) i;
        TraeAudioCodecList.a find = this._traeAudioCodecList.find(j);
        if (find == null) {
            return -1;
        }
        find.b.release();
        find.b = null;
        this._traeAudioCodecList.remove(j);
        return 0;
    }

    private int SeekMp3To(int i, int i2) {
        TraeAudioCodecList.a find = this._traeAudioCodecList.find((long) i);
        if (find != null) {
            return find.b.SeekTo(i2);
        }
        return 0;
    }

    private int getMp3SampleRate(int i) {
        TraeAudioCodecList.a find = this._traeAudioCodecList.find((long) i);
        if (find != null) {
            return find.b.getSampleRate();
        }
        return -1;
    }

    private int getMp3Channels(int i) {
        TraeAudioCodecList.a find = this._traeAudioCodecList.find((long) i);
        if (find != null) {
            return find.b.getChannels();
        }
        return -1;
    }

    private long getMp3FileTotalMs(int i) {
        TraeAudioCodecList.a find = this._traeAudioCodecList.find((long) i);
        if (find != null) {
            return find.b.getFileTotalMs();
        }
        return -1;
    }

    public int checkAACSupported() {
        int checkAACMediaCodecSupported = checkAACMediaCodecSupported(false);
        int checkAACMediaCodecSupported2 = checkAACMediaCodecSupported(true);
        if (QLog.isColorLevel()) {
            QLog.w("TRAE", 2, "checkAACSupported isSupportEncoder: " + checkAACMediaCodecSupported + ", isSupportDecoder:" + checkAACMediaCodecSupported2);
        }
        if (checkAACMediaCodecSupported == 1 && checkAACMediaCodecSupported2 == 1) {
            return 1;
        }
        return 0;
    }

    public int checkAACMediaCodecSupported(boolean z) {
        String[] supportedTypes;
        String[] supportedTypes2;
        try {
            if (Build.VERSION.SDK_INT >= 21) {
                MediaCodecInfo[] codecInfos = new MediaCodecList(1).getCodecInfos();
                for (MediaCodecInfo mediaCodecInfo : codecInfos) {
                    if (mediaCodecInfo.isEncoder() != z) {
                        if (mediaCodecInfo.getName().toLowerCase().contains("nvidia")) {
                            return 0;
                        }
                        for (String str : mediaCodecInfo.getSupportedTypes()) {
                            if (str.equalsIgnoreCase("audio/mp4a-latm")) {
                                if (QLog.isColorLevel()) {
                                    QLog.w("TRAE", 2, "checkAACSupported support!, " + mediaCodecInfo.getName());
                                }
                                return 1;
                            }
                        }
                        continue;
                    }
                }
            } else {
                int codecCount = MediaCodecList.getCodecCount();
                for (int i = 0; i < codecCount; i++) {
                    MediaCodecInfo codecInfoAt = MediaCodecList.getCodecInfoAt(i);
                    if (codecInfoAt.isEncoder() != z) {
                        if (codecInfoAt.getName().toLowerCase().contains("nvidia")) {
                            return 0;
                        }
                        for (String str2 : codecInfoAt.getSupportedTypes()) {
                            if (str2.equalsIgnoreCase("audio/mp4a-latm")) {
                                if (QLog.isColorLevel()) {
                                    QLog.w("TRAE", 2, "checkAACSupported support!, " + codecInfoAt.getName());
                                }
                                return 1;
                            }
                        }
                        continue;
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (QLog.isColorLevel()) {
            QLog.e("TRAE", 2, "Error when checking aac codec availability");
        }
        return 0;
    }
}
