package com.umeng.umcrash;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.res.Resources;
import android.os.Build;
import android.telephony.TelephonyManager;
import android.text.TextUtils;
import com.efs.sdk.base.core.util.concurrent.WorkThreadUtil;
import com.taobao.weex.WXEnvironment;
import com.uc.crashsdk.export.CrashApi;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Random;

public class UMCrashUtils {
    private static final int DEF_CLOSE_RATE = 0;
    private static final int MAX_TRACE_RATE = 100;
    public static final String UNKNOW = "";

    public static boolean random(int rate) {
        if (rate == 0) {
            return false;
        }
        if (rate != 100 && new Random().nextInt(100) > rate) {
            return false;
        }
        return true;
    }

    public static void saveInnerConfig(Context context, String key, Object value) {
        SharedPreferences sp;
        SharedPreferences.Editor editor;
        if (context != null) {
            try {
                if (!TextUtils.isEmpty(key) && value != null && (sp = context.getSharedPreferences(UMCrashContent.KEY_SP_UMCRASH, 0)) != null && (editor = sp.edit()) != null) {
                    editor.putInt(key, Integer.parseInt(value.toString()));
                    editor.commit();
                }
            } catch (Throwable e) {
                e.printStackTrace();
            }
        }
    }

    public static int getInnerConfig(Context context, String key, int defa) {
        SharedPreferences sp;
        if (context == null) {
            return defa;
        }
        try {
            if (TextUtils.isEmpty(key) || (sp = context.getSharedPreferences(UMCrashContent.KEY_SP_UMCRASH, 0)) == null) {
                return defa;
            }
            return sp.getInt(key, defa);
        } catch (Throwable e) {
            e.printStackTrace();
            return defa;
        }
    }

    public static void setCommonTag(String key, String value) {
        Class<?> cls;
        Method method;
        try {
            Class<?> clazz = Class.forName("com.umeng.commonsdk.UMConfigure");
            if (!(clazz == null || (cls = Class.forName("com.umeng.commonsdk.UMConfigure$BS_TYPE")) == null || (method = clazz.getDeclaredMethod("setModuleTag", cls, String.class, String.class)) == null)) {
                method.setAccessible(true);
                Enum[] enumConstants = (Enum[]) cls.getEnumConstants();
                for (Enum item : enumConstants) {
                    if (item != null && item.name().equals("APM")) {
                        method.invoke(clazz, item, key, value);
                    }
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public static boolean isHarmony(final Context context) {
        try {
            final SharedPreferences sp = context.getSharedPreferences(UMCrashContent.KEY_SP_UMCRASH, 0);
            if (sp.contains("um_apm_harmony")) {
                return sp.getBoolean("um_apm_harmony", false);
            }
            WorkThreadUtil.submit(new Runnable() {
                /* class com.umeng.umcrash.UMCrashUtils.AnonymousClass1 */

                public void run() {
                    try {
                        sp.edit().putBoolean("um_apm_harmony", context.getString(Resources.getSystem().getIdentifier("config_os_brand", "string", WXEnvironment.OS)).equals("harmony")).apply();
                    } catch (Throwable th) {
                    }
                }
            });
            return false;
        } catch (Throwable th) {
            return false;
        }
    }

    public static String[] getActiveUser(Context context) {
        if (context == null) {
            return null;
        }
        Class<?> mClass = null;
        try {
            mClass = Class.forName("com.umeng.commonsdk.utils.UMUtils");
        } catch (ClassNotFoundException e) {
        }
        if (mClass == null) {
            return null;
        }
        Method umConfigMethed = null;
        try {
            umConfigMethed = mClass.getMethod("getActiveUser", Context.class);
        } catch (NoSuchMethodException e2) {
        }
        if (umConfigMethed == null) {
            return null;
        }
        try {
            Object o = umConfigMethed.invoke(null, context);
            if (o != null) {
                return (String[]) o;
            }
            return null;
        } catch (IllegalAccessException | InvocationTargetException e3) {
            return null;
        }
    }

    public static void setPuidAndProvider(String puid, String provider) {
        if (CrashApi.getInstance() != null) {
            CrashApi.getInstance().addHeaderInfo(UMCrash.KEY_HEADER_PUID, puid);
            CrashApi.getInstance().addHeaderInfo(UMCrash.KEY_HEADER_PROVIDER, provider);
        }
        HashMap<String, String> params = new HashMap<>();
        params.put(UMCrash.KEY_HEADER_PUID, puid);
        params.put(UMCrash.KEY_HEADER_PROVIDER, provider);
        if (UMCrash.getReporter() != null) {
            UMCrash.getReporter().addPublicParams(params);
        }
    }

    public static void setIntegrationTesingParams(String debugKey) {
        if (CrashApi.getInstance() != null) {
            CrashApi.getInstance().addHeaderInfo("um_dk", debugKey);
        }
        if (UMCrash.getReporter() != null) {
            HashMap<String, String> params = new HashMap<>();
            params.put("um_dk", debugKey);
            UMCrash.getReporter().addPublicParams(params);
        }
    }

    public static String getNetworkOperatorName(Context context) {
        if (context == null) {
            return "";
        }
        try {
            TelephonyManager tm = (TelephonyManager) context.getSystemService("phone");
            if (checkPermission(context, "android.permission.READ_PHONE_STATE") && tm != null) {
                return tm.getNetworkOperatorName();
            }
        } catch (Throwable th) {
        }
        return "";
    }

    public static boolean checkPermission(Context context, String permission) {
        if (context == null) {
            return false;
        }
        if (Build.VERSION.SDK_INT >= 23) {
            try {
                if (((Integer) Class.forName("android.content.Context").getMethod("checkSelfPermission", String.class).invoke(context, permission)).intValue() == 0) {
                    return true;
                }
                return false;
            } catch (Throwable th) {
                return false;
            }
        } else if (context.getPackageManager().checkPermission(permission, context.getPackageName()) == 0) {
            return true;
        } else {
            return false;
        }
    }

    public static String splitByByte(String srcStr, int length) {
        StringBuffer sb = new StringBuffer(length);
        try {
            int srcLength = srcStr.length();
            int tempLength = 0;
            for (int i = 0; i < srcLength; i++) {
                String tempStr = String.valueOf(srcStr.charAt(i));
                tempLength += tempStr.getBytes().length;
                if (length < tempLength) {
                    break;
                }
                sb.append(tempStr);
            }
        } catch (Throwable th) {
        }
        return sb.toString();
    }
}
