package com.vivo.push.util;

import android.app.Notification;
import android.app.NotificationChannel;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.media.AudioManager;
import android.os.Build;
import android.os.Bundle;
import android.os.SystemClock;
import android.text.TextUtils;
import android.widget.RemoteViews;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.igexin.push.core.b;
import com.vivo.push.b.p;
import com.vivo.push.c.d;
import com.vivo.push.d.r;
import com.vivo.push.e;
import com.vivo.push.model.InsideNotificationItem;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.Locale;

public class NotifyAdapterUtil {
    private static final int HIDE_TITLE = 1;
    public static final int NOTIFY_MULTITERM_STYLE = 1;
    public static final int NOTIFY_SINGLE_STYLE = 0;
    public static final String PRIMARY_CHANNEL = "vivo_push_channel";
    private static final String PUSH_EN = "PUSH";
    private static final String PUSH_ID = "pushId";
    private static final String PUSH_ZH = "推送通知";
    private static final String TAG = "NotifyManager";
    private static NotificationManager sNotificationManager;
    private static int sNotifyId = 20000000;

    public static void cancelNotify(Context context) {
        cancelNotify(context, sNotifyId);
    }

    private static boolean cancelNotify(Context context, int i) {
        initAdapter(context);
        NotificationManager notificationManager = sNotificationManager;
        if (notificationManager == null) {
            return false;
        }
        notificationManager.cancel(i);
        return true;
    }

    private static synchronized void initAdapter(Context context) {
        synchronized (NotifyAdapterUtil.class) {
            if (sNotificationManager == null) {
                sNotificationManager = (NotificationManager) context.getSystemService(b.n);
            }
            if (Build.VERSION.SDK_INT >= 26 && sNotificationManager != null) {
                NotificationChannel notificationChannel = sNotificationManager.getNotificationChannel("default");
                if (notificationChannel != null) {
                    CharSequence name = notificationChannel.getName();
                    if (PUSH_ZH.equals(name) || "PUSH".equals(name)) {
                        sNotificationManager.deleteNotificationChannel("default");
                    }
                }
                NotificationChannel notificationChannel2 = new NotificationChannel(PRIMARY_CHANNEL, isZh(context) ? PUSH_ZH : "PUSH", 4);
                notificationChannel2.setLightColor(-16711936);
                notificationChannel2.enableVibration(true);
                notificationChannel2.setLockscreenVisibility(1);
                sNotificationManager.createNotificationChannel(notificationChannel2);
            }
        }
    }

    private static boolean isZh(Context context) {
        return context.getResources().getConfiguration().locale.getLanguage().endsWith("zh");
    }

    public static void pushNotification(Context context, List<Bitmap> list, InsideNotificationItem insideNotificationItem, long j, int i, r.a aVar) {
        p.d(TAG, "pushNotification");
        initAdapter(context);
        int notifyMode = NotifyUtil.getNotifyDataAdapter(context).getNotifyMode(insideNotificationItem);
        if (!TextUtils.isEmpty(insideNotificationItem.getPurePicUrl()) && list != null && list.size() > 1 && list.get(1) != null) {
            notifyMode = 1;
        }
        if (notifyMode == 2) {
            pushNotificationBySystem(context, list, insideNotificationItem, j, i, aVar);
        } else if (notifyMode == 1) {
            pushNotificationByCustom(context, list, insideNotificationItem, j, aVar);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:12:0x006e  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x00ad  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x00cf  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x00fa  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0113  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x0147  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0197  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x01bd  */
    /* JADX WARNING: Removed duplicated region for block: B:62:0x01f2 A[Catch:{ Exception -> 0x0219 }] */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x024a  */
    /* JADX WARNING: Removed duplicated region for block: B:89:? A[RETURN, SYNTHETIC] */
    private static void pushNotificationByCustom(Context context, List<Bitmap> list, InsideNotificationItem insideNotificationItem, long j, r.a aVar) {
        Notification notification;
        int defaultSmallIconId;
        RemoteViews remoteViews;
        int i;
        int suitIconId;
        Bitmap bitmap;
        int notifyType;
        int i2;
        int i3;
        Bitmap bitmap2;
        Notification.Builder builder;
        Resources resources = context.getResources();
        String packageName = context.getPackageName();
        String title = insideNotificationItem.getTitle();
        int defaultNotifyIcon = NotifyUtil.getNotifyDataAdapter(context).getDefaultNotifyIcon();
        int i4 = context.getApplicationInfo().icon;
        Bundle bundle = new Bundle();
        bundle.putLong("pushId", j);
        if (Build.VERSION.SDK_INT >= 26) {
            builder = new Notification.Builder(context, PRIMARY_CHANNEL);
            if (defaultNotifyIcon > 0) {
                bundle.putInt("vivo.summaryIconRes", defaultNotifyIcon);
            }
        } else if (Build.VERSION.SDK_INT >= 19) {
            builder = new Notification.Builder(context);
        } else {
            notification = new Notification();
            notification.priority = 2;
            notification.flags = 16;
            notification.tickerText = title;
            defaultSmallIconId = NotifyUtil.getNotifyDataAdapter(context).getDefaultSmallIconId();
            if (defaultSmallIconId <= 0) {
                defaultSmallIconId = i4;
            }
            notification.icon = defaultSmallIconId;
            remoteViews = new RemoteViews(packageName, NotifyUtil.getNotifyLayoutAdapter(context).getNotificationLayout());
            remoteViews.setTextViewText(resources.getIdentifier("notify_title", "id", packageName), title);
            remoteViews.setTextColor(resources.getIdentifier("notify_title", "id", packageName), NotifyUtil.getNotifyLayoutAdapter(context).getTitleColor());
            remoteViews.setTextViewText(resources.getIdentifier("notify_msg", "id", packageName), insideNotificationItem.getContent());
            if (!insideNotificationItem.isShowTime()) {
                remoteViews.setTextViewText(resources.getIdentifier("notify_when", "id", packageName), new SimpleDateFormat("HH:mm", Locale.CHINA).format(new Date()));
                i = 0;
                remoteViews.setViewVisibility(resources.getIdentifier("notify_when", "id", packageName), 0);
            } else {
                i = 0;
                remoteViews.setViewVisibility(resources.getIdentifier("notify_when", "id", packageName), 8);
            }
            suitIconId = NotifyUtil.getNotifyLayoutAdapter(context).getSuitIconId();
            remoteViews.setViewVisibility(suitIconId, i);
            if (list != null || list.isEmpty() || (bitmap2 = list.get(i)) == null) {
                if (defaultNotifyIcon <= 0) {
                    defaultNotifyIcon = i4;
                }
                remoteViews.setImageViewResource(suitIconId, defaultNotifyIcon);
            } else {
                remoteViews.setImageViewBitmap(suitIconId, bitmap2);
            }
            bitmap = null;
            if (list != null && list.size() > 1) {
                bitmap = list.get(1);
            }
            String str = "notify_cover";
            if (bitmap == null) {
                if (!TextUtils.isEmpty(insideNotificationItem.getPurePicUrl())) {
                    remoteViews.setViewVisibility(resources.getIdentifier("notify_content", "id", packageName), 8);
                    remoteViews.setViewVisibility(resources.getIdentifier(str, "id", packageName), 8);
                    str = "notify_pure_cover";
                    i3 = resources.getIdentifier(str, "id", packageName);
                    i2 = 0;
                } else {
                    i2 = 0;
                    i3 = resources.getIdentifier(str, "id", packageName);
                }
                remoteViews.setViewVisibility(i3, i2);
                remoteViews.setImageViewBitmap(resources.getIdentifier(str, "id", packageName), bitmap);
            } else {
                remoteViews.setViewVisibility(resources.getIdentifier(str, "id", packageName), 8);
            }
            notification.contentView = remoteViews;
            if (Build.VERSION.SDK_INT >= 16 && TextUtils.isEmpty(insideNotificationItem.getPurePicUrl())) {
                notification.bigContentView = remoteViews;
            }
            AudioManager audioManager = (AudioManager) context.getSystemService("audio");
            int ringerMode = audioManager.getRingerMode();
            int vibrateSetting = audioManager.getVibrateSetting(0);
            p.d(TAG, "ringMode=" + ringerMode + " callVibrateSetting=" + vibrateSetting);
            notifyType = insideNotificationItem.getNotifyType();
            if (notifyType == 2) {
                if (notifyType != 3) {
                    if (notifyType == 4) {
                        if (ringerMode == 2) {
                            notification.defaults = 1;
                        }
                        if (vibrateSetting == 1) {
                            notification.defaults |= 2;
                            notification.vibrate = new long[]{0, 100, 200, 300};
                        }
                    }
                } else if (vibrateSetting == 1) {
                    notification.defaults = 2;
                    notification.vibrate = new long[]{0, 100, 200, 300};
                }
            } else if (ringerMode == 2) {
                notification.defaults = 1;
            }
            Intent intent = new Intent("com.vivo.pushservice.action.RECEIVE");
            intent.setPackage(context.getPackageName());
            intent.setClassName(context.getPackageName(), "com.vivo.push.sdk.service.CommandService");
            intent.putExtra("command_type", "reflect_receiver");
            intent.putExtra("security_avoid_pull", a.a(context).a("com.vivo.pushservice"));
            if (Build.VERSION.SDK_INT >= 18) {
                intent.putExtra("security_avoid_pull_rsa", d.a(context).a().a("com.vivo.pushservice"));
                intent.putExtra("security_avoid_rsa_public_key", u.a(d.a(context).a().a()));
            }
            new p(packageName, j, insideNotificationItem).b(intent);
            notification.contentIntent = PendingIntent.getService(context, (int) SystemClock.uptimeMillis(), intent, AMapEngineUtils.MAX_P20_WIDTH);
            if (sNotificationManager == null) {
                int k = e.a().k();
                if (k == 0) {
                    try {
                        sNotificationManager.notify(sNotifyId, notification);
                        if (aVar != null) {
                            aVar.a();
                            return;
                        }
                        return;
                    } catch (Exception e) {
                        p.a(TAG, e);
                        if (aVar != null) {
                            aVar.b();
                            return;
                        }
                        return;
                    }
                } else if (k == 1) {
                    sNotificationManager.notify((int) j, notification);
                    if (aVar != null) {
                        aVar.a();
                        return;
                    }
                    return;
                } else {
                    p.a(TAG, "unknow notify style ".concat(String.valueOf(k)));
                    return;
                }
            } else {
                return;
            }
        }
        builder.setExtras(bundle);
        notification = builder.build();
        notification.priority = 2;
        notification.flags = 16;
        notification.tickerText = title;
        defaultSmallIconId = NotifyUtil.getNotifyDataAdapter(context).getDefaultSmallIconId();
        if (defaultSmallIconId <= 0) {
        }
        notification.icon = defaultSmallIconId;
        remoteViews = new RemoteViews(packageName, NotifyUtil.getNotifyLayoutAdapter(context).getNotificationLayout());
        remoteViews.setTextViewText(resources.getIdentifier("notify_title", "id", packageName), title);
        remoteViews.setTextColor(resources.getIdentifier("notify_title", "id", packageName), NotifyUtil.getNotifyLayoutAdapter(context).getTitleColor());
        remoteViews.setTextViewText(resources.getIdentifier("notify_msg", "id", packageName), insideNotificationItem.getContent());
        if (!insideNotificationItem.isShowTime()) {
        }
        suitIconId = NotifyUtil.getNotifyLayoutAdapter(context).getSuitIconId();
        remoteViews.setViewVisibility(suitIconId, i);
        if (list != null) {
        }
        if (defaultNotifyIcon <= 0) {
        }
        remoteViews.setImageViewResource(suitIconId, defaultNotifyIcon);
        bitmap = null;
        bitmap = list.get(1);
        String str2 = "notify_cover";
        if (bitmap == null) {
        }
        notification.contentView = remoteViews;
        notification.bigContentView = remoteViews;
        AudioManager audioManager2 = (AudioManager) context.getSystemService("audio");
        int ringerMode2 = audioManager2.getRingerMode();
        int vibrateSetting2 = audioManager2.getVibrateSetting(0);
        p.d(TAG, "ringMode=" + ringerMode2 + " callVibrateSetting=" + vibrateSetting2);
        notifyType = insideNotificationItem.getNotifyType();
        if (notifyType == 2) {
        }
        Intent intent2 = new Intent("com.vivo.pushservice.action.RECEIVE");
        intent2.setPackage(context.getPackageName());
        intent2.setClassName(context.getPackageName(), "com.vivo.push.sdk.service.CommandService");
        intent2.putExtra("command_type", "reflect_receiver");
        try {
            intent2.putExtra("security_avoid_pull", a.a(context).a("com.vivo.pushservice"));
            if (Build.VERSION.SDK_INT >= 18) {
            }
        } catch (Exception e2) {
            p.a(TAG, "pushNotificationByCustom encrypt ：" + e2.getMessage());
        }
        new p(packageName, j, insideNotificationItem).b(intent2);
        notification.contentIntent = PendingIntent.getService(context, (int) SystemClock.uptimeMillis(), intent2, AMapEngineUtils.MAX_P20_WIDTH);
        if (sNotificationManager == null) {
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:17:0x0080, code lost:
        if (r14 != null) goto L_0x0082;
     */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x00a5  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x00b8  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00c3  */
    /* JADX WARNING: Removed duplicated region for block: B:35:0x00cf  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00d4  */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x00e9  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x011a  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x0135  */
    /* JADX WARNING: Removed duplicated region for block: B:58:0x0145  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x018a A[Catch:{ Exception -> 0x01b1 }] */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x01f1  */
    /* JADX WARNING: Removed duplicated region for block: B:89:? A[RETURN, SYNTHETIC] */
    private static void pushNotificationBySystem(Context context, List<Bitmap> list, InsideNotificationItem insideNotificationItem, long j, int i, r.a aVar) {
        String str;
        Bitmap bitmap;
        Notification.Builder builder;
        int defaultSmallIconId;
        int notifyType;
        int i2;
        Bitmap bitmap2;
        NotificationManager notificationManager;
        Bitmap decodeResource;
        String packageName = context.getPackageName();
        String title = insideNotificationItem.getTitle();
        String content = insideNotificationItem.getContent();
        int i3 = context.getApplicationInfo().icon;
        boolean isShowTime = insideNotificationItem.isShowTime();
        AudioManager audioManager = (AudioManager) context.getSystemService("audio");
        int defaultNotifyIcon = NotifyUtil.getNotifyDataAdapter(context).getDefaultNotifyIcon();
        if (list == null || list.isEmpty()) {
            str = packageName;
            bitmap = null;
        } else {
            bitmap = list.get(0);
            if (bitmap == null || defaultNotifyIcon <= 0 || (decodeResource = BitmapFactory.decodeResource(context.getResources(), defaultNotifyIcon)) == null) {
                str = packageName;
            } else {
                int width = decodeResource.getWidth();
                str = packageName;
                int height = decodeResource.getHeight();
                decodeResource.recycle();
                bitmap = c.a(bitmap, width, height);
            }
        }
        Bundle bundle = new Bundle();
        if (Build.VERSION.SDK_INT >= 26) {
            builder = new Notification.Builder(context, PRIMARY_CHANNEL);
            if (defaultNotifyIcon > 0) {
                bundle.putInt("vivo.summaryIconRes", defaultNotifyIcon);
            }
        } else {
            builder = new Notification.Builder(context);
            if (bitmap == null) {
                if (Build.VERSION.SDK_INT <= 22) {
                    builder.setLargeIcon(BitmapFactory.decodeResource(context.getResources(), i3));
                }
                if (Build.VERSION.SDK_INT >= 19) {
                    bundle.putLong("pushId", j);
                    builder.setExtras(bundle);
                }
                defaultSmallIconId = NotifyUtil.getNotifyDataAdapter(context).getDefaultSmallIconId();
                if (defaultSmallIconId > 0) {
                    i3 = defaultSmallIconId;
                }
                builder.setSmallIcon(i3);
                if (insideNotificationItem.getCompatibleType() != 1) {
                    builder.setContentTitle(title);
                }
                builder.setPriority(2);
                builder.setContentText(content);
                builder.setWhen(!isShowTime ? System.currentTimeMillis() : 0);
                builder.setShowWhen(isShowTime);
                builder.setTicker(title);
                int ringerMode = audioManager.getRingerMode();
                notifyType = insideNotificationItem.getNotifyType();
                if (notifyType == 2) {
                    if (notifyType != 3) {
                        if (notifyType == 4) {
                            if (ringerMode == 2) {
                                builder.setDefaults(3);
                                builder.setVibrate(new long[]{0, 100, 200, 300});
                            } else if (ringerMode == 1) {
                                builder.setDefaults(2);
                                builder.setVibrate(new long[]{0, 100, 200, 300});
                            }
                        }
                    } else if (ringerMode == 2) {
                        builder.setDefaults(2);
                        builder.setVibrate(new long[]{0, 100, 200, 300});
                    }
                } else if (ringerMode == 2) {
                    builder.setDefaults(1);
                }
                if (list != null || list.size() <= 1) {
                    i2 = i;
                    bitmap2 = null;
                } else {
                    bitmap2 = list.get(1);
                    i2 = i;
                }
                if (i2 != 1) {
                    Notification.BigTextStyle bigTextStyle = new Notification.BigTextStyle();
                    bigTextStyle.setBigContentTitle(title);
                    bigTextStyle.bigText(content);
                    builder.setStyle(bigTextStyle);
                }
                if (bitmap2 != null) {
                    Notification.BigPictureStyle bigPictureStyle = new Notification.BigPictureStyle();
                    bigPictureStyle.setBigContentTitle(title);
                    bigPictureStyle.setSummaryText(content);
                    bigPictureStyle.bigPicture(bitmap2);
                    builder.setStyle(bigPictureStyle);
                }
                builder.setAutoCancel(true);
                Intent intent = new Intent("com.vivo.pushservice.action.RECEIVE");
                intent.setPackage(context.getPackageName());
                intent.setClassName(context.getPackageName(), "com.vivo.push.sdk.service.CommandService");
                intent.putExtra("command_type", "reflect_receiver");
                intent.putExtra("security_avoid_pull", a.a(context).a("com.vivo.pushservice"));
                if (Build.VERSION.SDK_INT >= 18) {
                    intent.putExtra("security_avoid_pull_rsa", d.a(context).a().a("com.vivo.pushservice"));
                    intent.putExtra("security_avoid_rsa_public_key", u.a(d.a(context).a().a()));
                }
                new p(str, j, insideNotificationItem).b(intent);
                builder.setContentIntent(PendingIntent.getService(context, (int) SystemClock.uptimeMillis(), intent, AMapEngineUtils.MAX_P20_WIDTH));
                Notification build = builder.build();
                int k = e.a().k();
                notificationManager = sNotificationManager;
                if (notificationManager != null) {
                    return;
                }
                if (k == 0) {
                    try {
                        notificationManager.notify(sNotifyId, build);
                        if (aVar != null) {
                            aVar.a();
                            return;
                        }
                        return;
                    } catch (Exception e) {
                        p.a(TAG, e);
                        if (aVar != null) {
                            aVar.b();
                            return;
                        }
                        return;
                    }
                } else if (k == 1) {
                    notificationManager.notify((int) j, build);
                    if (aVar != null) {
                        aVar.a();
                        return;
                    }
                    return;
                } else {
                    p.a(TAG, "unknow notify style ".concat(String.valueOf(k)));
                    return;
                }
            }
        }
        builder.setLargeIcon(bitmap);
        if (Build.VERSION.SDK_INT >= 19) {
        }
        defaultSmallIconId = NotifyUtil.getNotifyDataAdapter(context).getDefaultSmallIconId();
        if (defaultSmallIconId > 0) {
        }
        builder.setSmallIcon(i3);
        if (insideNotificationItem.getCompatibleType() != 1) {
        }
        builder.setPriority(2);
        builder.setContentText(content);
        builder.setWhen(!isShowTime ? System.currentTimeMillis() : 0);
        builder.setShowWhen(isShowTime);
        builder.setTicker(title);
        int ringerMode2 = audioManager.getRingerMode();
        notifyType = insideNotificationItem.getNotifyType();
        if (notifyType == 2) {
        }
        if (list != null) {
        }
        i2 = i;
        bitmap2 = null;
        if (i2 != 1) {
        }
        if (bitmap2 != null) {
        }
        builder.setAutoCancel(true);
        Intent intent2 = new Intent("com.vivo.pushservice.action.RECEIVE");
        intent2.setPackage(context.getPackageName());
        intent2.setClassName(context.getPackageName(), "com.vivo.push.sdk.service.CommandService");
        intent2.putExtra("command_type", "reflect_receiver");
        try {
            intent2.putExtra("security_avoid_pull", a.a(context).a("com.vivo.pushservice"));
            if (Build.VERSION.SDK_INT >= 18) {
            }
        } catch (Exception e2) {
            p.a(TAG, "pushNotificationBySystem encrypt ：" + e2.getMessage());
        }
        new p(str, j, insideNotificationItem).b(intent2);
        builder.setContentIntent(PendingIntent.getService(context, (int) SystemClock.uptimeMillis(), intent2, AMapEngineUtils.MAX_P20_WIDTH));
        Notification build2 = builder.build();
        int k2 = e.a().k();
        notificationManager = sNotificationManager;
        if (notificationManager != null) {
        }
    }

    public static boolean repealNotifyById(Context context, long j) {
        int k = e.a().k();
        if (k == 0) {
            long b = w.b().b("com.vivo.push.notify_key", -1);
            if (b == j) {
                p.d(TAG, "undo showed message ".concat(String.valueOf(j)));
                p.a(context, "回收已展示的通知： ".concat(String.valueOf(j)));
                return cancelNotify(context, sNotifyId);
            }
            p.d(TAG, "current showing message id " + b + " not match " + j);
            p.a(context, "与已展示的通知" + b + "与待回收的通知" + j + "不匹配");
            return false;
        } else if (k == 1) {
            return cancelNotify(context, (int) j);
        } else {
            p.a(TAG, "unknow cancle notify style ".concat(String.valueOf(k)));
            return false;
        }
    }

    public static void setNotifyId(int i) {
        sNotifyId = i;
    }
}
