package com.xiaomi.mipush.sdk;

import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.SharedPreferences;
import android.content.pm.PackageInfo;
import android.content.pm.ServiceInfo;
import android.preference.PreferenceManager;
import android.text.TextUtils;
import com.heytap.mcssdk.constant.IntentConstant;
import com.taobao.weex.bridge.WXBridgeManager;
import com.umeng.analytics.pro.d;
import com.xiaomi.a.a.a;
import com.xiaomi.channel.commonutils.logger.b;
import com.xiaomi.mipush.sdk.MiTinyDataClient;
import com.xiaomi.push.am;
import com.xiaomi.push.cc;
import com.xiaomi.push.cm;
import com.xiaomi.push.cp;
import com.xiaomi.push.cq;
import com.xiaomi.push.dk;
import com.xiaomi.push.dl;
import com.xiaomi.push.dm;
import com.xiaomi.push.dv;
import com.xiaomi.push.ez;
import com.xiaomi.push.gh;
import com.xiaomi.push.gl;
import com.xiaomi.push.gm;
import com.xiaomi.push.gr;
import com.xiaomi.push.gu;
import com.xiaomi.push.gv;
import com.xiaomi.push.hb;
import com.xiaomi.push.hc;
import com.xiaomi.push.hh;
import com.xiaomi.push.hi;
import com.xiaomi.push.hm;
import com.xiaomi.push.ho;
import com.xiaomi.push.hq;
import com.xiaomi.push.ht;
import com.xiaomi.push.ib;
import com.xiaomi.push.ir;
import com.xiaomi.push.ix;
import com.xiaomi.push.k;
import com.xiaomi.push.service.ad;
import com.xiaomi.push.service.ag;
import com.xiaomi.push.service.receivers.NetworkStatusReceiver;
import com.xiaomi.push.x;
import java.lang.Thread;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.TimeZone;

public abstract class MiPushClient {
    public static final String COMMAND_REGISTER = "register";
    public static final String COMMAND_SET_ACCEPT_TIME = "accept-time";
    public static final String COMMAND_SET_ACCOUNT = "set-account";
    public static final String COMMAND_SET_ALIAS = "set-alias";
    public static final String COMMAND_SUBSCRIBE_TOPIC = "subscribe-topic";
    public static final String COMMAND_UNREGISTER = "unregister";
    public static final String COMMAND_UNSET_ACCOUNT = "unset-account";
    public static final String COMMAND_UNSET_ALIAS = "unset-alias";
    public static final String COMMAND_UNSUBSCRIBE_TOPIC = "unsubscibe-topic";
    public static final String PREF_EXTRA = "mipush_extra";
    private static Context sContext;
    private static long sCurMsgId = System.currentTimeMillis();

    public static class CodeResult {
        private long resultCode = -1;

        public long getResultCode() {
            return this.resultCode;
        }

        /* access modifiers changed from: protected */
        public void setResultCode(long j) {
            this.resultCode = j;
        }
    }

    public interface ICallbackResult<R> {
        void onResult(R r);
    }

    @Deprecated
    public static abstract class MiPushClientCallback {
        private String category;

        /* access modifiers changed from: protected */
        public String getCategory() {
            return this.category;
        }

        public void onCommandResult(String str, long j, String str2, List<String> list) {
        }

        public void onInitializeResult(long j, String str, String str2) {
        }

        public void onReceiveMessage(MiPushMessage miPushMessage) {
        }

        public void onReceiveMessage(String str, String str2, String str3, boolean z) {
        }

        public void onSubscribeResult(long j, String str, String str2) {
        }

        public void onUnsubscribeResult(long j, String str, String str2) {
        }

        /* access modifiers changed from: protected */
        public void setCategory(String str) {
            this.category = str;
        }
    }

    public static class TokenResult {
        private long resultCode = -1;
        private String token = null;

        public long getResultCode() {
            return this.resultCode;
        }

        public String getToken() {
            return this.token;
        }

        /* access modifiers changed from: protected */
        public void setResultCode(long j) {
            this.resultCode = j;
        }

        /* access modifiers changed from: protected */
        public void setToken(String str) {
            this.token = str;
        }
    }

    public interface UPSRegisterCallBack extends ICallbackResult<TokenResult> {
    }

    public interface UPSTurnCallBack extends ICallbackResult<CodeResult> {
    }

    public interface UPSUnRegisterCallBack extends ICallbackResult<TokenResult> {
    }

    private static boolean acceptTimeSet(Context context, String str, String str2) {
        String acceptTime = getAcceptTime(context);
        return TextUtils.equals(acceptTime, str + "," + str2);
    }

    public static long accountSetTime(Context context, String str) {
        return context.getSharedPreferences("mipush_extra", 0).getLong("account_".concat(String.valueOf(str)), -1);
    }

    static synchronized void addAcceptTime(Context context, String str, String str2) {
        synchronized (MiPushClient.class) {
            SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
            edit.putString(Constants.EXTRA_KEY_ACCEPT_TIME, str + "," + str2);
            edit.apply();
        }
    }

    static synchronized void addAccount(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().putLong("account_".concat(String.valueOf(str)), System.currentTimeMillis()).commit();
        }
    }

    static synchronized void addAlias(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().putLong("alias_".concat(String.valueOf(str)), System.currentTimeMillis()).commit();
        }
    }

    private static void addPullNotificationTime(Context context) {
        SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
        edit.putLong("last_pull_notification", System.currentTimeMillis());
        edit.apply();
    }

    private static void addRegRequestTime(Context context) {
        SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
        edit.putLong("last_reg_request", System.currentTimeMillis());
        edit.apply();
    }

    static synchronized void addTopic(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().putLong("topic_".concat(String.valueOf(str)), System.currentTimeMillis()).commit();
        }
    }

    public static long aliasSetTime(Context context, String str) {
        return context.getSharedPreferences("mipush_extra", 0).getLong("alias_".concat(String.valueOf(str)), -1);
    }

    public static void awakeApps(final Context context, final String[] strArr) {
        k.a(context).a(new Runnable() {
            /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass4 */

            public final void run() {
                PackageInfo packageInfo;
                try {
                    String[] strArr = strArr;
                    for (String str : strArr) {
                        if (!TextUtils.isEmpty(str) && (packageInfo = context.getPackageManager().getPackageInfo(str, 4)) != null) {
                            MiPushClient.awakePushServiceByPackageInfo(context, packageInfo);
                        }
                    }
                } catch (Throwable th) {
                    b.a(th);
                }
            }
        }, 0);
    }

    /* access modifiers changed from: private */
    public static void awakePushServiceByPackageInfo(Context context, PackageInfo packageInfo) {
        ServiceInfo[] serviceInfoArr = packageInfo.services;
        if (serviceInfoArr != null) {
            for (ServiceInfo serviceInfo : serviceInfoArr) {
                if (serviceInfo.exported && serviceInfo.enabled && "com.xiaomi.mipush.sdk.PushMessageHandler".equals(serviceInfo.name) && !context.getPackageName().equals(serviceInfo.packageName)) {
                    try {
                        Thread.sleep(((long) ((Math.random() * 2.0d) + 1.0d)) * 1000);
                        Intent intent = new Intent();
                        intent.setClassName(serviceInfo.packageName, serviceInfo.name);
                        intent.setAction("com.xiaomi.mipush.sdk.WAKEUP");
                        intent.putExtra("waker_pkgname", context.getPackageName());
                        PushMessageHandler.a(context, intent);
                        return;
                    } catch (Throwable th) {
                        return;
                    }
                }
            }
        }
    }

    private static void checkNotNull(Object obj, String str) {
        if (obj == null) {
            throw new IllegalArgumentException("param " + str + " is not nullable");
        }
    }

    protected static void clearExtras(Context context) {
        SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
        edit.clear();
        edit.commit();
    }

    private static void clearExtrasForInitialize(Context context) {
        SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
        for (String str : getAllAlias(context)) {
            edit.remove("alias_".concat(String.valueOf(str)));
        }
        for (String str2 : getAllUserAccount(context)) {
            edit.remove("account_".concat(String.valueOf(str2)));
        }
        for (String str3 : getAllTopic(context)) {
            edit.remove("topic_".concat(String.valueOf(str3)));
        }
        edit.remove(Constants.EXTRA_KEY_ACCEPT_TIME);
        edit.commit();
    }

    public static void clearLocalNotificationType(Context context) {
        ao.a(context).f();
    }

    public static void clearNotification(Context context) {
        ao.a(context).a(-1);
    }

    public static void clearNotification(Context context, int i) {
        ao.a(context).a(i);
    }

    public static void clearNotification(Context context, String str, String str2) {
        ao.a(context).a(str, str2);
    }

    public static void disablePush(Context context) {
        ao.a(context).a(true);
    }

    public static void enablePush(Context context) {
        ao.a(context).a(false);
    }

    protected static String getAcceptTime(Context context) {
        return context.getSharedPreferences("mipush_extra", 0).getString(Constants.EXTRA_KEY_ACCEPT_TIME, "00:00-23:59");
    }

    public static List<String> getAllAlias(Context context) {
        ArrayList arrayList = new ArrayList();
        for (String str : context.getSharedPreferences("mipush_extra", 0).getAll().keySet()) {
            if (str.startsWith("alias_")) {
                arrayList.add(str.substring(6));
            }
        }
        return arrayList;
    }

    public static List<String> getAllTopic(Context context) {
        ArrayList arrayList = new ArrayList();
        for (String str : context.getSharedPreferences("mipush_extra", 0).getAll().keySet()) {
            if (str.startsWith("topic_") && !str.contains("**ALL**")) {
                arrayList.add(str.substring(6));
            }
        }
        return arrayList;
    }

    public static List<String> getAllUserAccount(Context context) {
        ArrayList arrayList = new ArrayList();
        for (String str : context.getSharedPreferences("mipush_extra", 0).getAll().keySet()) {
            if (str.startsWith("account_")) {
                arrayList.add(str.substring(8));
            }
        }
        return arrayList;
    }

    public static String getAppRegion(Context context) {
        if (b.m29a(context).m38c()) {
            return b.m29a(context).f();
        }
        return null;
    }

    private static boolean getDefaultSwitch() {
        return ib.b();
    }

    protected static boolean getOpenFCMPush(Context context) {
        checkNotNull(context, d.R);
        return f.a(context).b(e.ASSEMBLE_PUSH_FCM);
    }

    protected static boolean getOpenHmsPush(Context context) {
        checkNotNull(context, d.R);
        return f.a(context).b(e.ASSEMBLE_PUSH_HUAWEI);
    }

    protected static boolean getOpenOPPOPush(Context context) {
        checkNotNull(context, d.R);
        return f.a(context).b(e.ASSEMBLE_PUSH_COS);
    }

    protected static boolean getOpenVIVOPush(Context context) {
        return f.a(context).b(e.ASSEMBLE_PUSH_FTOS);
    }

    public static String getRegId(Context context) {
        if (b.m29a(context).m38c()) {
            return b.m29a(context).m37c();
        }
        return null;
    }

    private static void initEventPerfLogic(final Context context) {
        dm.a(new dm.a() {
            /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass5 */

            @Override // com.xiaomi.push.dm.a
            public final void uploader(Context context, gl glVar) {
                MiTinyDataClient.upload(context, glVar);
            }
        });
        a b = dm.b(context);
        com.xiaomi.a.b.b.a(context).f = "5_0_1-C";
        com.xiaomi.a.b.a.a(context, b, new dk(context), new dl(context));
        a.a(context);
        t.a(context, b);
        ad.a(context).a(new ad.a(100, "perf event job update") {
            /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass6 */

            @Override // com.xiaomi.push.service.ad.a
            public final void onCallback() {
                dm.a(context);
            }
        });
    }

    @Deprecated
    public static void initialize(Context context, String str, String str2, MiPushClientCallback miPushClientCallback) {
        initialize(context, str, str2, miPushClientCallback, null, null);
    }

    /* access modifiers changed from: private */
    public static void initialize(Context context, String str, String str2, MiPushClientCallback miPushClientCallback, String str3, ICallbackResult iCallbackResult) {
        try {
            b.a(context.getApplicationContext());
            b.f("sdk_version = 5_0_1-C");
            x.a(context);
            cc.a();
            if (miPushClientCallback != null) {
                PushMessageHandler.a(miPushClientCallback);
            }
            if (iCallbackResult != null) {
                PushMessageHandler.a(iCallbackResult);
            }
            if (ix.b(sContext)) {
                v.a(sContext);
            }
            boolean z = b.m29a(sContext).a() != Constants.a();
            if (z || shouldSendRegRequest(sContext)) {
                if (z || !b.m29a(sContext).a(str, str2) || b.m29a(sContext).m41f()) {
                    String a = am.a(6);
                    b.m29a(sContext).m31a();
                    b.m29a(sContext).a(Constants.a());
                    b.m29a(sContext).a(str, str2, a);
                    MiTinyDataClient.a.a().b(MiTinyDataClient.PENDING_REASON_APPID);
                    clearExtras(sContext);
                    clearNotification(context);
                    hi hiVar = new hi();
                    hiVar.c = ag.b();
                    hiVar.d = str;
                    hiVar.g = str2;
                    hiVar.f = sContext.getPackageName();
                    hiVar.h = a;
                    Context context2 = sContext;
                    hiVar.e = ez.a(context2, context2.getPackageName());
                    Context context3 = sContext;
                    hiVar.a(ez.b(context3, context3.getPackageName()));
                    hiVar.l = "5_0_1-C";
                    hiVar.a();
                    hiVar.t = gv.Init;
                    if (!TextUtils.isEmpty(str3)) {
                        hiVar.i = str3;
                    }
                    if (!ib.f()) {
                        hb.b();
                        if (!TextUtils.isEmpty(null)) {
                            hiVar.r = am.a((String) null) + "," + hb.d();
                        }
                    }
                    int e = hb.e();
                    if (e >= 0) {
                        hiVar.b(e);
                    }
                    ao.a(sContext).a(hiVar, z);
                    sContext.getSharedPreferences("mipush_extra", 4).getBoolean("mipush_registed", true);
                } else {
                    if (1 == PushMessageHelper.getPushMode(sContext)) {
                        checkNotNull(miPushClientCallback, WXBridgeManager.METHOD_CALLBACK);
                        miPushClientCallback.onInitializeResult(0, null, b.m29a(sContext).m37c());
                    } else {
                        ArrayList arrayList = new ArrayList();
                        arrayList.add(b.m29a(sContext).m37c());
                        PushMessageHelper.sendCommandMessageBroadcast(sContext, PushMessageHelper.generateCommandMessage(dv.COMMAND_REGISTER.k, arrayList, 0, null, null, null));
                    }
                    ao.a(sContext).m19a();
                    if (b.m29a(sContext).m33a()) {
                        hh hhVar = new hh();
                        hhVar.d = b.m29a(sContext).m30a();
                        hhVar.e = gr.ClientInfoUpdate.ah;
                        hhVar.c = ag.a();
                        hhVar.h = new HashMap();
                        Map<String, String> map = hhVar.h;
                        Context context4 = sContext;
                        map.put("app_version", ez.a(context4, context4.getPackageName()));
                        Map<String, String> map2 = hhVar.h;
                        Context context5 = sContext;
                        map2.put(Constants.EXTRA_KEY_APP_VERSION_CODE, Integer.toString(ez.b(context5, context5.getPackageName())));
                        hhVar.h.put("push_sdk_vn", "5_0_1-C");
                        hhVar.h.put("push_sdk_vc", Integer.toString(50001));
                        String e2 = b.m29a(sContext).e();
                        if (!TextUtils.isEmpty(e2)) {
                            hhVar.h.put("deviceid", e2);
                        }
                        ao.a(sContext).a((ht) hhVar, gh.Notification, false, (gu) null);
                        ao.a(sContext).m20a(sContext);
                    }
                    if (!PreferenceManager.getDefaultSharedPreferences(sContext).getBoolean("update_devId", false)) {
                        updateImeiOrOaid();
                        PreferenceManager.getDefaultSharedPreferences(sContext).edit().putBoolean("update_devId", true).commit();
                    }
                    if (shouldUseMIUIPush(sContext) && shouldPullNotification(sContext)) {
                        hh hhVar2 = new hh();
                        hhVar2.d = b.m29a(sContext).m30a();
                        hhVar2.e = gr.PullOfflineMessage.ah;
                        hhVar2.c = ag.a();
                        hhVar2.a(false);
                        ao.a(sContext).a((ht) hhVar2, gh.Notification, false, (gu) null, false);
                        addPullNotificationTime(sContext);
                    }
                }
                addRegRequestTime(sContext);
                scheduleOcVersionCheckJob();
                scheduleDataCollectionJobs(sContext);
                initEventPerfLogic(sContext);
                av.a(sContext);
                if (!sContext.getPackageName().equals("com.xiaomi.xmsf")) {
                    if (Logger.getUserLogger() != null) {
                        Logger.setLogger(sContext, Logger.getUserLogger());
                    }
                    b.a();
                }
                operateSyncAction(context);
                return;
            }
            ao.a(sContext).m19a();
            b.a("Could not send  register message within 5s repeatly .");
        } catch (Throwable th) {
            b.a(th);
        }
    }

    private static void operateSyncAction(Context context) {
        if ("syncing".equals(af.a(sContext).a(au.DISABLE_PUSH))) {
            disablePush(sContext);
        }
        if ("syncing".equals(af.a(sContext).a(au.ENABLE_PUSH))) {
            enablePush(sContext);
        }
        if ("syncing".equals(af.a(sContext).a(au.UPLOAD_HUAWEI_TOKEN))) {
            ao.a(sContext).a((String) null, au.UPLOAD_HUAWEI_TOKEN, e.ASSEMBLE_PUSH_HUAWEI, "init");
        }
        if ("syncing".equals(af.a(sContext).a(au.UPLOAD_FCM_TOKEN))) {
            syncAssembleFCMPushToken(sContext);
        }
        if ("syncing".equals(af.a(sContext).a(au.UPLOAD_COS_TOKEN))) {
            ao.a(sContext).a((String) null, au.UPLOAD_COS_TOKEN, e.ASSEMBLE_PUSH_COS, "init");
        }
        if ("syncing".equals(af.a(sContext).a(au.UPLOAD_FTOS_TOKEN))) {
            ao.a(context).a((String) null, au.UPLOAD_FTOS_TOKEN, e.ASSEMBLE_PUSH_FTOS, "init");
        }
    }

    public static void pausePush(Context context, String str) {
        setAcceptTime(context, 0, 0, 0, 0, str);
    }

    static void reInitialize(Context context, gv gvVar) {
        b.f("re-register reason: ".concat(String.valueOf(gvVar)));
        String a = am.a(6);
        String a2 = b.m29a(context).m30a();
        String b = b.m29a(context).b();
        b.m29a(context).m31a();
        clearExtrasForInitialize(context);
        clearNotification(context);
        b.m29a(context).a(Constants.a());
        b.m29a(context).a(a2, b, a);
        hi hiVar = new hi();
        hiVar.c = ag.b();
        hiVar.d = a2;
        hiVar.g = b;
        hiVar.h = a;
        hiVar.f = context.getPackageName();
        hiVar.e = ez.a(context, context.getPackageName());
        hiVar.a(ez.b(context, context.getPackageName()));
        hiVar.l = "5_0_1-C";
        hiVar.a();
        hiVar.t = gvVar;
        int e = hb.e();
        if (e >= 0) {
            hiVar.b(e);
        }
        ao.a(context).a(hiVar, false);
    }

    @Deprecated
    public static void registerCrashHandler(Thread.UncaughtExceptionHandler uncaughtExceptionHandler) {
        Thread.setDefaultUncaughtExceptionHandler(uncaughtExceptionHandler);
    }

    private static void registerNetworkReceiver(Context context) {
        try {
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction("android.net.conn.CONNECTIVITY_CHANGE");
            intentFilter.addCategory("android.intent.category.DEFAULT");
            ir.a(context.getApplicationContext(), new NetworkStatusReceiver(null), intentFilter);
            ir.a(context, NetworkStatusReceiver.class);
        } catch (Throwable th) {
            b.a("dynamic register network status receiver failed:".concat(String.valueOf(th)));
        }
    }

    public static void registerPush(Context context, String str, String str2) {
        registerPush(context, str, str2, new PushConfiguration());
    }

    public static void registerPush(Context context, String str, String str2, PushConfiguration pushConfiguration) {
        registerPush(context, str, str2, pushConfiguration, null, null);
    }

    private static void registerPush(Context context, final String str, final String str2, PushConfiguration pushConfiguration, final String str3, final ICallbackResult iCallbackResult) {
        checkNotNull(context, d.R);
        checkNotNull(str, IntentConstant.APP_ID);
        checkNotNull(str2, "appToken");
        Context applicationContext = context.getApplicationContext();
        sContext = applicationContext;
        if (applicationContext == null) {
            sContext = context;
        }
        Context context2 = sContext;
        ix.a(context2);
        if (!NetworkStatusReceiver.a()) {
            registerNetworkReceiver(sContext);
        }
        f.a(sContext).a(pushConfiguration);
        k.a(context2).a(new Runnable() {
            /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass1 */

            public final void run() {
                MiPushClient.initialize(MiPushClient.sContext, str, str2, null, str3, iCallbackResult);
            }
        }, 0);
    }

    public static void registerPush(Context context, String str, String str2, String str3) {
        registerPush(context, str, str2, new PushConfiguration(), str3, null);
    }

    public static void registerToken(Context context, String str, String str2, String str3, UPSRegisterCallBack uPSRegisterCallBack) {
        registerPush(context, str, str2, new PushConfiguration(), null, uPSRegisterCallBack);
    }

    static synchronized void removeAcceptTime(Context context) {
        synchronized (MiPushClient.class) {
            SharedPreferences.Editor edit = context.getSharedPreferences("mipush_extra", 0).edit();
            edit.remove(Constants.EXTRA_KEY_ACCEPT_TIME);
            edit.apply();
        }
    }

    static synchronized void removeAccount(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().remove("account_".concat(String.valueOf(str))).commit();
        }
    }

    static synchronized void removeAlias(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().remove("alias_".concat(String.valueOf(str))).commit();
        }
    }

    static synchronized void removeAllAccounts(Context context) {
        synchronized (MiPushClient.class) {
            for (String str : getAllUserAccount(context)) {
                removeAccount(context, str);
            }
        }
    }

    static synchronized void removeAllAliases(Context context) {
        synchronized (MiPushClient.class) {
            for (String str : getAllAlias(context)) {
                removeAlias(context, str);
            }
        }
    }

    static synchronized void removeAllTopics(Context context) {
        synchronized (MiPushClient.class) {
            for (String str : getAllTopic(context)) {
                removeTopic(context, str);
            }
        }
    }

    static synchronized void removeTopic(Context context, String str) {
        synchronized (MiPushClient.class) {
            context.getSharedPreferences("mipush_extra", 0).edit().remove("topic_".concat(String.valueOf(str))).commit();
        }
    }

    public static void removeWindow(Context context) {
        ao.a(context).m28e();
    }

    public static void reportAppRunInBackground(Context context, boolean z) {
        if (b.m29a(context).m36b()) {
            gr grVar = z ? gr.APP_SLEEP : gr.APP_WAKEUP;
            hh hhVar = new hh();
            hhVar.d = b.m29a(context).m30a();
            hhVar.e = grVar.ah;
            hhVar.i = context.getPackageName();
            hhVar.c = ag.a();
            hhVar.a(false);
            ao.a(context).a((ht) hhVar, gh.Notification, false, (gu) null, false);
        }
    }

    static void reportIgnoreRegMessageClicked(Context context, String str, gu guVar, String str2, String str3) {
        hh hhVar = new hh();
        if (TextUtils.isEmpty(str3)) {
            b.d("do not report clicked message");
            return;
        }
        hhVar.d = str3;
        hhVar.e = "bar:click";
        hhVar.c = str;
        hhVar.a(false);
        ao.a(context).a(hhVar, gh.Notification, false, true, guVar, true, str2, str3);
    }

    public static void reportMessageClicked(Context context, MiPushMessage miPushMessage) {
        gu guVar = new gu();
        guVar.a = miPushMessage.getMessageId();
        guVar.c = miPushMessage.getTopic();
        guVar.e = miPushMessage.getDescription();
        guVar.d = miPushMessage.getTitle();
        guVar.c(miPushMessage.getNotifyId());
        guVar.a(miPushMessage.getNotifyType());
        guVar.b(miPushMessage.getPassThrough());
        guVar.j = miPushMessage.getExtra();
        reportMessageClicked(context, miPushMessage.getMessageId(), guVar, null);
    }

    @Deprecated
    public static void reportMessageClicked(Context context, String str) {
        reportMessageClicked(context, str, null, null);
    }

    static void reportMessageClicked(Context context, String str, gu guVar, String str2) {
        hh hhVar = new hh();
        if (TextUtils.isEmpty(str2)) {
            if (b.m29a(context).m36b()) {
                str2 = b.m29a(context).m30a();
            } else {
                b.d("do not report clicked message");
                return;
            }
        }
        hhVar.d = str2;
        hhVar.e = "bar:click";
        hhVar.c = str;
        hhVar.a(false);
        ao.a(context).a((ht) hhVar, gh.Notification, false, guVar);
    }

    public static void resumePush(Context context, String str) {
        setAcceptTime(context, 0, 0, 23, 59, str);
    }

    private static void scheduleDataCollectionJobs(Context context) {
        if (ad.a(sContext).a(gm.DataCollectionSwitch.bw, getDefaultSwitch())) {
            cm.a().a = new r(context);
            k.a(sContext).a(new Runnable() {
                /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass2 */

                public final void run() {
                    cp a = cp.a(MiPushClient.sContext);
                    k.a(a.a).a(new cq(a), 0);
                }
            }, 10);
        }
    }

    private static void scheduleOcVersionCheckJob() {
        k.a(sContext).a(new ae(sContext), ad.a(sContext).a(gm.OcVersionCheckFrequency.bw, 86400), 5);
    }

    public static void setAcceptTime(Context context, int i, int i2, int i3, int i4, String str) {
        if (i < 0 || i >= 24 || i3 < 0 || i3 >= 24 || i2 < 0 || i2 >= 60 || i4 < 0 || i4 >= 60) {
            throw new IllegalArgumentException("the input parameter is not valid.");
        }
        long rawOffset = (long) (((TimeZone.getTimeZone("GMT+08").getRawOffset() - TimeZone.getDefault().getRawOffset()) / 1000) / 60);
        long j = ((((long) ((i * 60) + i2)) + rawOffset) + 1440) % 1440;
        long j2 = ((((long) ((i3 * 60) + i4)) + rawOffset) + 1440) % 1440;
        ArrayList arrayList = new ArrayList();
        arrayList.add(String.format("%1$02d:%2$02d", Long.valueOf(j / 60), Long.valueOf(j % 60)));
        arrayList.add(String.format("%1$02d:%2$02d", Long.valueOf(j2 / 60), Long.valueOf(j2 % 60)));
        ArrayList arrayList2 = new ArrayList();
        arrayList2.add(String.format("%1$02d:%2$02d", Integer.valueOf(i), Integer.valueOf(i2)));
        arrayList2.add(String.format("%1$02d:%2$02d", Integer.valueOf(i3), Integer.valueOf(i4)));
        if (!acceptTimeSet(context, (String) arrayList.get(0), (String) arrayList.get(1))) {
            setCommand(context, dv.COMMAND_SET_ACCEPT_TIME.k, arrayList, str);
        } else if (1 == PushMessageHelper.getPushMode(context)) {
            PushMessageHandler.a(context, str, dv.COMMAND_SET_ACCEPT_TIME.k, 0, null, arrayList2);
        } else {
            PushMessageHelper.sendCommandMessageBroadcast(context, PushMessageHelper.generateCommandMessage(dv.COMMAND_SET_ACCEPT_TIME.k, arrayList2, 0, null, null, null));
        }
    }

    public static void setAlias(Context context, String str, String str2) {
        if (!TextUtils.isEmpty(str)) {
            setCommand(context, dv.COMMAND_SET_ALIAS.k, str, str2);
        }
    }

    protected static void setCommand(Context context, String str, String str2, String str3) {
        ArrayList arrayList = new ArrayList();
        if (!TextUtils.isEmpty(str2)) {
            arrayList.add(str2);
        }
        if (!dv.COMMAND_SET_ALIAS.k.equalsIgnoreCase(str) || Math.abs(System.currentTimeMillis() - aliasSetTime(context, str2)) >= 86400000) {
            if (dv.COMMAND_UNSET_ALIAS.k.equalsIgnoreCase(str) && aliasSetTime(context, str2) < 0) {
                b.a("Don't cancel alias for " + am.a(arrayList.toString(), 3) + " is unseted");
            } else if (!dv.COMMAND_SET_ACCOUNT.k.equalsIgnoreCase(str) || Math.abs(System.currentTimeMillis() - accountSetTime(context, str2)) >= 3600000) {
                if (!dv.COMMAND_UNSET_ACCOUNT.k.equalsIgnoreCase(str) || accountSetTime(context, str2) >= 0) {
                    setCommand(context, str, arrayList, str3);
                    return;
                }
                b.a("Don't cancel account for " + am.a(arrayList.toString(), 3) + " is unseted");
            } else if (1 == PushMessageHelper.getPushMode(context)) {
                PushMessageHandler.a(context, str3, str, 0, null, arrayList);
            } else {
                PushMessageHelper.sendCommandMessageBroadcast(context, PushMessageHelper.generateCommandMessage(dv.COMMAND_SET_ACCOUNT.k, arrayList, 0, null, str3, null));
            }
        } else if (1 == PushMessageHelper.getPushMode(context)) {
            PushMessageHandler.a(context, str3, str, 0, null, arrayList);
        } else {
            PushMessageHelper.sendCommandMessageBroadcast(context, PushMessageHelper.generateCommandMessage(dv.COMMAND_SET_ALIAS.k, arrayList, 0, null, str3, null));
        }
    }

    protected static void setCommand(Context context, String str, ArrayList<String> arrayList, String str2) {
        if (!TextUtils.isEmpty(b.m29a(context).m30a())) {
            hc hcVar = new hc();
            String a = ag.a();
            hcVar.b = a;
            hcVar.c = b.m29a(context).m30a();
            hcVar.d = str;
            Iterator<String> it = arrayList.iterator();
            while (it.hasNext()) {
                String next = it.next();
                if (hcVar.e == null) {
                    hcVar.e = new ArrayList();
                }
                hcVar.e.add(next);
            }
            hcVar.g = str2;
            hcVar.f = context.getPackageName();
            b.f("cmd:" + str + ", " + a);
            ao.a(context).a(hcVar, gh.Command, (gu) null);
        }
    }

    public static void setLocalNotificationType(Context context, int i) {
        ao.a(context).b(i & -1);
    }

    public static void setUserAccount(Context context, String str, String str2) {
        if (!TextUtils.isEmpty(str)) {
            setCommand(context, dv.COMMAND_SET_ACCOUNT.k, str, str2);
        }
    }

    private static boolean shouldPullNotification(Context context) {
        return Math.abs(System.currentTimeMillis() - context.getSharedPreferences("mipush_extra", 0).getLong("last_pull_notification", -1)) > 300000;
    }

    private static boolean shouldSendRegRequest(Context context) {
        return Math.abs(System.currentTimeMillis() - context.getSharedPreferences("mipush_extra", 0).getLong("last_reg_request", -1)) > 5000;
    }

    public static boolean shouldUseMIUIPush(Context context) {
        return ao.a(context).m22a();
    }

    public static void subscribe(Context context, String str, String str2) {
        if (!TextUtils.isEmpty(b.m29a(context).m30a()) && !TextUtils.isEmpty(str)) {
            if (Math.abs(System.currentTimeMillis() - topicSubscribedTime(context, str)) > 86400000) {
                hm hmVar = new hm();
                String a = ag.a();
                hmVar.c = a;
                hmVar.d = b.m29a(context).m30a();
                hmVar.e = str;
                hmVar.f = context.getPackageName();
                hmVar.g = str2;
                b.f("cmd:" + dv.COMMAND_SUBSCRIBE_TOPIC + ", " + a);
                ao.a(context).a(hmVar, gh.Subscription, (gu) null);
            } else if (1 == PushMessageHelper.getPushMode(context)) {
                PushMessageHandler.a(context, str2, 0, null, str);
            } else {
                ArrayList arrayList = new ArrayList();
                arrayList.add(str);
                PushMessageHelper.sendCommandMessageBroadcast(context, PushMessageHelper.generateCommandMessage(dv.COMMAND_SUBSCRIBE_TOPIC.k, arrayList, 0, null, null, null));
            }
        }
    }

    @Deprecated
    public static void syncAssembleCOSPushToken(Context context) {
    }

    public static void syncAssembleFCMPushToken(Context context) {
        ao.a(context).a((String) null, au.UPLOAD_FCM_TOKEN, e.ASSEMBLE_PUSH_FCM, "");
    }

    @Deprecated
    public static void syncAssembleFTOSPushToken(Context context) {
    }

    @Deprecated
    public static void syncAssemblePushToken(Context context) {
    }

    public static long topicSubscribedTime(Context context, String str) {
        return context.getSharedPreferences("mipush_extra", 0).getLong("topic_".concat(String.valueOf(str)), -1);
    }

    public static void turnOffPush(Context context, UPSTurnCallBack uPSTurnCallBack) {
        disablePush(context);
        if (uPSTurnCallBack != null) {
            CodeResult codeResult = new CodeResult();
            codeResult.setResultCode(0);
            codeResult.getResultCode();
            uPSTurnCallBack.onResult(codeResult);
        }
    }

    public static void turnOnPush(Context context, UPSTurnCallBack uPSTurnCallBack) {
        enablePush(context);
        if (uPSTurnCallBack != null) {
            CodeResult codeResult = new CodeResult();
            codeResult.setResultCode(0);
            codeResult.getResultCode();
            uPSTurnCallBack.onResult(codeResult);
        }
    }

    public static void unRegisterToken(Context context, UPSUnRegisterCallBack uPSUnRegisterCallBack) {
        unregisterPush(context);
        if (uPSUnRegisterCallBack != null) {
            TokenResult tokenResult = new TokenResult();
            tokenResult.setToken(null);
            tokenResult.getToken();
            tokenResult.setResultCode(0);
            tokenResult.getResultCode();
            uPSUnRegisterCallBack.onResult(tokenResult);
        }
    }

    public static void unregisterPush(Context context) {
        i.c(context);
        ad.a(context).a();
        if (b.m29a(context).m36b()) {
            ho hoVar = new ho();
            hoVar.c = ag.a();
            hoVar.d = b.m29a(context).m30a();
            hoVar.e = b.m29a(context).m37c();
            hoVar.h = b.m29a(context).b();
            hoVar.g = context.getPackageName();
            ao.a(context).a(hoVar);
            PushMessageHandler.a();
            PushMessageHandler.b();
            b.m29a(context).m35b();
            clearLocalNotificationType(context);
            clearNotification(context);
            clearExtras(context);
        }
    }

    public static void unsetAlias(Context context, String str, String str2) {
        setCommand(context, dv.COMMAND_UNSET_ALIAS.k, str, str2);
    }

    public static void unsetUserAccount(Context context, String str, String str2) {
        setCommand(context, dv.COMMAND_UNSET_ACCOUNT.k, str, str2);
    }

    public static void unsubscribe(Context context, String str, String str2) {
        if (b.m29a(context).m36b()) {
            if (topicSubscribedTime(context, str) < 0) {
                b.a("Don't cancel subscribe for " + str + " is unsubscribed");
                return;
            }
            hq hqVar = new hq();
            String a = ag.a();
            hqVar.c = a;
            hqVar.d = b.m29a(context).m30a();
            hqVar.e = str;
            hqVar.f = context.getPackageName();
            hqVar.g = str2;
            b.f("cmd:" + dv.COMMAND_UNSUBSCRIBE_TOPIC + ", " + a);
            ao.a(context).a(hqVar, gh.UnSubscription, (gu) null);
        }
    }

    private static void updateImeiOrOaid() {
        new Thread(new Runnable() {
            /* class com.xiaomi.mipush.sdk.MiPushClient.AnonymousClass3 */

            public final void run() {
                if (!ib.f()) {
                    Context unused = MiPushClient.sContext;
                    hb.a();
                    if (x.a(MiPushClient.sContext).a()) {
                        hh hhVar = new hh();
                        hhVar.d = b.m29a(MiPushClient.sContext).m30a();
                        hhVar.e = gr.ClientInfoUpdate.ah;
                        hhVar.c = ag.a();
                        hhVar.h = new HashMap();
                        String str = "";
                        Context unused2 = MiPushClient.sContext;
                        hb.a();
                        if (!TextUtils.isEmpty(null)) {
                            str = str + am.a((String) null);
                        }
                        Context unused3 = MiPushClient.sContext;
                        hb.c();
                        if (!TextUtils.isEmpty(str) && !TextUtils.isEmpty(null)) {
                            str = str + "," + ((String) null);
                        }
                        if (!TextUtils.isEmpty(str)) {
                            hhVar.h.put(Constants.EXTRA_KEY_IMEI_MD5, str);
                        }
                        x.a(MiPushClient.sContext).a(hhVar.h);
                        int e = hb.e();
                        if (e >= 0) {
                            hhVar.h.put("space_id", Integer.toString(e));
                        }
                        ao.a(MiPushClient.sContext).a((ht) hhVar, gh.Notification, false, (gu) null);
                    }
                }
            }
        }).start();
    }
}
