package com.xiaomi.mipush.sdk;

import android.content.Context;
import android.content.Intent;
import android.content.pm.ResolveInfo;
import android.text.TextUtils;
import com.xiaomi.push.gu;
import com.xiaomi.push.hl;
import java.util.List;

public class PushMessageHelper {
    public static final String ERROR_MESSAGE = "error_message";
    public static final String ERROR_TYPE = "error_type";
    public static final String ERROR_TYPE_NEED_PERMISSION = "error_lack_of_permission";
    public static final String KEY_COMMAND = "key_command";
    public static final String KEY_MESSAGE = "key_message";
    public static final int MESSAGE_COMMAND = 3;
    public static final int MESSAGE_ERROR = 5;
    public static final int MESSAGE_QUIT = 4;
    public static final int MESSAGE_RAW = 1;
    public static final int MESSAGE_SENDMESSAGE = 2;
    public static final String MESSAGE_TYPE = "message_type";
    public static final int PUSH_MODE_BROADCAST = 2;
    public static final int PUSH_MODE_CALLBACK = 1;
    private static int pushMode = 0;

    public static MiPushCommandMessage generateCommandMessage(String str, List<String> list, long j, String str2, String str3, List<String> list2) {
        MiPushCommandMessage miPushCommandMessage = new MiPushCommandMessage();
        miPushCommandMessage.setCommand(str);
        miPushCommandMessage.setCommandArguments(list);
        miPushCommandMessage.setResultCode(j);
        miPushCommandMessage.setReason(str2);
        miPushCommandMessage.setCategory(str3);
        miPushCommandMessage.setAutoMarkPkgs(list2);
        return miPushCommandMessage;
    }

    public static MiPushMessage generateMessage(hl hlVar, gu guVar, boolean z) {
        MiPushMessage miPushMessage = new MiPushMessage();
        miPushMessage.setMessageId(hlVar.c);
        if (!TextUtils.isEmpty(hlVar.g)) {
            miPushMessage.setMessageType(1);
            miPushMessage.setAlias(hlVar.g);
        } else if (!TextUtils.isEmpty(hlVar.f)) {
            miPushMessage.setMessageType(2);
            miPushMessage.setTopic(hlVar.f);
        } else if (!TextUtils.isEmpty(hlVar.l)) {
            miPushMessage.setMessageType(3);
            miPushMessage.setUserAccount(hlVar.l);
        } else {
            miPushMessage.setMessageType(0);
        }
        miPushMessage.setCategory(hlVar.k);
        if (hlVar.h != null) {
            miPushMessage.setContent(hlVar.h.d);
        }
        if (guVar != null) {
            if (TextUtils.isEmpty(miPushMessage.getMessageId())) {
                miPushMessage.setMessageId(guVar.a);
            }
            if (TextUtils.isEmpty(miPushMessage.getTopic())) {
                miPushMessage.setTopic(guVar.c);
            }
            miPushMessage.setDescription(guVar.e);
            miPushMessage.setTitle(guVar.d);
            miPushMessage.setNotifyType(guVar.f);
            miPushMessage.setNotifyId(guVar.i);
            miPushMessage.setPassThrough(guVar.h);
            miPushMessage.setExtra(guVar.j);
        }
        miPushMessage.setNotified(z);
        return miPushMessage;
    }

    public static gu generateMessage(MiPushMessage miPushMessage) {
        gu guVar = new gu();
        guVar.a = miPushMessage.getMessageId();
        guVar.c = miPushMessage.getTopic();
        guVar.e = miPushMessage.getDescription();
        guVar.d = miPushMessage.getTitle();
        guVar.c(miPushMessage.getNotifyId());
        guVar.a(miPushMessage.getNotifyType());
        guVar.b(miPushMessage.getPassThrough());
        guVar.j = miPushMessage.getExtra();
        return guVar;
    }

    public static int getPushMode(Context context) {
        if (pushMode == 0) {
            setPushMode(isUseCallbackPushMode(context) ? 1 : 2);
        }
        return pushMode;
    }

    private static boolean isIntentAvailable(Context context, Intent intent) {
        try {
            List<ResolveInfo> queryBroadcastReceivers = context.getPackageManager().queryBroadcastReceivers(intent, 32);
            return queryBroadcastReceivers != null && !queryBroadcastReceivers.isEmpty();
        } catch (Exception e) {
            return true;
        }
    }

    public static boolean isUseCallbackPushMode(Context context) {
        Intent intent = new Intent("com.xiaomi.mipush.RECEIVE_MESSAGE");
        intent.setClassName(context.getPackageName(), "com.xiaomi.mipush.sdk.PushServiceReceiver");
        return isIntentAvailable(context, intent);
    }

    public static void sendCommandMessageBroadcast(Context context, MiPushCommandMessage miPushCommandMessage) {
        Intent intent = new Intent("com.xiaomi.mipush.RECEIVE_MESSAGE");
        intent.setPackage(context.getPackageName());
        intent.putExtra(MESSAGE_TYPE, 3);
        intent.putExtra(KEY_COMMAND, miPushCommandMessage);
        new PushServiceReceiver().onReceive(context, intent);
    }

    public static void sendQuitMessageBroadcast(Context context) {
        Intent intent = new Intent("com.xiaomi.mipush.RECEIVE_MESSAGE");
        intent.setPackage(context.getPackageName());
        intent.putExtra(MESSAGE_TYPE, 4);
        new PushServiceReceiver().onReceive(context, intent);
    }

    private static void setPushMode(int i) {
        pushMode = i;
    }
}
