package io.dcloud.adapter.messaging;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.telephony.SmsManager;
import com.alipay.sdk.m.u.i;
import com.tencent.smtt.sdk.WebView;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;

/* access modifiers changed from: package-private */
public class DHMessagCenter {
    private static Context mContext;

    DHMessagCenter() {
    }

    protected static void initDHMessaging(Context pContext) {
        mContext = pContext;
    }

    protected static void sendMail(DHMessaging pMessaging) {
        if (pMessaging != null) {
            try {
                Intent mEmailIntent = new Intent();
                mEmailIntent.setData(Uri.parse(WebView.SCHEME_MAILTO));
                mEmailIntent.putExtra("android.intent.extra.EMAIL", pMessaging.mTo);
                if (pMessaging.mCc != null && pMessaging.mCc.length > 0) {
                    mEmailIntent.putExtra("android.intent.extra.CC", pMessaging.mCc);
                }
                if (pMessaging.mBcc != null && pMessaging.mBcc.length > 0) {
                    mEmailIntent.putExtra("android.intent.extra.BCC", pMessaging.mBcc);
                }
                mEmailIntent.putExtra("android.intent.extra.SUBJECT", pMessaging.mSubject);
                mEmailIntent.putExtra("android.intent.extra.TEXT", pMessaging.mBody);
                int attachMentsSize = pMessaging.mAttachments != null ? pMessaging.mAttachments.size() : 0;
                if (attachMentsSize > 1) {
                    mEmailIntent.setAction("android.intent.action.SEND_MULTIPLE");
                    mEmailIntent.putParcelableArrayListExtra("android.intent.extra.STREAM", pMessaging.mAttachments);
                    mEmailIntent.setType("application/octet-stream");
                    mEmailIntent.setType("message/rfc822");
                } else if (attachMentsSize == 1) {
                    mEmailIntent.putExtra("android.intent.extra.STREAM", pMessaging.mAttachments.get(0));
                    mEmailIntent.setType(PdrUtil.getMimeType(pMessaging.mAttachments.get(0).getPath()));
                    mEmailIntent.setType("message/rfc882");
                    mEmailIntent.setAction("android.intent.action.SEND");
                } else {
                    mEmailIntent.setAction("android.intent.action.SENDTO");
                }
                pMessaging.mWebview.getActivity().startActivity(mEmailIntent);
                Deprecated_JSUtil.execCallback(pMessaging.mWebview, pMessaging.mCallbackId, "", JSUtil.OK, false, false);
            } catch (Exception e) {
                e.printStackTrace();
                Deprecated_JSUtil.execCallback(pMessaging.mWebview, pMessaging.mCallbackId, DOMException.toJSON(13, e.getLocalizedMessage()), JSUtil.ERROR, true, false);
            }
        }
    }

    protected static void sendMessage(DHMessaging pMessaging) {
        if (pMessaging != null) {
            String _phoneCode = null;
            try {
                if (pMessaging.mTo != null && pMessaging.mTo.length > 0) {
                    StringBuffer _sb = new StringBuffer();
                    String[] strArr = pMessaging.mTo;
                    for (String _s : strArr) {
                        _sb.append(_s + i.b);
                    }
                    _phoneCode = _sb.toString();
                }
                if (pMessaging.mSilent) {
                    SmsManager.getDefault().sendTextMessage(_phoneCode, null, pMessaging.mBody, null, null);
                } else {
                    Intent _intent = new Intent("android.intent.action.VIEW", Uri.parse("sms:" + _phoneCode));
                    _intent.putExtra("address", _phoneCode);
                    _intent.putExtra("sms_body", pMessaging.mBody);
                    pMessaging.mWebview.getActivity().startActivity(_intent);
                }
            } catch (Exception e) {
                e.printStackTrace();
                Deprecated_JSUtil.execCallback(pMessaging.mWebview, pMessaging.mCallbackId, DOMException.toJSON(13, e.getLocalizedMessage()), JSUtil.ERROR, true, false);
                return;
            }
        }
        Deprecated_JSUtil.execCallback(pMessaging.mWebview, pMessaging.mCallbackId, "", JSUtil.OK, false, false);
    }

    public static void sendMMS(DHMessaging _messaging) {
        try {
            Intent sendIntent = new Intent("android.intent.action.SEND");
            sendIntent.setData(Uri.parse("mms:"));
            sendIntent.setType("*/*");
            if (_messaging.mAttachments != null && _messaging.mAttachments.size() > 0) {
                sendIntent.putExtra("android.intent.extra.STREAM", _messaging.mAttachments.get(0));
            }
            sendIntent.putExtra("android.intent.extra.TEXT", _messaging.mBody);
            _messaging.mWebview.getActivity().startActivity(sendIntent);
            Deprecated_JSUtil.execCallback(_messaging.mWebview, _messaging.mCallbackId, "", JSUtil.OK, false, false);
        } catch (Exception e) {
            e.printStackTrace();
            Deprecated_JSUtil.execCallback(_messaging.mWebview, _messaging.mCallbackId, DOMException.toJSON(13, e.getLocalizedMessage()), JSUtil.ERROR, true, false);
        }
    }
}
