package io.dcloud.adapter.messaging;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.database.ContentObserver;
import android.database.Cursor;
import android.net.Uri;
import android.os.Handler;
import android.os.Message;
import android.telephony.SmsMessage;
import android.text.TextUtils;
import com.tencent.connect.common.Constants;
import io.dcloud.common.DHInterface.IEventCallback;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import org.json.JSONException;
import org.json.JSONObject;

public class SMSListener {
    String mCallbackId;
    Context mContext;
    SMSBroadcastReceiver mSMSBroadcastReceiver;
    SMSContentObserver mSMSContentObserver;
    IWebview mWebview;

    SMSListener(IWebview webview, String callbackid) {
        this.mWebview = webview;
        this.mContext = webview.getContext();
        this.mCallbackId = callbackid;
        webview.obtainFrameView().addFrameViewListener(new IEventCallback() {
            /* class io.dcloud.adapter.messaging.SMSListener.AnonymousClass1 */

            @Override // io.dcloud.common.DHInterface.IEventCallback
            public Object onCallBack(String pEventType, Object pArgs) {
                if (!PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_WINDOW_CLOSE)) {
                    return null;
                }
                if (SMSListener.this.mSMSBroadcastReceiver != null) {
                    SMSListener.this.mContext.unregisterReceiver(SMSListener.this.mSMSBroadcastReceiver);
                }
                if (SMSListener.this.mSMSContentObserver == null) {
                    return null;
                }
                SMSListener.this.mContext.getContentResolver().unregisterContentObserver(SMSListener.this.mSMSContentObserver);
                return null;
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onSucess(String address, String body, long timestamp) {
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put(Constants.FROM, address);
            jsonObject.put("body", body);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(this.mWebview, this.mCallbackId, jsonObject, JSUtil.OK, true);
    }

    /* access modifiers changed from: package-private */
    public void onFail(String errorMsg) {
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put("message", errorMsg);
            jsonObject.put("code", 13);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(this.mWebview, this.mCallbackId, jsonObject, JSUtil.ERROR, true);
    }

    /* access modifiers changed from: package-private */
    public void listen() {
        try {
            IntentFilter filter = new IntentFilter();
            filter.setPriority(1000);
            filter.addAction("android.provider.Telephony.SMS_RECEIVED");
            filter.addAction("android.provider.Telephony.SMS_READ");
            Handler mHandler = new Handler() {
                /* class io.dcloud.adapter.messaging.SMSListener.AnonymousClass2 */
                String lastBody;
                long lastTimestamp = System.currentTimeMillis();

                public void handleMessage(Message msg) {
                    SMS sms = (SMS) msg.obj;
                    if (sms.timestamp - this.lastTimestamp > 2000 && !TextUtils.equals(this.lastBody, sms.body)) {
                        int i = msg.what;
                        if (i == 1) {
                            SMSListener.this.onSucess(sms.address, sms.body, sms.timestamp);
                        } else if (i == 2) {
                            SMSListener.this.onFail(sms.body);
                        }
                        this.lastTimestamp = sms.timestamp;
                        this.lastBody = sms.body;
                    }
                }
            };
            this.mSMSBroadcastReceiver = new SMSBroadcastReceiver(mHandler);
            this.mWebview.getContext().registerReceiver(this.mSMSBroadcastReceiver, filter);
            Uri smsUri = Uri.parse("content://sms");
            this.mSMSContentObserver = new SMSContentObserver(this.mWebview.getContext(), mHandler);
            this.mContext.getContentResolver().registerContentObserver(smsUri, true, this.mSMSContentObserver);
        } catch (Exception e) {
            e.printStackTrace();
            onFail(e.getMessage());
        }
    }

    class SMS {
        String address;
        String body;
        long timestamp;

        SMS(String address2, String body2, long timestamp2) {
            this.address = address2;
            this.body = body2;
            this.timestamp = timestamp2;
        }
    }

    class SMSContentObserver extends ContentObserver {
        Context mContext = null;
        Handler mHandler;

        public SMSContentObserver(Context context, Handler handler) {
            super(handler);
            this.mContext = context;
            this.mHandler = handler;
        }

        public void onChange(boolean selfChange) {
            try {
                Cursor cursor = this.mContext.getContentResolver().query(Uri.parse("content://sms/inbox"), new String[]{"address", "body", "date"}, null, null, "date desc");
                if (cursor != null) {
                    cursor.moveToFirst();
                    String address = cursor.getString(cursor.getColumnIndex("address"));
                    String body = cursor.getString(cursor.getColumnIndex("body"));
                    long date = cursor.getLong(cursor.getColumnIndex("date"));
                    Message message = Message.obtain();
                    message.what = 1;
                    message.obj = new SMS(address, body, date);
                    this.mHandler.sendMessage(message);
                }
            } catch (Exception e) {
                e.printStackTrace();
                Message message2 = Message.obtain();
                message2.what = 2;
                message2.obj = new SMS("none", e.getMessage(), System.currentTimeMillis());
                this.mHandler.sendMessage(message2);
            }
            super.onChange(selfChange);
        }
    }

    class SMSBroadcastReceiver extends BroadcastReceiver {
        Handler mHandler;

        SMSBroadcastReceiver(Handler handler) {
            this.mHandler = handler;
        }

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (action == "android.provider.Telephony.SMS_RECEIVED_DCLOUD" || action == "android.provider.Telephony.SMS_RECEIVED" || action == "android.provider.Telephony.SMS_READ") {
                Object[] messages = (Object[]) intent.getSerializableExtra("pdus");
                byte[][] pduObjs = new byte[messages.length][];
                for (int i = 0; i < messages.length; i++) {
                    pduObjs[i] = (byte[]) messages[i];
                }
                byte[][] pdus = new byte[pduObjs.length][];
                int pduCount = pdus.length;
                SmsMessage[] msgs = new SmsMessage[pduCount];
                for (int i2 = 0; i2 < pduCount; i2++) {
                    pdus[i2] = pduObjs[i2];
                    msgs[i2] = SmsMessage.createFromPdu(pdus[i2]);
                }
                SmsMessage smsMessage = msgs[0];
                Message message = Message.obtain();
                message.what = 1;
                message.obj = new SMS(smsMessage.getDisplayOriginatingAddress(), smsMessage.getMessageBody(), smsMessage.getTimestampMillis());
                this.mHandler.sendMessage(message);
            }
        }
    }
}
