package io.dcloud.common.ui.blur;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.text.TextUtils;
import android.view.Choreographer;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import com.igexin.push.config.c;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.ui.blur.AppEventForBlurManager;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.TitleNViewUtil;
import java.lang.ref.WeakReference;

public class DCBlurDraweeView extends FrameLayout implements AppEventForBlurManager.OnAppChangedCallBack {
    public static final String AUTOMATICALLY = "automatically";
    public static final String DARK = "dark";
    public static final String EXTRALIGHT = "extralight";
    public static final String LIGHT = "light";
    public static final String NONE = "none";
    public static final String SEMI_AUTOMATICALLY = "semi-automatic";
    public static final String STATIC = "static";
    private final String TAG = "DCBlurDraweeView";
    private Choreographer.FrameCallback invalidationLoop = new Choreographer.FrameCallback() {
        /* class io.dcloud.common.ui.blur.DCBlurDraweeView.AnonymousClass1 */

        public void doFrame(long j) {
            if (!BaseInfo.sDoingAnimation) {
                DCBlurDraweeView.this.invalidate();
            }
            Choreographer.getInstance().postFrameCallbackDelayed(this, (long) (1000 / DCBlurDraweeView.this.mFPS));
        }
    };
    private boolean isBlur = false;
    private float mAlpha = Float.NaN;
    private boolean mAttachedToWindow;
    private String mBlurEffect = "none";
    private int mBlurRadius = 15;
    private String mBlurState = "static";
    private BlurLayoutChangeCallBack mChangeCB;
    private float mCornerRadius = 0.0f;
    private float mDownscaleFactor = 0.2f;
    private int mFPS = 60;
    private int mGravityType = 17;
    private ImageView mImageView;
    private float mOverlayColorAlpha = 0.6f;
    private long mPostTime = c.j;
    private WeakReference<View> mRootView;
    private boolean mRunning;
    private int postDelayTime = 50;
    private Choreographer.FrameCallback postInvalidationLoop = new Choreographer.FrameCallback() {
        /* class io.dcloud.common.ui.blur.DCBlurDraweeView.AnonymousClass2 */

        public void doFrame(long j) {
            if (!DCBlurDraweeView.this.mRunning) {
                if (!BaseInfo.sDoingAnimation) {
                    DCBlurDraweeView.this.invalidate();
                }
                Choreographer.getInstance().postFrameCallbackDelayed(this, (long) DCBlurDraweeView.this.postDelayTime);
            }
        }
    };
    private Runnable removePostDelayed = new Runnable() {
        /* class io.dcloud.common.ui.blur.DCBlurDraweeView.AnonymousClass3 */

        public void run() {
            Choreographer.getInstance().removeFrameCallback(DCBlurDraweeView.this.postInvalidationLoop);
        }
    };

    public interface BlurLayoutChangeCallBack {
        void setVisibility(int i);
    }

    public DCBlurDraweeView(Context context) {
        super(context);
    }

    private View getActivityView() {
        try {
            return ((Activity) getContext()).getWindow().getDecorView().findViewById(16908290);
        } catch (ClassCastException e) {
            return null;
        }
    }

    private Bitmap getDownscaledBitmapForView(View view, Rect rect, float f, int i) throws Exception {
        int i2;
        float f2 = f / 0.5f;
        if (f >= 0.5f) {
            f2 = 1.0f;
        } else {
            f = 0.5f;
        }
        int width = (int) (((float) rect.width()) * f);
        int height = (int) (((float) rect.height()) * f);
        if (view.getWidth() <= 0 || view.getHeight() <= 0 || width <= 0 || height <= 0) {
            throw new Exception("No screen available (width or height = 0)");
        }
        float f3 = ((float) (-rect.left)) * f;
        float f4 = ((float) ((-rect.top) + i)) * f;
        int i3 = this.mGravityType;
        if (i3 == 17) {
            i2 = (int) (((float) (rect.height() + (i * 2))) * f);
        } else if (i3 != 48) {
            i2 = (int) (((float) (rect.height() + i)) * f);
        } else {
            i2 = (int) (((float) (rect.height() + i)) * f);
            f4 -= ((float) i) * f;
        }
        setViewVisibility(4);
        Bitmap createBitmap = Bitmap.createBitmap(width, i2, Bitmap.Config.ARGB_8888);
        BlurCanvas blurCanvas = new BlurCanvas(createBitmap);
        Matrix matrix = new Matrix();
        matrix.postScale(f, f);
        matrix.postTranslate(f3, f4);
        blurCanvas.setMatrix(matrix);
        view.draw(blurCanvas);
        blurCanvas.drawColor(getOverlayColor());
        blurCanvas.save();
        setViewVisibility(0);
        float f5 = (float) width;
        int i4 = (int) (f5 * f2);
        float f6 = (float) i2;
        int i5 = (int) (f2 * f6);
        Bitmap createBitmap2 = Bitmap.createBitmap(i4, i5, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap2);
        Matrix matrix2 = new Matrix();
        matrix2.setScale(((float) i4) / f5, ((float) i5) / f6);
        canvas.setMatrix(matrix2);
        canvas.drawColor(getBlurBGColor());
        Paint paint = new Paint();
        paint.setFlags(3);
        canvas.drawBitmap(createBitmap, 0.0f, 0.0f, paint);
        createBitmap.recycle();
        return createBitmap2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x005f  */
    private int getOverlayColor() {
        char c;
        String str = this.mBlurEffect;
        str.hashCode();
        int hashCode = str.hashCode();
        if (hashCode != 3075958) {
            if (hashCode != 102970646) {
                if (hashCode == 759540486 && str.equals(EXTRALIGHT)) {
                    c = 2;
                    if (c != 0) {
                        return Color.parseColor(TitleNViewUtil.changeColorAlpha("#454545", this.mOverlayColorAlpha));
                    }
                    if (c == 1) {
                        return Color.parseColor(TitleNViewUtil.changeColorAlpha("#F8F8F8", this.mOverlayColorAlpha));
                    }
                    if (c != 2) {
                        return 0;
                    }
                    return Color.parseColor(TitleNViewUtil.changeColorAlpha(TitleNViewUtil.TRANSPARENT_BUTTON_TEXT_COLOR, this.mOverlayColorAlpha));
                }
            } else if (str.equals(LIGHT)) {
                c = 1;
                if (c != 0) {
                }
            }
        } else if (str.equals(DARK)) {
            c = 0;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    private Point getPositionInScreen() {
        PointF positionInScreen = getPositionInScreen(this);
        return new Point((int) positionInScreen.x, (int) positionInScreen.y);
    }

    private void initImageView() {
        ImageView imageView = this.mImageView;
        if (imageView == null) {
            this.mImageView = new ImageView(getContext());
        } else if (imageView.getParent() == null) {
            ((ViewGroup) this.mImageView.getParent()).removeView(this.mImageView);
        }
        this.mImageView.setScaleType(ImageView.ScaleType.FIT_XY);
        addView(this.mImageView, 0);
        setCornerRadius(this.mCornerRadius);
    }

    private void pauseBlur() {
        if (this.mRunning && this.isBlur) {
            this.mRunning = false;
            Choreographer.getInstance().removeFrameCallback(this.invalidationLoop);
        }
    }

    private void setViewVisibility(int i) {
        setVisibility(i);
        BlurLayoutChangeCallBack blurLayoutChangeCallBack = this.mChangeCB;
        if (blurLayoutChangeCallBack != null) {
            blurLayoutChangeCallBack.setVisibility(i);
        }
    }

    private void startBlur() {
        if (!this.mRunning && this.isBlur && this.mFPS > 0 && !this.mBlurState.equals("static")) {
            this.mRunning = true;
            Choreographer.getInstance().removeFrameCallback(this.postInvalidationLoop);
            Choreographer.getInstance().postFrameCallback(this.invalidationLoop);
        }
    }

    public boolean checkBlurEffect(String str) {
        if (!TextUtils.isEmpty(str)) {
            return str.equals(LIGHT) || str.equals(DARK) || str.equals(EXTRALIGHT);
        }
        return false;
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0054  */
    public int getBlurBGColor() {
        char c;
        String str = this.mBlurEffect;
        str.hashCode();
        int hashCode = str.hashCode();
        if (hashCode != 3075958) {
            if (hashCode != 102970646) {
                if (hashCode == 759540486 && str.equals(EXTRALIGHT)) {
                    c = 2;
                    if (c != 0) {
                        return Color.parseColor("#F2454545");
                    }
                    if (c == 1) {
                        return Color.parseColor("#F2F8F8F8");
                    }
                    if (c != 2) {
                        return 0;
                    }
                    return Color.parseColor("#F2FFFFFF");
                }
            } else if (str.equals(LIGHT)) {
                c = 1;
                if (c != 0) {
                }
            }
        } else if (str.equals(DARK)) {
            c = 0;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    public void invalidate() {
        Bitmap makeBlur;
        super.invalidate();
        if (this.mAttachedToWindow && this.mImageView != null && this.isBlur && (makeBlur = makeBlur()) != null) {
            this.mImageView.setImageBitmap(makeBlur);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:40:0x00ad, code lost:
        if (r7 != 80) goto L_0x00cf;
     */
    public Bitmap makeBlur() {
        Bitmap bitmap = null;
        if (getContext() == null || isInEditMode() || !this.isBlur) {
            return null;
        }
        WeakReference<View> weakReference = this.mRootView;
        if (weakReference == null || weakReference.get() == null) {
            WeakReference<View> weakReference2 = new WeakReference<>(getActivityView());
            this.mRootView = weakReference2;
            if (weakReference2.get() == null) {
                return null;
            }
        }
        getLocationOnScreen(new int[2]);
        Point positionInScreen = getPositionInScreen();
        Rect rect = new Rect();
        if (!getGlobalVisibleRect(rect)) {
            return null;
        }
        int height = getHeight();
        int width = getWidth();
        boolean z = rect.height() >= height;
        int i = z ? this.mBlurRadius : 0;
        try {
            int i2 = positionInScreen.x;
            int i3 = positionInScreen.y;
            bitmap = getDownscaledBitmapForView(this.mRootView.get(), new Rect(i2, i3, width + i2, height + i3), this.mDownscaleFactor, i);
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (bitmap == null) {
            return bitmap;
        }
        Bitmap processNatively = BlurManager.getInstance().processNatively(bitmap, this.mBlurRadius, false);
        int i4 = (int) (((float) i) * this.mDownscaleFactor);
        int i5 = z ? i4 : 0;
        int height2 = z ? processNatively.getHeight() - (i4 * 2) : processNatively.getHeight();
        int i6 = this.mGravityType;
        if (i6 != 17) {
            if (i6 == 48) {
                i5 = 5;
                height2 = (z ? processNatively.getHeight() - i4 : processNatively.getHeight()) - 5;
            }
            return Bitmap.createBitmap(processNatively, 0, i5, processNatively.getWidth(), height2);
        }
        height2 = z ? processNatively.getHeight() - (i4 * 2) : processNatively.getHeight();
        return Bitmap.createBitmap(processNatively, 0, i5, processNatively.getWidth(), height2);
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        this.mAttachedToWindow = true;
        if (this.isBlur) {
            String str = this.mBlurState;
            str.hashCode();
            char c = 65535;
            int hashCode = str.hashCode();
            if (hashCode != -892481938) {
                if (hashCode != 1030681228) {
                    if (hashCode == 1977933731 && str.equals(AUTOMATICALLY)) {
                        c = 2;
                    }
                } else if (str.equals(SEMI_AUTOMATICALLY)) {
                    c = 1;
                }
            } else if (str.equals("static")) {
                c = 0;
            }
            if (c == 0) {
                postInvalidate(this.mPostTime);
                AppEventForBlurManager.removeEventChangedCallBack(this);
            } else if (c == 1) {
                postInvalidate(this.mPostTime);
                AppEventForBlurManager.addEventChangedCallBack(this);
            } else if (c == 2) {
                AppEventForBlurManager.removeEventChangedCallBack(this);
                startBlur();
            }
        }
    }

    @Override // io.dcloud.common.ui.blur.AppEventForBlurManager.OnAppChangedCallBack
    public void onContentScrollEnd() {
        pauseBlur();
    }

    @Override // io.dcloud.common.ui.blur.AppEventForBlurManager.OnAppChangedCallBack
    public void onContentScrollStart() {
        startBlur();
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        this.mAttachedToWindow = false;
        pauseBlur();
        AppEventForBlurManager.removeEventChangedCallBack(this);
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        if (this.isBlur) {
            postInvalidate(this.mPostTime);
        }
    }

    @Override // io.dcloud.common.ui.blur.AppEventForBlurManager.OnAppChangedCallBack
    public void onSplashclosed() {
        postInvalidate(this.mPostTime);
    }

    public void postInvalidate(long j) {
        if (!this.mRunning && this.isBlur) {
            MessageHandler.removeCallbacks(this.removePostDelayed);
            Choreographer.getInstance().removeFrameCallback(this.postInvalidationLoop);
            Choreographer.getInstance().postFrameCallback(this.postInvalidationLoop);
            MessageHandler.postDelayed(this.removePostDelayed, j + 10);
        }
    }

    public void setBlur(boolean z) {
        this.isBlur = z;
        if (z && this.mImageView == null) {
            initImageView();
        }
    }

    public void setBlurEffect(String str) {
        this.mBlurEffect = str;
        if (this.isBlur || !this.mBlurState.equals("none")) {
            setBackgroundColor(0);
        } else {
            setBackgroundColor(getBlurBGColor());
        }
    }

    public void setBlurLayoutChangeCallBack(BlurLayoutChangeCallBack blurLayoutChangeCallBack) {
        this.mChangeCB = blurLayoutChangeCallBack;
    }

    public void setBlurRadius(int i) {
        if (i < 0) {
            i = 15;
        } else if (i > 25) {
            i = 25;
        }
        this.mBlurRadius = i;
        invalidate();
    }

    public void setBlurState(String str) {
        this.mBlurState = str;
    }

    /* JADX WARNING: Removed duplicated region for block: B:17:0x0040  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0059  */
    public void setContentFocusable(boolean z) {
        char c;
        String str = this.mBlurState;
        str.hashCode();
        int hashCode = str.hashCode();
        if (hashCode != -892481938) {
            if (hashCode != 1030681228) {
                if (hashCode == 1977933731 && str.equals(AUTOMATICALLY)) {
                    c = 2;
                    if (c != 0) {
                        AppEventForBlurManager.removeEventChangedCallBack(this);
                        pauseBlur();
                        return;
                    } else if (c != 1) {
                        if (c == 2) {
                            if (z) {
                                startBlur();
                                return;
                            } else {
                                pauseBlur();
                                return;
                            }
                        } else {
                            return;
                        }
                    } else if (z) {
                        AppEventForBlurManager.addEventChangedCallBack(this);
                        return;
                    } else {
                        AppEventForBlurManager.removeEventChangedCallBack(this);
                        return;
                    }
                }
            } else if (str.equals(SEMI_AUTOMATICALLY)) {
                c = 1;
                if (c != 0) {
                }
            }
        } else if (str.equals("static")) {
            c = 0;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    public void setCornerRadius(float f) {
        this.mCornerRadius = f;
        invalidate();
    }

    public void setDownscaleFactor(float f) {
        this.mDownscaleFactor = f;
        invalidate();
    }

    public void setFPS(int i) {
        if (this.mRunning) {
            pauseBlur();
        }
        this.mFPS = i;
    }

    public void setGravityType(int i) {
        this.mGravityType = i;
    }

    public void setOverlayColorAlpha(float f) {
        this.mOverlayColorAlpha = f;
    }

    public void setRootView(View view) {
        WeakReference<View> weakReference = this.mRootView;
        if (!(weakReference == null || weakReference.get() == null)) {
            this.mRootView.clear();
        }
        this.mRootView = new WeakReference<>(view);
    }

    private PointF getPositionInScreen(View view) {
        if (getParent() == null) {
            return new PointF();
        }
        if (this.mRootView.get() != null && view == this.mRootView.get()) {
            return new PointF();
        }
        try {
            ViewGroup viewGroup = (ViewGroup) view.getParent();
            if (viewGroup == null) {
                return new PointF();
            }
            PointF positionInScreen = getPositionInScreen(viewGroup);
            positionInScreen.offset(view.getX(), view.getY());
            return positionInScreen;
        } catch (Exception e) {
            return new PointF();
        }
    }

    public DCBlurDraweeView(Context context, boolean z, String str) {
        super(context);
        this.isBlur = z;
        this.mBlurState = str;
        if (z) {
            initImageView();
        }
    }
}
