package io.dcloud.feature.aps;

import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.BaseFeature;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.feature.internal.sdk.SDK;
import java.util.ArrayList;
import java.util.Iterator;
import org.json.JSONArray;

public class APSFeatureImpl extends BaseFeature {
    public static String CLEAR_NOTIFICATION = F_CLEAR_NOTIFICATION;
    public static String CLILK_NOTIFICATION = F_CLILK_NOTIFICATION;
    public static String CREATE_NOTIFICATION = F_CREATE_NOTIFICATION;
    public static final String F_CLEAR_NOTIFICATION = "__CLEAR_NOTIFICATION";
    public static final String F_CLILK_NOTIFICATION = "__CLILK_NOTIFICATION";
    public static final String F_CREATE_NOTIFICATION = "__CREATE_NOTIFICATION";
    public static final String F_REMOVE_NOTIFICATION = "__REMOVE_NOTIFICATION";
    public static String PRE = null;
    public static String REMOVE_NOTIFICATION = F_REMOVE_NOTIFICATION;
    private boolean isInit = false;
    private NotificationReceiver mNotificationReceiver;
    protected PushManager mPushManager;

    @Override // io.dcloud.common.DHInterface.BaseFeature
    public String execute(IWebview pWebViewImpl, String pActionName, JSONArray pJsArgs) {
        try {
            if (!SDK.isUniMPSDK()) {
                return this.mPushManager.execute(pWebViewImpl, pActionName, pJsArgs, this);
            }
            return null;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature
    public void init(AbsMgr pFeatureMgr, String pFeatureName) {
        super.init(pFeatureMgr, pFeatureName);
        Context context = pFeatureMgr.getContext();
        this.mPushManager = PushManager.getInstance(context);
        initNotification(context);
        registerReceiver(context);
    }

    private void registerReceiver(Context context) {
        this.mNotificationReceiver = new NotificationReceiver();
        IntentFilter mFilter = new IntentFilter();
        mFilter.addAction(CLEAR_NOTIFICATION);
        mFilter.addAction(REMOVE_NOTIFICATION);
        mFilter.addAction(CREATE_NOTIFICATION);
        LocalBroadcastManager.getInstance(this.mApplicationContext).registerReceiver(this.mNotificationReceiver, mFilter);
    }

    public static void initNotification(Context context) {
        if (PRE == null) {
            PRE = context.getPackageName();
        }
        if (!CREATE_NOTIFICATION.startsWith(PRE)) {
            CREATE_NOTIFICATION = PRE + Operators.DOT_STR + F_CREATE_NOTIFICATION;
            REMOVE_NOTIFICATION = PRE + Operators.DOT_STR + F_REMOVE_NOTIFICATION;
            CLEAR_NOTIFICATION = PRE + Operators.DOT_STR + F_CLEAR_NOTIFICATION;
            CLILK_NOTIFICATION = PRE + Operators.DOT_STR + F_CLILK_NOTIFICATION;
        }
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.IBoot
    public void onStart(Context pContext, Bundle pSavedInstanceState, String[] pRuntimeArgs) {
        super.onStart(pContext, pSavedInstanceState, pRuntimeArgs);
        if (!SDK.isUniMPSDK()) {
            if (!AppRuntime.hasPrivacyForNotShown(pContext)) {
                boolean needLazyInit = needLazyInit();
                boolean needLoad = !needLazyInit;
                if (needLazyInit) {
                    needLoad = pContext.getSharedPreferences(AbsPushService.PUSH_DB_NAME, 0).getBoolean(AbsPushService.PUSH_DB_LAZY_INITIALIZED, false);
                }
                if (needLoad) {
                    ArrayList<BaseFeature.BaseModule> modules = loadModules();
                    if (modules != null && !modules.isEmpty()) {
                        Iterator<BaseFeature.BaseModule> it = modules.iterator();
                        while (it.hasNext()) {
                            ((AbsPushService) it.next()).onStart(pContext, pSavedInstanceState, pRuntimeArgs);
                        }
                    }
                    this.isInit = true;
                    return;
                }
                return;
            }
            this.isInit = false;
        }
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.IBoot
    public void onRestart(Context context) {
        super.onRestart(context);
        if (!this.isInit) {
            onStart(context, null, null);
        }
        registerReceiver(context);
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature
    public void onReceiver(Intent intent) {
        super.onReceiver(intent);
        ArrayList<BaseFeature.BaseModule> modules = loadModules();
        if (modules != null && !modules.isEmpty()) {
            Iterator<BaseFeature.BaseModule> it = modules.iterator();
            while (it.hasNext()) {
                ((AbsPushService) it.next()).onReceiver(intent);
            }
        }
    }

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature
    public void dispose(String pAppid) {
        try {
            if (this.mNotificationReceiver != null) {
                LocalBroadcastManager.getInstance(this.mApplicationContext).unregisterReceiver(this.mNotificationReceiver);
            }
            ArrayList<BaseFeature.BaseModule> modules = loadModules();
            if (modules != null && !modules.isEmpty()) {
                Iterator<BaseFeature.BaseModule> it = modules.iterator();
                while (it.hasNext()) {
                    ((AbsPushService) it.next()).onStop();
                }
            }
        } catch (IllegalArgumentException e) {
        }
    }

    public static void addPushMessage(Context context, String appid, PushMessage _pushMessage) {
        PushManager.getInstance(context).addPushMessage(appid, _pushMessage);
    }

    public static boolean execScript(Context context, String pEventType, String pMessage) {
        return PushManager.getInstance(context).execScript(pEventType, pMessage);
    }

    public static void sendCreateNotificationBroadcast(Context context, String appid, PushMessage pushMessage) {
        PushManager.getInstance(context).sendCreateNotificationBroadcast(context, appid, pushMessage);
    }

    public static void addNeedExecReceiveMessage(Context context, PushMessage pushMessage) {
        PushManager.getInstance(context).addNeedExecReceiveMessage(pushMessage);
    }

    public static void addNeedExecMessage(Context context, PushMessage pushMessage) {
        PushManager.getInstance(context).addNeedExecMessage(pushMessage);
    }

    private boolean needLazyInit() {
        String pushLazyInit = AndroidResources.getMetaValue("dcloud_push_lazy_init");
        if (pushLazyInit == null || !pushLazyInit.equalsIgnoreCase(AbsoluteConst.TRUE)) {
            return false;
        }
        return true;
    }
}
