package io.dcloud.feature.aps;

import android.app.NotificationChannel;
import android.app.NotificationChannelGroup;
import android.app.NotificationManager;
import android.content.Context;
import android.content.Intent;
import android.os.Build;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.alipay.sdk.m.u.i;
import com.igexin.push.core.b;
import com.taobao.weex.common.Constants;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.BaseFeature;
import io.dcloud.common.DHInterface.IEventCallback;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.ui.AdaUniWebView;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.push.R;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

/* access modifiers changed from: package-private */
public class PushManager {
    public static final String LOCAL_PUSH_CHANNEL_ID = "DcloudChannelID";
    public static final String LOCAL_PUSH_GROUP_ID = "DcloudGroupID";
    protected static PushManager mPushManager;
    APSFeatureImpl apsFeatureImpl;
    public HashMap<String, ArrayList<PushMessage>> mAppsmMessages = new HashMap<>();
    private AbsPushService mBaseAbsPushService = null;
    protected ArrayList<PushMessage> mNeedExecMessages = new ArrayList<>();
    protected ArrayList<PushMessage> mNeedExecMessages_receive = new ArrayList<>();
    protected HashMap<IWebview, HashMap<String, ArrayList<String>>> mWebViewCallbackIds = new HashMap<>();

    public static PushManager getInstance(Context context) {
        APSFeatureImpl.initNotification(context);
        if (mPushManager == null) {
            mPushManager = new PushManager();
        }
        return mPushManager;
    }

    protected PushManager() {
    }

    public void sendCreateNotificationBroadcast(Context _context, String _appId, PushMessage _message) {
        createChannel(_context, null, null);
        Intent _intent = new Intent(APSFeatureImpl.CREATE_NOTIFICATION);
        _intent.putExtras(_message.toBundle());
        if (!LocalBroadcastManager.getInstance(_context).sendBroadcast(_intent)) {
            NotificationReceiver.sOnReceiver(_context, _intent);
        }
    }

    public String execute(IWebview pWebViewImpl, String pActionName, JSONArray pJsArgs, BaseFeature baseFeature) throws Exception {
        AbsPushService channel;
        Context context = pWebViewImpl.getContext();
        AppRuntime.checkPrivacyComplianceAndPrompt(context, "Push-" + pActionName);
        String _appId = pWebViewImpl.obtainFrameView().obtainApp().obtainAppId();
        Context _context = pWebViewImpl.getActivity();
        if (!baseFeature.loadModules().isEmpty()) {
            channel = (AbsPushService) baseFeature.loadModules().get(0);
        } else {
            if (this.mBaseAbsPushService == null) {
                this.mBaseAbsPushService = new AbsPushService() {
                    /* class io.dcloud.feature.aps.PushManager.AnonymousClass1 */

                    @Override // io.dcloud.feature.aps.AbsPushService, io.dcloud.common.DHInterface.BaseFeature.BaseModule
                    public JSONObject toJSONObject() throws JSONException {
                        return super.toJSONObject();
                    }

                    @Override // io.dcloud.feature.aps.AbsPushService
                    public void getClientInfoAsync(IWebview iWebview, String callBackId) {
                        Deprecated_JSUtil.execCallback(iWebview, callBackId, "{code:-1,message:'no push platform'}", JSUtil.ERROR, true, false);
                    }
                };
            }
            channel = this.mBaseAbsPushService;
        }
        char c = 65535;
        switch (pActionName.hashCode()) {
            case -1093524629:
                if (pActionName.equals("createMessage")) {
                    c = 2;
                    break;
                }
                break;
            case -973690692:
                if (pActionName.equals("setAutoNotification")) {
                    c = 7;
                    break;
                }
                break;
            case -934610812:
                if (pActionName.equals(AbsoluteConst.XML_REMOVE)) {
                    c = 5;
                    break;
                }
                break;
            case -625809843:
                if (pActionName.equals("addEventListener")) {
                    c = 4;
                    break;
                }
                break;
            case 94746189:
                if (pActionName.equals("clear")) {
                    c = 3;
                    break;
                }
                break;
            case 804366095:
                if (pActionName.equals("getClientInfo")) {
                    c = 0;
                    break;
                }
                break;
            case 895581357:
                if (pActionName.equals("getClientInfoAsync")) {
                    c = 1;
                    break;
                }
                break;
            case 2048257820:
                if (pActionName.equals("getAllMessage")) {
                    c = 6;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                if (channel != null) {
                    return channel.getClientInfo(pWebViewImpl.getContext());
                }
                return null;
            case 1:
                if (channel != null) {
                    channel.getClientInfoAsync(pWebViewImpl, pJsArgs.optString(0));
                    return null;
                }
                Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs.optString(0), "{code:-1,message:'no push platform'}", JSUtil.ERROR, true, false);
                return null;
            case 2:
                if (channel != null) {
                    return channel.createMessage(pWebViewImpl, pJsArgs, _appId, _context);
                }
                return null;
            case 3:
                if (channel == null) {
                    return null;
                }
                channel.clear(_context, _appId);
                return null;
            case 4:
                if (channel == null) {
                    return null;
                }
                channel.addEventListener(_context, pWebViewImpl, pJsArgs);
                return null;
            case 5:
                if (channel == null) {
                    return null;
                }
                channel.remove(_context, pJsArgs, _appId);
                return null;
            case 6:
                return getAllMessages(_appId);
            case 7:
                if (channel == null) {
                    return null;
                }
                channel.setAutoNotification(pWebViewImpl, pJsArgs, _appId);
                return null;
            default:
                return null;
        }
    }

    /* access modifiers changed from: protected */
    public void dispatchEvent(IWebview webview, String callBackId, String evtType) {
        String eventJs = "window." + "__Mkey__Push__.execCallback_Push('%s', '%s', %s);";
        if (webview instanceof AdaUniWebView) {
            eventJs = "plus.push." + "__Mkey__Push__.execCallback_Push('%s', '%s', %s);";
        }
        if (Constants.Event.CLICK.equals(evtType)) {
            if (!this.mNeedExecMessages.isEmpty()) {
                Iterator<PushMessage> it = this.mNeedExecMessages.iterator();
                while (it.hasNext()) {
                    webview.executeScript(StringUtil.format(eventJs, callBackId, evtType, it.next().toJSON()));
                }
                this.mNeedExecMessages.clear();
            }
        } else if ("receive".equals(evtType) && !this.mNeedExecMessages_receive.isEmpty()) {
            Iterator<PushMessage> it2 = this.mNeedExecMessages_receive.iterator();
            while (it2.hasNext()) {
                webview.executeScript(StringUtil.format(eventJs, callBackId, evtType, it2.next().toJSON()));
            }
            this.mNeedExecMessages_receive.clear();
        }
    }

    public void addPushMessage(String pAppid, PushMessage pMsg) {
        if (pAppid == null) {
            pAppid = BaseInfo.PDR;
        }
        ArrayList<PushMessage> _arr = this.mAppsmMessages.get(pAppid);
        if (_arr == null) {
            _arr = new ArrayList<>();
            this.mAppsmMessages.put(pAppid, _arr);
        }
        _arr.add(pMsg);
    }

    public void addNeedExecMessage(PushMessage pMsg) {
        ArrayList<PushMessage> arrayList = this.mNeedExecMessages;
        if (arrayList != null && arrayList.size() > 0) {
            this.mNeedExecMessages.clear();
        }
        this.mNeedExecMessages.add(pMsg);
    }

    public void addNeedExecReceiveMessage(PushMessage pMsg) {
        this.mNeedExecMessages_receive.add(pMsg);
    }

    public void removePushMessage(String pAppid, PushMessage pPushMsg) {
        if (pAppid == null) {
            pAppid = BaseInfo.PDR;
        }
        ArrayList<PushMessage> _arr = this.mAppsmMessages.get(pAppid);
        if (_arr != null && _arr.contains(pPushMsg)) {
            _arr.remove(pPushMsg);
            Logger.d("push", "removePushMessage" + _arr.size());
        }
    }

    public PushMessage findPushMessage(String pAppid, String pUuid) {
        if (pAppid == null) {
            pAppid = BaseInfo.PDR;
        }
        PushMessage _ret = null;
        ArrayList<PushMessage> _arr = this.mAppsmMessages.get(pAppid);
        if (_arr == null) {
            for (String key : this.mAppsmMessages.keySet()) {
                ArrayList<PushMessage> _arr2 = this.mAppsmMessages.get(key);
                int count = _arr2.size();
                int i = 0;
                while (true) {
                    if (i >= count) {
                        break;
                    }
                    PushMessage _pushMessage = _arr2.get(i);
                    if (pUuid.equals(_pushMessage.mUUID)) {
                        _ret = _pushMessage;
                        break;
                    }
                    i++;
                }
            }
            return _ret;
        } else if (_arr == null) {
            return null;
        } else {
            int count2 = _arr.size();
            for (int i2 = 0; i2 < count2; i2++) {
                PushMessage _pushMessage2 = _arr.get(i2);
                if (pUuid.equals(_pushMessage2.mUUID)) {
                    return _pushMessage2;
                }
            }
            return null;
        }
    }

    public ArrayList<String> findWebViewCallbacks(IWebview pWebview, String evtType) {
        HashMap<String, ArrayList<String>> _webEvtArr = this.mWebViewCallbackIds.get(pWebview);
        if (_webEvtArr == null) {
            HashMap<String, ArrayList<String>> _webEvtArr2 = new HashMap<>();
            ArrayList<String> _ret = new ArrayList<>();
            _webEvtArr2.put(evtType, _ret);
            addWindowCloseListener(pWebview);
            this.mWebViewCallbackIds.put(pWebview, _webEvtArr2);
            return _ret;
        } else if (_webEvtArr.get(evtType) != null) {
            ArrayList<String> _ret2 = _webEvtArr.get(evtType);
            addWindowCloseListener(pWebview);
            return _ret2;
        } else {
            ArrayList<String> _ret3 = new ArrayList<>();
            _webEvtArr.put(evtType, _ret3);
            return _ret3;
        }
    }

    public void removeWebviewCallback(IWebview pWebview) {
        this.mWebViewCallbackIds.remove(pWebview);
    }

    private void addWindowCloseListener(IWebview pWebview) {
        ((AdaFrameView) pWebview.obtainFrameView()).addFrameViewListener(new IEventCallback() {
            /* class io.dcloud.feature.aps.PushManager.AnonymousClass2 */

            @Override // io.dcloud.common.DHInterface.IEventCallback
            public Object onCallBack(String pEventType, Object pArgs) {
                if ((!PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_WINDOW_CLOSE) && !PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CLOSE)) || !(pArgs instanceof IWebview)) {
                    return null;
                }
                PushManager.this.removeWebviewCallback((IWebview) pArgs);
                ((AdaFrameView) ((IWebview) pArgs).obtainFrameView()).removeFrameViewListener(this);
                return null;
            }
        });
    }

    /* access modifiers changed from: protected */
    public String getAllMessages(String appid) {
        ArrayList<PushMessage> _arr = this.mAppsmMessages.get(appid);
        StringBuffer _sb = new StringBuffer();
        if (_arr != null && _arr.size() > 0) {
            int count = _arr.size();
            for (int i = 0; i < count; i++) {
                _sb.append("arr[" + i + "]=");
                _sb.append(_arr.get(i).toJSON());
                _sb.append(i.b);
            }
        }
        return StringUtil.format("(function(){var arr = new Array;%s;return arr;})();", _sb.toString());
    }

    public boolean execScript(String pEventType, String pMessage) {
        boolean _ret = false;
        for (IWebview _webView : this.mWebViewCallbackIds.keySet()) {
            if (!((AdaFrameItem) _webView).isDisposed()) {
                String eventJs = "window." + "__Mkey__Push__.execCallback_Push('%s', '%s', %s);";
                if (_webView instanceof AdaUniWebView) {
                    eventJs = "plus.push." + "__Mkey__Push__.execCallback_Push('%s', '%s', %s);";
                }
                ArrayList<String> _callbacks = this.mWebViewCallbackIds.get(_webView).get(pEventType);
                if (_callbacks != null) {
                    for (int i = _callbacks.size() - 1; i >= 0; i--) {
                        String _callbackId = _callbacks.get(i);
                        String scriptJs = StringUtil.format(eventJs, _callbackId, pEventType, pMessage);
                        if (_callbackId.startsWith(pEventType)) {
                            _webView.executeScript(scriptJs);
                            _ret = true;
                        }
                    }
                }
            }
        }
        return _ret;
    }

    public static void createChannel(Context context, String channelId, String channelName) {
        if (Build.VERSION.SDK_INT >= 26) {
            NotificationManager notificationManager = (NotificationManager) context.getSystemService(b.n);
            if (PdrUtil.isEmpty(channelId) || PdrUtil.isEmpty(channelName)) {
                String pChannelName = DCLoudApplicationImpl.self().getContext().getResources().getString(R.string.dcloud_feature_aps_notification_channel);
                if (notificationManager.getNotificationChannel(LOCAL_PUSH_CHANNEL_ID) == null) {
                    notificationManager.createNotificationChannelGroup(new NotificationChannelGroup(LOCAL_PUSH_GROUP_ID, DCLoudApplicationImpl.self().getContext().getResources().getString(R.string.dcloud_feature_aps_notification_group)));
                    NotificationChannel channel = new NotificationChannel(LOCAL_PUSH_CHANNEL_ID, pChannelName, 3);
                    channel.enableLights(true);
                    channel.setShowBadge(true);
                    notificationManager.createNotificationChannel(channel);
                }
            } else if (notificationManager.getNotificationChannel(channelId) == null) {
                NotificationChannel channel2 = new NotificationChannel(channelId, channelName, 3);
                channel2.enableLights(true);
                channel2.setShowBadge(true);
                notificationManager.createNotificationChannel(channel2);
            }
        }
    }
}
