package io.dcloud.feature.aps;

import android.os.Bundle;
import android.text.TextUtils;
import com.coremedia.iso.boxes.UserBox;
import com.igexin.assist.sdk.AssistPushConsts;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IReflectAble;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import java.io.IOException;
import java.util.Iterator;
import java.util.Map;
import org.json.JSONException;
import org.json.JSONObject;

public class PushMessage implements IReflectAble {
    protected static int mNotificationId = 1;
    public JSONObject extJSON;
    protected boolean isCover;
    public String mContent;
    protected long mDelay;
    private String mForceNotification;
    public String mIconPath;
    public boolean mIsStreamApp;
    public String mMessageAppid;
    private String mPath;
    public String mPayload;
    public JSONObject mPayloadJSON;
    public String mTitle;
    public String mUUID;
    public long mWhen;
    public int nID;
    private boolean needCreateNotification;
    private double pushVersion;
    public String sound;

    public PushMessage(String pJsonMsg, String defaultAppid, String defaultTitle) {
        this.needCreateNotification = true;
        this.mMessageAppid = null;
        this.mUUID = null;
        this.mContent = null;
        this.mPayload = null;
        this.mPayloadJSON = null;
        this.sound = "system";
        this.mWhen = 0;
        this.mTitle = null;
        this.isCover = PlatformUtil.APS_COVER;
        this.mDelay = 0;
        this.mIconPath = null;
        this.mIsStreamApp = false;
        this.pushVersion = 1.0d;
        init(pJsonMsg, null, defaultAppid, defaultTitle);
    }

    public PushMessage(String pJsonMsg, IApp app) {
        this.needCreateNotification = true;
        String defaultTitle = null;
        this.mMessageAppid = null;
        this.mUUID = null;
        this.mContent = null;
        this.mPayload = null;
        this.mPayloadJSON = null;
        this.sound = "system";
        this.mWhen = 0;
        this.mTitle = null;
        this.isCover = PlatformUtil.APS_COVER;
        this.mDelay = 0;
        this.mIconPath = null;
        this.mIsStreamApp = false;
        this.pushVersion = 1.0d;
        init(pJsonMsg, app, app != null ? app.obtainAppId() : null, app != null ? app.obtainAppName() : defaultTitle);
    }

    public PushMessage(Map map, IApp app) {
        this.needCreateNotification = true;
        String defaultAppId = null;
        this.mMessageAppid = null;
        this.mUUID = null;
        this.mContent = null;
        this.mPayload = null;
        this.mPayloadJSON = null;
        this.sound = "system";
        this.mWhen = 0;
        this.mTitle = null;
        this.isCover = PlatformUtil.APS_COVER;
        this.mDelay = 0;
        this.mIconPath = null;
        this.mIsStreamApp = false;
        this.pushVersion = 1.0d;
        defaultAppId = app != null ? app.obtainAppId() : defaultAppId;
        this.mIsStreamApp = false;
        this.mUUID = getMessageUUID();
        this.extJSON = new JSONObject(map);
        this.mMessageAppid = defaultAppId;
        setNotificationID();
    }

    public PushMessage(JSONObject jsonObject, String appId) {
        this.needCreateNotification = true;
        this.mMessageAppid = null;
        this.mUUID = null;
        this.mContent = null;
        this.mPayload = null;
        this.mPayloadJSON = null;
        this.sound = "system";
        this.mWhen = 0;
        this.mTitle = null;
        this.isCover = PlatformUtil.APS_COVER;
        this.mDelay = 0;
        this.mIconPath = null;
        this.mIsStreamApp = false;
        this.pushVersion = 1.0d;
        this.mIsStreamApp = false;
        this.mUUID = getMessageUUID();
        this.extJSON = jsonObject;
        this.mMessageAppid = appId;
        setNotificationID();
        this.pushVersion = 2.0d;
    }

    private void init(String pJsonMsg, IApp app, String defaultAppid, String defaultTitle) {
        this.mIsStreamApp = false;
        this.mUUID = getMessageUUID();
        parseJson(pJsonMsg, app, defaultAppid, defaultTitle);
        setNotificationID();
    }

    public PushMessage(Bundle bundle) {
        this.needCreateNotification = true;
        this.mMessageAppid = null;
        this.mUUID = null;
        this.mContent = null;
        this.mPayload = null;
        this.mPayloadJSON = null;
        this.sound = "system";
        this.mWhen = 0;
        this.mTitle = null;
        this.isCover = PlatformUtil.APS_COVER;
        this.mDelay = 0;
        this.mIconPath = null;
        this.mIsStreamApp = false;
        this.pushVersion = 1.0d;
        parse(bundle);
    }

    public boolean needCreateNotification() {
        return this.needCreateNotification;
    }

    public String getMessageUUID() {
        return "androidPushMsg" + hashCode();
    }

    private void setNotificationID() {
        if (!this.isCover) {
            mNotificationId++;
        }
        this.nID = mNotificationId;
    }

    private void parseJson(String pJsonMsg, IApp app, String defaultAppid, String defaultTitle) {
        JSONObject _json = null;
        try {
            _json = new JSONObject(pJsonMsg);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        if (_json != null) {
            String t_appid = _json.optString("appid");
            if (_json.has("content")) {
                this.mContent = _json.optString("content");
            } else if (_json.has("message")) {
                this.mContent = _json.optString("message");
            } else {
                this.needCreateNotification = false;
                this.mContent = pJsonMsg;
            }
            if (_json.has(AssistPushConsts.MSG_TYPE_PAYLOAD)) {
                if (!PdrUtil.isEmpty(_json.optJSONObject(AssistPushConsts.MSG_TYPE_PAYLOAD))) {
                    this.mPayloadJSON = _json.optJSONObject(AssistPushConsts.MSG_TYPE_PAYLOAD);
                } else {
                    this.mPayload = _json.optString(AssistPushConsts.MSG_TYPE_PAYLOAD);
                }
            } else if (!_json.has("Payload")) {
                this.needCreateNotification = false;
                this.mPayload = pJsonMsg;
            } else if (!PdrUtil.isEmpty(_json.optJSONObject("Payload"))) {
                this.mPayloadJSON = _json.optJSONObject("Payload");
            } else {
                this.mPayload = _json.optString("Payload");
            }
            JSONObject _option = _json.optJSONObject("options");
            if (_json.has("title")) {
                this.mTitle = _json.optString("title");
            } else if (_option == null || !_option.has("title")) {
                this.needCreateNotification = false;
                this.mTitle = defaultTitle;
            } else {
                this.mTitle = _option.optString("title");
            }
            if (_option != null) {
                this.isCover = _option.optBoolean(IApp.ConfigProperty.CONFIG_COVER);
                if ("none".equals(_option.optString("sound"))) {
                    this.sound = "none";
                }
                this.mWhen = _option.optLong("when");
                this.mDelay = _option.optLong(IApp.ConfigProperty.CONFIG_DELAY);
                if (TextUtils.isEmpty(t_appid)) {
                    t_appid = _option.optString("appid");
                }
                this.mPath = _option.optString("path");
                this.mForceNotification = _option.optString("force_notification");
            }
            if (TextUtils.isEmpty(t_appid)) {
                t_appid = defaultAppid;
            }
            this.mMessageAppid = t_appid;
            if (_option != null) {
                String optString = _option.optString("icon");
                this.mIconPath = app != null ? app.convert2AbsFullPath(optString) : convert2AbsFullPath(optString, this.mMessageAppid);
                return;
            }
            return;
        }
        this.needCreateNotification = false;
        this.mContent = pJsonMsg;
        this.mPayload = pJsonMsg;
        this.mTitle = defaultTitle;
    }

    public String convert2AbsFullPath(String pSrcPath, String mAppid) {
        try {
            if (!PdrUtil.isEmpty(pSrcPath) && DHFile.isExist(pSrcPath)) {
                return pSrcPath;
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        if (PdrUtil.isEmpty(pSrcPath)) {
            return pSrcPath;
        }
        int p = pSrcPath.indexOf(Operators.CONDITION_IF_STRING);
        if (p > 0) {
            pSrcPath = pSrcPath.substring(0, p);
        }
        if (pSrcPath.startsWith("_documents/")) {
            return BaseInfo.sDocumentFullPath + pSrcPath.substring("_documents/".length());
        } else if (pSrcPath.startsWith(BaseInfo.REL_PUBLIC_DOCUMENTS_DIR)) {
            return BaseInfo.sDocumentFullPath + pSrcPath.substring(BaseInfo.REL_PUBLIC_DOCUMENTS_DIR.length());
        } else if (pSrcPath.startsWith(AbsoluteConst.MINI_SERVER_APP_DOC)) {
            return BaseInfo.sBaseFsAppsPath + mAppid + "/" + BaseInfo.REAL_PRIVATE_DOC_DIR + pSrcPath.substring(AbsoluteConst.MINI_SERVER_APP_DOC.length());
        } else if (pSrcPath.startsWith(BaseInfo.REL_PRIVATE_DOC_DIR)) {
            return BaseInfo.sBaseFsAppsPath + mAppid + "/" + BaseInfo.REAL_PRIVATE_DOC_DIR + pSrcPath.substring(BaseInfo.REL_PRIVATE_DOC_DIR.length());
        } else if (pSrcPath.startsWith("_downloads/")) {
            return BaseInfo.sDownloadFullPath + pSrcPath.substring("_downloads/".length());
        } else if (pSrcPath.startsWith(BaseInfo.REL_PUBLIC_DOWNLOADS_DIR)) {
            return BaseInfo.sDownloadFullPath + pSrcPath.substring(BaseInfo.REL_PUBLIC_DOWNLOADS_DIR.length());
        } else if (pSrcPath.startsWith(AbsoluteConst.MINI_SERVER_APP_WWW)) {
            String pSrcPath2 = BaseInfo.sCacheFsAppsPath + mAppid + "/www/" + pSrcPath.substring(AbsoluteConst.MINI_SERVER_APP_WWW.length());
            try {
                if (DHFile.isExist(pSrcPath2)) {
                    return pSrcPath2;
                }
                return BaseInfo.sBaseResAppsPath + mAppid + "/" + BaseInfo.APP_WWW_FS_DIR + pSrcPath2.substring(AbsoluteConst.MINI_SERVER_APP_WWW.length());
            } catch (IOException e2) {
                e2.printStackTrace();
                return pSrcPath2;
            }
        } else if (pSrcPath.startsWith(BaseInfo.REL_PRIVATE_WWW_DIR)) {
            String pSrcPath3 = BaseInfo.sCacheFsAppsPath + mAppid + "/www/" + pSrcPath.substring(BaseInfo.REL_PRIVATE_WWW_DIR.length());
            try {
                if (DHFile.isExist(pSrcPath3)) {
                    return pSrcPath3;
                }
                return BaseInfo.sBaseResAppsPath + mAppid + "/" + BaseInfo.APP_WWW_FS_DIR + pSrcPath3.substring(BaseInfo.REL_PRIVATE_WWW_DIR.length());
            } catch (IOException e3) {
                e3.printStackTrace();
                return pSrcPath3;
            }
        } else if (pSrcPath.startsWith(DeviceInfo.FILE_PROTOCOL)) {
            return pSrcPath.substring(DeviceInfo.FILE_PROTOCOL.length());
        } else {
            if (pSrcPath.startsWith(DeviceInfo.sDeviceRootDir)) {
                return pSrcPath;
            }
            return pSrcPath;
        }
    }

    public void parse(Bundle b) {
        this.mTitle = b.getString("title");
        this.mContent = b.getString("content");
        this.nID = b.getInt("nId");
        this.mWhen = b.getLong("when");
        this.sound = b.getString("sound");
        this.mMessageAppid = b.getString("appid");
        this.mUUID = b.getString(UserBox.TYPE);
        this.mPayload = b.getString(AssistPushConsts.MSG_TYPE_PAYLOAD);
        this.mIconPath = b.getString("icon");
        this.mIsStreamApp = b.getBoolean("isstreamapp");
    }

    public Bundle toBundle() {
        Bundle b = new Bundle();
        if (this.extJSON == null || this.pushVersion != 2.0d) {
            b.putString("title", this.mTitle);
            b.putString("content", this.mContent);
            b.putInt("nId", this.nID);
            b.putLong("when", this.mWhen);
            b.putString("sound", this.sound);
            b.putString("appid", this.mMessageAppid);
            b.putString(UserBox.TYPE, this.mUUID);
            if (!PdrUtil.isEmpty(this.mPayloadJSON)) {
                b.putString(AssistPushConsts.MSG_TYPE_PAYLOAD, this.mPayloadJSON.toString());
            } else {
                b.putString(AssistPushConsts.MSG_TYPE_PAYLOAD, this.mPayload);
            }
            b.putString("icon", this.mIconPath);
            b.putBoolean("isstreamapp", this.mIsStreamApp);
            return b;
        }
        b.putInt("nId", this.nID);
        b.putLong("when", this.mWhen);
        b.putString("sound", this.sound);
        b.putString("appid", this.mMessageAppid);
        b.putString(UserBox.TYPE, this.mUUID);
        b.putString("icon", this.mIconPath);
        b.putBoolean("isstreamapp", this.mIsStreamApp);
        Iterator<String> iterator = this.extJSON.keys();
        while (iterator.hasNext()) {
            String key = iterator.next();
            Object o = null;
            try {
                o = this.extJSON.get(key);
            } catch (JSONException e) {
                e.printStackTrace();
            }
            if (o != null) {
                if (o instanceof String) {
                    b.putString(key, (String) o);
                } else if (o instanceof Integer) {
                    b.putInt(key, ((Integer) o).intValue());
                } else if (o instanceof Double) {
                    b.putDouble(key, ((Double) o).doubleValue());
                } else if (o instanceof Boolean) {
                    b.putBoolean(key, ((Boolean) o).booleanValue());
                } else if (o instanceof JSONObject) {
                    b.putString(key, String.valueOf(o));
                }
            }
        }
        return b;
    }

    public String toJSON() {
        JSONObject payLoadObj;
        JSONObject json = new JSONObject();
        JSONObject jsonObject = this.extJSON;
        if (jsonObject == null) {
            try {
                json.put(AbsoluteConst.JSON_KEY_UUID, this.mUUID);
                json.put("title", this.mTitle);
                json.put("appid", this.mMessageAppid);
                json.put("content", this.mContent);
                if (!PdrUtil.isEmpty(this.mPayloadJSON)) {
                    json.put(AssistPushConsts.MSG_TYPE_PAYLOAD, this.mPayloadJSON);
                } else {
                    try {
                        payLoadObj = new JSONObject(this.mPayload);
                    } catch (Exception e) {
                        payLoadObj = null;
                    }
                    if (payLoadObj != null) {
                        json.put(AssistPushConsts.MSG_TYPE_PAYLOAD, payLoadObj);
                    } else {
                        json.put(AssistPushConsts.MSG_TYPE_PAYLOAD, this.mPayload);
                    }
                }
                if (!PdrUtil.isEmpty(this.mPath)) {
                    json.put("path", this.mPath);
                }
                if (!PdrUtil.isEmpty(this.mForceNotification)) {
                    json.put("force_notification", this.mForceNotification);
                }
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            return json.toString();
        } else if (this.pushVersion != 2.0d) {
            return jsonObject.toString();
        } else {
            JSONObject jsonObject2 = JSONUtil.createJSONObject(jsonObject.toString());
            try {
                jsonObject2.put(AbsoluteConst.JSON_KEY_UUID, this.mUUID);
                jsonObject2.put("appid", this.mMessageAppid);
                return jsonObject2.toString();
            } catch (JSONException e3) {
                e3.printStackTrace();
                return "";
            }
        }
    }
}
