package io.dcloud.feature.bluetooth;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGatt;
import android.bluetooth.BluetoothGattCallback;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothGattDescriptor;
import android.bluetooth.BluetoothGattService;
import android.bluetooth.BluetoothManager;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Build;
import com.coremedia.iso.boxes.UserBox;
import com.igexin.push.core.b;
import com.igexin.sdk.PushConsts;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class BluetoothBaseAdapter implements MessageHandler.IMessages {
    private static String CALLBACK_ADAPTER_STATUS_CHANGED = "callback_adapter_status_changed";
    private static String CALLBACK_BLECHARACTERISTIC_VALUE_CHANGE = "callback_blecharacteristicvaluechange";
    private static String CALLBACK_CONNECTION_STATUS_CHANGED = "callback_connection_status_change";
    static String CALLBACK_DEVICE_FOUND = "callback_device_found";
    public static String CLIENT_CHARACTERISTIC_CONFIG = "00002902-0000-1000-8000-00805f9b34fb";
    String STATUS_ACTION = "io.dcloud.bluetooth.sendsearch";
    final String _JS_FUNCTION = DOMException.JSON_ERROR_INFO;
    boolean allowDuplicatesDevice = false;
    private Map<String, BluetoothGatt> bleConnected;
    private BroadcastReceiver bluetoothStatuReceiver = new BroadcastReceiver() {
        /* class io.dcloud.feature.bluetooth.BluetoothBaseAdapter.AnonymousClass1 */

        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            boolean z = false;
            if (action.equals("android.bluetooth.adapter.action.STATE_CHANGED")) {
                int blueState = intent.getIntExtra("android.bluetooth.adapter.extra.STATE", 0);
                BluetoothBaseAdapter bluetoothBaseAdapter = BluetoothBaseAdapter.this;
                String str = BluetoothBaseAdapter.CALLBACK_ADAPTER_STATUS_CHANGED;
                Object[] objArr = new Object[2];
                objArr[0] = Boolean.valueOf(BluetoothBaseAdapter.this.isSearchBTDevice);
                if (blueState == 12) {
                    z = true;
                }
                objArr[1] = Boolean.valueOf(z);
                bluetoothBaseAdapter.execJsCallback(str, StringUtil.format("{discovering:%b,available:%b}", objArr), true);
            } else if (action.equalsIgnoreCase(BluetoothBaseAdapter.this.STATUS_ACTION)) {
                BluetoothBaseAdapter.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_ADAPTER_STATUS_CHANGED, StringUtil.format("{discovering:%b,available:%b}", Boolean.valueOf(BluetoothBaseAdapter.this.isSearchBTDevice), true), true);
            }
        }
    };
    private Map<String, HashMap<String, IWebview>> callbacks;
    private HashMap<String, BluetoothGatt> createGatt;
    private BTBluetoothGattCallback gattCallback;
    private String getDeviceRSSICallback;
    private IWebview getDeviceRSSIWebview;
    boolean isInit = false;
    boolean isSearchBTDevice = false;

    public void openBluetoothAdapter(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
        if (!pwebview.getContext().getPackageManager().hasSystemFeature("android.hardware.bluetooth_le")) {
            execCallback(pwebview, callbackid, 10009, "system not support", JSUtil.ERROR);
        } else if (adapter == null) {
            execCallback(pwebview, callbackid, 10010, "unsupport", JSUtil.ERROR);
        } else if (!adapter.isEnabled()) {
            execCallback(pwebview, callbackid, 10001, "not available", JSUtil.ERROR);
        } else {
            adapter.enable();
            this.isInit = true;
            this.gattCallback = new BTBluetoothGattCallback();
            execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
        }
    }

    public void dispose(String pAppid) {
        Map<String, HashMap<String, IWebview>> map = this.callbacks;
        if (map != null) {
            HashMap<String, IWebview> adapters = map.get(CALLBACK_ADAPTER_STATUS_CHANGED);
            if (adapters != null) {
                for (String key : adapters.keySet()) {
                    if (adapters.get(key) != null) {
                        adapters.get(key).getContext().unregisterReceiver(this.bluetoothStatuReceiver);
                    }
                }
            }
            this.callbacks.clear();
        }
        this.isInit = false;
        Map<String, BluetoothGatt> map2 = this.bleConnected;
        if (map2 != null && map2.size() > 0) {
            for (String key2 : this.bleConnected.keySet()) {
                BluetoothGatt gatt = this.bleConnected.get(key2);
                gatt.disconnect();
                gatt.close();
            }
            this.bleConnected.clear();
        }
    }

    public void closeBluetoothAdapter(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
        if (!pwebview.getContext().getPackageManager().hasSystemFeature("android.hardware.bluetooth_le")) {
            execCallback(pwebview, callbackid, 10009, "system not support", JSUtil.ERROR);
        } else if (adapter == null) {
            execCallback(pwebview, callbackid, 10010, "unsupport", JSUtil.ERROR);
        } else if (!adapter.isEnabled()) {
            execCallback(pwebview, callbackid, 10001, "not available", JSUtil.ERROR);
        } else {
            this.isInit = false;
            Map<String, BluetoothGatt> map = this.bleConnected;
            if (map != null && map.size() > 0) {
                for (String key : this.bleConnected.keySet()) {
                    BluetoothGatt gatt = this.bleConnected.get(key);
                    gatt.disconnect();
                    gatt.close();
                }
                this.bleConnected.clear();
            }
            HashMap<String, BluetoothGatt> hashMap = this.createGatt;
            if (hashMap != null) {
                hashMap.clear();
            }
            execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
        }
    }

    public void getBluetoothAdapterState(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        if (this.isInit) {
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{discovering:%b,available:true}", Boolean.valueOf(this.isSearchBTDevice)), JSUtil.OK, true, false);
            return;
        }
        execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
    }

    public void onBluetoothDeviceFound(IWebview pwebview, JSONArray args) {
        HashMap<String, IWebview> adapter = getStringIWebviewHashMap(CALLBACK_DEVICE_FOUND);
        adapter.put(args.optString(0), pwebview);
        this.callbacks.put(CALLBACK_DEVICE_FOUND, adapter);
    }

    public void getBluetoothDevices(IWebview pwebview, JSONArray args) {
    }

    public void startBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
    }

    public void stopBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
    }

    public void onBluetoothAdapterStateChange(IWebview pwebview, JSONArray args) {
        HashMap<String, IWebview> adapter = getStringIWebviewHashMap(CALLBACK_ADAPTER_STATUS_CHANGED);
        adapter.put(args.optString(0), pwebview);
        this.callbacks.put(CALLBACK_ADAPTER_STATUS_CHANGED, adapter);
        IntentFilter stateChangeFilter = new IntentFilter("android.bluetooth.adapter.action.STATE_CHANGED");
        IntentFilter connectedFilter = new IntentFilter("android.bluetooth.device.action.ACL_CONNECTED");
        IntentFilter disConnectedFilter = new IntentFilter("android.bluetooth.device.action.ACL_DISCONNECTED");
        IntentFilter statusFilter = new IntentFilter(this.STATUS_ACTION);
        pwebview.getContext().registerReceiver(this.bluetoothStatuReceiver, stateChangeFilter);
        pwebview.getContext().registerReceiver(this.bluetoothStatuReceiver, connectedFilter);
        pwebview.getContext().registerReceiver(this.bluetoothStatuReceiver, disConnectedFilter);
        if (Build.VERSION.SDK_INT >= 33) {
            pwebview.getContext().registerReceiver(this.bluetoothStatuReceiver, statusFilter, 4);
        } else {
            pwebview.getContext().registerReceiver(this.bluetoothStatuReceiver, statusFilter);
        }
    }

    private HashMap<String, IWebview> getStringIWebviewHashMap(String key) {
        if (this.callbacks == null) {
            this.callbacks = new HashMap();
        }
        return new HashMap<>();
    }

    public void getConnectedBluetoothDevices(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        args.optJSONObject(1).optJSONArray(IApp.ConfigProperty.CONFIG_SERVICES);
        if (this.isInit) {
            BluetoothManager bluetoothManager = (BluetoothManager) pwebview.getContext().getSystemService("bluetooth");
            if (bluetoothManager != null) {
                List<BluetoothDevice> devices = bluetoothManager.getConnectedDevices(7);
                JSONArray array = new JSONArray();
                Map<String, BluetoothGatt> map = this.bleConnected;
                if (map != null && map.size() > 0) {
                    try {
                        for (BluetoothDevice device : devices) {
                            JSONObject object = new JSONObject();
                            if (this.bleConnected.containsKey(device.getAddress())) {
                                object.put("name", device.getName());
                                object.put("deviceId", device.getAddress());
                                array.put(object);
                            }
                        }
                    } catch (Exception e) {
                    }
                }
                Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{devices:%s}", array.toString()), JSUtil.OK, true, false);
                return;
            }
            return;
        }
        execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
    }

    public void createBLEConnection(IWebview pwebview, JSONArray args) {
        BluetoothGatt gatt;
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        String deviceid = param.optString("deviceId");
        String timeout = param.optString("timeout");
        if (!checkNull(pwebview, callbackid, deviceid)) {
            if (this.isInit) {
                BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
                if (this.bleConnected == null) {
                    this.bleConnected = new HashMap();
                }
                if (this.createGatt == null) {
                    this.createGatt = new HashMap<>();
                }
                try {
                    BluetoothDevice device = adapter.getRemoteDevice(deviceid);
                    if (!this.bleConnected.containsKey(deviceid) || this.bleConnected.get(deviceid) == null) {
                        HashMap<String, IWebview> create = getStringIWebviewHashMap("");
                        create.put(callbackid, pwebview);
                        this.callbacks.put(deviceid, create);
                        if (Build.VERSION.SDK_INT >= 23) {
                            gatt = device.connectGatt(pwebview.getContext(), false, this.gattCallback, 2);
                        } else {
                            gatt = device.connectGatt(pwebview.getContext(), false, this.gattCallback);
                        }
                        this.createGatt.put(deviceid, gatt);
                        if (param.has("timeout") && !PdrUtil.isEmpty(timeout)) {
                            try {
                                MessageHandler.sendMessage(this, Long.parseLong(timeout), gatt);
                            } catch (Exception e) {
                            }
                        }
                    } else {
                        execCallback(pwebview, callbackid, -1, "already connect", JSUtil.ERROR);
                    }
                } catch (Exception e2) {
                    execCallback(pwebview, callbackid, 10002, "no device", JSUtil.ERROR);
                }
            } else {
                execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
            }
        }
    }

    public void setBLEMTU(IWebview pwebview, JSONArray args) {
        String deviceid = args.optJSONObject(1).optString("deviceId");
        String callbackid = args.optString(0);
        String mtuStr = args.optJSONObject(1).optString("mtu");
        if (Build.VERSION.SDK_INT < 21) {
            execCallback(pwebview, callbackid, 10004, "not support", JSUtil.ERROR);
        } else if (!this.isInit) {
            execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
        } else {
            if (!checkNull(pwebview, callbackid, deviceid, mtuStr)) {
                try {
                    int mtu = Integer.parseInt(mtuStr);
                    if (mtu <= 22 || mtu > 512) {
                        execCallback(pwebview, callbackid, PushConsts.GET_DEVICETOKEN, "invalid data", JSUtil.ERROR);
                    } else if (this.bleConnected == null || !this.bleConnected.containsKey(deviceid)) {
                        execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                    } else {
                        BluetoothGatt gatt = this.bleConnected.get(deviceid);
                        if (gatt != null) {
                            gatt.requestMtu(mtu);
                            execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
                        } else {
                            execCallback(pwebview, callbackid, 10004, "no service", JSUtil.ERROR);
                        }
                    }
                } catch (Exception e) {
                    execCallback(pwebview, callbackid, PushConsts.GET_DEVICETOKEN, "parameter.mtu should be Number", JSUtil.ERROR);
                }
            }
        }
    }

    public void getBLEDeviceRSSI(IWebview pwebview, JSONArray args) {
        String deviceid = args.optJSONObject(1).optString("deviceId");
        String callbackid = args.optString(0);
        if (!this.isInit) {
            execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
            return;
        }
        if (!checkNull(pwebview, callbackid, deviceid)) {
            Map<String, BluetoothGatt> map = this.bleConnected;
            if (map == null || !map.containsKey(deviceid) || this.bleConnected.get(deviceid) == null) {
                execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                return;
            }
            BluetoothGatt currentService = this.bleConnected.get(deviceid);
            if (currentService == null) {
                execCallback(pwebview, callbackid, 10004, "no service", JSUtil.ERROR);
                return;
            }
            this.getDeviceRSSIWebview = pwebview;
            this.getDeviceRSSICallback = callbackid;
            currentService.readRemoteRssi();
        }
    }

    public void closeBLEConnection(IWebview pwebview, JSONArray args) {
        String deviceid = args.optJSONObject(1).optString("deviceId");
        String callbackid = args.optString(0);
        if (!checkNull(pwebview, callbackid, deviceid)) {
            if (this.isInit) {
                Map<String, BluetoothGatt> map = this.bleConnected;
                if (map == null) {
                    execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                    return;
                }
                if (!map.containsKey(deviceid) || this.bleConnected.get(deviceid) == null) {
                    HashMap<String, BluetoothGatt> hashMap = this.createGatt;
                    if (!(hashMap == null || !hashMap.containsKey(deviceid) || this.createGatt.get(deviceid) == null)) {
                        this.createGatt.get(deviceid).disconnect();
                    }
                } else {
                    this.bleConnected.get(deviceid).disconnect();
                }
                execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
                return;
            }
            execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:32:0x00be A[Catch:{ JSONException -> 0x00d6 }] */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x00bf A[Catch:{ JSONException -> 0x00d6 }] */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00c9 A[Catch:{ JSONException -> 0x00d6 }] */
    /* JADX WARNING: Removed duplicated region for block: B:37:0x00cb A[Catch:{ JSONException -> 0x00d6 }] */
    public void getBLEDeviceCharacteristics(IWebview pwebview, JSONArray args) {
        boolean isWrite;
        boolean z = false;
        String callbackid = args.optString(0);
        boolean z2 = true;
        JSONObject param = args.optJSONObject(1);
        String deviceid = param.optString("deviceId");
        String serviceId = param.optString("serviceId");
        if (!checkNull(pwebview, callbackid, deviceid, serviceId)) {
            if (this.isInit) {
                Map<String, BluetoothGatt> map = this.bleConnected;
                if (map == null || !map.containsKey(deviceid) || this.bleConnected.get(deviceid) == null) {
                    execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                    return;
                }
                BluetoothGattService currentService = this.bleConnected.get(deviceid).getService(UUID.fromString(serviceId));
                if (currentService == null) {
                    execCallback(pwebview, callbackid, 10004, "no service", JSUtil.ERROR);
                    return;
                }
                List<BluetoothGattCharacteristic> characteristics = currentService.getCharacteristics();
                JSONArray characteristicArray = new JSONArray();
                int i = 0;
                while (i < characteristics.size()) {
                    BluetoothGattCharacteristic characteristic = characteristics.get(i);
                    JSONObject characteristicItem = null;
                    try {
                        characteristicItem = new JSONObject();
                        characteristicItem.put(UserBox.TYPE, characteristic.getUuid().toString().toUpperCase());
                        JSONObject properties = new JSONObject();
                        int property = characteristic.getProperties();
                        if ((property & 2) > 0) {
                            z = true;
                        }
                        properties.put("read", z);
                        if ((property & 8) <= 0) {
                            if ((property & 4) <= 0) {
                                isWrite = false;
                                properties.put("write", isWrite);
                                if ((property & 16) > 0) {
                                    z2 = false;
                                }
                                properties.put("notify", z2);
                                properties.put("indicate", (property & 32) <= 0);
                                characteristicItem.put("properties", properties);
                                characteristicArray.put(characteristicItem);
                                i++;
                                z = false;
                                z2 = true;
                            }
                        }
                        isWrite = true;
                        properties.put("write", isWrite);
                        if ((property & 16) > 0) {
                        }
                        properties.put("notify", z2);
                        properties.put("indicate", (property & 32) <= 0);
                        characteristicItem.put("properties", properties);
                    } catch (JSONException e) {
                    }
                    characteristicArray.put(characteristicItem);
                    i++;
                    z = false;
                    z2 = true;
                }
                Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{'characteristics':%s}", characteristicArray.toString()), JSUtil.OK, true, false);
                return;
            }
            execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
        }
    }

    public void getBLEDeviceServices(IWebview pwebview, JSONArray args) {
        String deviceid = args.optJSONObject(1).optString("deviceId");
        String callbackid = args.optString(0);
        if (!checkNull(pwebview, callbackid, deviceid)) {
            if (this.isInit) {
                BluetoothGatt gatt = getBluetoothGatt(deviceid);
                if (gatt != null) {
                    List<BluetoothGattService> services = gatt.getServices();
                    JSONArray serviceArray = new JSONArray();
                    for (BluetoothGattService service : services) {
                        JSONObject serviceObject = new JSONObject();
                        try {
                            serviceObject.put(UserBox.TYPE, service.getUuid().toString().toUpperCase());
                            serviceObject.put("isPrimary", service.getType() == 0);
                        } catch (JSONException e) {
                        }
                        serviceArray.put(serviceObject);
                    }
                    Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{'services':%s}", serviceArray.toString()), JSUtil.OK, true, false);
                    return;
                }
                execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                return;
            }
            execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
        }
    }

    public void notifyBLECharacteristicValueChange(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        String serviceId = param.optString("serviceId");
        String deviceid = param.optString("deviceId");
        String characteristicId = param.optString("characteristicId");
        boolean state = param.optBoolean("state", true);
        if (!checkNull(pwebview, callbackid, serviceId, deviceid, characteristicId)) {
            if (this.isInit) {
                BluetoothGatt gatt = getBluetoothGatt(deviceid);
                if (gatt != null) {
                    BluetoothGattService service = gatt.getService(UUID.fromString(serviceId));
                    if (service != null) {
                        BluetoothGattCharacteristic characteristic = service.getCharacteristic(UUID.fromString(characteristicId));
                        if (characteristic == null) {
                            execCallback(pwebview, callbackid, 10005, "no characteristic", JSUtil.ERROR);
                            return;
                        }
                        boolean notification = gatt.setCharacteristicNotification(characteristic, true);
                        BluetoothGattDescriptor descriptor = characteristic.getDescriptor(UUID.fromString(CLIENT_CHARACTERISTIC_CONFIG));
                        if (descriptor != null) {
                            if (!state) {
                                descriptor.setValue(BluetoothGattDescriptor.DISABLE_NOTIFICATION_VALUE);
                                gatt.writeDescriptor(descriptor);
                            } else if ((characteristic.getProperties() & 32) == 32) {
                                descriptor.setValue(BluetoothGattDescriptor.ENABLE_INDICATION_VALUE);
                                gatt.writeDescriptor(descriptor);
                            } else {
                                descriptor.setValue(BluetoothGattDescriptor.ENABLE_NOTIFICATION_VALUE);
                                gatt.writeDescriptor(descriptor);
                            }
                            if (notification) {
                                execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
                            } else {
                                execCallback(pwebview, callbackid, 10011, "notify fail", JSUtil.ERROR);
                            }
                        } else {
                            execCallback(pwebview, callbackid, 10008, "no descriptor", JSUtil.ERROR);
                        }
                    } else {
                        execCallback(pwebview, callbackid, 10004, "no service", JSUtil.ERROR);
                    }
                } else {
                    execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                }
            } else {
                execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
            }
        }
    }

    private void execCallback(IWebview pwebview, String callbackid, int i, String s, int error) {
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf(i), s), error, true, false);
    }

    private BluetoothGatt getBluetoothGatt(String deviceid) {
        Map<String, BluetoothGatt> map = this.bleConnected;
        if (map == null || !map.containsKey(deviceid) || this.bleConnected.get(deviceid) == null) {
            return null;
        }
        return this.bleConnected.get(deviceid);
    }

    public void onBLECharacteristicValueChange(IWebview pwebview, JSONArray args) {
        HashMap<String, IWebview> adapter = getStringIWebviewHashMap(CALLBACK_BLECHARACTERISTIC_VALUE_CHANGE);
        adapter.put(args.optString(0), pwebview);
        this.callbacks.put(CALLBACK_BLECHARACTERISTIC_VALUE_CHANGE, adapter);
    }

    public void onBLEConnectionStateChange(IWebview pwebview, JSONArray args) {
        HashMap<String, IWebview> adapter = getStringIWebviewHashMap(CALLBACK_CONNECTION_STATUS_CHANGED);
        adapter.put(args.optString(0), pwebview);
        this.callbacks.put(CALLBACK_CONNECTION_STATUS_CHANGED, adapter);
    }

    public void readBLECharacteristicValue(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        String serviceId = param.optString("serviceId");
        String deviceid = param.optString("deviceId");
        String characteristicId = param.optString("characteristicId");
        if (!checkNull(pwebview, callbackid, serviceId, deviceid, characteristicId)) {
            if (this.isInit) {
                BluetoothGatt gatt = getBluetoothGatt(deviceid);
                if (gatt != null) {
                    BluetoothGattService service = gatt.getService(UUID.fromString(serviceId));
                    if (service != null) {
                        BluetoothGattCharacteristic characteristic = service.getCharacteristic(UUID.fromString(characteristicId));
                        if (characteristic == null) {
                            execCallback(pwebview, callbackid, 10005, "no characteristic", JSUtil.ERROR);
                        } else if (gatt.readCharacteristic(characteristic)) {
                            execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
                        } else {
                            execCallback(pwebview, callbackid, 10007, "property not support", JSUtil.ERROR);
                        }
                    }
                } else {
                    execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                }
            } else {
                execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
            }
        }
    }

    public static byte[] hexToByte(String str) {
        byte[] bytes = new byte[(str.length() / 2)];
        for (int i = 0; i < str.length() / 2; i++) {
            bytes[i] = (byte) Integer.parseInt(str.substring(i * 2, (i * 2) + 2), 16);
        }
        return bytes;
    }

    public static String bytesToHexString(byte[] bArray) {
        StringBuilder sb = new StringBuilder(bArray.length);
        for (byte b : bArray) {
            String sTemp = Integer.toHexString(b & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
            if (sTemp.length() < 2) {
                sb.append(0);
            }
            sb.append(sTemp.toUpperCase());
        }
        return sb.toString();
    }

    public void writeBLECharacteristicValue(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        String serviceId = param.optString("serviceId");
        String deviceid = param.optString("deviceId");
        String characteristicId = param.optString("characteristicId");
        String valueOpt = param.optString("value");
        if (!checkNull(pwebview, callbackid, serviceId, deviceid, characteristicId, valueOpt)) {
            byte[] value = hexToByte(valueOpt);
            if (this.isInit) {
                BluetoothGatt gatt = getBluetoothGatt(deviceid);
                if (gatt != null) {
                    BluetoothGattService service = gatt.getService(UUID.fromString(serviceId));
                    if (service != null) {
                        BluetoothGattCharacteristic characteristic = service.getCharacteristic(UUID.fromString(characteristicId));
                        if (characteristic == null) {
                            execCallback(pwebview, callbackid, 10005, "no characteristic", JSUtil.ERROR);
                            return;
                        }
                        characteristic.setValue(value);
                        if (gatt.writeCharacteristic(characteristic)) {
                            execCallback(pwebview, callbackid, 0, b.y, JSUtil.OK);
                        } else {
                            execCallback(pwebview, callbackid, 10007, "property not support", JSUtil.ERROR);
                        }
                    }
                } else {
                    execCallback(pwebview, callbackid, 10004, "no connection", JSUtil.ERROR);
                }
            } else {
                execCallback(pwebview, callbackid, 10000, "not init", JSUtil.ERROR);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public boolean checkNull(IWebview pwebview, String callbackid, String... param) {
        for (String p : param) {
            if (PdrUtil.isEmpty(p)) {
                execCallback(pwebview, callbackid, PushConsts.GET_DEVICETOKEN, "invalid data,please check parameters", JSUtil.ERROR);
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public void execJsCallback(String type, String msg, boolean keepCallback, boolean isResultOk) {
        HashMap<String, IWebview> jscallback;
        Map<String, HashMap<String, IWebview>> map = this.callbacks;
        if (!(map == null || (jscallback = map.get(type)) == null)) {
            for (String key : jscallback.keySet()) {
                Deprecated_JSUtil.execCallback(jscallback.get(key), key, msg, isResultOk ? JSUtil.OK : JSUtil.ERROR, true, keepCallback);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void execJsCallback(String type, String msg, boolean keepCallback) {
        execJsCallback(type, msg, keepCallback, true);
    }

    @Override // io.dcloud.common.adapter.util.MessageHandler.IMessages
    public void execute(Object pArgs) {
        try {
            BluetoothGatt gatt = (BluetoothGatt) pArgs;
            String deviceId = gatt.getDevice().getAddress();
            if (!this.bleConnected.containsKey(deviceId) || this.bleConnected.get(deviceId) == null) {
                HashMap<String, IWebview> cb = this.callbacks.get(deviceId);
                if (cb != null && cb.size() > 0) {
                    Iterator<Map.Entry<String, IWebview>> it = cb.entrySet().iterator();
                    if (it.hasNext()) {
                        Map.Entry<String, IWebview> entry = it.next();
                        IWebview webView = entry.getValue();
                        String callbackId = entry.getKey();
                        for (BluetoothDevice device : ((BluetoothManager) webView.getContext().getSystemService("bluetooth")).getConnectedDevices(7)) {
                            if (device.getAddress().equals(deviceId)) {
                                return;
                            }
                        }
                        gatt.disconnect();
                        execCallback(webView, callbackId, 10012, "operate time out", JSUtil.ERROR);
                        this.callbacks.remove(deviceId);
                    }
                }
            }
        } catch (Exception e) {
        }
    }

    private class BTBluetoothGattCallback extends BluetoothGattCallback {
        private BTBluetoothGattCallback() {
        }

        public void onConnectionStateChange(BluetoothGatt gatt, int status, int newState) {
            String deviceid = gatt.getDevice().getAddress();
            if (status == 0 && newState == 2) {
                gatt.discoverServices();
                BluetoothBaseAdapter.this.bleConnected.put(deviceid, gatt);
                BluetoothBaseAdapter.this.execJsCallback(deviceid, StringUtil.format(DOMException.JSON_ERROR_INFO, 0, b.y), false);
                BluetoothBaseAdapter.this.callbacks.remove(deviceid);
                BluetoothBaseAdapter.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_CONNECTION_STATUS_CHANGED, StringUtil.format("{deviceId:'%s',connected:%b}", deviceid, true), true);
                return;
            }
            if (newState == 0) {
                BluetoothBaseAdapter.this.execJsCallback(deviceid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10012, "operate time out"), false, false);
                BluetoothBaseAdapter.this.callbacks.remove(deviceid);
            }
            if (BluetoothBaseAdapter.this.bleConnected == null || !BluetoothBaseAdapter.this.bleConnected.containsKey(deviceid)) {
                gatt.disconnect();
                gatt.close();
                return;
            }
            ((BluetoothGatt) BluetoothBaseAdapter.this.bleConnected.get(deviceid)).disconnect();
            ((BluetoothGatt) BluetoothBaseAdapter.this.bleConnected.get(deviceid)).close();
            BluetoothBaseAdapter.this.bleConnected.remove(deviceid);
            BluetoothBaseAdapter.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_CONNECTION_STATUS_CHANGED, StringUtil.format("{deviceId:'%s',connected:%b}", deviceid, false), true);
        }

        public void onServicesDiscovered(BluetoothGatt gatt, int status) {
        }

        public void onCharacteristicChanged(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic) {
            BluetoothBaseAdapter.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_BLECHARACTERISTIC_VALUE_CHANGE, StringUtil.format("{deviceId:'%s',serviceId:'%s',characteristicId:'%s',value:'%s'}", gatt.getDevice().getAddress().toUpperCase(), characteristic.getService().getUuid().toString().toUpperCase(), characteristic.getUuid().toString().toUpperCase(), BluetoothBaseAdapter.bytesToHexString(characteristic.getValue())), true);
        }

        public void onCharacteristicRead(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic, int status) {
            BluetoothBaseAdapter.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_BLECHARACTERISTIC_VALUE_CHANGE, StringUtil.format("{deviceId:'%s',serviceId:'%s',characteristicId:'%s',value:'%s'}", gatt.getDevice().getAddress().toUpperCase(), characteristic.getService().getUuid().toString().toUpperCase(), characteristic.getUuid().toString().toUpperCase(), BluetoothBaseAdapter.bytesToHexString(characteristic.getValue())), true);
        }

        public void onCharacteristicWrite(BluetoothGatt gatt, BluetoothGattCharacteristic characteristic, int status) {
        }

        public void onReadRemoteRssi(BluetoothGatt gatt, int rssi, int status) {
            if (BluetoothBaseAdapter.this.getDeviceRSSIWebview != null && BluetoothBaseAdapter.this.getDeviceRSSICallback != null) {
                Deprecated_JSUtil.execCallback(BluetoothBaseAdapter.this.getDeviceRSSIWebview, BluetoothBaseAdapter.this.getDeviceRSSICallback, StringUtil.format("{RSSI:%d,code:%d}", Integer.valueOf(rssi), 0), JSUtil.OK, true, false);
                BluetoothBaseAdapter.this.getDeviceRSSIWebview = null;
                BluetoothBaseAdapter.this.getDeviceRSSICallback = null;
            }
        }
    }
}
