package io.dcloud.feature.bluetooth;

import android.os.Build;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.DHInterface.StandardFeature;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.StringUtil;
import org.json.JSONArray;

public class BluetoothFeature extends StandardFeature {
    private BluetoothBaseAdapter bluetoothF;

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.StandardFeature
    public void init(AbsMgr pFeatureMgr, String pFeatureName) {
        super.init(pFeatureMgr, pFeatureName);
        this.bluetoothF = new BluetoothUnder21();
    }

    public void openBluetoothAdapter(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-openBluetoothAdapter");
        this.bluetoothF.openBluetoothAdapter(pwebview, args);
    }

    public void closeBluetoothAdapter(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-closeBluetoothAdapter");
        this.bluetoothF.closeBluetoothAdapter(pwebview, args);
    }

    public void getBluetoothAdapterState(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getBluetoothAdapterState");
        this.bluetoothF.getBluetoothAdapterState(pwebview, args);
    }

    public void onBluetoothAdapterStateChange(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-onBluetoothAdapterStateChange");
        this.bluetoothF.onBluetoothAdapterStateChange(pwebview, args);
    }

    public void onBluetoothDeviceFound(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-onBluetoothDeviceFound");
        this.bluetoothF.onBluetoothDeviceFound(pwebview, args);
    }

    public void getBluetoothDevices(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getBluetoothDevices");
        this.bluetoothF.getBluetoothDevices(pwebview, args);
    }

    public void getConnectedBluetoothDevices(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getConnectedBluetoothDevices");
        this.bluetoothF.getConnectedBluetoothDevices(pwebview, args);
    }

    public void startBluetoothDevicesDiscovery(final IWebview pwebview, final JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-startBluetoothDevicesDiscovery");
        if (Build.VERSION.SDK_INT >= 31) {
            PermissionUtil.useSystemPermissions(pwebview.getActivity(), new String[]{"android.permission.BLUETOOTH_SCAN", "android.permission.BLUETOOTH_CONNECT", "android.permission.ACCESS_FINE_LOCATION", "android.permission.ACCESS_COARSE_LOCATION"}, new PermissionUtil.Request() {
                /* class io.dcloud.feature.bluetooth.BluetoothFeature.AnonymousClass1 */
                int time = 0;

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    int i = this.time + 1;
                    this.time = i;
                    if (i == 4) {
                        BluetoothFeature.this.bluetoothF.startBluetoothDevicesDiscovery(pwebview, args);
                    }
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    String callbackid = args.optString(0);
                    IWebview iWebview = pwebview;
                    Deprecated_JSUtil.execCallback(iWebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, streamPerName + "permission denied"), JSUtil.ERROR, true, false);
                }
            });
        } else {
            PermissionUtil.useSystemPermissions(pwebview.getActivity(), new String[]{"android.permission.ACCESS_FINE_LOCATION", "android.permission.ACCESS_COARSE_LOCATION"}, new PermissionUtil.Request() {
                /* class io.dcloud.feature.bluetooth.BluetoothFeature.AnonymousClass2 */
                int times = 0;

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    int i = this.times + 1;
                    this.times = i;
                    if (i == 2) {
                        BluetoothFeature.this.bluetoothF.startBluetoothDevicesDiscovery(pwebview, args);
                    }
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    int i = this.times + 1;
                    this.times = i;
                    if (i == 2) {
                        BluetoothFeature.this.bluetoothF.startBluetoothDevicesDiscovery(pwebview, args);
                    }
                }
            });
        }
    }

    public void stopBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-stopBluetoothDevicesDiscovery");
        this.bluetoothF.stopBluetoothDevicesDiscovery(pwebview, args);
    }

    public void createBLEConnection(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-createBLEConnection");
        this.bluetoothF.createBLEConnection(pwebview, args);
    }

    public void setBLEMTU(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-setBLEMTU");
        this.bluetoothF.setBLEMTU(pwebview, args);
    }

    public void getBLEDeviceRSSI(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getBLEDeviceRSSI");
        this.bluetoothF.getBLEDeviceRSSI(pwebview, args);
    }

    public void closeBLEConnection(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-closeBLEConnection");
        this.bluetoothF.closeBLEConnection(pwebview, args);
    }

    public void getBLEDeviceCharacteristics(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getBLEDeviceCharacteristics");
        this.bluetoothF.getBLEDeviceCharacteristics(pwebview, args);
    }

    public void getBLEDeviceServices(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-getBLEDeviceServices");
        this.bluetoothF.getBLEDeviceServices(pwebview, args);
    }

    public void notifyBLECharacteristicValueChange(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-notifyBLECharacteristicValueChange");
        this.bluetoothF.notifyBLECharacteristicValueChange(pwebview, args);
    }

    public void onBLECharacteristicValueChange(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-onBLECharacteristicValueChange");
        this.bluetoothF.onBLECharacteristicValueChange(pwebview, args);
    }

    public void onBLEConnectionStateChange(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-onBLEConnectionStateChange");
        this.bluetoothF.onBLEConnectionStateChange(pwebview, args);
    }

    public void readBLECharacteristicValue(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-readBLECharacteristicValue");
        this.bluetoothF.readBLECharacteristicValue(pwebview, args);
    }

    public void writeBLECharacteristicValue(IWebview pwebview, JSONArray args) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pwebview.getContext(), "Bluetooth-writeBLECharacteristicValue");
        this.bluetoothF.writeBLECharacteristicValue(pwebview, args);
    }

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature
    public void dispose(String pAppid) {
        this.bluetoothF.dispose(pAppid);
    }
}
