package io.dcloud.feature.bluetooth;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.le.BluetoothLeScanner;
import android.bluetooth.le.ScanCallback;
import android.bluetooth.le.ScanFilter;
import android.bluetooth.le.ScanResult;
import android.bluetooth.le.ScanSettings;
import android.content.Intent;
import android.os.Build;
import android.os.ParcelUuid;
import com.igexin.push.core.b;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import org.json.JSONArray;
import org.json.JSONObject;

public class BluetoothOver21 extends BluetoothBaseAdapter {
    private BTScanCallback mScanCallback;
    private BluetoothLeScanner scanner;

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void closeBluetoothAdapter(IWebview pwebview, JSONArray args) {
        BluetoothLeScanner bluetoothLeScanner;
        BTScanCallback bTScanCallback;
        super.closeBluetoothAdapter(pwebview, args);
        if (this.isSearchBTDevice && Build.VERSION.SDK_INT >= 21 && (bluetoothLeScanner = this.scanner) != null && (bTScanCallback = this.mScanCallback) != null) {
            bluetoothLeScanner.stopScan(bTScanCallback);
            this.isSearchBTDevice = false;
        }
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void getBluetoothDevices(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        if (this.isInit) {
            StringBuilder builder = new StringBuilder();
            BTScanCallback bTScanCallback = this.mScanCallback;
            if (bTScanCallback != null) {
                Map<String, DCBluetoothDevice> scanresult = bTScanCallback.getScanList();
                Iterator<String> it = scanresult.keySet().iterator();
                while (it.hasNext()) {
                    builder.append(scanresult.get(it.next()).toString() + ",");
                }
            }
            if (builder.lastIndexOf(",") > 5) {
                builder.deleteCharAt(builder.lastIndexOf(","));
            }
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{devices:[%s]}", builder.toString()), JSUtil.OK, true, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void startBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
        List<ScanFilter> scanFilters;
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        JSONArray serviceIds = param.optJSONArray(IApp.ConfigProperty.CONFIG_SERVICES);
        this.allowDuplicatesDevice = param.optBoolean("allowDuplicatesKey", false);
        String interval = param.optString("interval");
        if (this.isInit) {
            this.mScanCallback = new BTScanCallback(this);
            BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
            if (adapter != null && Build.VERSION.SDK_INT >= 21) {
                this.scanner = adapter.getBluetoothLeScanner();
                ScanSettings.Builder settings = new ScanSettings.Builder();
                if (serviceIds == null || serviceIds.length() <= 0) {
                    scanFilters = null;
                } else {
                    List<ScanFilter> scanFilters2 = new ArrayList<>();
                    for (int i = 0; i < serviceIds.length(); i++) {
                        ScanFilter.Builder filter = new ScanFilter.Builder();
                        filter.setServiceUuid(new ParcelUuid(UUID.fromString(serviceIds.optString(i))));
                        scanFilters2.add(filter.build());
                    }
                    scanFilters = scanFilters2;
                }
                if (!PdrUtil.isEmpty(interval)) {
                    try {
                        settings.setReportDelay(Long.parseLong(interval));
                    } catch (Exception e) {
                    }
                }
                this.scanner.startScan(scanFilters, settings.build(), this.mScanCallback);
                Intent intent = new Intent();
                intent.setAction(this.STATUS_ACTION);
                intent.setPackage(pwebview.getContext().getPackageName());
                intent.putExtra("android.bluetooth.adapter.extra.STATE", 12);
                pwebview.getContext().sendBroadcast(intent);
                this.isSearchBTDevice = true;
                Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 0, b.y), JSUtil.OK, true, false);
                return;
            }
            return;
        }
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void stopBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
        BluetoothLeScanner bluetoothLeScanner;
        BTScanCallback bTScanCallback;
        String callbackid = args.optString(0);
        if (!this.isInit) {
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
        } else if (Build.VERSION.SDK_INT >= 21 && (bluetoothLeScanner = this.scanner) != null && (bTScanCallback = this.mScanCallback) != null) {
            bluetoothLeScanner.stopScan(bTScanCallback);
            this.isSearchBTDevice = false;
            Intent intent = new Intent();
            intent.setAction(this.STATUS_ACTION);
            intent.setPackage(pwebview.getContext().getPackageName());
            intent.putExtra("android.bluetooth.adapter.extra.STATE", 12);
            pwebview.getContext().sendBroadcast(intent);
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 0, b.y), JSUtil.OK, true, false);
        }
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void dispose(String pAppid) {
        super.dispose(pAppid);
        if (this.isSearchBTDevice && Build.VERSION.SDK_INT >= 21) {
            this.scanner.stopScan(this.mScanCallback);
            this.isSearchBTDevice = false;
        }
    }

    private class BTScanCallback extends ScanCallback {
        private String __JS__FUNCTION;
        private String callbackId;
        private IWebview pwebview;
        private Map<String, DCBluetoothDevice> scanList;

        public BTScanCallback(BluetoothOver21 bluetoothOver21) {
            this(null, null);
        }

        public BTScanCallback(IWebview pwebview2, String callbackId2) {
            this.__JS__FUNCTION = "{devices:[%s]}";
            this.pwebview = pwebview2;
            this.callbackId = callbackId2;
            this.scanList = new HashMap();
        }

        public void onScanResult(int callbackType, ScanResult result) {
            DCBluetoothDevice device = new DCBluetoothDevice(result);
            if (BluetoothOver21.this.allowDuplicatesDevice) {
                BluetoothOver21.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_DEVICE_FOUND, StringUtil.format(this.__JS__FUNCTION, device.toString()), true);
                return;
            }
            String deviceId = result.getDevice().getAddress();
            if (!this.scanList.containsKey(deviceId)) {
                this.scanList.put(deviceId, device);
                BluetoothOver21.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_DEVICE_FOUND, StringUtil.format(this.__JS__FUNCTION, device.toString()), true);
            }
        }

        public void onScanFailed(int errorCode) {
        }

        public Map<String, DCBluetoothDevice> getScanList() {
            return this.scanList;
        }
    }
}
