package io.dcloud.feature.bluetooth;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.Intent;
import com.igexin.push.core.b;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.StringUtil;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.UUID;
import org.json.JSONArray;
import org.json.JSONObject;

public class BluetoothUnder21 extends BluetoothBaseAdapter {
    private BTScanCallback m21ScanCallback;

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void closeBluetoothAdapter(IWebview pwebview, JSONArray args) {
        BluetoothAdapter adapter;
        BTScanCallback bTScanCallback;
        super.closeBluetoothAdapter(pwebview, args);
        if (this.isSearchBTDevice && (adapter = BluetoothAdapter.getDefaultAdapter()) != null && (bTScanCallback = this.m21ScanCallback) != null) {
            adapter.stopLeScan(bTScanCallback);
            this.isSearchBTDevice = false;
        }
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void startBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        JSONObject param = args.optJSONObject(1);
        JSONArray serviceIds = param.optJSONArray(IApp.ConfigProperty.CONFIG_SERVICES);
        this.allowDuplicatesDevice = param.optBoolean("allowDuplicatesKey", false);
        param.optString("interval");
        if (this.isInit) {
            BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
            if (adapter != null) {
                this.m21ScanCallback = new BTScanCallback();
                ArrayList<UUID> uuids = null;
                if (serviceIds != null) {
                    ArrayList<UUID> uuids2 = new ArrayList<>();
                    for (int i = 0; i < serviceIds.length(); i++) {
                        try {
                            uuids2.add(UUID.fromString(serviceIds.optString(i)));
                        } catch (Exception e) {
                        }
                    }
                    uuids = uuids2;
                }
                if (adapter.startLeScan(uuids != null ? (UUID[]) uuids.toArray(new UUID[0]) : null, this.m21ScanCallback)) {
                    Intent intent = new Intent();
                    intent.setAction(this.STATUS_ACTION);
                    intent.setPackage(pwebview.getContext().getPackageName());
                    intent.putExtra("android.bluetooth.adapter.extra.STATE", 12);
                    pwebview.getContext().sendBroadcast(intent);
                    this.isSearchBTDevice = true;
                    Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 0, b.y), JSUtil.OK, true, false);
                    return;
                }
                Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10015, "startBluetoothDevicesDiscovery fail"), JSUtil.ERROR, true, false);
                return;
            }
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10010, "unsupport"), JSUtil.ERROR, true, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void stopBluetoothDevicesDiscovery(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        if (this.isInit) {
            BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
            BTScanCallback bTScanCallback = this.m21ScanCallback;
            if (bTScanCallback == null || adapter == null) {
                Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10015, "stopBluetoothDevicesDiscovery fail"), JSUtil.ERROR, true, false);
                return;
            }
            adapter.stopLeScan(bTScanCallback);
            this.isSearchBTDevice = false;
            Intent intent = new Intent();
            intent.setAction(this.STATUS_ACTION);
            intent.setPackage(pwebview.getContext().getPackageName());
            intent.putExtra("android.bluetooth.adapter.extra.STATE", 12);
            pwebview.getContext().sendBroadcast(intent);
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 0, b.y), JSUtil.OK, true, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void getBluetoothDevices(IWebview pwebview, JSONArray args) {
        String callbackid = args.optString(0);
        if (this.isInit) {
            StringBuilder builder = new StringBuilder();
            BTScanCallback bTScanCallback = this.m21ScanCallback;
            if (bTScanCallback != null) {
                Map<String, DCBluetoothDevice> scanresult = bTScanCallback.getScanList();
                Iterator<String> it = scanresult.keySet().iterator();
                while (it.hasNext()) {
                    builder.append(scanresult.get(it.next()).toString() + ",");
                }
            }
            if (builder.lastIndexOf(",") > 5) {
                builder.deleteCharAt(builder.lastIndexOf(","));
            }
            Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format("{devices:[%s]}", builder.toString()), JSUtil.OK, true, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pwebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, "not init"), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.feature.bluetooth.BluetoothBaseAdapter
    public void dispose(String pAppid) {
        super.dispose(pAppid);
        BluetoothAdapter adapter = BluetoothAdapter.getDefaultAdapter();
        if (adapter != null) {
            adapter.stopLeScan(this.m21ScanCallback);
            this.isSearchBTDevice = false;
        }
    }

    class BTScanCallback implements BluetoothAdapter.LeScanCallback {
        private String __JS__FUNCTION = "{devices:[%s]}";
        private Map<String, DCBluetoothDevice> scanList = new HashMap();

        public BTScanCallback() {
        }

        public void onLeScan(BluetoothDevice device1, int rssi, byte[] scanRecord) {
            DCBluetoothDevice dcDevice = new DCBluetoothDevice(device1, scanRecord);
            dcDevice.setRSSI(rssi);
            if (BluetoothUnder21.this.allowDuplicatesDevice) {
                BluetoothUnder21.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_DEVICE_FOUND, StringUtil.format(this.__JS__FUNCTION, dcDevice.toString()), true);
                this.scanList.put(device1.getAddress(), dcDevice);
                return;
            }
            String deviceId = device1.getAddress();
            if (!this.scanList.containsKey(deviceId)) {
                this.scanList.put(deviceId, dcDevice);
                BluetoothUnder21.this.execJsCallback(BluetoothBaseAdapter.CALLBACK_DEVICE_FOUND, StringUtil.format(this.__JS__FUNCTION, dcDevice.toString()), true);
            }
        }

        public Map<String, DCBluetoothDevice> getScanList() {
            return this.scanList;
        }
    }
}
