package io.dcloud.feature.contacts;

import android.content.Context;
import android.os.Build;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class JsContactsMgr {
    private static final String INVALID_ARGUMENT_ERROR = "1";
    private static final String IO_ERROR = "4";
    private static final String NOT_SUPPORTED_ERROR = "5";
    private static final String PENDING_OPERATION_ERROR = "3";
    private static final String PERMISSION_DENIED_ERROR = "20";
    private static final String TIMEOUT_ERROR = "2";
    private static final String UNKNOWN_ERROR = "0";
    private ContactAccessor mContactAccessor;

    public JsContactsMgr(Context pContext) {
        this.mContactAccessor = new ContactAccessorImpl(pContext);
    }

    public String execute(final IWebview pWebViewImpl, String pActionName, final String[] pJsArgs) {
        if (Build.VERSION.RELEASE.startsWith("1.")) {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "5", JSUtil.ERROR, false, false);
        }
        this.mContactAccessor.mApp = pWebViewImpl.getActivity();
        this.mContactAccessor.mView = pWebViewImpl;
        if (pActionName.equals("getAddressBook")) {
            PermissionUtil.usePermission(pWebViewImpl.getActivity(), "contacts", "android.permission.READ_CONTACTS", 2, new PermissionUtil.Request() {
                /* class io.dcloud.feature.contacts.JsContactsMgr.AnonymousClass1 */

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "", JSUtil.OK, false, false);
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], JsContactsMgr.PERMISSION_DENIED_ERROR, JSUtil.ERROR, false, false);
                }
            });
            return null;
        } else if (pActionName.equals("search")) {
            JSONArray fieldArray = null;
            JSONObject jsonObject = null;
            try {
                if (PdrUtil.isEmpty(pJsArgs[1])) {
                    fieldArray = new JSONArray();
                } else if (pJsArgs[1].indexOf(91) >= 0) {
                    fieldArray = new JSONArray(pJsArgs[1]);
                } else {
                    fieldArray = new JSONArray();
                    fieldArray.put(0, pJsArgs[1]);
                }
            } catch (Exception e) {
                try {
                    e.printStackTrace();
                } catch (JSONException e2) {
                    e2.printStackTrace();
                    Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "1", JSUtil.ERROR, false, false);
                    return null;
                }
            }
            if (!PdrUtil.isEmpty(pJsArgs[2])) {
                jsonObject = new JSONObject(pJsArgs[2]);
            }
            Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], this.mContactAccessor.search(fieldArray, jsonObject).toString(), JSUtil.OK, true, false);
            return null;
        } else if (pActionName.equals("save")) {
            PermissionUtil.usePermission(pWebViewImpl.getActivity(), "contacts", "android.permission.WRITE_CONTACTS", 2, new PermissionUtil.Request() {
                /* class io.dcloud.feature.contacts.JsContactsMgr.AnonymousClass2 */

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    try {
                        JSONObject jsonObject = new JSONObject(pJsArgs[1]);
                        if (JsContactsMgr.this.mContactAccessor.save(jsonObject)) {
                            Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], jsonObject.toString(), JSUtil.OK, true, false);
                        } else {
                            Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "1", JSUtil.ERROR, false, false);
                        }
                    } catch (JSONException e) {
                        e.printStackTrace();
                        Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "1", JSUtil.ERROR, false, false);
                    }
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], JsContactsMgr.PERMISSION_DENIED_ERROR, JSUtil.ERROR, false, false);
                }
            });
            return null;
        } else if (!pActionName.equals(AbsoluteConst.XML_REMOVE)) {
            return null;
        } else {
            PermissionUtil.usePermission(pWebViewImpl.getActivity(), "contacts", "android.permission.WRITE_CONTACTS", 2, new PermissionUtil.Request() {
                /* class io.dcloud.feature.contacts.JsContactsMgr.AnonymousClass3 */

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    if (JsContactsMgr.this.mContactAccessor.remove(pJsArgs[1])) {
                        Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "", JSUtil.OK, false, false);
                    } else {
                        Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], "0", JSUtil.ERROR, false, false);
                    }
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    Deprecated_JSUtil.execCallback(pWebViewImpl, pJsArgs[0], JsContactsMgr.PERMISSION_DENIED_ERROR, JSUtil.ERROR, false, false);
                }
            });
            return null;
        }
    }

    /* access modifiers changed from: package-private */
    public void dispose(String pAppid) {
    }
}
