package io.dcloud.feature.fingerprint;

import android.app.Activity;
import android.app.KeyguardManager;
import androidx.core.hardware.fingerprint.FingerprintManagerCompat;
import androidx.core.os.CancellationSignal;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.DHInterface.StandardFeature;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.JSUtil;
import org.json.JSONArray;
import org.json.JSONObject;

public class FingerPrintsImpl extends StandardFeature implements ISysEventListener {
    private IWebview iWebview;
    private CancellationSignal mCancellationSignal;
    private FingerprintManagerCompat mFingerprintManager;

    public interface IFingerprintResultListener {
        void onAuthenticateError(int i, CharSequence charSequence);

        void onAuthenticateFailed();

        void onAuthenticateHelp(int i, CharSequence charSequence);

        void onAuthenticateSucceeded(FingerprintManagerCompat.AuthenticationResult authenticationResult);
    }

    public String isSupport(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Fingerprint-isSupport");
        if (this.mFingerprintManager == null) {
            this.mFingerprintManager = FingerprintManagerCompat.from(pWebview.getActivity());
        }
        if (isHardwareDetected()) {
            return JSUtil.wrapJsVar(true);
        }
        return JSUtil.wrapJsVar(false);
    }

    public String isEnrolledFingerprints(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Fingerprint-isEnrolledFingerprints");
        if (this.mFingerprintManager == null) {
            this.mFingerprintManager = FingerprintManagerCompat.from(pWebview.getActivity());
        }
        if (isHasEnrolledFingerprints()) {
            return JSUtil.wrapJsVar(true);
        }
        return JSUtil.wrapJsVar(false);
    }

    public String isKeyguardSecure(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Fingerprint-isKeyguardSecure");
        if (isKeyguardSecure(pWebview.getActivity())) {
            return JSUtil.wrapJsVar(true);
        }
        return JSUtil.wrapJsVar(false);
    }

    public void cancel(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Fingerprint-cancel");
        cancelAuthenticate(pWebview);
    }

    public void authenticate(final IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Fingerprint-authenticate");
        final String cbid = array.optString(0);
        if (this.mFingerprintManager == null) {
            this.mFingerprintManager = FingerprintManagerCompat.from(pWebview.getActivity());
        }
        if (!isHardwareDetected()) {
            resultCallback(pWebview, cbid, 1, "no fingerprint device", JSUtil.ERROR, false);
        } else if (!isHasEnrolledFingerprints()) {
            resultCallback(pWebview, cbid, 3, "UNENROLLED", JSUtil.ERROR, false);
        } else if (!isKeyguardSecure(pWebview.getActivity())) {
            resultCallback(pWebview, cbid, 2, "IN SECURE", JSUtil.ERROR, false);
        } else {
            this.iWebview = pWebview;
            registerSysEvent(pWebview, ISysEventListener.SysEventType.onKeyUp);
            callFingerPrintVerify(new IFingerprintResultListener() {
                /* class io.dcloud.feature.fingerprint.FingerPrintsImpl.AnonymousClass1 */

                @Override // io.dcloud.feature.fingerprint.FingerPrintsImpl.IFingerprintResultListener
                public void onAuthenticateError(int errMsgId, CharSequence errString) {
                    int nErrorCode = 7;
                    if (errMsgId == 5) {
                        nErrorCode = 6;
                    } else if (errMsgId == 7) {
                        nErrorCode = 5;
                    }
                    FingerPrintsImpl.this.resultCallback(pWebview, cbid, nErrorCode, errString.toString(), JSUtil.ERROR, false);
                }

                @Override // io.dcloud.feature.fingerprint.FingerPrintsImpl.IFingerprintResultListener
                public void onAuthenticateFailed() {
                    FingerPrintsImpl.this.resultCallback(pWebview, cbid, 4, "Authenticate not match", JSUtil.ERROR, true);
                }

                @Override // io.dcloud.feature.fingerprint.FingerPrintsImpl.IFingerprintResultListener
                public void onAuthenticateHelp(int helpMsgId, CharSequence helpString) {
                }

                @Override // io.dcloud.feature.fingerprint.FingerPrintsImpl.IFingerprintResultListener
                public void onAuthenticateSucceeded(FingerprintManagerCompat.AuthenticationResult result) {
                    FingerPrintsImpl.this.resultCallback(pWebview, cbid, 0, "Authenticate Succeeded", JSUtil.OK, false);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void resultCallback(IWebview pWebiew, String strCbid, int nErrCode, String resString, int resState, Boolean keepCallback) {
        JSONObject resultObj = new JSONObject();
        try {
            resultObj.put("code", nErrCode);
            resultObj.put("message", resString);
        } catch (Exception e) {
        }
        JSUtil.execCallback(pWebiew, strCbid, resultObj, resState, keepCallback.booleanValue());
    }

    public void callFingerPrintVerify(final IFingerprintResultListener listener) {
        if (this.mCancellationSignal == null) {
            this.mCancellationSignal = new CancellationSignal();
        }
        try {
            this.mFingerprintManager.authenticate(null, 0, this.mCancellationSignal, new FingerprintManagerCompat.AuthenticationCallback() {
                /* class io.dcloud.feature.fingerprint.FingerPrintsImpl.AnonymousClass2 */

                @Override // androidx.core.hardware.fingerprint.FingerprintManagerCompat.AuthenticationCallback
                public void onAuthenticationError(int errMsgId, CharSequence errString) {
                    IFingerprintResultListener iFingerprintResultListener = listener;
                    if (iFingerprintResultListener != null) {
                        iFingerprintResultListener.onAuthenticateError(errMsgId, errString);
                    }
                }

                @Override // androidx.core.hardware.fingerprint.FingerprintManagerCompat.AuthenticationCallback
                public void onAuthenticationFailed() {
                    IFingerprintResultListener iFingerprintResultListener = listener;
                    if (iFingerprintResultListener != null) {
                        iFingerprintResultListener.onAuthenticateFailed();
                    }
                }

                @Override // androidx.core.hardware.fingerprint.FingerprintManagerCompat.AuthenticationCallback
                public void onAuthenticationHelp(int helpMsgId, CharSequence helpString) {
                    IFingerprintResultListener iFingerprintResultListener = listener;
                    if (iFingerprintResultListener != null) {
                        iFingerprintResultListener.onAuthenticateHelp(helpMsgId, helpString);
                    }
                }

                @Override // androidx.core.hardware.fingerprint.FingerprintManagerCompat.AuthenticationCallback
                public void onAuthenticationSucceeded(FingerprintManagerCompat.AuthenticationResult result) {
                    IFingerprintResultListener iFingerprintResultListener = listener;
                    if (iFingerprintResultListener != null) {
                        iFingerprintResultListener.onAuthenticateSucceeded(result);
                    }
                }
            }, null);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private boolean isHasEnrolledFingerprints() {
        try {
            return this.mFingerprintManager.hasEnrolledFingerprints();
        } catch (Exception e) {
            return false;
        }
    }

    public boolean isHardwareDetected() {
        try {
            return this.mFingerprintManager.isHardwareDetected();
        } catch (Exception e) {
            return false;
        }
    }

    private boolean isKeyguardSecure(Activity activity) {
        try {
            return ((KeyguardManager) activity.getSystemService("keyguard")).isKeyguardSecure();
        } catch (Exception e) {
            return false;
        }
    }

    public void cancelAuthenticate(IWebview pWebview) {
        if (pWebview != null) {
            unregisterSysEvent(pWebview, ISysEventListener.SysEventType.onKeyUp);
        }
        CancellationSignal cancellationSignal = this.mCancellationSignal;
        if (cancellationSignal != null) {
            cancellationSignal.cancel();
            this.mCancellationSignal = null;
            this.iWebview = null;
        }
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature
    public boolean onEventExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        CancellationSignal cancellationSignal;
        if (pEventType != ISysEventListener.SysEventType.onKeyUp || ((Integer) ((Object[]) pArgs)[0]).intValue() != 4 || (cancellationSignal = this.mCancellationSignal) == null || cancellationSignal.isCanceled()) {
            return false;
        }
        cancelAuthenticate(this.iWebview);
        return true;
    }
}
