package io.dcloud.feature.iBeacon;

import android.bluetooth.BluetoothDevice;
import java.util.Calendar;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONArray;

public class IBeaconContainer {
    private static JSONArray WxBeaconUUID;
    private Map<String, IBeaconRecord> iBeaconRecordMap = new HashMap();
    private long mExpireProcessTimeStampMillis = 0;
    private long mExpireTimeMillis = 8000;
    private int mRssiMinFilter = -75;

    public synchronized void update(BluetoothDevice device, int rssi, byte[] scanData) {
        IBeaconRecord iBeaconRecord;
        if (rssi >= this.mRssiMinFilter && rssi < -1 && (iBeaconRecord = IBeaconRecord.fromScanData(device, scanData, rssi)) != null) {
            if (WxBeaconUUID == null || WxBeaconUUID.length() <= 0) {
                this.iBeaconRecordMap.put(iBeaconRecord.address, iBeaconRecord);
            } else {
                for (int i = 0; i < WxBeaconUUID.length(); i++) {
                    if (WxBeaconUUID.optString(i).equalsIgnoreCase(iBeaconRecord.getUuid())) {
                        this.iBeaconRecordMap.put(iBeaconRecord.address, iBeaconRecord);
                    }
                }
            }
        }
        processExpireBeacons();
    }

    public static void setWxBeaconUUID(JSONArray wxBeaconUUID) {
        WxBeaconUUID = wxBeaconUUID;
    }

    public synchronized Map<String, IBeaconRecord> getBeacons() {
        processExpireBeacons();
        return new HashMap(this.iBeaconRecordMap);
    }

    private void processExpireBeacons() {
        long currentTimeStamp = Calendar.getInstance().getTimeInMillis();
        if (currentTimeStamp - this.mExpireProcessTimeStampMillis >= 1000) {
            Map<String, IBeaconRecord> beaconMap = new HashMap<>();
            for (Map.Entry<String, IBeaconRecord> entry : this.iBeaconRecordMap.entrySet()) {
                if (currentTimeStamp - entry.getValue().timeStampMillis <= this.mExpireTimeMillis) {
                    beaconMap.put(entry.getKey(), entry.getValue());
                }
            }
            this.iBeaconRecordMap.clear();
            this.iBeaconRecordMap.putAll(beaconMap);
            this.mExpireProcessTimeStampMillis = currentTimeStamp;
        }
    }
}
