package io.dcloud.feature.iBeacon;

import android.bluetooth.BluetoothDevice;
import io.dcloud.common.DHInterface.IApp;
import java.util.Calendar;

public class IBeaconRecord {
    private static final char[] hexArray = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
    String address;
    int major;
    int minor;
    int rssi;
    long timeStampMillis;
    int txPower;
    String uuid;

    public String getAddress() {
        return this.address;
    }

    public void setAddress(String address2) {
        this.address = address2;
    }

    public String getUuid() {
        return this.uuid;
    }

    public void setUuid(String uuid2) {
        this.uuid = uuid2;
    }

    public int getMajor() {
        return this.major;
    }

    public void setMajor(int major2) {
        this.major = major2;
    }

    public int getMinor() {
        return this.minor;
    }

    public void setMinor(int minor2) {
        this.minor = minor2;
    }

    public int getTxPower() {
        return this.txPower;
    }

    public void setTxPower(int txPower2) {
        this.txPower = txPower2;
    }

    public int getRssi() {
        return this.rssi;
    }

    public void setRssi(int rssi2) {
        this.rssi = rssi2;
    }

    public long getTimeStampMillis() {
        return this.timeStampMillis;
    }

    public void setTimeStampMillis(long timeStampMillis2) {
        this.timeStampMillis = timeStampMillis2;
    }

    public double getAccuracy() {
        int i = this.rssi;
        if (i >= -1 || this.txPower >= 0) {
            return -1.0d;
        }
        double ratio = Double.parseDouble(String.valueOf(i)) / ((double) this.txPower);
        double rssiCorrection = ((Math.pow((double) Math.abs(this.rssi), 3.0d) % 10.0d) / 150.0d) + 0.96d;
        if (ratio <= 1.0d) {
            return Math.pow(ratio, 9.98d) * rssiCorrection;
        }
        double distance = Math.max(0.0d, ((Math.pow(ratio, 7.5d) * 0.89978d) + 0.103d) * rssiCorrection);
        if (Double.NaN == distance) {
            return -1.0d;
        }
        return distance;
    }

    public static IBeaconRecord fromScanData(BluetoothDevice device, byte[] scanData, int rssi2) {
        int startByte = 2;
        boolean patternFound = false;
        while (true) {
            if (startByte > 5) {
                break;
            }
            int start2 = scanData[startByte + 2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
            int start3 = scanData[startByte + 3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
            if (start2 == 2 && start3 == 21) {
                patternFound = true;
                break;
            } else if ((scanData[startByte] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 45 && (scanData[startByte + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 36 && (scanData[startByte + 2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 191 && (scanData[startByte + 3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 22) {
                return null;
            } else {
                if ((scanData[startByte] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 173 && (scanData[startByte + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 119 && (scanData[startByte + 2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 0 && (scanData[startByte + 3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) == 198) {
                    return null;
                }
                startByte++;
            }
        }
        if (!patternFound) {
            return null;
        }
        IBeaconRecord record = new IBeaconRecord();
        record.address = device.getAddress();
        record.major = ((scanData[startByte + 20] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) * 256) + (scanData[startByte + 21] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
        record.minor = ((scanData[startByte + 22] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) * 256) + (scanData[startByte + 23] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
        record.txPower = scanData[startByte + 24];
        record.rssi = rssi2;
        try {
            byte[] proximityUuidBytes = new byte[16];
            System.arraycopy(scanData, startByte + 4, proximityUuidBytes, 0, 16);
            String hexString = bytesToHex(proximityUuidBytes);
            record.uuid = hexString.substring(0, 8) + "-" + hexString.substring(8, 12) + "-" + hexString.substring(12, 16) + "-" + hexString.substring(16, 20) + "-" + hexString.substring(20, 32);
        } catch (Exception e) {
            e.printStackTrace();
        }
        record.timeStampMillis = Calendar.getInstance().getTimeInMillis();
        return record;
    }

    private static String bytesToHex(byte[] bytes) {
        char[] hexChars = new char[(bytes.length * 2)];
        for (int j = 0; j < bytes.length; j++) {
            int v = bytes[j] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
            char[] cArr = hexArray;
            hexChars[j * 2] = cArr[v >>> 4];
            hexChars[(j * 2) + 1] = cArr[v & 15];
        }
        return new String(hexChars);
    }
}
