package io.dcloud.feature.iBeacon;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.location.LocationManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import com.amap.api.services.geocoder.GeocodeSearch;
import com.baidu.speech.utils.AsrError;
import com.coremedia.iso.boxes.UserBox;
import com.taobao.weex.ui.component.WXImage;
import com.umeng.analytics.pro.bg;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.DHInterface.StandardFeature;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.StringUtil;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Collections;
import java.util.Comparator;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONObject;

public class WxBluetoothFeatureImpl extends StandardFeature {
    private static final int MSG_BEACON_SCAN_RESTART_NOTIFY = 2;
    private static final int MSG_BEACON_SCAN_UPDATE_NOTIFY = 1;
    private static final String TAG = WxBluetoothFeatureImpl.class.getSimpleName();
    private Sensor accelerometerSensor = null;
    private float[] accelerometerValues = null;
    private long beaconScanRestartMillis = 15000;
    private long beaconScanUpdateMillis = 1000;
    private String bindCallbackID = null;
    private IWebview bindWebview = null;
    private BroadcastReceiver bluetoothStatuReceiver = new BroadcastReceiver() {
        /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass8 */

        public void onReceive(Context context, Intent intent) {
            if (intent.getAction() == "android.bluetooth.adapter.action.STATE_CHANGED") {
                int blueState = intent.getIntExtra("android.bluetooth.adapter.extra.STATE", 0);
                if (blueState == 12) {
                    Deprecated_JSUtil.execCallback(WxBluetoothFeatureImpl.this.bindWebview, WxBluetoothFeatureImpl.this.bindCallbackID, StringUtil.format("{discovering:%b,available:true}", Boolean.valueOf(WxBluetoothFeatureImpl.this.mBeaconScanFlag)), JSUtil.OK, true, true);
                } else if (blueState == 10) {
                    WxBluetoothFeatureImpl.this.stopDiscovery();
                    Deprecated_JSUtil.execCallback(WxBluetoothFeatureImpl.this.bindWebview, WxBluetoothFeatureImpl.this.bindCallbackID, StringUtil.format("{discovering:%b,available:false}", Boolean.valueOf(WxBluetoothFeatureImpl.this.mBeaconScanFlag)), JSUtil.OK, true, true);
                }
            }
        }
    };
    private DecimalFormat df = new DecimalFormat("0.000000");
    private DecimalFormat df_heading = new DecimalFormat("0.0000");
    private Handler handler = new Handler() {
        /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass1 */

        public void handleMessage(Message msg) {
            BluetoothAdapter bluetoothAdapter;
            super.handleMessage(msg);
            int i = msg.what;
            if (i == 1) {
                WxBluetoothFeatureImpl.this.processBeaconRecords();
                WxBluetoothFeatureImpl.this.startBeaconScanNotifyCheck();
            } else if (i == 2) {
                if (WxBluetoothFeatureImpl.this.mBeaconScanFlag && (bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()) != null && bluetoothAdapter.isEnabled()) {
                    bluetoothAdapter.stopLeScan(WxBluetoothFeatureImpl.this.leScanCallback);
                    bluetoothAdapter.stopLeScan(WxBluetoothFeatureImpl.this.leScanCallback);
                }
                WxBluetoothFeatureImpl.this.startBeaconScanRestartNotify();
            }
        }
    };
    private IBeaconContainer iBeaconContainer = new IBeaconContainer();
    private BluetoothAdapter.LeScanCallback leScanCallback = new BluetoothAdapter.LeScanCallback() {
        /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass5 */

        public void onLeScan(BluetoothDevice device, int rssi, byte[] scanRecord) {
            WxBluetoothFeatureImpl.this.iBeaconContainer.update(device, rssi, scanRecord);
            String str = WxBluetoothFeatureImpl.TAG;
            Log.d(str, "onLeScan: " + WxBluetoothFeatureImpl.this.iBeaconContainer.getBeacons().size());
        }
    };
    private boolean mBeaconScanFlag = false;
    private Sensor magneticSensor = null;
    private float[] magneticValues = null;
    private Sensor orientationSensor = null;
    private float[] resultValues = new float[3];
    private double rotateDegree = 0.0d;
    private float[] rotateValues = new float[9];
    private SensorEventListener sensorEventListener = new SensorEventListener() {
        /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass7 */
        private long lastRotateUpdateMillis = 0;

        public void onSensorChanged(SensorEvent event) {
            int sensorType = event.sensor.getType();
            if (sensorType == 1) {
                WxBluetoothFeatureImpl.this.accelerometerValues = event.values;
            } else if (sensorType == 2) {
                WxBluetoothFeatureImpl.this.magneticValues = event.values;
            } else {
                return;
            }
            if (WxBluetoothFeatureImpl.this.accelerometerValues != null && WxBluetoothFeatureImpl.this.magneticValues != null) {
                SensorManager.getRotationMatrix(WxBluetoothFeatureImpl.this.rotateValues, null, WxBluetoothFeatureImpl.this.accelerometerValues, WxBluetoothFeatureImpl.this.magneticValues);
                SensorManager.getOrientation(WxBluetoothFeatureImpl.this.rotateValues, WxBluetoothFeatureImpl.this.resultValues);
                WxBluetoothFeatureImpl.this.rotateDegree = (Math.toDegrees((double) WxBluetoothFeatureImpl.this.resultValues[0]) + 360.0d) % 360.0d;
                long currentTimeMillis = Calendar.getInstance().getTimeInMillis();
                if (currentTimeMillis - this.lastRotateUpdateMillis >= 250) {
                    WxBluetoothFeatureImpl.this.processBeaconRecords();
                    this.lastRotateUpdateMillis = currentTimeMillis;
                }
            }
        }

        public void onAccuracyChanged(Sensor sensor, int accuracy) {
        }
    };
    private SensorManager sm = null;
    private Map<String, IWebview> updateListener = null;

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startBeaconScanNotifyCheck() {
        this.handler.removeMessages(1);
        this.handler.sendEmptyMessageDelayed(1, this.beaconScanUpdateMillis);
    }

    private void stopBeaconScanNotifyCheck() {
        this.handler.removeMessages(1);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startBeaconScanRestartNotify() {
        this.handler.removeMessages(2);
        this.handler.sendEmptyMessageDelayed(2, this.beaconScanRestartMillis);
    }

    private void stopBeaconScanRestartNotify() {
        this.handler.removeMessages(2);
    }

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.StandardFeature
    public void init(AbsMgr absMgr, String s) {
        super.init(absMgr, s);
        startBeaconScanNotifyCheck();
        SensorManager sensorManager = (SensorManager) this.mApplicationContext.getSystemService(bg.ac);
        this.sm = sensorManager;
        this.orientationSensor = sensorManager.getDefaultSensor(3);
        this.accelerometerSensor = this.sm.getDefaultSensor(1);
        this.magneticSensor = this.sm.getDefaultSensor(2);
        this.sm.registerListener(this.sensorEventListener, this.accelerometerSensor, 1);
        this.sm.registerListener(this.sensorEventListener, this.magneticSensor, 1);
        this.updateListener = new HashMap();
    }

    @Override // io.dcloud.common.DHInterface.IFeature, io.dcloud.common.DHInterface.BaseFeature
    public void dispose(String s) {
        BluetoothAdapter bluetoothAdapter;
        super.dispose(s);
        stopBeaconScanNotifyCheck();
        this.sm.unregisterListener(this.sensorEventListener, this.accelerometerSensor);
        this.sm.unregisterListener(this.sensorEventListener, this.magneticSensor);
        if (this.mBeaconScanFlag && (bluetoothAdapter = BluetoothAdapter.getDefaultAdapter()) != null) {
            bluetoothAdapter.stopLeScan(this.leScanCallback);
            this.mBeaconScanFlag = false;
        }
        IWebview iWebview = this.bindWebview;
        if (iWebview != null) {
            iWebview.getContext().unregisterReceiver(this.bluetoothStatuReceiver);
        }
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.IBoot
    public void onStart(Context context, Bundle bundle, String[] strings) {
        super.onStart(context, bundle, strings);
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature, io.dcloud.common.DHInterface.IBoot
    public void onStop() {
        super.onStop();
    }

    public void openBluetoothAdapter(IWebview pWebview, JSONArray array) {
        int code;
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-openBluetoothAdapter");
        String CallBackID = array.optString(0);
        BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if (bluetoothAdapter == null) {
            code = 10001;
        } else {
            code = bluetoothAdapter.enable() ? 0 : 10001;
        }
        JSONObject jsonResult = new JSONObject();
        try {
            jsonResult.put("code", code);
        } catch (Exception e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(pWebview, CallBackID, jsonResult, code == 0 ? JSUtil.OK : JSUtil.ERROR, false);
    }

    public void closeBluetoothAdapter(IWebview pWebview, JSONArray array) {
        int code;
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-closeBluetoothAdapter");
        String CallBackID = array.optString(0);
        BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if (bluetoothAdapter == null) {
            code = 10001;
        } else {
            code = bluetoothAdapter.disable() ? 0 : 10001;
        }
        JSONObject jsonResult = new JSONObject();
        try {
            jsonResult.put("code", code);
        } catch (Exception e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(pWebview, CallBackID, jsonResult, code == 0 ? JSUtil.OK : JSUtil.ERROR, false);
    }

    public void getBluetoothAdapterState(IWebview pWebview, JSONArray array) {
    }

    public static final boolean isGpsEnable(Context context) {
        LocationManager locationManager = (LocationManager) context.getSystemService("location");
        boolean gps = locationManager.isProviderEnabled(GeocodeSearch.GPS);
        boolean network = locationManager.isProviderEnabled("network");
        if (gps || network) {
            return true;
        }
        return false;
    }

    public void startBeaconDiscovery(final IWebview pWebview, final JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-startBeaconDiscovery");
        final ICallBack startCB = new ICallBack() {
            /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass2 */

            @Override // io.dcloud.common.DHInterface.ICallBack
            public Object onCallBack(int pType, Object pArgs) {
                int code;
                String CallBackID = array.optString(0);
                JSONArray uuids = array.optJSONArray(1);
                BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
                bluetoothAdapter.enable();
                String message = "";
                if (bluetoothAdapter == null) {
                    code = 11000;
                    message = "Bluetooth is not supported on this hardware platform";
                    WxBluetoothFeatureImpl.this.mBeaconScanFlag = false;
                } else if (!bluetoothAdapter.isEnabled()) {
                    code = AsrError.ERROR_WAKEUP_ENGINE_EXCEPTION;
                    message = "Bluetooth is off";
                    WxBluetoothFeatureImpl.this.mBeaconScanFlag = false;
                } else if (WxBluetoothFeatureImpl.this.mBeaconScanFlag) {
                    Deprecated_JSUtil.execCallback(pWebview, CallBackID, "{code:11003,message:'already start'}", JSUtil.ERROR, true, false);
                    return null;
                } else if (!WxBluetoothFeatureImpl.isGpsEnable(pWebview.getContext())) {
                    code = AsrError.ERROR_WAKEUP_NO_LICENSE;
                    message = "location service unavailable";
                    WxBluetoothFeatureImpl.this.mBeaconScanFlag = false;
                } else {
                    bluetoothAdapter.stopLeScan(WxBluetoothFeatureImpl.this.leScanCallback);
                    bluetoothAdapter.startLeScan(WxBluetoothFeatureImpl.this.leScanCallback);
                    code = 0;
                    WxBluetoothFeatureImpl.this.mBeaconScanFlag = true;
                }
                JSONObject jsonResult = new JSONObject();
                try {
                    jsonResult.put("code", code);
                    jsonResult.put("message", message);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                IBeaconContainer.setWxBeaconUUID(uuids);
                JSUtil.execCallback(pWebview, CallBackID, jsonResult, code == 0 ? JSUtil.OK : JSUtil.ERROR, false);
                return null;
            }
        };
        if (Build.VERSION.SDK_INT >= 31) {
            PermissionUtil.useSystemPermissions(pWebview.getActivity(), new String[]{"android.permission.BLUETOOTH_SCAN", "android.permission.BLUETOOTH_CONNECT", "android.permission.ACCESS_FINE_LOCATION", "android.permission.ACCESS_COARSE_LOCATION"}, new PermissionUtil.Request() {
                /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass3 */
                int time = 0;

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onGranted(String streamPerName) {
                    int i = this.time + 1;
                    this.time = i;
                    if (i == 4) {
                        startCB.onCallBack(0, null);
                    }
                }

                @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                public void onDenied(String streamPerName) {
                    String callbackid = array.optString(0);
                    IWebview iWebview = pWebview;
                    Deprecated_JSUtil.execCallback(iWebview, callbackid, StringUtil.format(DOMException.JSON_ERROR_INFO, 10000, streamPerName + "permission denied"), JSUtil.ERROR, true, false);
                }
            });
            return;
        }
        PermissionUtil.useSystemPermission(pWebview.getActivity(), "android.permission.ACCESS_COARSE_LOCATION", new PermissionUtil.Request() {
            /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass4 */

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onGranted(String streamPerName) {
            }

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onDenied(String streamPerName) {
            }
        });
        startCB.onCallBack(0, null);
    }

    public void stopBeaconDiscovery(IWebview pWebview, JSONArray array) {
        int code;
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-stopBeaconDiscovery");
        String CallBackID = array.optString(0);
        BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        String message = WXImage.SUCCEED;
        if (bluetoothAdapter == null) {
            code = 11000;
            message = "Bluetooth is not supported on this hardware platform";
        } else if (!bluetoothAdapter.isEnabled()) {
            code = AsrError.ERROR_WAKEUP_ENGINE_EXCEPTION;
            message = "Bluetooth is off";
        } else if (!isGpsEnable(pWebview.getContext())) {
            code = AsrError.ERROR_WAKEUP_NO_LICENSE;
            message = "location service unavailable";
        } else {
            bluetoothAdapter.stopLeScan(this.leScanCallback);
            code = 0;
        }
        this.mBeaconScanFlag = false;
        JSONObject jsonResult = new JSONObject();
        try {
            jsonResult.put("code", code);
            jsonResult.put("message", message);
        } catch (Exception e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(pWebview, CallBackID, jsonResult, code == 0 ? JSUtil.OK : JSUtil.ERROR, false);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopDiscovery() {
        BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if (bluetoothAdapter != null) {
            if (bluetoothAdapter.isEnabled()) {
                bluetoothAdapter.stopLeScan(this.leScanCallback);
            }
        }
        this.mBeaconScanFlag = false;
    }

    public void getBeacons(IWebview pWebview, JSONArray array) {
        int code;
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-getBeacons");
        String CallBackID = array.optString(0);
        BluetoothAdapter bluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        JSONArray jsonBeacons = null;
        String message = WXImage.SUCCEED;
        if (bluetoothAdapter == null) {
            code = 11000;
            message = "Bluetooth is not supported on this hardware platform";
        } else if (!bluetoothAdapter.isEnabled()) {
            code = AsrError.ERROR_WAKEUP_ENGINE_EXCEPTION;
            message = "Bluetooth is off";
        } else {
            code = 0;
            jsonBeacons = getBeaconsJSON();
        }
        JSONObject jsonResult = new JSONObject();
        try {
            jsonResult.put("code", code);
            if (jsonBeacons != null) {
                jsonResult.put("beacons", jsonBeacons);
            } else {
                jsonResult.put("message", message);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        JSUtil.execCallback(pWebview, CallBackID, jsonResult, code == 0 ? JSUtil.OK : JSUtil.ERROR, false);
    }

    public void onBeaconUpdate(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-onBeaconUpdate");
        this.updateListener.put(array.optString(0), pWebview);
    }

    public void onBeaconServiceChange(IWebview pWebview, JSONArray array) {
        AppRuntime.checkPrivacyComplianceAndPrompt(pWebview.getContext(), "Geolocation-onBeaconServiceChange");
        this.bindCallbackID = array.optString(0);
        this.bindWebview = pWebview;
        IntentFilter stateChangeFilter = new IntentFilter("android.bluetooth.adapter.action.STATE_CHANGED");
        IntentFilter connectedFilter = new IntentFilter("android.bluetooth.device.action.ACL_CONNECTED");
        IntentFilter disConnectedFilter = new IntentFilter("android.bluetooth.device.action.ACL_DISCONNECTED");
        pWebview.getContext().registerReceiver(this.bluetoothStatuReceiver, stateChangeFilter);
        pWebview.getContext().registerReceiver(this.bluetoothStatuReceiver, connectedFilter);
        pWebview.getContext().registerReceiver(this.bluetoothStatuReceiver, disConnectedFilter);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processBeaconRecords() {
        if (this.mBeaconScanFlag) {
            JSONObject jsonResult = new JSONObject();
            try {
                jsonResult.put("code", 0);
                jsonResult.put("beacons", getBeaconsJSON());
            } catch (Exception e) {
                e.printStackTrace();
            }
            for (String callbackid : this.updateListener.keySet()) {
                JSUtil.execCallback(this.updateListener.get(callbackid), callbackid, jsonResult, JSUtil.OK, true);
            }
        }
    }

    private JSONArray getBeaconsJSON() {
        JSONArray jsonBeacons = new JSONArray();
        Map<String, IBeaconRecord> iBeaconRecordMap = this.iBeaconContainer.getBeacons();
        if (!iBeaconRecordMap.isEmpty()) {
            List<IBeaconRecord> iBeaconRecordList = new ArrayList<>(iBeaconRecordMap.values());
            Collections.sort(iBeaconRecordList, new Comparator<IBeaconRecord>() {
                /* class io.dcloud.feature.iBeacon.WxBluetoothFeatureImpl.AnonymousClass6 */

                public int compare(IBeaconRecord o1, IBeaconRecord o2) {
                    return o1.getRssi() - o2.getRssi();
                }
            });
            try {
                for (IBeaconRecord record : iBeaconRecordList) {
                    JSONObject jsonBeacon = new JSONObject();
                    jsonBeacon.put(UserBox.TYPE, record.getUuid());
                    jsonBeacon.put("major", String.valueOf(record.getMajor()));
                    jsonBeacon.put("minor", String.valueOf(record.getMinor()));
                    jsonBeacon.put("rssi", String.valueOf(record.getRssi()));
                    jsonBeacon.put("accuracy", this.df.format(record.getAccuracy()));
                    jsonBeacon.put("heading", this.df_heading.format(this.rotateDegree));
                    jsonBeacons.put(jsonBeacon);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return jsonBeacons;
    }
}
