package io.dcloud.feature.oauth.qq;

import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.text.TextUtils;
import com.tencent.connect.UnionInfo;
import com.tencent.connect.UserInfo;
import com.tencent.connect.common.Constants;
import com.tencent.open.SocialOperation;
import com.tencent.tauth.IUiListener;
import com.tencent.tauth.Tencent;
import com.tencent.tauth.UiError;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.feature.oauth.BaseOAuthService;
import io.dcloud.share.sina.SinaWeiboApiManager;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class QQOAuthService extends BaseOAuthService {
    private static final String TAG = "QQOAuthService";
    protected static String appId = null;
    protected static String appKEY = null;
    protected static String appSecret = null;
    protected static String redirectUri = null;
    private Context mContext;
    IUiListener mIUiListener = new IUiListener() {
        /* class io.dcloud.feature.oauth.qq.QQOAuthService.AnonymousClass1 */

        @Override // com.tencent.tauth.IUiListener
        public void onError(UiError arg0) {
            QQOAuthService qQOAuthService = QQOAuthService.this;
            qQOAuthService.onLoginFinished(qQOAuthService.getErrorJsonbject(-100, arg0.errorMessage, arg0.errorCode), false);
        }

        @Override // com.tencent.tauth.IUiListener
        public void onComplete(Object response) {
            if (response == null) {
                QQOAuthService qQOAuthService = QQOAuthService.this;
                qQOAuthService.onLoginFinished(qQOAuthService.getErrorJsonbject(-1002, DOMException.MSG_GET_TOKEN_ERROR), false);
                return;
            }
            JSONObject object = (JSONObject) response;
            if (object == null || object.length() != 0) {
                QQOAuthService.this.authResult = (JSONObject) response;
                QQOAuthService qQOAuthService2 = QQOAuthService.this;
                qQOAuthService2.initOpenidAndToken(qQOAuthService2.authResult);
                QQOAuthService.this.updateUserInfo(new UserInfo(QQOAuthService.this.mContext, QQOAuthService.this.mTencent.getQQToken()));
                return;
            }
            QQOAuthService qQOAuthService3 = QQOAuthService.this;
            qQOAuthService3.onLoginFinished(qQOAuthService3.getErrorJsonbject(-1002, DOMException.MSG_GET_TOKEN_ERROR), false);
        }

        @Override // com.tencent.tauth.IUiListener
        public void onCancel() {
            QQOAuthService qQOAuthService = QQOAuthService.this;
            qQOAuthService.onLoginFinished(qQOAuthService.getErrorJsonbject(-2, DOMException.MSG_USER_CANCEL), false);
        }

        @Override // com.tencent.tauth.IUiListener
        public void onWarning(int i) {
        }
    };
    private Tencent mTencent;

    @Override // io.dcloud.common.DHInterface.BaseFeature.BaseModule
    public void init(Context context) {
        super.init(context);
        this.mContext = context;
        this.id = "qq";
        this.description = Constants.SOURCE_QQ;
        this.nativeClient = PlatformUtil.isAppInstalled(context, "com.tencent.mobileqq");
        if (!AppRuntime.hasPrivacyForNotShown(context)) {
            Tencent.setIsPermissionGranted(true, Build.MODEL);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public boolean hasFullConfigData() {
        return !TextUtils.isEmpty(appId);
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initMetaData() {
        appId = AndroidResources.getMetaValue("QQ_APPID");
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initAuthOptions(JSONObject mLoginOptions) {
        if (mLoginOptions != null) {
            appId = mLoginOptions.optString("appid", appId);
            Logger.e(TAG, "initAuthOptions: appId" + appId);
            appSecret = mLoginOptions.optString("appsecret", appSecret);
            redirectUri = mLoginOptions.optString(SinaWeiboApiManager.KEY_REDIRECT_URI, redirectUri);
            appKEY = mLoginOptions.optString("appkey", appKEY);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void login(final IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.login(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mLoginWebViewImpl, this.mLoginCallbackId)) {
            if (this.mTencent == null) {
                this.mTencent = Tencent.createInstance(appId, this.mContext);
            }
            pWebViewImpl.obtainApp().registerSysEventListener(new ISysEventListener() {
                /* class io.dcloud.feature.oauth.qq.QQOAuthService.AnonymousClass2 */

                @Override // io.dcloud.common.DHInterface.ISysEventListener
                public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                    Object[] _args = (Object[]) pArgs;
                    int requestCode = ((Integer) _args[0]).intValue();
                    int resultCode = ((Integer) _args[1]).intValue();
                    Intent data = (Intent) _args[2];
                    if (pEventType == ISysEventListener.SysEventType.onActivityResult && requestCode == 11101 && resultCode == -1) {
                        QQOAuthService.this.mTencent.handleLoginData(data, QQOAuthService.this.mIUiListener);
                    }
                    IWebview iWebview = pWebViewImpl;
                    if (iWebview != null) {
                        iWebview.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onActivityResult);
                    }
                    return false;
                }
            }, ISysEventListener.SysEventType.onActivityResult);
            String value = getValue("authResult");
            if (!TextUtils.isEmpty(value)) {
                initOpenidAndToken(value);
            }
            if (this.mTencent.isSessionValid()) {
                updateUserInfo(new UserInfo(this.mContext, this.mTencent.getQQToken()));
            } else {
                this.mTencent.login(pWebViewImpl.getActivity(), "all", this.mIUiListener);
            }
        }
    }

    public void initOpenidAndToken(JSONObject jsonObject) {
        try {
            String token = jsonObject.getString(Constants.PARAM_ACCESS_TOKEN);
            String expires = jsonObject.getString("expires_in");
            String openId = jsonObject.getString("openid");
            if (!TextUtils.isEmpty(token) && !TextUtils.isEmpty(expires) && !TextUtils.isEmpty(openId)) {
                this.mTencent.setAccessToken(token, expires);
                this.mTencent.setOpenId(openId);
                saveValue("authResult", jsonObject.toString());
            }
        } catch (Exception e) {
        }
    }

    public void initOpenidAndToken(String stringJson) {
        try {
            JSONObject jsonObject = new JSONObject(stringJson);
            String token = jsonObject.getString(Constants.PARAM_ACCESS_TOKEN);
            String expires = jsonObject.getString("expires_in");
            String openId = jsonObject.getString("openid");
            if (!TextUtils.isEmpty(token) && !TextUtils.isEmpty(expires) && !TextUtils.isEmpty(openId)) {
                if (this.mTencent == null) {
                    this.mTencent = Tencent.createInstance(appId, this.mContext);
                }
                this.mTencent.setAccessToken(token, expires);
                this.mTencent.setOpenId(openId);
                this.authResult = jsonObject;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateUserInfo(UserInfo info) {
        Tencent tencent = this.mTencent;
        if (tencent != null && tencent.isSessionValid()) {
            info.getUserInfo(new IUiListener() {
                /* class io.dcloud.feature.oauth.qq.QQOAuthService.AnonymousClass3 */

                @Override // com.tencent.tauth.IUiListener
                public void onError(UiError e) {
                    QQOAuthService qQOAuthService = QQOAuthService.this;
                    qQOAuthService.onLoginFinished(qQOAuthService.getErrorJsonbject(-100, e.errorMessage, e.errorCode), false);
                }

                @Override // com.tencent.tauth.IUiListener
                public void onComplete(Object response) {
                    if (response != null) {
                        JSONObject tempuserInfo = (JSONObject) response;
                        QQOAuthService.this.userInfo = tempuserInfo;
                        try {
                            QQOAuthService.this.userInfo.put("headimgurl", tempuserInfo.optString("figureurl"));
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }
                        QQOAuthService qQOAuthService = QQOAuthService.this;
                        qQOAuthService.saveValue("userInfo", qQOAuthService.userInfo.toString());
                        QQOAuthService.this.updateUnionId();
                        return;
                    }
                    QQOAuthService qQOAuthService2 = QQOAuthService.this;
                    qQOAuthService2.onLoginFinished(qQOAuthService2.getErrorJsonbject(-1002, DOMException.MSG_GET_TOKEN_ERROR), false);
                }

                @Override // com.tencent.tauth.IUiListener
                public void onCancel() {
                    QQOAuthService qQOAuthService = QQOAuthService.this;
                    qQOAuthService.onLoginFinished(qQOAuthService.getErrorJsonbject(-2, DOMException.MSG_USER_CANCEL), false);
                }

                @Override // com.tencent.tauth.IUiListener
                public void onWarning(int i) {
                }
            });
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void logout(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.logout(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mLogoutWebViewImpl, this.mLogoutCallbackId)) {
            this.userInfo = null;
            this.authResult = null;
            removeToken();
            onLogoutFinished(makeResultJson(), true);
            this.mTencent.logout(this.mContext);
            this.mTencent = null;
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void getUserInfo(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.getUserInfo(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mGetUserInfoWebViewImpl, this.mGetUserInfoCallbackId)) {
            String result = getValue("authResult");
            if (!TextUtils.isEmpty(result)) {
                initOpenidAndToken(result);
            }
            Tencent tencent = this.mTencent;
            if (tencent == null || !tencent.isSessionValid()) {
                onGetUserInfoFinished(getErrorJsonbject(-1001, DOMException.MSG_OAUTH_FAIL), false);
                return;
            }
            try {
                this.userInfo = new JSONObject(getValue("userInfo"));
            } catch (JSONException e) {
                e.printStackTrace();
            }
            onGetUserInfoFinished(makeResultJson(), true);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateUnionId() {
        Tencent tencent = this.mTencent;
        if (tencent == null || !tencent.isSessionValid()) {
            Logger.d(TAG, "please login frist!");
            return;
        }
        new UnionInfo(this.mContext, this.mTencent.getQQToken()).getUnionId(new IUiListener() {
            /* class io.dcloud.feature.oauth.qq.QQOAuthService.AnonymousClass4 */

            @Override // com.tencent.tauth.IUiListener
            public void onError(UiError e) {
                QQOAuthService qQOAuthService = QQOAuthService.this;
                qQOAuthService.onLoginFinished(qQOAuthService.makeResultJson(), true);
            }

            @Override // com.tencent.tauth.IUiListener
            public void onComplete(Object response) {
                if (response != null) {
                    JSONObject jsonObject = (JSONObject) response;
                    try {
                        if (jsonObject.has(SocialOperation.GAME_UNION_ID)) {
                            QQOAuthService.this.userInfo.put(SocialOperation.GAME_UNION_ID, jsonObject.getString(SocialOperation.GAME_UNION_ID));
                            QQOAuthService.this.saveValue("userInfo", QQOAuthService.this.userInfo.toString());
                        }
                    } catch (Exception e) {
                        Logger.d(QQOAuthService.TAG, "no unionid" + e.getMessage());
                    }
                }
                QQOAuthService qQOAuthService = QQOAuthService.this;
                qQOAuthService.onLoginFinished(qQOAuthService.makeResultJson(), true);
            }

            @Override // com.tencent.tauth.IUiListener
            public void onCancel() {
                QQOAuthService qQOAuthService = QQOAuthService.this;
                qQOAuthService.onLoginFinished(qQOAuthService.makeResultJson(), true);
            }

            @Override // com.tencent.tauth.IUiListener
            public void onWarning(int i) {
            }
        });
    }
}
