package io.dcloud.feature.oauth.sina;

import android.content.Context;
import android.content.SharedPreferences;
import com.sina.weibo.sdk.auth.Oauth2AccessToken;

public class AccessTokenKeeper {
    private static final String KEY_ACCESS_TOKEN = "access_token";
    private static final String KEY_EXPIRES_IN = "expires_in";
    private static final String KEY_UID = "uid";
    private static final String PREFERENCES_NAME = "com_weibo_sdk_android";

    public static void writeAccessToken(Context context, SinaOAuthTokenWrapper token) {
        if (context != null && token != null) {
            SharedPreferences.Editor editor = context.getSharedPreferences(PREFERENCES_NAME, 0).edit();
            editor.putString(KEY_UID, token.getUid());
            editor.putString("access_token", token.getAccessToken());
            editor.putLong("expires_in", token.getExpiresTime());
            editor.commit();
        }
    }

    public static SinaOAuthTokenWrapper readAccessToken(Context context) {
        if (context == null) {
            return null;
        }
        SinaOAuthTokenWrapper token = new SinaOAuthTokenWrapper(null);
        SharedPreferences pref = context.getSharedPreferences(PREFERENCES_NAME, 0);
        token.setUid(pref.getString(KEY_UID, ""));
        token.setAccessToken(pref.getString("access_token", ""));
        token.setExpiresTime(pref.getLong("expires_in", 0));
        return token;
    }

    public static void clear(Context context) {
        if (context != null) {
            SharedPreferences.Editor editor = context.getSharedPreferences(PREFERENCES_NAME, 0).edit();
            editor.clear();
            editor.commit();
        }
    }

    public static class SinaOAuthTokenWrapper {
        private String localAccessToken;
        private long localExpiresTime;
        private String localUid;
        Oauth2AccessToken sourceToken;

        public SinaOAuthTokenWrapper(Oauth2AccessToken token) {
            this.sourceToken = token;
        }

        public boolean isSessionValid() {
            Oauth2AccessToken oauth2AccessToken = this.sourceToken;
            if (oauth2AccessToken == null) {
                return false;
            }
            return oauth2AccessToken.isSessionValid();
        }

        public String getUid() {
            Oauth2AccessToken oauth2AccessToken = this.sourceToken;
            if (oauth2AccessToken != null) {
                return oauth2AccessToken.getUid();
            }
            return this.localUid;
        }

        /* access modifiers changed from: protected */
        public void setUid(String var1) {
            this.localUid = var1;
        }

        public String getAccessToken() {
            Oauth2AccessToken oauth2AccessToken = this.sourceToken;
            if (oauth2AccessToken != null) {
                return oauth2AccessToken.getAccessToken();
            }
            return this.localAccessToken;
        }

        /* access modifiers changed from: protected */
        public void setAccessToken(String var1) {
            this.localAccessToken = var1;
        }

        public long getExpiresTime() {
            Oauth2AccessToken oauth2AccessToken = this.sourceToken;
            if (oauth2AccessToken != null) {
                return oauth2AccessToken.getExpiresTime();
            }
            return this.localExpiresTime;
        }

        /* access modifiers changed from: protected */
        public void setExpiresTime(long var1) {
            this.localExpiresTime = var1;
        }

        public String getRefreshToken() {
            Oauth2AccessToken oauth2AccessToken = this.sourceToken;
            if (oauth2AccessToken != null) {
                return oauth2AccessToken.getRefreshToken();
            }
            return "";
        }
    }
}
