package io.dcloud.feature.oauth.sina;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import com.sina.weibo.BuildConfig;
import com.sina.weibo.sdk.auth.AuthInfo;
import com.sina.weibo.sdk.auth.Oauth2AccessToken;
import com.sina.weibo.sdk.auth.WbAuthListener;
import com.sina.weibo.sdk.common.UiError;
import com.sina.weibo.sdk.openapi.IWBAPI;
import com.sina.weibo.sdk.openapi.WBAPIFactory;
import com.tencent.connect.common.Constants;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.NetTool;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.oauth.BaseOAuthService;
import io.dcloud.feature.oauth.sina.AccessTokenKeeper;
import io.dcloud.share.sina.SinaWeiboApiManager;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class SinaOAuthService extends BaseOAuthService {
    private static final String EXPIRES_TIME = "expires_time";
    private static final String SCOPE = "email,direct_messages_read,direct_messages_write,friendships_groups_read,friendships_groups_write,statuses_to_me_read,follow_app_official_microblog,invitation_write";
    public static final String TAG = "SinaOAuthService";
    private static final String TOKEN = "token";
    private static final String UID = "uid";
    private static final String URL_GETUID = "https://api.weibo.com/2/account/get_uid.json?access_token=%s";
    private static final String URL_GET_USERINFO = "https://api.weibo.com/2/users/show.json?access_token=%s&uid=%s";
    private static final String URL_REVOKE_OAUTH = "https://api.weibo.com/oauth2/revokeoauth2";
    protected static String appKEY = null;
    protected static String redirectUri = null;
    private AccessTokenKeeper.SinaOAuthTokenWrapper mAccessToken;
    private Context mContext;
    private IWBAPI mWBAPI;

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initMetaData() {
        if (!TextUtils.isEmpty(AndroidResources.getMetaValue("SINA_APPKEY"))) {
            appKEY = AndroidResources.getMetaValue("SINA_APPKEY").substring(1);
        }
        redirectUri = AndroidResources.getMetaValue("SINA_REDIRECT_URI");
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initAuthOptions(JSONObject mLoginOptions) {
        if (mLoginOptions != null) {
            redirectUri = mLoginOptions.optString(SinaWeiboApiManager.KEY_REDIRECT_URI, redirectUri);
            appKEY = mLoginOptions.optString("appkey", appKEY);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public boolean hasFullConfigData() {
        return !TextUtils.isEmpty(redirectUri) && !TextUtils.isEmpty(appKEY);
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature.BaseModule
    public void init(Context context) {
        super.init(context);
        this.mContext = context;
        this.id = SinaWeiboApiManager.SINAWEIBO_ID;
        this.description = DCLoudApplicationImpl.self().getContext().getResources().getString(R.string.dcloud_feature_oauth_sina_plugin_description);
        this.nativeClient = PlatformUtil.isAppInstalled(context, BuildConfig.APPLICATION_ID);
    }

    private void initWBAPI(Activity activity) {
        IWBAPI createWBAPI = WBAPIFactory.createWBAPI(activity);
        this.mWBAPI = createWBAPI;
        createWBAPI.registerApp(activity, new AuthInfo(activity, appKEY, redirectUri, SCOPE));
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void login(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.login(pWebViewImpl, pJsArgs);
        initWBAPI(pWebViewImpl.getActivity());
        if (!hasGeneralError(this.mLoginWebViewImpl, this.mLoginCallbackId)) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.sina.SinaOAuthService.AnonymousClass1 */

                public void run() {
                    SinaOAuthService.this.loginInThread();
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loginInThread() {
        AccessTokenKeeper.SinaOAuthTokenWrapper sinaOAuthTokenWrapper = this.mAccessToken;
        if (sinaOAuthTokenWrapper != null && sinaOAuthTokenWrapper.isSessionValid() && !PdrUtil.isEmpty(this.mAccessToken.getAccessToken())) {
            String resultStr = getToken(StringUtil.format(URL_GETUID, this.mAccessToken.getAccessToken()));
            if (resultStr != null && !PdrUtil.isEmpty(JSONUtil.createJSONObject(resultStr).optString(UID))) {
                this.authResult = getSinaAuthResultJB(this.mAccessToken);
                onLoginFinished(makeResultJson(), true);
                return;
            }
        }
        this.mWBAPI.authorize(this.mLoginWebViewImpl.getActivity(), new WbAuthListener() {
            /* class io.dcloud.feature.oauth.sina.SinaOAuthService.AnonymousClass2 */

            @Override // com.sina.weibo.sdk.auth.WbAuthListener
            public void onComplete(Oauth2AccessToken oauth2AccessToken) {
                SinaOAuthService.this.mAccessToken = new AccessTokenKeeper.SinaOAuthTokenWrapper(oauth2AccessToken);
                if (SinaOAuthService.this.mAccessToken.isSessionValid()) {
                    AccessTokenKeeper.writeAccessToken(SinaOAuthService.this.mContext, SinaOAuthService.this.mAccessToken);
                    SinaOAuthService sinaOAuthService = SinaOAuthService.this;
                    sinaOAuthService.authResult = sinaOAuthService.getSinaAuthResultJB(sinaOAuthService.mAccessToken);
                    SinaOAuthService.this.onLoginFinished(SinaOAuthService.this.makeResultJSONObject(), true);
                }
            }

            @Override // com.sina.weibo.sdk.auth.WbAuthListener
            public void onError(UiError uiError) {
                SinaOAuthService sinaOAuthService = SinaOAuthService.this;
                sinaOAuthService.onLoginFinished(sinaOAuthService.getErrorJsonbject(uiError.errorCode, uiError.errorMessage), false);
            }

            @Override // com.sina.weibo.sdk.auth.WbAuthListener
            public void onCancel() {
                SinaOAuthService sinaOAuthService = SinaOAuthService.this;
                sinaOAuthService.onLoginFinished(sinaOAuthService.getErrorJsonbject(-2, DOMException.MSG_USER_CANCEL), false);
            }
        });
        if (this.mLoginWebViewImpl != null && this.mLoginWebViewImpl.obtainApp() != null) {
            this.mLoginWebViewImpl.obtainApp().registerSysEventListener(new ISysEventListener() {
                /* class io.dcloud.feature.oauth.sina.SinaOAuthService.AnonymousClass3 */

                @Override // io.dcloud.common.DHInterface.ISysEventListener
                public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                    Object[] _args = (Object[]) pArgs;
                    int requestCode = ((Integer) _args[0]).intValue();
                    int resultCode = ((Integer) _args[1]).intValue();
                    Intent data = (Intent) _args[2];
                    if (SinaOAuthService.this.mWBAPI != null) {
                        SinaOAuthService.this.mWBAPI.authorizeCallback(SinaOAuthService.this.mLoginWebViewImpl.getActivity(), requestCode, resultCode, data);
                    }
                    if (SinaOAuthService.this.mLoginWebViewImpl != null) {
                        SinaOAuthService.this.mLoginWebViewImpl.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onActivityResult);
                    }
                    return false;
                }
            }, ISysEventListener.SysEventType.onActivityResult);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void logout(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.logout(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mLogoutWebViewImpl, this.mLogoutCallbackId)) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.sina.SinaOAuthService.AnonymousClass4 */

                public void run() {
                    if (SinaOAuthService.this.mAccessToken == null) {
                        SinaOAuthService sinaOAuthService = SinaOAuthService.this;
                        sinaOAuthService.mAccessToken = AccessTokenKeeper.readAccessToken(sinaOAuthService.mContext);
                    }
                    if (!PdrUtil.isEmpty(SinaOAuthService.this.mAccessToken.getAccessToken())) {
                        StringBuffer buffer = new StringBuffer();
                        buffer.append("access_token=" + SinaOAuthService.this.mAccessToken.getAccessToken());
                        byte[] resultByte = NetTool.httpPost(SinaOAuthService.URL_REVOKE_OAUTH, buffer.toString(), null);
                        if (resultByte == null || resultByte.length <= 0) {
                            SinaOAuthService sinaOAuthService2 = SinaOAuthService.this;
                            sinaOAuthService2.onLogoutFinished(sinaOAuthService2.getErrorJsonbject(-1001, DOMException.MSG_OAUTH_FAIL), false);
                            return;
                        }
                        String resultStr = new String(resultByte);
                        Logger.e("ian", "logout resultStr==" + resultStr);
                        try {
                            if (PdrUtil.isEquals(new JSONObject(resultStr).optString("result"), AbsoluteConst.TRUE)) {
                                AccessTokenKeeper.clear(SinaOAuthService.this.mContext);
                                SinaOAuthService.this.mAccessToken = null;
                                SinaOAuthService.this.userInfo = null;
                                SinaOAuthService.this.authResult = null;
                                SinaOAuthService.this.removeToken();
                                SinaOAuthService.this.onLogoutFinished(SinaOAuthService.this.makeResultJson(), true);
                                return;
                            }
                            SinaOAuthService.this.onLogoutFinished(SinaOAuthService.this.getErrorJsonbject(-1001, DOMException.MSG_OAUTH_FAIL), false);
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }
                    } else {
                        SinaOAuthService sinaOAuthService3 = SinaOAuthService.this;
                        sinaOAuthService3.onLogoutFinished(sinaOAuthService3.getErrorJsonbject(-1001, DOMException.MSG_OAUTH_FAIL), false);
                    }
                }
            });
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void getUserInfo(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.getUserInfo(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mGetUserInfoWebViewImpl, this.mGetUserInfoCallbackId)) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.sina.SinaOAuthService.AnonymousClass5 */

                public void run() {
                    boolean suc = SinaOAuthService.this.initUserInfo();
                    if (suc) {
                        SinaOAuthService.this.onGetUserInfoFinished(SinaOAuthService.this.makeResultJSONObject(), suc);
                        return;
                    }
                    SinaOAuthService sinaOAuthService = SinaOAuthService.this;
                    sinaOAuthService.onGetUserInfoFinished(sinaOAuthService.getErrorJsonbject(-1001, DOMException.MSG_OAUTH_FAIL), false);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean initUserInfo() {
        if (this.mAccessToken == null) {
            this.mAccessToken = AccessTokenKeeper.readAccessToken(this.mContext);
        }
        AccessTokenKeeper.SinaOAuthTokenWrapper sinaOAuthTokenWrapper = this.mAccessToken;
        if (sinaOAuthTokenWrapper == null || !sinaOAuthTokenWrapper.isSessionValid()) {
            return false;
        }
        String s_userInfoResult = getUserInfo(StringUtil.format(URL_GET_USERINFO, this.mAccessToken.getAccessToken(), this.mAccessToken.getUid()));
        Logger.e("ian", "inituserinfo  s_userinforesult" + s_userInfoResult);
        if (s_userInfoResult == null) {
            return false;
        }
        JSONObject userInfoResult = JSONUtil.createJSONObject(s_userInfoResult);
        this.userInfo = userInfoResult;
        try {
            this.userInfo.put("headimgurl", userInfoResult.optString("profile_image_url"));
            this.userInfo.put("nickname", userInfoResult.optString("screen_name"));
            this.userInfo.put("openid", userInfoResult.optString("idstr"));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        saveValue("userInfo", this.userInfo.toString());
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private JSONObject getSinaAuthResultJB(AccessTokenKeeper.SinaOAuthTokenWrapper token) {
        JSONObject jsonObject = new JSONObject();
        try {
            jsonObject.put("expires_in", token.getExpiresTime());
            jsonObject.put(Constants.PARAM_ACCESS_TOKEN, token.getAccessToken());
            jsonObject.put("refresh_token", token.getRefreshToken());
            jsonObject.put("openid", token.getUid());
            jsonObject.put(UID, token.getUid());
            jsonObject.put("expires_time", token.getExpiresTime());
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jsonObject;
    }
}
