package io.dcloud.feature.oauth.weixin;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import com.tencent.mm.opensdk.channel.MMessageActV2;
import com.tencent.mm.opensdk.modelbase.BaseReq;
import com.tencent.mm.opensdk.modelmsg.SendAuth;
import com.tencent.mm.opensdk.modelmsg.SendMessageToWX;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.NetTool;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.oauth.BaseOAuthService;
import io.dcloud.share.mm.WeiXinApiManager;
import io.dcloud.share.sina.SinaWeiboApiManager;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class WeiXinOAuthService extends BaseOAuthService {
    private static final String DEFAULT_SCOPE = "snsapi_userinfo";
    private static final String DEFAULT_STATE = "wechat_sdk_dcloud_weixin_oauth";
    private static final String ERR_MSG_AUTH_DENIED = "Authentication failed";
    private static final String ERR_MSG_COMM = "General errors";
    private static final String ERR_MSG_SENT_FAILED = "Unable to send";
    private static final String ERR_MSG_UNSUPPORT = "Unsupport error";
    private static final String ERR_MSG_USER_CANCEL = "User canceled";
    private static final String KEY_ACCESS_TOKEN = "access_token";
    private static final String KEY_ERRCODE = "errcode";
    private static final String KEY_ERRMSG = "errmsg";
    private static final String KEY_OPENID = "openid";
    private static final String KEY_REFRESH_TOKEN = "refresh_token";
    private static final String TAG = "WeiXinOAuthService";
    private static final String URL_CHECK_TOKEN = "https://api.weixin.qq.com/sns/auth?access_token=%s&openid=%s";
    private static final String URL_GET_ACCESS_TOKEN = "https://api.weixin.qq.com/sns/oauth2/access_token?appid=%s&secret=%s&code=%s&grant_type=authorization_code";
    private static final String URL_GET_USERINFO = "https://api.weixin.qq.com/sns/userinfo?access_token=%s&openid=%s&lang=zh_CN";
    private static final String URL_REFRESH_TOKEN = "https://api.weixin.qq.com/sns/oauth2/refresh_token?appid=%s&grant_type=refresh_token&refresh_token=%s";
    protected static String appId = null;
    protected static String appKEY = null;
    protected static String appSecret = null;
    protected static String redirectUri = null;
    private IWXAPI api;
    private boolean isAuth = false;
    private boolean isLoginReceiver = false;
    FeatureMessageDispatcher.MessageListener sLoginMessageListener = new FeatureMessageDispatcher.MessageListener() {
        /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass1 */

        @Override // io.dcloud.common.DHInterface.FeatureMessageDispatcher.MessageListener
        public void onReceiver(final Object msg) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass1.AnonymousClass1 */

                public void run() {
                    Object obj = msg;
                    if (obj instanceof SendMessageToWX.Resp) {
                        WeiXinOAuthService.this.onLoginCallBack(WeiXinOAuthService.this.mLoginWebViewImpl, WeiXinOAuthService.this.mLoginCallbackId, ((SendMessageToWX.Resp) obj).errCode);
                    }
                    if (msg instanceof SendAuth.Resp) {
                        WeiXinOAuthService.this.isLoginReceiver = true;
                        SendAuth.Resp resp = (SendAuth.Resp) msg;
                        String code = resp.code;
                        String state = resp.state;
                        JSONObject result = null;
                        String s_access_token = null;
                        if (WeiXinOAuthService.this.isAuth) {
                            WeiXinOAuthService.this.isAuth = false;
                            if (resp.errCode == 0) {
                                JSONObject jsonResult = new JSONObject();
                                try {
                                    JSONObject jSONObject = WeiXinOAuthService.this.mAuthOptions;
                                    String str = WeiXinOAuthService.DEFAULT_SCOPE;
                                    if (jSONObject != null) {
                                        str = WeiXinOAuthService.this.mAuthOptions.optString("scope", str);
                                    }
                                    jsonResult.put("scope", str);
                                    jsonResult.put("state", state);
                                    jsonResult.put("code", code);
                                    jsonResult.put(AbsoluteConst.JSON_KEY_LANG, resp.lang);
                                    jsonResult.put("country", resp.country);
                                    Deprecated_JSUtil.execCallback(WeiXinOAuthService.this.mAuthWebview, WeiXinOAuthService.this.mAuthCallbackId, jsonResult.toString(), JSUtil.OK, true, false);
                                } catch (JSONException e) {
                                }
                            } else {
                                WeiXinOAuthService.this.onLoginCallBack(WeiXinOAuthService.this.mAuthWebview, WeiXinOAuthService.this.mAuthCallbackId, resp.errCode);
                            }
                            FeatureMessageDispatcher.unregisterListener(WeiXinOAuthService.this.sLoginMessageListener);
                            return;
                        }
                        if (!(code == null || (s_access_token = WeiXinOAuthService.this.getToken(StringUtil.format(WeiXinOAuthService.URL_GET_ACCESS_TOKEN, WeiXinOAuthService.appId, WeiXinOAuthService.appSecret, code))) == null)) {
                            result = JSONUtil.createJSONObject(s_access_token);
                        }
                        if (result == null) {
                            WeiXinOAuthService.this.onLoginCallBack(WeiXinOAuthService.this.mLoginWebViewImpl, WeiXinOAuthService.this.mLoginCallbackId, resp.errCode);
                        } else if (result.has(WeiXinOAuthService.KEY_ERRCODE)) {
                            Deprecated_JSUtil.execCallback(WeiXinOAuthService.this.mLoginWebViewImpl, WeiXinOAuthService.this.mLoginCallbackId, DOMException.toJSON(-100, JSONUtil.getString(result, WeiXinOAuthService.KEY_ERRMSG), JSONUtil.getInt(result, WeiXinOAuthService.KEY_ERRCODE)), JSUtil.ERROR, true, false);
                        } else {
                            WeiXinOAuthService.this.saveValue("authResult", s_access_token);
                            WeiXinOAuthService.this.saveValue("state", state);
                            WeiXinOAuthService.this.initUserInfo();
                            WeiXinOAuthService.this.onLoginCallBack(WeiXinOAuthService.this.mLoginWebViewImpl, WeiXinOAuthService.this.mLoginCallbackId, 0);
                        }
                        FeatureMessageDispatcher.unregisterListener(WeiXinOAuthService.this.sLoginMessageListener);
                    }
                }
            }, true);
        }
    };
    ISysEventListener wxMediator;

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public boolean hasFullConfigData() {
        return !TextUtils.isEmpty(appId) && !TextUtils.isEmpty(appSecret);
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initAuthOptions(JSONObject mLoginOptions) {
        if (mLoginOptions != null) {
            appId = mLoginOptions.optString("appid", appId);
            Logger.e(TAG, "initAuthOptions: appId" + appId);
            appSecret = mLoginOptions.optString("appsecret", appSecret);
            redirectUri = mLoginOptions.optString(SinaWeiboApiManager.KEY_REDIRECT_URI, redirectUri);
            appKEY = mLoginOptions.optString("appkey", appKEY);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void initMetaData() {
        appId = AndroidResources.getMetaValue("WX_APPID");
        appSecret = AndroidResources.getMetaValue("WX_SECRET");
    }

    @Override // io.dcloud.common.DHInterface.BaseFeature.BaseModule
    public void init(Context context) {
        super.init(context);
        this.id = WeiXinApiManager.WEIXIN_ID;
        this.description = DCLoudApplicationImpl.self().getContext().getResources().getString(R.string.dcloud_feature_oauth_weixin_plugin_description);
        this.nativeClient = PlatformUtil.isAppInstalled(context, "com.tencent.mm");
    }

    private void reFreshTokenAndSave(String refresh_token) {
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onLoginCallBack(IWebview pWebViewImpl, String pCallbackId, int code) {
        boolean suc = false;
        String errorMsg = "send";
        if (code == 0) {
            suc = true;
        } else if (code == -4) {
            errorMsg = ERR_MSG_AUTH_DENIED;
        } else if (code == -1) {
            errorMsg = ERR_MSG_COMM;
        } else if (code == -3) {
            errorMsg = ERR_MSG_SENT_FAILED;
        } else if (code == -5) {
            errorMsg = ERR_MSG_UNSUPPORT;
        } else if (code == -2) {
            onLoginFinished(getErrorJsonbject(-2, DOMException.MSG_USER_CANCEL), false, pWebViewImpl, pCallbackId);
            return;
        }
        if (suc) {
            JSUtil.execCallback(pWebViewImpl, pCallbackId, makeResultJSONObject(), JSUtil.OK, false);
        } else {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, DOMException.toJSON(-100, errorMsg, code), JSUtil.ERROR, true, false);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void login(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.login(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mLoginWebViewImpl, this.mLoginCallbackId)) {
            if (!PlatformUtil.isAppInstalled(pWebViewImpl.getContext(), "com.tencent.mm")) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, this.mLoginCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED)), JSUtil.ERROR, true, false);
                return;
            }
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass2 */

                public void run() {
                    WeiXinOAuthService weiXinOAuthService = WeiXinOAuthService.this;
                    weiXinOAuthService.loginInThread(weiXinOAuthService.mLoginWebViewImpl, WeiXinOAuthService.this.mLoginCallbackId, WeiXinOAuthService.this.mLoginOptions);
                }
            });
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void authorize(IWebview pwebview, JSONArray pJsArgs) {
        super.authorize(pwebview, pJsArgs);
        if (TextUtils.isEmpty(appId)) {
            Deprecated_JSUtil.execCallback(pwebview, this.mAuthCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT)), JSUtil.ERROR, true, false);
        } else if (!PlatformUtil.isAppInstalled(pwebview.getContext(), "com.tencent.mm")) {
            Deprecated_JSUtil.execCallback(pwebview, this.mAuthCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED)), JSUtil.ERROR, true, false);
        } else {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass3 */

                public void run() {
                    WeiXinOAuthService.this.isAuth = true;
                    WeiXinOAuthService weiXinOAuthService = WeiXinOAuthService.this;
                    weiXinOAuthService.loginInThread(weiXinOAuthService.mAuthWebview, WeiXinOAuthService.this.mAuthCallbackId, WeiXinOAuthService.this.mAuthOptions);
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loginInThread(IWebview pwebview, String callbackId, JSONObject option) {
        JSONObject refreshTokenResult;
        Logger.d(TAG, "isLoginReceiver = false");
        this.isLoginReceiver = false;
        JSONObject authResult = JSONUtil.createJSONObject(getValue("authResult"));
        if (!this.isAuth && authResult != null && authResult.has("access_token")) {
            byte[] temp = NetTool.httpGet(StringUtil.format(URL_CHECK_TOKEN, authResult.optString("access_token"), authResult.optString("openid")), 15000);
            if (temp != null) {
                JSONObject checkTokenResult = JSONUtil.createJSONObject(new String(temp));
                if (checkTokenResult != null) {
                    if (checkTokenResult.optInt(KEY_ERRCODE) == 0) {
                        initUserInfo();
                        onLoginCallBack(pwebview, callbackId, 0);
                        return;
                    }
                    removeToken();
                    String s_refreshToken = refreshToken(StringUtil.format(URL_REFRESH_TOKEN, appId, authResult.optString(KEY_REFRESH_TOKEN)));
                    if (!PdrUtil.isEmpty(s_refreshToken)) {
                        refreshTokenResult = JSONUtil.createJSONObject(s_refreshToken);
                    } else {
                        onLoginCallBack(pwebview, callbackId, -1);
                        refreshTokenResult = null;
                    }
                    if (PdrUtil.isEmpty(refreshTokenResult)) {
                        onLoginCallBack(pwebview, callbackId, -1);
                    } else if (!refreshTokenResult.has(KEY_ERRCODE)) {
                        saveValue("authResult", s_refreshToken);
                        initUserInfo();
                        onLoginCallBack(pwebview, callbackId, 0);
                        return;
                    }
                }
            } else {
                onLoginCallBack(pwebview, callbackId, -1);
            }
        }
        loginInUIThread(pwebview, callbackId, option);
    }

    private void loginInUIThread(final IWebview pwebview, final String callbackId, final JSONObject option) {
        MessageHandler.post(new Runnable() {
            /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass4 */

            public void run() {
                IWebview iWebview = pwebview;
                if (iWebview != null && iWebview.obtainFrameView() != null && pwebview.obtainApp() != null) {
                    SendAuth.Req req = new SendAuth.Req();
                    req.scope = WeiXinOAuthService.DEFAULT_SCOPE;
                    req.state = WeiXinOAuthService.DEFAULT_STATE;
                    req.transaction = String.valueOf(System.currentTimeMillis());
                    JSONObject jSONObject = option;
                    if (jSONObject != null) {
                        req.scope = jSONObject.optString("scope", req.scope);
                        req.state = option.optString("state", req.state);
                    }
                    if (!(pwebview.getActivity() instanceof IActivityHandler) || !((IActivityHandler) pwebview.getActivity()).isMultiProcessMode()) {
                        if (WeiXinOAuthService.this.api == null) {
                            WeiXinOAuthService.this.api = WXAPIFactory.createWXAPI(pwebview.getActivity(), WeiXinOAuthService.appId, true);
                            WeiXinOAuthService.this.api.registerApp(WeiXinOAuthService.appId);
                        }
                        boolean suc = WeiXinOAuthService.this.api.sendReq(req);
                        final IApp app = pwebview.obtainFrameView().obtainApp();
                        app.registerSysEventListener(new ISysEventListener() {
                            /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass4.AnonymousClass1 */

                            @Override // io.dcloud.common.DHInterface.ISysEventListener
                            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                                Logger.d(WeiXinOAuthService.TAG, "isLoginReceiver1 " + WeiXinOAuthService.this.isLoginReceiver);
                                if (!WeiXinOAuthService.this.isLoginReceiver) {
                                    Logger.d(WeiXinOAuthService.TAG, "isLoginReceiver2 " + WeiXinOAuthService.this.isLoginReceiver);
                                    WeiXinOAuthService.this.onLoginFinished(WeiXinOAuthService.this.getErrorJsonbject(-2, DOMException.MSG_USER_CANCEL), false, pwebview, callbackId);
                                }
                                IApp iApp = app;
                                if (iApp != null) {
                                    iApp.unregisterSysEventListener(this, ISysEventListener.SysEventType.onResume);
                                }
                                return false;
                            }
                        }, ISysEventListener.SysEventType.onResume);
                        if (!suc || !WeiXinOAuthService.this.hasWXEntryActivity(pwebview.getContext())) {
                            pwebview.obtainWindowView().postDelayed(new Runnable() {
                                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass4.AnonymousClass2 */

                                public void run() {
                                    WeiXinOAuthService.this.onLoginCallBack(pwebview, callbackId, -3);
                                }
                            }, 500);
                            return;
                        }
                        WeiXinOAuthService.this.isLoginReceiver = true;
                        if (!FeatureMessageDispatcher.sFeatureMessage.contains(WeiXinOAuthService.this.sLoginMessageListener)) {
                            FeatureMessageDispatcher.registerListener(WeiXinOAuthService.this.sLoginMessageListener);
                            return;
                        }
                        return;
                    }
                    WeiXinOAuthService.this.startWeiXinMediator(req, pwebview, callbackId);
                }
            }
        });
    }

    /* access modifiers changed from: protected */
    public void onLoginFinished(JSONObject msg, boolean suc, IWebview pwebview, String callbackId) {
        JSUtil.execCallback(pwebview, callbackId, msg, suc ? JSUtil.OK : JSUtil.ERROR, false);
        if (this.isAuth) {
            this.mAuthWebview = null;
            this.mAuthCallbackId = null;
            return;
        }
        this.mLoginCallbackId = null;
        this.mLoginWebViewImpl = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startWeiXinMediator(SendAuth.Req req, final IWebview pwebview, final String callbackId) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WeiXinMediator.class.getName());
        Bundle bundle = new Bundle();
        req.toBundle(bundle);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.putExtra("transaction", req.transaction);
        intent.setClassName(pwebview.getActivity(), ProcessMediator.class.getName());
        pwebview.getActivity().startActivityForResult(intent, 1000);
        pwebview.getActivity().overridePendingTransition(0, 0);
        if (this.wxMediator == null) {
            this.wxMediator = new ISysEventListener() {
                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass5 */

                @Override // io.dcloud.common.DHInterface.ISysEventListener
                public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                    Object[] _args = (Object[]) pArgs;
                    int requestCode = ((Integer) _args[0]).intValue();
                    ((Integer) _args[1]).intValue();
                    Intent data = (Intent) _args[2];
                    if (pEventType == ISysEventListener.SysEventType.onActivityResult && requestCode == 1000) {
                        Bundle bundle = data.getBundleExtra("result");
                        if (bundle == null) {
                            WeiXinOAuthService.this.onLoginCallBack(pwebview, callbackId, -2);
                        } else {
                            String s = bundle.getString("style");
                            if ("BaseResp".equals(s)) {
                                SendAuth.Resp payResp = new SendAuth.Resp();
                                payResp.fromBundle(bundle);
                                WeiXinOAuthService.this.sLoginMessageListener.onReceiver(payResp);
                            } else if ("BaseReq".equals(s)) {
                                BaseReq baseReq = new SendAuth.Req();
                                baseReq.fromBundle(bundle);
                                WeiXinOAuthService.this.sLoginMessageListener.onReceiver(baseReq);
                            }
                        }
                    }
                    return false;
                }
            };
            pwebview.obtainApp().registerSysEventListener(this.wxMediator, ISysEventListener.SysEventType.onActivityResult);
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void logout(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.logout(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mLogoutWebViewImpl, this.mLogoutCallbackId)) {
            removeToken();
            this.userInfo = null;
            this.authResult = null;
            onLogoutFinished(makeResultJSONObject(), true);
            this.api = null;
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public void getUserInfo(IWebview pWebViewImpl, JSONArray pJsArgs) {
        super.getUserInfo(pWebViewImpl, pJsArgs);
        if (!hasGeneralError(this.mGetUserInfoWebViewImpl, this.mGetUserInfoCallbackId)) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.oauth.weixin.WeiXinOAuthService.AnonymousClass6 */

                public void run() {
                    boolean suc = WeiXinOAuthService.this.initUserInfo();
                    if (suc) {
                        WeiXinOAuthService.this.onGetUserInfoFinished(WeiXinOAuthService.this.makeResultJSONObject(), suc);
                        return;
                    }
                    Deprecated_JSUtil.execCallback(WeiXinOAuthService.this.mGetUserInfoWebViewImpl, WeiXinOAuthService.this.mGetUserInfoCallbackId, DOMException.toJSON(-100, DOMException.MSG_UNOAUTH_ERROR, -1003), JSUtil.ERROR, true, false);
                }
            });
        }
    }

    @Override // io.dcloud.feature.oauth.BaseOAuthService
    public JSONObject makeResultJSONObject() {
        JSONObject sucJSON = new JSONObject();
        try {
            sucJSON.put("authResult", this.authResult);
            sucJSON.put("userInfo", this.userInfo);
            sucJSON.put("state", getValue("state"));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return sucJSON;
    }

    /* access modifiers changed from: package-private */
    public boolean initUserInfo() {
        this.authResult = JSONUtil.createJSONObject(getValue("authResult"));
        if (this.authResult == null || !this.authResult.has("access_token")) {
            return false;
        }
        String s_userInfoResult = getUserInfo(StringUtil.format(URL_GET_USERINFO, this.authResult.opt("access_token"), this.authResult.opt("openid")));
        JSONObject userInfoResult = JSONUtil.createJSONObject(s_userInfoResult);
        if (userInfoResult == null || userInfoResult.has(KEY_ERRCODE)) {
            return false;
        }
        saveValue("userInfo", s_userInfoResult);
        this.userInfo = userInfoResult;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean hasWXEntryActivity(Context context) {
        try {
            Class.forName(context.getPackageName() + MMessageActV2.DEFAULT_ENTRY_CLASS_NAME);
            return true;
        } catch (ClassNotFoundException e) {
            return false;
        }
    }
}
