package io.dcloud.feature.payment.weixin;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import com.taobao.weex.el.parse.Operators;
import com.tencent.mm.opensdk.modelbase.BaseReq;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.modelpay.PayReq;
import com.tencent.mm.opensdk.modelpay.PayResp;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.payment.AbsPaymentChannel;
import io.dcloud.feature.payment.PaymentResult;
import java.util.Set;
import org.json.JSONObject;

public class WeiXinPay extends AbsPaymentChannel implements ISysEventListener {
    private static String APPID = null;
    private static final String ERR_MSG_AUTH_DENIED = "Authentication failed";
    private static final String ERR_MSG_COMM = "General errors";
    private static final String ERR_MSG_SENT_FAILED = "Unable to send";
    private static final String ERR_MSG_UNSUPPORT = "Unsupport error";
    private static final String ERR_MSG_USER_CANCEL = "User canceled";
    private static final String PNAME_MM = "com.tencent.mm";
    private static final String URL_MARKET_DETAILS = "market://search?q=pname:%s";
    private IWXAPI api;
    private boolean isInstallingService = false;
    FeatureMessageDispatcher.MessageListener sPayCallbackMessageListener = new FeatureMessageDispatcher.MessageListener() {
        /* class io.dcloud.feature.payment.weixin.WeiXinPay.AnonymousClass2 */

        @Override // io.dcloud.common.DHInterface.FeatureMessageDispatcher.MessageListener
        public void onReceiver(Object msg) {
            if (msg instanceof BaseResp) {
                WeiXinPay.this.executePayCallbackMsg((BaseResp) msg);
                FeatureMessageDispatcher.unregisterListener(WeiXinPay.this.sPayCallbackMessageListener);
            }
        }
    };
    private String statement = null;

    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    public void init(Context context) {
        super.init(context);
        this.id = "wxpay";
        this.description = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_wxpay_plugin_description);
        this.serviceReady = PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm");
        String metaValue = AndroidResources.getMetaValue("WX_APPID");
        APPID = metaValue;
        IWXAPI createWXAPI = WXAPIFactory.createWXAPI(context, metaValue);
        this.api = createWXAPI;
        createWXAPI.registerApp(APPID);
    }

    private boolean hasFullConfigData() {
        return !TextUtils.isEmpty(APPID);
    }

    private boolean hasGeneralError() {
        if (!hasFullConfigData()) {
            this.mListener.onError(-7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT));
            return true;
        } else if (PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm")) {
            return false;
        } else {
            this.mListener.onError(-8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED));
            return true;
        }
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    public void installService() {
        try {
            PlatformUtil.openURL(this.mContext, StringUtil.format(URL_MARKET_DETAILS, "com.tencent.mm"), null);
            this.isInstallingService = true;
            this.mWebview.obtainApp().registerSysEventListener(this, ISysEventListener.SysEventType.onResume);
        } catch (Exception e) {
            e.printStackTrace();
            this.mWebview.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onResume);
        }
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        if (pEventType == ISysEventListener.SysEventType.onResume) {
            this.serviceReady = PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm");
            this.isInstallingService = false;
            this.mWebview.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onResume);
            if (!this.serviceReady) {
                this.mListener.onError(-8, DOMException.MSG_CLIENT_UNINSTALLED);
            } else if (!PdrUtil.isEmpty(this.statement)) {
                request(this.statement);
                this.statement = null;
            }
        }
        return false;
    }

    private void startWXPayMediator(PayReq req) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WXPayMediator.class.getName());
        Bundle bundle = new Bundle();
        req.toBundle(bundle);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.putExtra("transaction", req.prepayId);
        intent.putExtra(ProcessMediator.PROCESS_ACTIVITY_SOURCE, this.mWebview.getActivity().getClass().getName());
        intent.setClassName(this.mWebview.getActivity(), WXPayProcessMeadiatorActivity.class.getName());
        this.mWebview.getActivity().startActivityForResult(intent, 1000);
        this.mWebview.getActivity().overridePendingTransition(0, 0);
        this.mWebview.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.feature.payment.weixin.WeiXinPay.AnonymousClass1 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Object[] _args = (Object[]) pArgs;
                int requestCode = ((Integer) _args[0]).intValue();
                ((Integer) _args[1]).intValue();
                Intent data = (Intent) _args[2];
                if (data == null || pEventType != ISysEventListener.SysEventType.onActivityResult || requestCode != 1000 || !data.hasExtra("result")) {
                    return false;
                }
                Bundle bundle = data.getBundleExtra("result");
                String s = bundle.getString("style");
                if ("BaseResp".equals(s)) {
                    PayResp payResp = new PayResp();
                    payResp.fromBundle(bundle);
                    WeiXinPay.this.sPayCallbackMessageListener.onReceiver(payResp);
                } else if ("BaseReq".equals(s)) {
                    BaseReq baseReq = new PayReq();
                    baseReq.fromBundle(bundle);
                    WeiXinPay.this.sPayCallbackMessageListener.onReceiver(baseReq);
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    public void request(String pStatement) {
        if (!hasGeneralError()) {
            if (PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm")) {
                PayInfoResult result = new PayInfoResult();
                result.parseFrom(pStatement);
                PayReq req = new PayReq();
                req.appId = result.appid;
                req.partnerId = result.partnerid;
                req.prepayId = result.prepayid;
                req.nonceStr = result.noncestr;
                req.timeStamp = result.timestamp;
                req.packageValue = result.result_package;
                req.sign = result.sign;
                if (!(this.mWebview.getActivity() instanceof IActivityHandler) || !((IActivityHandler) this.mWebview.getActivity()).isMultiProcessMode()) {
                    boolean ret = this.api.sendReq(req);
                    if (!ret || !hasWXPayEntryActivity(this.mWebview.getContext())) {
                        onPayCallback(ret ? 0 : -1, null);
                        return;
                    }
                    FeatureMessageDispatcher.registerListener(this.sPayCallbackMessageListener);
                    Logger.d("wxpay", "will pay");
                    return;
                }
                startWXPayMediator(req);
            } else if (this.isInstallingService) {
                this.statement = pStatement;
            } else {
                this.mListener.onError(-8, DOMException.MSG_CLIENT_UNINSTALLED);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void executePayCallbackMsg(BaseResp resp) {
        if (resp != null) {
            int code = resp.errCode;
            StringBuffer sb = new StringBuffer(Operators.BLOCK_START_STR);
            Bundle bundle = new Bundle();
            resp.toBundle(bundle);
            Set<String> sets = bundle.keySet();
            if (sets != null) {
                int size = sets.size();
                String[] keys = new String[size];
                sets.toArray(keys);
                for (int i = 0; i < size; i++) {
                    String key = keys[i];
                    sb.append("'");
                    sb.append(key);
                    sb.append("':");
                    sb.append("'");
                    sb.append(bundle.get(key));
                    sb.append("'");
                    if (i != size - 1) {
                        sb.append(",");
                    }
                }
            }
            sb.append("}");
            onPayCallback(code, sb.toString());
        }
    }

    /* access modifiers changed from: package-private */
    public void onPayCallback(int code, String rawData) {
        boolean suc = false;
        String errorMsg = null;
        if (code == 0) {
            suc = true;
        } else if (code == -4) {
            errorMsg = ERR_MSG_AUTH_DENIED;
        } else if (code == -1) {
            errorMsg = ERR_MSG_COMM;
        } else if (code == -3) {
            errorMsg = ERR_MSG_SENT_FAILED;
        } else if (code == -5) {
            errorMsg = ERR_MSG_UNSUPPORT;
        } else if (code == -2) {
            errorMsg = ERR_MSG_USER_CANCEL;
        }
        if (suc) {
            Logger.d("wxpay", "pay success");
            PaymentResult pr = new PaymentResult(this);
            pr.rawDataJson = rawData;
            this.mListener.onSuccess(pr);
            return;
        }
        Logger.d("wxpay", "pay failed code=" + code);
        this.mListener.onError(-100, DOMException.toString(code, getFullDescription(), errorMsg, (String) null));
    }

    private static boolean hasWXPayEntryActivity(Context context) {
        try {
            Class.forName(context.getPackageName() + ".wxapi.WXPayEntryActivity");
            return true;
        } catch (ClassNotFoundException e) {
            return false;
        }
    }

    /* access modifiers changed from: private */
    public static class PayInfoResult {
        private static final String KEY_APPID = "appid";
        private static final String KEY_NONCESTR = "noncestr";
        private static final String KEY_PACKAGE = "package";
        private static final String KEY_PARTNERID = "partnerid";
        private static final String KEY_PREPAYID = "prepayid";
        private static final String KEY_RETCODE = "retcode";
        private static final String KEY_RETMSG = "retmsg";
        private static final String KEY_SIGN = "sign";
        private static final String KEY_TIMESTAMP = "timestamp";
        public String appid;
        public String noncestr;
        public String partnerid;
        public String prepayid;
        public String result_package;
        public int retcode;
        public String retmsg;
        public String sign;
        public String timestamp;

        private PayInfoResult() {
        }

        public void parseFrom(String content) {
            try {
                JSONObject json = new JSONObject(content);
                this.appid = json.optString("appid");
                if (json.has("nonceStr")) {
                    this.noncestr = json.optString("nonceStr");
                } else {
                    this.noncestr = json.optString(KEY_NONCESTR);
                }
                this.result_package = json.optString(KEY_PACKAGE, "Sign=WXPay");
                this.partnerid = json.optString(KEY_PARTNERID);
                this.prepayid = json.optString(KEY_PREPAYID);
                this.timestamp = json.optString("timestamp");
                this.sign = json.optString(KEY_SIGN);
            } catch (Exception e) {
                this.retcode = -1000;
            }
        }
    }
}
