package io.dcloud.feature.speech;

import android.content.Context;
import io.dcloud.common.DHInterface.IReflectAble;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.StringUtil;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public abstract class AbsSpeechEngine implements IReflectAble {
    public static final int ERROR_CODE_DEVICE_NO_SUPPORT = 61002;
    public static final int ERROR_CODE_DONT_RECOGNISE = 61007;
    public static final int ERROR_CODE_GRAMMAR = 61005;
    public static final int ERROR_CODE_INNER_WRONG = 61006;
    public static final int ERROR_CODE_IN_USE = 61003;
    public static final int ERROR_CODE_NETWORK = 61008;
    public static final int ERROR_CODE_PARAM_WRONG = 61004;
    public static final int ERROR_CODE_UNKNOWN = 61009;
    public static final int ERROR_CODE_USER_STOP = 61001;
    private Map<String, String> event;
    private String mCallbackId;
    protected Context mContext;
    private JSONObject mEventCallbackIds;
    protected ISpeechListener mListener;
    ISpeechListener mSpeechListener = new ISpeechListener() {
        /* class io.dcloud.feature.speech.AbsSpeechEngine.AnonymousClass1 */

        private String convert(String str) {
            String temp = str;
            if (str.contains("'")) {
                temp = str.replaceAll("'", "\\\\\\'");
            }
            if (temp.contains("\"")) {
                return temp.replaceAll("\"", "\\\\\\\"");
            }
            return temp;
        }

        @Override // io.dcloud.feature.speech.ISpeechListener
        public void onStateChange(byte state, Object args, boolean keepCallback) {
            String str;
            SpeechManager manager = SpeechManager.getInstance();
            if (state == 1) {
                Deprecated_JSUtil.execCallback(AbsSpeechEngine.this.mWebview, JSONUtil.getString(AbsSpeechEngine.this.mEventCallbackIds, AbsoluteConst.JSON_KEY_ONSTART), "", JSUtil.OK, false, false);
                manager.eventListener("start", "{}", JSUtil.OK, true);
            } else if (state == 2) {
                Deprecated_JSUtil.execCallback(AbsSpeechEngine.this.mWebview, JSONUtil.getString(AbsSpeechEngine.this.mEventCallbackIds, AbsoluteConst.JSON_KEY_ONEND), "", JSUtil.OK, false, false);
                manager.eventListener("end", "{}", JSUtil.OK, true);
            } else if (state == 7) {
                String[] objs = (String[]) args;
                String msg = StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf(Integer.parseInt(objs[0])), String.valueOf(objs[1]));
                Deprecated_JSUtil.execCallback(AbsSpeechEngine.this.mWebview, AbsSpeechEngine.this.mCallbackId, msg, JSUtil.ERROR, true, false);
                manager.eventListener("error", msg, JSUtil.OK, true);
            } else if (state == 8) {
                String successResult = "";
                if (args != null) {
                    if (args instanceof String[]) {
                        String[] value = (String[]) args;
                        if (value.length > 0) {
                            successResult = value[0];
                        }
                    } else {
                        successResult = (String) args;
                    }
                }
                String successResult2 = convert(successResult);
                Deprecated_JSUtil.execCallback(AbsSpeechEngine.this.mWebview, AbsSpeechEngine.this.mCallbackId, successResult2, JSUtil.OK, false, keepCallback);
                try {
                    Object[] objArr = new Object[2];
                    objArr[0] = successResult2;
                    if (args == null) {
                        str = "[]";
                    } else if (args instanceof String) {
                        str = "[\"" + convert((String) args) + "\"]";
                    } else {
                        str = new JSONArray(args).toString();
                    }
                    objArr[1] = str;
                    manager.eventListener("recognition", StringUtil.format("{result:\"%s\",results:%s}", objArr), JSUtil.OK, true);
                } catch (JSONException e) {
                }
            } else if (state == 10) {
                manager.eventListener("recognizing", StringUtil.format("{partialResult:\"%s\"}", convert((String) args)), JSUtil.OK, keepCallback);
            } else if (state == 11) {
                manager.eventListener("volumeChange", StringUtil.format("{volume:%f}", Float.valueOf(((float) ((Integer) args).intValue()) * 0.14285715f)), JSUtil.OK, keepCallback);
            }
        }
    };
    protected IWebview mWebview;

    public abstract void startRecognize(JSONObject jSONObject);

    public abstract void stopRecognize(boolean z);

    public void init(Context context, IWebview pWebview) {
        this.mContext = context;
        this.mWebview = pWebview;
        setSpeechListener(this.mSpeechListener);
    }

    private final void setSpeechListener(ISpeechListener listener) {
        this.mListener = listener;
    }

    /* access modifiers changed from: package-private */
    public final void startRecognize(String pCallbackId, JSONObject pOption, JSONObject eventCallbackIds) {
        this.mCallbackId = pCallbackId;
        this.mEventCallbackIds = eventCallbackIds;
        startRecognize(pOption);
    }

    public void addEventListener(String action, String mCallbackId2) {
        if (this.event == null) {
            this.event = new HashMap();
        }
        this.event.put(action, mCallbackId2);
    }
}
