package io.dcloud.feature.speech.dialog;

import android.app.Activity;
import android.app.Dialog;
import android.content.Context;
import android.graphics.Color;
import android.os.Handler;
import android.widget.TextView;
import com.baidu.aip.core.recog.MyRecognizer;
import com.baidu.aip.core.recog.listener.MessageStatusRecogListener;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.PdrUtil;
import java.util.Map;

public class BaiduSpeechDialog extends Dialog {
    private TextView dialogTitle;
    private Activity mAttachActivity;
    private Context mContext;
    private MyRecognizer recognizer;
    private VolumeView volumeView;

    public BaiduSpeechDialog(Context context) {
        super(context);
        this.mContext = context;
        requestWindowFeature(1);
        setContentView(SpeechR.LAYOUT_DIALOG);
        initView(this.mContext);
        getWindow().setBackgroundDrawable(null);
    }

    private void initView(Context context) {
        if (context instanceof Activity) {
            this.mAttachActivity = (Activity) context;
            this.dialogTitle = (TextView) findViewById(SpeechR.ID_VOICE_TITLE);
            VolumeView volumeView2 = (VolumeView) findViewById(SpeechR.ID_VOICE_VOLUME);
            this.volumeView = volumeView2;
            volumeView2.setMaxVolume(7);
            this.volumeView.setVisibility(0);
            this.volumeView.setCurrentVolume(1);
            this.volumeView.setVolumeColor(Color.parseColor("#9C9C9C"));
            return;
        }
        throw new RuntimeException("not an activity");
    }

    public void startRecog(Map<String, Object> params, Handler mHandler) {
        this.recognizer = new MyRecognizer(this.mAttachActivity, new MessageStatusRecogListener(mHandler));
        if (((Boolean) params.get(AbsoluteConst.JSON_KEY_USERINTERFACE)).booleanValue()) {
            show();
        }
        params.remove(AbsoluteConst.JSON_KEY_USERINTERFACE);
        this.recognizer.start(params);
    }

    public boolean stopRecog() {
        if (isShowing()) {
            dismiss();
        }
        MyRecognizer myRecognizer = this.recognizer;
        if (myRecognizer == null) {
            return false;
        }
        try {
            myRecognizer.stop();
            this.recognizer.cancel();
            this.recognizer.release();
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public void setVoiceText(String text) {
        if (!PdrUtil.isEmpty(text)) {
            this.dialogTitle.setText(text);
        }
    }

    public int setVolume(int volume) {
        int voice = getVoiceVolume(volume);
        if (voice > 0) {
            this.volumeView.setCurrentVolume(voice);
        }
        return voice;
    }

    private int getVoiceVolume(int volume) {
        if (volume >= 0 && volume < 200) {
            return 1;
        }
        if (200 <= volume && volume < 400) {
            return 2;
        }
        if (400 <= volume && volume < 600) {
            return 3;
        }
        if (600 <= volume && volume < 800) {
            return 4;
        }
        if (800 <= volume && volume < 1000) {
            return 5;
        }
        if (1000 <= volume && volume < 1200) {
            return 6;
        }
        if (1200 <= volume) {
            return 7;
        }
        return 1;
    }
}
