package io.dcloud.feature.speech.dialog;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;

public class VolumeView extends View {
    private int mCurrentVolume = 0;
    private int mMaxVolume = 1;
    private Paint mPaint = null;
    private int mVolumeColor = -65536;

    public VolumeView(Context context) {
        super(context);
        init();
    }

    public VolumeView(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    public VolumeView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init();
    }

    public VolumeView(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        init();
    }

    private void init() {
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setStyle(Paint.Style.FILL);
        this.mPaint.setColor(this.mVolumeColor);
        this.mPaint.setAntiAlias(true);
    }

    public void draw(Canvas canvas) {
        super.draw(canvas);
        int i = this.mCurrentVolume;
        if (1 <= i && i <= this.mMaxVolume) {
            float viewHeight = (float) getHeight();
            float viewWidth = (float) getWidth();
            int i2 = this.mMaxVolume;
            float volumeHeight = viewHeight / ((float) ((i2 + i2) - 1));
            float volumeSpaceHeight = viewHeight / ((float) ((i2 + i2) - 1));
            for (int i3 = 1; i3 <= this.mCurrentVolume; i3++) {
                int i4 = this.mMaxVolume;
                float volumeTop = ((float) (i4 - i3)) * (volumeHeight + volumeSpaceHeight);
                canvas.drawRect(0.0f, volumeTop, (((float) i3) * viewWidth) / ((float) i4), volumeTop + volumeHeight, this.mPaint);
            }
        }
    }

    public int getCurrentVolume() {
        return this.mCurrentVolume;
    }

    public void setCurrentVolume(int currentVolume) {
        this.mCurrentVolume = currentVolume;
        invalidate();
    }

    public int getMaxVolume() {
        return this.mMaxVolume;
    }

    public void setMaxVolume(int maxVolume) {
        this.mMaxVolume = maxVolume;
    }

    public int getVolumeColor() {
        return this.mVolumeColor;
    }

    public void setVolumeColor(int volumeColor) {
        this.mVolumeColor = volumeColor;
        Paint paint = this.mPaint;
        if (paint != null) {
            try {
                paint.setColor(volumeColor);
            } catch (Exception e) {
            }
        }
    }
}
