package io.dcloud.feature.sqlite;

import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.text.TextUtils;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.DHInterface.StandardFeature;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import java.io.File;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.Arrays;
import java.util.HashMap;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DataBaseFeature extends StandardFeature {
    public HashMap<String, SQLiteDatabase> map = new HashMap<>();
    private String resultMessage = "{'code':%d,'message':\"%s\"}";

    public void openDatabase(IWebview pWebview, JSONArray array) {
        int dbFlag;
        String toPath;
        int dbFlag2;
        String callBackID = array.optString(0);
        String name = array.optString(1);
        String path = array.optString(2);
        if (PdrUtil.isEmpty(name) || PdrUtil.isEmpty(path)) {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("parameter can't be null")), JSUtil.ERROR, true, false);
            return;
        }
        if (path.startsWith(BaseInfo.REL_PRIVATE_WWW_DIR)) {
            dbFlag = 1;
        } else if (PdrUtil.isDeviceRootDir(path)) {
            dbFlag = AMapEngineUtils.MAX_P20_WIDTH;
        } else if (path.startsWith(BaseInfo.REL_PRIVATE_DOC_DIR) || path.startsWith(BaseInfo.REL_PUBLIC_DOCUMENTS_DIR) || path.startsWith(BaseInfo.REL_PUBLIC_DOWNLOADS_DIR)) {
            dbFlag = AMapEngineUtils.MAX_P20_WIDTH;
        } else {
            dbFlag = 1;
        }
        String path2 = pWebview.obtainApp().convert2AbsFullPath(pWebview.obtainFullUrl(), path);
        if (!PdrUtil.isDeviceRootDir(path2)) {
            String toPath2 = DeviceInfo.sBaseFsRootPath + path2;
            if (!new File(toPath2).exists()) {
                DHFile.copyAssetsFile(path2, toPath2);
            }
            dbFlag2 = 1;
            toPath = pWebview.obtainApp().convert2AbsFullPath(pWebview.obtainFullUrl(), toPath2);
        } else {
            dbFlag2 = dbFlag;
            toPath = path2;
        }
        if (new File(toPath).exists() || dbFlag2 != 1) {
            File file = new File(toPath);
            if (!file.exists()) {
                if (!file.getParentFile().exists()) {
                    file.getParentFile().mkdirs();
                }
                try {
                    file.createNewFile();
                } catch (IOException e) {
                }
            }
            if (this.map.containsKey(name)) {
                Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1402, DOMException.toString("Same Name Already Open")), JSUtil.ERROR, true, false);
                return;
            }
            try {
                this.map.put(name, SQLiteDatabase.openDatabase(toPath, null, dbFlag2, null));
                Deprecated_JSUtil.execCallback(pWebview, callBackID, "{}", JSUtil.OK, true, false);
            } catch (Exception e2) {
                JSONObject object = new JSONObject();
                try {
                    object.put("code", -1404);
                    object.put("message", DOMException.toString(e2.toString()));
                } catch (JSONException e3) {
                }
                JSUtil.execCallback(pWebview, callBackID, object, JSUtil.ERROR, false);
            }
        } else {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1403, DOMException.toString("Cannot create file private directory,such as:\\'www\\'")), JSUtil.ERROR, true, false);
        }
    }

    public String isOpenDatabase(IWebview pwebview, JSONArray array) {
        JSONObject param = array.optJSONObject(0);
        if (PdrUtil.isEmpty(param)) {
            return Deprecated_JSUtil.wrapJsVar(Constants.Name.UNDEFINED, false);
        }
        String dbName = param.optString("name");
        String dbPath = param.optString("path");
        if (PdrUtil.isEmpty(dbName) || PdrUtil.isEmpty(dbPath)) {
            return Deprecated_JSUtil.wrapJsVar(Constants.Name.UNDEFINED, false);
        }
        for (String key : this.map.keySet()) {
            SQLiteDatabase db = this.map.get(key);
            String realPath = pwebview.obtainApp().convert2AbsFullPath(pwebview.obtainFullUrl(), dbPath);
            if (!PdrUtil.isDeviceRootDir(realPath)) {
                realPath = DeviceInfo.sBaseFsRootPath + realPath;
            }
            if (realPath.equalsIgnoreCase(db.getPath())) {
                return JSUtil.wrapJsVar(true);
            }
        }
        if (this.map.containsKey(dbName)) {
            return JSUtil.wrapJsVar(true);
        }
        return JSUtil.wrapJsVar(false);
    }

    public void closeDatabase(IWebview pWebview, JSONArray array) {
        String callBackID = array.optString(0);
        String name = array.optString(1);
        SQLiteDatabase database = this.map.get(name);
        if (PdrUtil.isEmpty(name)) {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("parameter can't be null")), JSUtil.ERROR, true, false);
        } else if (database != null) {
            database.close();
            this.map.remove(name);
            Deprecated_JSUtil.execCallback(pWebview, callBackID, "{}", JSUtil.OK, true, false);
        } else {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, Integer.valueOf((int) DOMException.CODE_STATISTICS_SERVICE_INVALID), DOMException.toString("Not Open")), JSUtil.ERROR, true, false);
        }
    }

    public void transaction(IWebview pWebview, JSONArray array) {
        String callBackID = array.optString(0);
        String name = array.optString(1);
        SQLiteDatabase database = this.map.get(name);
        String operation = array.optString(2);
        if (PdrUtil.isEmpty(name) || PdrUtil.isEmpty(operation)) {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("parameter can't be null")), JSUtil.ERROR, true, false);
        } else if (database != null) {
            try {
                if (operation.equals("begin")) {
                    database.beginTransaction();
                } else if (operation.equals("commit")) {
                    database.setTransactionSuccessful();
                    database.endTransaction();
                } else if (operation.equals("rollback")) {
                    database.endTransaction();
                } else {
                    Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("Operation Error")), JSUtil.ERROR, true, false);
                }
                Deprecated_JSUtil.execCallback(pWebview, callBackID, "{}", JSUtil.OK, true, false);
            } catch (Exception e) {
                JSONObject object = new JSONObject();
                try {
                    object.put("code", -1404);
                    object.put("message", DOMException.toString(e.toString()));
                } catch (JSONException e2) {
                }
                JSUtil.execCallback(pWebview, callBackID, object, JSUtil.ERROR, false);
            }
        } else {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, Integer.valueOf((int) DOMException.CODE_STATISTICS_SERVICE_INVALID), DOMException.toString("Not Open")), JSUtil.ERROR, true, false);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:30:0x00a6 A[SYNTHETIC, Splitter:B:30:0x00a6] */
    /* JADX WARNING: Removed duplicated region for block: B:43:0x00cc  */
    public void executeSql(IWebview pWebview, JSONArray array) {
        String sql;
        Exception e;
        int i;
        Exception e2;
        JSONObject object;
        String callBackID = array.optString(0);
        String name = array.optString(1);
        SQLiteDatabase database = this.map.get(name);
        String sql2 = array.optString(2);
        if (!PdrUtil.isEmpty(name)) {
            if (!PdrUtil.isEmpty(sql2)) {
                if (database != null) {
                    try {
                        JSONArray sqls = new JSONArray(sql2);
                        if (sqls.length() > 0) {
                            for (int i2 = 0; i2 < sqls.length(); i2++) {
                                try {
                                    String s = sqls.optString(i2);
                                    if (!TextUtils.isEmpty(s.trim())) {
                                        database.execSQL(s);
                                    }
                                } catch (Exception e3) {
                                    e = e3;
                                    sql = sql2;
                                    try {
                                        if (e instanceof SQLException) {
                                            try {
                                                object = new JSONObject();
                                                i = -1404;
                                                try {
                                                    object.put("code", -1404);
                                                    object.put("message", DOMException.toString(e.toString()));
                                                } catch (JSONException e4) {
                                                }
                                            } catch (Exception e5) {
                                                e2 = e5;
                                                i = -1404;
                                                JSONObject object2 = new JSONObject();
                                                try {
                                                    object2.put("code", i);
                                                    object2.put("message", DOMException.toString(e2.toString()));
                                                } catch (JSONException e6) {
                                                }
                                                JSUtil.execCallback(pWebview, callBackID, object2, JSUtil.ERROR, false);
                                                return;
                                            }
                                            try {
                                                JSUtil.execCallback(pWebview, callBackID, object, JSUtil.ERROR, false);
                                                return;
                                            } catch (Exception e7) {
                                                e2 = e7;
                                                JSONObject object22 = new JSONObject();
                                                object22.put("code", i);
                                                object22.put("message", DOMException.toString(e2.toString()));
                                                JSUtil.execCallback(pWebview, callBackID, object22, JSUtil.ERROR, false);
                                                return;
                                            }
                                        } else {
                                            i = -1404;
                                            try {
                                                database.execSQL(sql);
                                                Deprecated_JSUtil.execCallback(pWebview, callBackID, "{}", JSUtil.OK, true, false);
                                                return;
                                            } catch (Exception e8) {
                                                e2 = e8;
                                                JSONObject object222 = new JSONObject();
                                                object222.put("code", i);
                                                object222.put("message", DOMException.toString(e2.toString()));
                                                JSUtil.execCallback(pWebview, callBackID, object222, JSUtil.ERROR, false);
                                                return;
                                            }
                                        }
                                    } catch (Exception e9) {
                                        e2 = e9;
                                        i = -1404;
                                        JSONObject object2222 = new JSONObject();
                                        object2222.put("code", i);
                                        object2222.put("message", DOMException.toString(e2.toString()));
                                        JSUtil.execCallback(pWebview, callBackID, object2222, JSUtil.ERROR, false);
                                        return;
                                    }
                                }
                            }
                            sql = sql2;
                            try {
                                Deprecated_JSUtil.execCallback(pWebview, callBackID, "{}", JSUtil.OK, true, false);
                                return;
                            } catch (Exception e10) {
                                e = e10;
                                if (e instanceof SQLException) {
                                }
                            }
                        } else {
                            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("parameter can't be null")), JSUtil.ERROR, true, false);
                            return;
                        }
                    } catch (Exception e11) {
                        e = e11;
                        sql = sql2;
                        if (e instanceof SQLException) {
                        }
                    }
                } else {
                    Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, Integer.valueOf((int) DOMException.CODE_STATISTICS_SERVICE_INVALID), DOMException.toString("Not Open")), JSUtil.ERROR, true, false);
                    return;
                }
            }
        }
        Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, -1404, DOMException.toString("parameter can't be null")), JSUtil.ERROR, true, false);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:31:0x00a0 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:94:0x0117 */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX INFO: Multiple debug info for r6v9 ??: [D('type' int), D('res' org.json.JSONObject)] */
    /* JADX INFO: Multiple debug info for r6v10 ??: [D('type' int), D('res' org.json.JSONObject)] */
    /* JADX INFO: Multiple debug info for r6v11 ??: [D('type' int), D('res' org.json.JSONObject)] */
    /* JADX INFO: Multiple debug info for r6v14 ??: [D('type' int), D('res' org.json.JSONObject)] */
    /* JADX WARN: Type inference failed for: r6v6 */
    /* JADX WARN: Type inference failed for: r6v7 */
    /* JADX WARN: Type inference failed for: r6v9, types: [org.json.JSONObject] */
    /* JADX WARN: Type inference failed for: r6v10, types: [org.json.JSONObject] */
    /* JADX WARN: Type inference failed for: r6v11, types: [org.json.JSONObject] */
    /* JADX WARN: Type inference failed for: r6v12 */
    /* JADX WARN: Type inference failed for: r6v13 */
    /* JADX WARN: Type inference failed for: r6v14, types: [org.json.JSONObject] */
    /* JADX WARN: Type inference failed for: r6v15 */
    /* JADX WARNING: Code restructure failed: missing block: B:40:0x00d3, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:43:0x00db, code lost:
        r17 = r11;
        r19 = r12;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x00d3 A[ExcHandler: Exception (e java.lang.Exception), Splitter:B:31:0x00a0] */
    /* JADX WARNING: Unknown variable types count: 1 */
    public void selectSql(IWebview pWebview, JSONArray array) {
        char c;
        Exception e;
        SQLiteDatabase database;
        String callBackID = array.optString(0);
        boolean z = true;
        String name = array.optString(1);
        SQLiteDatabase database2 = this.map.get(name);
        if (database2 == null) {
            Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(this.resultMessage, Integer.valueOf((int) DOMException.CODE_STATISTICS_SERVICE_INVALID), DOMException.toString("Not Open")), JSUtil.ERROR, true, false);
            return;
        }
        String sql = array.optString(2);
        if (PdrUtil.isEmpty(name)) {
            c = 0;
        } else if (PdrUtil.isEmpty(sql)) {
            c = 0;
        } else {
            try {
                Cursor cursor = database2.rawQuery(sql, null);
                JSONArray arr = new JSONArray();
                try {
                    if (cursor.moveToFirst()) {
                        String[] names = cursor.getColumnNames();
                        while (true) {
                            String name2 = new JSONObject();
                            int i = 0;
                            while (i < names.length) {
                                ?? type = cursor.getType(i);
                                if (type == 0) {
                                    database = database2;
                                    type = name2;
                                    name2 = name;
                                    type.put(names[i], JSONObject.NULL);
                                } else if (type == z || type == 2) {
                                    type = name2;
                                    try {
                                        name2 = name;
                                        database = database2;
                                        try {
                                            type.put(names[i], new BigDecimal(String.valueOf(cursor.getDouble(i))).doubleValue());
                                        } catch (JSONException e2) {
                                        }
                                    } catch (JSONException e3) {
                                        name2 = name;
                                        database = database2;
                                    }
                                } else if (type == 3) {
                                    type = name2;
                                    type.put(names[i], cursor.getString(i));
                                    name2 = name;
                                    database = database2;
                                } else if (type != 4) {
                                    database = database2;
                                    type = name2;
                                    name2 = name;
                                } else {
                                    try {
                                        type = name2;
                                        type.put(names[i], Arrays.toString(cursor.getBlob(i)));
                                        name2 = name;
                                        database = database2;
                                    } catch (JSONException e4) {
                                        type = name2;
                                        name2 = name;
                                        database = database2;
                                    } catch (Exception e5) {
                                    }
                                }
                                i++;
                                names = names;
                                name = name2;
                                database2 = database;
                                z = true;
                                name2 = type;
                            }
                            database = database2;
                            try {
                                arr.put(name2);
                                if (!cursor.moveToNext()) {
                                    break;
                                }
                                names = names;
                                name = name;
                                database2 = database;
                                z = true;
                            } catch (Exception e6) {
                                e = e6;
                                JSONObject object = new JSONObject();
                                try {
                                    object.put("code", -1404);
                                    object.put("message", DOMException.toString(e.toString()));
                                } catch (JSONException e7) {
                                }
                                JSUtil.execCallback(pWebview, callBackID, object, JSUtil.ERROR, false);
                                return;
                            }
                        }
                    }
                    cursor.close();
                    JSUtil.execCallback(pWebview, callBackID, arr, JSUtil.OK, false);
                    return;
                } catch (Exception e8) {
                    e = e8;
                    JSONObject object2 = new JSONObject();
                    object2.put("code", -1404);
                    object2.put("message", DOMException.toString(e.toString()));
                    JSUtil.execCallback(pWebview, callBackID, object2, JSUtil.ERROR, false);
                    return;
                }
            } catch (Exception e9) {
                JSONObject object3 = new JSONObject();
                try {
                    object3.put("code", -1404);
                    object3.put("message", DOMException.toString(e9.toString()));
                } catch (JSONException e10) {
                }
                JSUtil.execCallback(pWebview, callBackID, object3, JSUtil.ERROR, false);
                return;
            }
        }
        String str = this.resultMessage;
        Object[] objArr = new Object[2];
        objArr[c] = -1404;
        objArr[1] = DOMException.toString("parameter can't be null");
        Deprecated_JSUtil.execCallback(pWebview, callBackID, StringUtil.format(str, objArr), JSUtil.ERROR, true, false);
    }
}
