package io.dcloud.feature.uniapp.dom;

import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXImageSharpen;
import com.taobao.weex.dom.WXImageQuality;
import com.taobao.weex.dom.binding.ELUtils;
import com.taobao.weex.dom.binding.WXStatement;
import com.taobao.weex.el.parse.Parser;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

public abstract class AbsAttr implements Map<String, Object>, Cloneable {
    private static final long serialVersionUID = -2619357510079360946L;
    private Map<String, Object> attr;
    private ArrayMap<String, Object> mBindingAttrs;
    private WXStatement mStatement;
    private Map<String, Object> writeAttr;

    @Override // java.lang.Object
    public abstract AbsAttr clone();

    public Map<String, Object> getAttr() {
        return this.attr;
    }

    public AbsAttr() {
        this.attr = new HashMap();
    }

    public AbsAttr(Map<String, Object> standardMap) {
        this.attr = standardMap;
    }

    public AbsAttr(Map<String, Object> standardMap, int extra) {
        this.attr = standardMap;
    }

    public static String getPrefix(Map<String, Object> attr2) {
        Object src;
        if (attr2 == null || (src = attr2.get(Constants.Name.PREFIX)) == null) {
            return null;
        }
        return src.toString();
    }

    public static String getSuffix(Map<String, Object> attr2) {
        Object src;
        if (attr2 == null || (src = attr2.get(Constants.Name.SUFFIX)) == null) {
            return null;
        }
        return src.toString();
    }

    public static String getValue(Map<String, Object> attr2) {
        if (attr2 == null) {
            return null;
        }
        Object src = attr2.get("value");
        if (src == null && (src = attr2.get("content")) == null) {
            return null;
        }
        return src.toString();
    }

    public WXImageQuality getImageQuality() {
        String str = Constants.Name.QUALITY;
        if (!containsKey(str)) {
            str = Constants.Name.IMAGE_QUALITY;
        }
        Object obj = get(str);
        WXImageQuality imageQuality = WXImageQuality.AUTO;
        if (obj == null) {
            return imageQuality;
        }
        String value = obj.toString();
        if (TextUtils.isEmpty(value)) {
            return imageQuality;
        }
        try {
            return WXImageQuality.valueOf(value.toUpperCase(Locale.US));
        } catch (IllegalArgumentException e) {
            WXLogUtils.e("Image", "Invalid value image quality. Only low, normal, high, original are valid");
            return imageQuality;
        }
    }

    public WXImageSharpen getImageSharpen() {
        Object obj = get(Constants.Name.SHARPEN);
        if (obj == null) {
            obj = get(Constants.Name.IMAGE_SHARPEN);
        }
        if (obj == null) {
            return WXImageSharpen.UNSHARPEN;
        }
        String imageSharpen = obj.toString();
        WXImageSharpen waImageSharpen = WXImageSharpen.UNSHARPEN;
        if (imageSharpen.equals(Constants.Name.SHARPEN)) {
            return WXImageSharpen.SHARPEN;
        }
        return waImageSharpen;
    }

    public String getImageSrc() {
        Object src = get("src");
        if (src == null) {
            return null;
        }
        return src.toString();
    }

    public boolean canRecycled() {
        Object obj = get(Constants.Name.RECYCLE);
        if (obj == null) {
            return true;
        }
        try {
            return Boolean.parseBoolean(String.valueOf(obj));
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] recycle:", e);
            return true;
        }
    }

    public boolean showIndicators() {
        Object obj = get(Constants.Name.SHOW_INDICATORS);
        if (obj == null) {
            return true;
        }
        try {
            return Boolean.parseBoolean(String.valueOf(obj));
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] showIndicators:", e);
            return true;
        }
    }

    public boolean autoPlay() {
        Object obj = get(Constants.Name.AUTO_PLAY);
        if (obj == null) {
            return false;
        }
        try {
            return Boolean.parseBoolean(String.valueOf(obj));
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] autoPlay:", e);
            return false;
        }
    }

    public String getScope() {
        Object src = get("scope");
        if (src == null) {
            return null;
        }
        return src.toString();
    }

    public String getLoadMoreRetry() {
        Object src = get(Constants.Name.LOADMORERETRY);
        if (src == null) {
            return null;
        }
        return src.toString();
    }

    public String getLoadMoreOffset() {
        Object src = get("loadmoreoffset");
        if (src == null) {
            return null;
        }
        return src.toString();
    }

    public String optString(String key) {
        if (!containsKey(key)) {
            return "";
        }
        Object value = get(key);
        if (value instanceof String) {
            return (String) value;
        }
        if (value != null) {
            return String.valueOf(value);
        }
        return "";
    }

    public boolean getIsRecycleImage() {
        Object obj = get(Constants.Name.RECYCLE_IMAGE);
        if (obj == null) {
            return true;
        }
        try {
            return Boolean.parseBoolean(String.valueOf(obj));
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] recycleImage:", e);
            return false;
        }
    }

    public String getScrollDirection() {
        Object scrollDirection = get(Constants.Name.SCROLL_DIRECTION);
        if (scrollDirection == null) {
            return "vertical";
        }
        return scrollDirection.toString();
    }

    public int getOrientation() {
        String direction = getScrollDirection();
        if (!TextUtils.isEmpty(direction) && direction.equals(Constants.Value.HORIZONTAL)) {
            return 0;
        }
        Object value = get("orientation");
        if (value == null || !Constants.Value.HORIZONTAL.equals(value.toString())) {
            return 1;
        }
        return 0;
    }

    public float getElevation(float viewPortW) {
        Object obj = get(Constants.Name.ELEVATION);
        if (obj == null) {
            return Float.NaN;
        }
        String number = obj.toString();
        if (!TextUtils.isEmpty(number)) {
            return WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(number), viewPortW);
        }
        return 0.0f;
    }

    public float getColumnWidth() {
        Object obj = get(Constants.Name.COLUMN_WIDTH);
        if (obj == null) {
            return -1.0f;
        }
        String value = String.valueOf(obj);
        if ("auto".equals(value)) {
            return -1.0f;
        }
        try {
            float columnWidth = Float.parseFloat(value);
            if (columnWidth > 0.0f) {
                return columnWidth;
            }
            return 0.0f;
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] getColumnWidth:", e);
            return -1.0f;
        }
    }

    public int getColumnCount() {
        Object obj = get(Constants.Name.COLUMN_COUNT);
        if (obj == null) {
            return -1;
        }
        String value = String.valueOf(obj);
        if ("auto".equals(value)) {
            return -1;
        }
        try {
            int columnCount = Integer.parseInt(value);
            if (columnCount > 0) {
                return columnCount;
            }
            return -1;
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] getColumnCount:", e);
            return -1;
        }
    }

    public float getColumnGap() {
        Object obj = get(Constants.Name.COLUMN_GAP);
        if (obj == null) {
            return 32.0f;
        }
        String value = String.valueOf(obj);
        if ("normal".equals(value)) {
            return 32.0f;
        }
        try {
            float columnGap = Float.parseFloat(value);
            if (columnGap >= 0.0f) {
                return columnGap;
            }
            return -1.0f;
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] getColumnGap:", e);
            return 32.0f;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0033  */
    /* JADX WARNING: Removed duplicated region for block: B:19:0x0038 A[RETURN] */
    public int getLayoutType() {
        Object obj = get(Constants.Name.LAYOUT);
        if (obj == null) {
            return 1;
        }
        try {
            String valueOf = String.valueOf(obj);
            char c = 65535;
            int hashCode = valueOf.hashCode();
            if (hashCode != 3181382) {
                if (hashCode == 674874986 && valueOf.equals(Constants.Value.MULTI_COLUMN)) {
                    c = 0;
                    if (c == 0) {
                        return 3;
                    }
                    if (c != 1) {
                        return 1;
                    }
                    return 2;
                }
            } else if (valueOf.equals(Constants.Value.GRID)) {
                c = 1;
                if (c == 0) {
                }
            }
            if (c == 0) {
            }
        } catch (Exception e) {
            WXLogUtils.e("[WXAttr] getLayoutType:", e);
            return 1;
        }
    }

    public boolean equals(Object o) {
        return this.attr.equals(o);
    }

    public int hashCode() {
        return this.attr.hashCode();
    }

    public void clear() {
        this.attr.clear();
    }

    public boolean containsKey(Object key) {
        return this.attr.containsKey(key);
    }

    public boolean containsValue(Object value) {
        return this.attr.containsValue(value);
    }

    @Override // java.util.Map
    public Set<Map.Entry<String, Object>> entrySet() {
        return this.attr.entrySet();
    }

    @Override // java.util.Map
    public Object get(Object key) {
        Object obj;
        Map<String, Object> temp = this.writeAttr;
        if (temp == null || (obj = temp.get(key)) == null) {
            return this.attr.get(key);
        }
        return obj;
    }

    public boolean isEmpty() {
        return this.attr.isEmpty();
    }

    @Override // java.util.Map
    public Set<String> keySet() {
        return this.attr.keySet();
    }

    public Object put(String key, Object value) {
        if (addBindingAttrIfStatement(key, value)) {
            return null;
        }
        return this.attr.put(key, value);
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.util.Map<? extends java.lang.String, ?>] */
    @Override // java.util.Map
    public void putAll(Map<? extends String, ? extends Object> map) {
        if (this.writeAttr == null) {
            this.writeAttr = new ArrayMap();
        }
        this.writeAttr.putAll(map);
    }

    @Override // java.util.Map
    public Object remove(Object key) {
        return this.attr.remove(key);
    }

    public int size() {
        return this.attr.size();
    }

    @Override // java.util.Map
    public Collection<Object> values() {
        return this.attr.values();
    }

    public ArrayMap<String, Object> getBindingAttrs() {
        return this.mBindingAttrs;
    }

    public WXStatement getStatement() {
        return this.mStatement;
    }

    public void setBindingAttrs(ArrayMap<String, Object> mBindingAttrs2) {
        this.mBindingAttrs = mBindingAttrs2;
    }

    public void setStatement(WXStatement mStatement2) {
        this.mStatement = mStatement2;
    }

    public void parseStatements() {
        Map<String, Object> map = this.attr;
        if (map != null) {
            this.attr = filterStatementsFromAttrs(map);
        }
    }

    private Map<String, Object> filterStatementsFromAttrs(Map attrs) {
        if (attrs == null || attrs.size() == 0) {
            return attrs;
        }
        Iterator<Map.Entry<String, Object>> it = attrs.entrySet().iterator();
        while (it.hasNext()) {
            Map.Entry<String, Object> entry = it.next();
            if (ELUtils.COMPONENT_PROPS.equals(entry.getKey())) {
                entry.setValue(ELUtils.bindingBlock(entry.getValue()));
            } else if (addBindingAttrIfStatement((String) entry.getKey(), entry.getValue())) {
                it.remove();
            }
        }
        return attrs;
    }

    private boolean addBindingAttrIfStatement(String key, Object value) {
        for (String exclude : ELUtils.EXCLUDES_BINDING) {
            if (key.equals(exclude)) {
                return false;
            }
        }
        if (ELUtils.isBinding(value)) {
            if (this.mBindingAttrs == null) {
                this.mBindingAttrs = new ArrayMap<>();
            }
            this.mBindingAttrs.put(key, ELUtils.bindingBlock(value));
            return true;
        } else if (WXStatement.WX_IF.equals(key)) {
            if (this.mStatement == null) {
                this.mStatement = new WXStatement();
            }
            if (value != null) {
                this.mStatement.put(key, Parser.parse(value.toString()));
            }
            return true;
        } else {
            if (WXStatement.WX_FOR.equals(key)) {
                if (this.mStatement == null) {
                    this.mStatement = new WXStatement();
                }
                Object value2 = ELUtils.vforBlock(value);
                if (value2 != null) {
                    this.mStatement.put(key, value2);
                    return true;
                }
            }
            if (WXStatement.WX_ONCE.equals(key)) {
                if (this.mStatement == null) {
                    this.mStatement = new WXStatement();
                }
                this.mStatement.put(key, true);
            }
            return false;
        }
    }

    public void skipFilterPutAll(Map<String, Object> attrs) {
        this.attr.putAll(attrs);
    }

    public void mergeAttr() {
        Map<String, Object> map = this.writeAttr;
        if (map != null) {
            this.attr.putAll(map);
            this.writeAttr = null;
        }
    }

    public String toString() {
        return this.attr.toString();
    }
}
