package io.dcloud.feature.uniapp.dom;

import android.text.Layout;
import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.binding.ELUtils;
import com.taobao.weex.ui.component.WXTextDecoration;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

public abstract class AbsStyle implements Map<String, Object>, Cloneable {
    public static final int UNSET = -1;
    private static final long serialVersionUID = 611132641365274134L;
    protected ArrayMap<String, Object> mBindingStyle;
    protected Map<String, Object> mPesudoResetStyleMap;
    protected Map<String, Map<String, Object>> mPesudoStyleMap;
    protected Map<String, Object> mStyles;

    @Override // java.lang.Object
    public abstract AbsStyle clone();

    public AbsStyle() {
        this.mStyles = new ArrayMap();
    }

    public AbsStyle(Map<String, Object> styles) {
        this.mStyles = styles;
        processPesudoClasses(styles);
    }

    public AbsStyle(Map<String, Object> mStyles2, boolean byPesudo) {
        this();
        putAll(mStyles2, byPesudo);
    }

    public String getBlur() {
        if (get(Constants.Name.FILTER) == null) {
            return null;
        }
        return get(Constants.Name.FILTER).toString().trim();
    }

    public static WXTextDecoration getTextDecoration(Map<String, Object> style) {
        Object obj;
        if (style == null || (obj = style.get(Constants.Name.TEXT_DECORATION)) == null) {
            return WXTextDecoration.NONE;
        }
        String textDecoration = obj.toString();
        char c = 65535;
        int hashCode = textDecoration.hashCode();
        if (hashCode != -1171789332) {
            if (hashCode != -1026963764) {
                if (hashCode == 3387192 && textDecoration.equals("none")) {
                    c = 2;
                }
            } else if (textDecoration.equals("underline")) {
                c = 0;
            }
        } else if (textDecoration.equals("line-through")) {
            c = 1;
        }
        if (c == 0) {
            return WXTextDecoration.UNDERLINE;
        }
        if (c == 1) {
            return WXTextDecoration.LINETHROUGH;
        }
        if (c != 2) {
            return WXTextDecoration.INVALID;
        }
        return WXTextDecoration.NONE;
    }

    public static String getTextColor(Map<String, Object> style) {
        Object temp;
        if (style == null || (temp = style.get("color")) == null) {
            return "";
        }
        return temp.toString();
    }

    public static int getFontWeight(Map<String, Object> style) {
        Object temp;
        if (style == null || (temp = style.get(Constants.Name.FONT_WEIGHT)) == null) {
            return 0;
        }
        String fontWeight = temp.toString();
        char c = 65535;
        switch (fontWeight.hashCode()) {
            case 53430:
                if (fontWeight.equals("600")) {
                    c = 0;
                    break;
                }
                break;
            case 54391:
                if (fontWeight.equals("700")) {
                    c = 1;
                    break;
                }
                break;
            case 55352:
                if (fontWeight.equals("800")) {
                    c = 2;
                    break;
                }
                break;
            case 56313:
                if (fontWeight.equals("900")) {
                    c = 3;
                    break;
                }
                break;
            case 3029637:
                if (fontWeight.equals(Constants.Value.BOLD)) {
                    c = 4;
                    break;
                }
                break;
        }
        if (c == 0 || c == 1 || c == 2 || c == 3 || c == 4) {
            return 1;
        }
        return 0;
    }

    public static int getFontStyle(Map<String, Object> style) {
        Object temp;
        if (style == null || (temp = style.get(Constants.Name.FONT_STYLE)) == null || !temp.toString().equals(Constants.Value.ITALIC)) {
            return 0;
        }
        return 2;
    }

    public static int getFontSize(Map<String, Object> style, int defaultSize, float viewPortW) {
        if (style == null) {
            return (int) WXViewUtils.getRealPxByWidth((float) defaultSize, viewPortW);
        }
        int fontSize = WXUtils.getInt(style.get(Constants.Name.FONT_SIZE));
        if (fontSize <= 0) {
            fontSize = defaultSize;
        }
        return (int) WXViewUtils.getRealPxByWidth((float) fontSize, viewPortW);
    }

    public static String getFontFamily(Map<String, Object> style) {
        Object temp;
        if (style == null || (temp = style.get(Constants.Name.FONT_FAMILY)) == null) {
            return null;
        }
        return temp.toString();
    }

    public static Layout.Alignment getTextAlignment(Map<String, Object> style) {
        return getTextAlignment(style, false);
    }

    public static Layout.Alignment getTextAlignment(Map<String, Object> style, boolean isRTL) {
        Layout.Alignment alignment = isRTL ? Layout.Alignment.ALIGN_OPPOSITE : Layout.Alignment.ALIGN_NORMAL;
        String textAlign = (String) style.get(Constants.Name.TEXT_ALIGN);
        if (TextUtils.equals("left", textAlign)) {
            return Layout.Alignment.ALIGN_NORMAL;
        }
        if (TextUtils.equals("center", textAlign)) {
            return Layout.Alignment.ALIGN_CENTER;
        }
        if (TextUtils.equals("right", textAlign)) {
            return Layout.Alignment.ALIGN_OPPOSITE;
        }
        return alignment;
    }

    public static TextUtils.TruncateAt getTextOverflow(Map<String, Object> style) {
        if (TextUtils.equals(Constants.Name.ELLIPSIS, (String) style.get(Constants.Name.TEXT_OVERFLOW))) {
            return TextUtils.TruncateAt.END;
        }
        return null;
    }

    public static int getLines(Map<String, Object> style) {
        return WXUtils.getInt(style.get(Constants.Name.LINES));
    }

    public static int getLineHeight(Map<String, Object> style, float viewPortW) {
        int lineHeight;
        if (style != null && (lineHeight = WXUtils.getInt(style.get(Constants.Name.LINE_HEIGHT))) > 0) {
            return (int) WXViewUtils.getRealPxByWidth((float) lineHeight, viewPortW);
        }
        return -1;
    }

    public float getBorderRadius() {
        float temp = WXUtils.getFloat(get(Constants.Name.BORDER_RADIUS));
        if (WXUtils.isUndefined(temp)) {
            return Float.NaN;
        }
        return temp;
    }

    public String getBorderColor() {
        Object color = get(Constants.Name.BORDER_COLOR);
        if (color == null) {
            return null;
        }
        return color.toString();
    }

    public String getBorderStyle() {
        Object borderStyle = get(Constants.Name.BORDER_STYLE);
        if (borderStyle == null) {
            return null;
        }
        return borderStyle.toString();
    }

    public boolean isSticky() {
        Object position = get("position");
        if (position == null) {
            return false;
        }
        return position.toString().equals("sticky");
    }

    public boolean isFixed() {
        Object position = get("position");
        if (position == null) {
            return false;
        }
        return position.toString().equals(Constants.Value.FIXED);
    }

    public float getLeft() {
        float temp = WXUtils.getFloat(get("left"));
        if (WXUtils.isUndefined(temp)) {
            return Float.NaN;
        }
        return temp;
    }

    public float getRight() {
        float temp = WXUtils.getFloat(get("right"));
        if (WXUtils.isUndefined(temp)) {
            return Float.NaN;
        }
        return temp;
    }

    public float getTop() {
        float temp = WXUtils.getFloat(get("top"));
        if (WXUtils.isUndefined(temp)) {
            return Float.NaN;
        }
        return temp;
    }

    public float getBottom() {
        float temp = WXUtils.getFloat(get("bottom"));
        if (WXUtils.isUndefined(temp)) {
            return Float.NaN;
        }
        return temp;
    }

    public String getBackgroundColor() {
        Object temp = get("backgroundColor");
        return temp == null ? "" : temp.toString();
    }

    public int getTimeFontSize(int defaultSize) {
        int fontSize = WXUtils.getInt(get("timeFontSize"));
        return fontSize <= 0 ? defaultSize : fontSize;
    }

    public float getOpacity() {
        Object object = get("opacity");
        if (object == null) {
            return 1.0f;
        }
        return WXUtils.getFloat(object);
    }

    public String getOverflow() {
        Object obj = get(Constants.Name.OVERFLOW);
        return obj == null ? "visible" : obj.toString();
    }

    public boolean equals(Object o) {
        return this.mStyles.equals(o);
    }

    public int hashCode() {
        return this.mStyles.hashCode();
    }

    public void clear() {
        this.mStyles.clear();
    }

    public boolean containsKey(Object key) {
        return this.mStyles.containsKey(key);
    }

    public boolean containsValue(Object value) {
        return this.mStyles.containsValue(value);
    }

    @Override // java.util.Map
    public Set<Map.Entry<String, Object>> entrySet() {
        return this.mStyles.entrySet();
    }

    @Override // java.util.Map
    public Object get(Object key) {
        return this.mStyles.get(key);
    }

    public boolean isEmpty() {
        return this.mStyles.isEmpty();
    }

    @Override // java.util.Map
    public Set<String> keySet() {
        return this.mStyles.keySet();
    }

    public Object put(String key, Object value) {
        if (addBindingStyleIfStatement(key, value)) {
            return null;
        }
        return this.mStyles.put(key, value);
    }

    /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.util.Map<? extends java.lang.String, ?>] */
    @Override // java.util.Map
    public void putAll(Map<? extends String, ? extends Object> map) {
        this.mStyles.putAll(map);
    }

    public void putAll(Map<? extends String, ?> map, boolean byPesudo) {
        this.mStyles.putAll(map);
        if (!byPesudo) {
            processPesudoClasses(map);
        }
    }

    public void updateStyle(Map<? extends String, ?> map, boolean byPesudo) {
        parseBindingStylesStatements(map);
        putAll(map, byPesudo);
    }

    public Map<String, Object> getPesudoResetStyles() {
        if (this.mPesudoResetStyleMap == null) {
            this.mPesudoResetStyleMap = new ArrayMap();
        }
        return this.mPesudoResetStyleMap;
    }

    public Map<String, Map<String, Object>> getPesudoStyles() {
        if (this.mPesudoStyleMap == null) {
            this.mPesudoStyleMap = new ArrayMap();
        }
        return this.mPesudoStyleMap;
    }

    /* access modifiers changed from: package-private */
    public <T extends String, V> void processPesudoClasses(Map<T, V> styles) {
        Map<String, Object> tempMap = null;
        for (Map.Entry<T, V> entry : styles.entrySet()) {
            String key = entry.getKey();
            int i = key.indexOf(com.xiaomi.mipush.sdk.Constants.COLON_SEPARATOR);
            if (i > 0) {
                initPesudoMapsIfNeed(styles);
                String clzName = key.substring(i);
                if (clzName.equals(Constants.PSEUDO.ENABLED)) {
                    String styleKey = key.substring(0, i);
                    if (tempMap == null) {
                        tempMap = new ArrayMap<>();
                    }
                    tempMap.put(styleKey, entry.getValue());
                    this.mPesudoResetStyleMap.put(styleKey, entry.getValue());
                } else {
                    String clzName2 = clzName.replace(Constants.PSEUDO.ENABLED, "");
                    Map<String, Object> stylesMap = this.mPesudoStyleMap.get(clzName2);
                    if (stylesMap == null) {
                        stylesMap = new ArrayMap();
                        this.mPesudoStyleMap.put(clzName2, stylesMap);
                    }
                    stylesMap.put(key.substring(0, i), entry.getValue());
                }
            }
        }
        if (!(tempMap == null || tempMap.isEmpty())) {
            this.mStyles.putAll(tempMap);
        }
    }

    @Override // java.util.Map
    public Object remove(Object key) {
        return this.mStyles.remove(key);
    }

    public int size() {
        return this.mStyles.size();
    }

    @Override // java.util.Map
    public Collection<Object> values() {
        return this.mStyles.values();
    }

    private void initPesudoMapsIfNeed(Map<? extends String, ?> styles) {
        if (this.mPesudoStyleMap == null) {
            this.mPesudoStyleMap = new ArrayMap();
        }
        if (this.mPesudoResetStyleMap == null) {
            this.mPesudoResetStyleMap = new ArrayMap();
        }
        if (this.mPesudoResetStyleMap.isEmpty()) {
            this.mPesudoResetStyleMap.putAll(styles);
        }
    }

    public void parseStatements() {
        Map<String, Object> map = this.mStyles;
        if (map != null) {
            this.mStyles = parseBindingStylesStatements(map);
        }
    }

    private Map<String, Object> parseBindingStylesStatements(Map styles) {
        if (styles == null || styles.size() == 0) {
            return styles;
        }
        Iterator<Map.Entry<String, Object>> it = styles.entrySet().iterator();
        while (it.hasNext()) {
            Map.Entry<String, Object> entry = it.next();
            if (addBindingStyleIfStatement(entry.getKey(), entry.getValue())) {
                Map<String, Map<String, Object>> map = this.mPesudoStyleMap;
                if (map != null) {
                    map.remove(entry.getKey());
                }
                Map<String, Object> map2 = this.mPesudoResetStyleMap;
                if (map2 != null) {
                    map2.remove(entry.getKey());
                }
                it.remove();
            }
        }
        return styles;
    }

    private boolean addBindingStyleIfStatement(String key, Object value) {
        if (!ELUtils.isBinding(value)) {
            return false;
        }
        if (this.mBindingStyle == null) {
            this.mBindingStyle = new ArrayMap<>();
        }
        this.mBindingStyle.put(key, ELUtils.bindingBlock(value));
        return true;
    }

    public ArrayMap<String, Object> getBindingStyle() {
        return this.mBindingStyle;
    }

    public String toString() {
        return this.mStyles.toString();
    }
}
