package io.dcloud.feature.uniapp.ui.component;

import android.content.Intent;
import android.util.Pair;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import androidx.core.view.ViewCompat;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseScroller;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.WXImageView;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import java.util.ArrayList;
import java.util.Iterator;

public abstract class AbsVContainer<T extends ViewGroup> extends WXComponent<T> {
    protected ArrayList<WXComponent> mChildren;

    public abstract View getBoxShadowHost(boolean z);

    public abstract void removeBoxShadowHost();

    @Deprecated
    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    @Deprecated
    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, boolean lazy, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mChildren = new ArrayList<>();
    }

    public AbsVContainer(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mChildren = new ArrayList<>();
    }

    public void interceptFocus() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            viewGroup.setFocusable(true);
            viewGroup.setFocusableInTouchMode(true);
            viewGroup.setDescendantFocusability(131072);
            viewGroup.requestFocus();
        }
    }

    public void ignoreFocus() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            viewGroup.setFocusable(false);
            viewGroup.setFocusableInTouchMode(false);
            viewGroup.clearFocus();
        }
    }

    /* access modifiers changed from: protected */
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    @Deprecated
    public ViewGroup getView() {
        return (ViewGroup) getHostView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void applyLayoutAndEvent(AbsBasicComponent component) {
        if (!isLazy()) {
            if (component == null) {
                component = this;
            }
            super.applyLayoutAndEvent(component);
            int count = childCount();
            for (int i = 0; i < count; i++) {
                getChild(i).applyLayoutAndEvent(((WXVContainer) component).getChild(i));
            }
        }
    }

    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View childView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.LayoutParams lp = null;
        if (childView != null) {
            lp = childView.getLayoutParams();
        }
        if (lp == null) {
            return new ViewGroup.LayoutParams(width, height);
        }
        lp.width = width;
        lp.height = height;
        if (!(lp instanceof ViewGroup.MarginLayoutParams)) {
            return lp;
        }
        setMarginsSupportRTL((ViewGroup.MarginLayoutParams) lp, left, top, right, bottom);
        return lp;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public Scrollable getFirstScroller() {
        if (this instanceof Scrollable) {
            return (Scrollable) this;
        }
        for (int i = 0; i < getChildCount(); i++) {
            Scrollable scrollable = getChild(i).getFirstScroller();
            if (scrollable != null) {
                return scrollable;
            }
        }
        return null;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void bindComponentData(AbsBasicComponent component) {
        if (!isLazy()) {
            if (component == null) {
                component = this;
            }
            super.bindComponentData(component);
            int count = childCount();
            for (int i = 0; i < count; i++) {
                getChild(i).bindData(((WXVContainer) component).getChild(i));
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void refreshData(WXComponent component) {
        if (component == null) {
            component = this;
        }
        super.refreshData(component);
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).refreshData(((WXVContainer) component).getChild(i));
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        return (ViewGroup) super.getRealView();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void createViewImpl() {
        super.createViewImpl();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            createChildViewAt(i);
        }
        if (getHostView() != null) {
            ((ViewGroup) getHostView()).setClipToPadding(false);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList != null) {
            int count = arrayList.size();
            for (int i = 0; i < count; i++) {
                this.mChildren.get(i).destroy();
            }
            this.mChildren.clear();
        }
        super.destroy();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void recycled() {
        if (this.mChildren != null && !isFixed() && getAttrs().canRecycled()) {
            int count = this.mChildren.size();
            for (int i = 0; i < count; i++) {
                this.mChildren.get(i).recycled();
            }
        }
        super.recycled();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public View detachViewAndClearPreInfo() {
        View original = super.detachViewAndClearPreInfo();
        if (this.mChildren != null) {
            int count = childCount();
            for (int i = 0; i < count; i++) {
                this.mChildren.get(i).detachViewAndClearPreInfo();
            }
        }
        return original;
    }

    public int childCount() {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList == null) {
            return 0;
        }
        return arrayList.size();
    }

    public WXComponent getChild(int index) {
        ArrayList<WXComponent> arrayList = this.mChildren;
        if (arrayList == null || index < 0 || index >= arrayList.size()) {
            return null;
        }
        return this.mChildren.get(index);
    }

    public int getChildCount() {
        return childCount();
    }

    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    public void addChild(WXComponent child, int index) {
        if (child != null && index >= -1) {
            child.mDeepInComponentTree = this.mDeepInComponentTree + 1;
            getInstance().setMaxDomDeep(child.mDeepInComponentTree);
            int index2 = index >= this.mChildren.size() ? -1 : index;
            if (index2 == -1) {
                this.mChildren.add(child);
            } else {
                this.mChildren.add(index2, child);
            }
        }
    }

    public final int indexOf(WXComponent comp) {
        return this.mChildren.indexOf(comp);
    }

    public void createChildViewAt(int index) {
        Pair<WXComponent, Integer> ret = rearrangeIndexAndGetChild(index);
        if (ret.first != null) {
            WXComponent child = (WXComponent) ret.first;
            child.createView();
            if (!child.isVirtualComponent()) {
                addSubView(child.getHostView(), ((Integer) ret.second).intValue());
            }
        }
    }

    /* access modifiers changed from: protected */
    public Pair<WXComponent, Integer> rearrangeIndexAndGetChild(int index) {
        int indexToCreate = index;
        if (indexToCreate < 0) {
            indexToCreate = childCount() - 1;
        }
        if (indexToCreate < 0) {
            return new Pair<>(null, Integer.valueOf(indexToCreate));
        }
        return new Pair<>(getChild(indexToCreate), Integer.valueOf(indexToCreate));
    }

    public void addSubView(View child, int index) {
        if (child != null && getRealView() != null) {
            if (child.getParent() != null) {
                ((ViewGroup) child.getParent()).removeView(child);
            }
            int index2 = index >= getRealView().getChildCount() ? -1 : index;
            if (index2 == -1) {
                getRealView().addView(child);
            } else {
                getRealView().addView(child, index2);
            }
            WXSDKInstance instance = getInstance();
            if (instance != null) {
                instance.getApmForInstance().hasAddView = true;
            }
        }
    }

    public void remove(WXComponent child, boolean destroy) {
        ArrayList<WXComponent> arrayList;
        if (child != null && (arrayList = this.mChildren) != null && arrayList.size() != 0) {
            this.mChildren.remove(child);
            if (getInstance() != null && getInstance().getRootView() != null && child.isFixed()) {
                getInstance().removeFixedView(child.getHostView());
            } else if (getRealView() != null) {
                if (!child.isVirtualComponent()) {
                    ViewParent parent = null;
                    if ((child.getParent() instanceof WXBaseScroller) && child.getHostView() != null) {
                        parent = child.getHostView().getParent();
                    }
                    if (parent == null || !(parent instanceof ViewGroup)) {
                        getRealView().removeView(child.getHostView());
                    } else {
                        ((ViewGroup) parent).removeView(child.getHostView());
                    }
                } else {
                    child.removeVirtualComponent();
                }
            }
            if (destroy) {
                child.destroy();
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void notifyAppearStateChange(String wxEventType, String direction) {
        ArrayList<WXComponent> arrayList;
        super.notifyAppearStateChange(wxEventType, direction);
        if (getHostView() != null && (arrayList = this.mChildren) != null) {
            Iterator<WXComponent> it = arrayList.iterator();
            while (it.hasNext()) {
                WXComponent component = it.next();
                if (!(component.getHostView() == null || component.getHostView().getVisibility() == 0)) {
                    wxEventType = Constants.Event.DISAPPEAR;
                }
                component.notifyAppearStateChange(wxEventType, direction);
            }
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityCreate() {
        super.onActivityCreate();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityCreate();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityStart() {
        super.onActivityStart();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityStart();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        super.onActivityPause();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityPause();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        super.onActivityResume();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityResume();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityStop() {
        super.onActivityStop();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityStop();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityDestroy() {
        super.onActivityDestroy();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityDestroy();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public boolean onActivityBack() {
        super.onActivityBack();
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityBack();
        }
        return false;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onActivityResult(requestCode, resultCode, data);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean onCreateOptionsMenu(Menu menu) {
        super.onCreateOptionsMenu(menu);
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onCreateOptionsMenu(menu);
        }
        return false;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        int count = childCount();
        for (int i = 0; i < count; i++) {
            getChild(i).onRequestPermissionsResult(requestCode, permissions, grantResults);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onRenderFinish(int state) {
        for (int i = 0; i < getChildCount(); i++) {
            WXComponent child = getChild(i);
            if (child != null) {
                child.mTraceInfo.uiQueueTime = this.mTraceInfo.uiQueueTime;
                child.onRenderFinish(state);
            }
        }
        super.onRenderFinish(state);
    }

    @UniJSMethod
    public void releaseImageList(String viewTreeRecycle) {
        if (getHostView() != null && ViewCompat.isAttachedToWindow(getHostView()) && (getHostView() instanceof ViewGroup)) {
            if (WXUtils.getBoolean(viewTreeRecycle, false).booleanValue()) {
                doViewTreeRecycleImageView((ViewGroup) getHostView(), true);
                return;
            }
            int count = getChildCount();
            for (int i = 0; i < count; i++) {
                WXComponent component = getChild(i);
                if ((component instanceof WXImage) && (((WXImage) component).getHostView() instanceof WXImageView)) {
                    WXImageView imageView = (WXImageView) component.getHostView();
                    if (imageView != null && ViewCompat.isAttachedToWindow(imageView)) {
                        imageView.autoReleaseImage();
                    }
                } else if (component instanceof WXVContainer) {
                    ((WXVContainer) component).releaseImageList(viewTreeRecycle);
                }
            }
        }
    }

    @UniJSMethod
    public void recoverImageList(String viewTreeRecycle) {
        if (getHostView() != null && ViewCompat.isAttachedToWindow(getHostView()) && (getHostView() instanceof ViewGroup)) {
            if (WXUtils.getBoolean(viewTreeRecycle, false).booleanValue()) {
                doViewTreeRecycleImageView((ViewGroup) getHostView(), false);
                return;
            }
            int count = getChildCount();
            for (int i = 0; i < count; i++) {
                WXComponent component = getChild(i);
                if ((component instanceof WXImage) && (((WXImage) component).getHostView() instanceof WXImageView)) {
                    WXImageView imageView = (WXImageView) component.getHostView();
                    if (imageView != null && ViewCompat.isAttachedToWindow(imageView)) {
                        imageView.autoRecoverImage();
                    }
                } else if (component instanceof WXVContainer) {
                    ((WXVContainer) component).recoverImageList(viewTreeRecycle);
                }
            }
        }
    }

    private void doViewTreeRecycleImageView(ViewGroup viewGroup, boolean isRelease) {
        int count = viewGroup.getChildCount();
        for (int i = 0; i < count; i++) {
            View view = viewGroup.getChildAt(i);
            if (view instanceof WXImageView) {
                if (isRelease) {
                    ((WXImageView) view).autoReleaseImage();
                } else {
                    ((WXImageView) view).autoRecoverImage();
                }
            } else if (view instanceof ViewGroup) {
                doViewTreeRecycleImageView((ViewGroup) view, isRelease);
            }
        }
    }

    public void requestDisallowInterceptTouchEvent(boolean requestDisallowInterceptTouchEvent) {
        if (this.mGesture != null) {
            if (!this.mGesture.isRequestDisallowInterceptTouchEvent()) {
                this.mGesture.setRequestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent);
            } else {
                return;
            }
        }
        if (getParent() != null) {
            getParent().requestDisallowInterceptTouchEvent(requestDisallowInterceptTouchEvent);
        }
    }

    public void appendTreeCreateFinish() {
    }
}
