package io.dcloud.feature.uniapp.ui.shadow;

import android.graphics.PointF;
import android.graphics.Rect;
import android.text.TextUtils;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.List;

public class UniBoxShadowOptions {
    private static final String TAG = "UniBoxShadowOptions";
    public float blur = 0.0f;
    public int color = -16777216;
    public float hShadow;
    public boolean isInset = false;
    public List<IParser> optionParamParsers;
    public float[] radii = {0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
    public float spread = 0.0f;
    public PointF topLeft = null;
    public float vShadow;
    public int viewHeight = 0;
    public int viewWidth = 0;
    private float viewport = 750.0f;

    public interface IParser {
        void parse(String str);
    }

    public UniBoxShadowOptions(float vp) {
        if (750.0f != 0.0f) {
            this.viewport = vp;
        }
        this.optionParamParsers = new ArrayList();
        IParser spreadParser = new IParser() {
            /* class io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions.AnonymousClass1 */

            @Override // io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions.IParser
            public void parse(String param) {
                if (!TextUtils.isEmpty(param)) {
                    float px = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                    UniBoxShadowOptions uniBoxShadowOptions = UniBoxShadowOptions.this;
                    uniBoxShadowOptions.spread = WXViewUtils.getRealSubPxByWidth(px, uniBoxShadowOptions.viewport);
                    WXLogUtils.w(UniBoxShadowOptions.TAG, "Experimental box-shadow attribute: spread");
                }
            }
        };
        this.optionParamParsers.add(new IParser() {
            /* class io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions.AnonymousClass2 */

            @Override // io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions.IParser
            public void parse(String param) {
                if (!TextUtils.isEmpty(param)) {
                    float px = WXUtils.getFloat(param, Float.valueOf(0.0f)).floatValue();
                    UniBoxShadowOptions uniBoxShadowOptions = UniBoxShadowOptions.this;
                    uniBoxShadowOptions.blur = WXViewUtils.getRealSubPxByWidth(px, uniBoxShadowOptions.viewport);
                }
            }
        });
        this.optionParamParsers.add(spreadParser);
    }

    public UniBoxShadowOptions scale(float scale) {
        if (scale <= 0.0f || scale > 1.0f) {
            return null;
        }
        UniBoxShadowOptions scaledOptions = new UniBoxShadowOptions(this.viewport);
        scaledOptions.hShadow = this.hShadow * scale;
        scaledOptions.vShadow = this.vShadow * scale;
        scaledOptions.blur = this.blur * scale;
        scaledOptions.spread = this.spread * scale;
        int i = 0;
        while (true) {
            float[] fArr = this.radii;
            if (i >= fArr.length) {
                break;
            }
            scaledOptions.radii[i] = fArr[i] * scale;
            i++;
        }
        scaledOptions.viewHeight = (int) (((float) this.viewHeight) * scale);
        scaledOptions.viewWidth = (int) (((float) this.viewWidth) * scale);
        if (this.topLeft != null) {
            PointF pointF = new PointF();
            scaledOptions.topLeft = pointF;
            pointF.x = this.topLeft.x * scale;
            scaledOptions.topLeft.y = this.topLeft.y * scale;
        }
        scaledOptions.color = this.color;
        scaledOptions.isInset = this.isInset;
        WXLogUtils.d(TAG, "Scaled BoxShadowOptions: [" + scale + "] " + scaledOptions);
        return scaledOptions;
    }

    public Rect getTargetCanvasRect() {
        return new Rect(0, 0, this.viewWidth + (((int) (this.blur + this.spread + Math.abs(this.hShadow))) * 2), this.viewHeight + (((int) (this.blur + this.spread + Math.abs(this.vShadow))) * 2));
    }

    public String toString() {
        StringBuffer sb = new StringBuffer("BoxShadowOptions{");
        sb.append("h-shadow=");
        sb.append(this.hShadow);
        sb.append(", v-shadow=");
        sb.append(this.vShadow);
        sb.append(", blur=");
        sb.append(this.blur);
        sb.append(", spread=");
        sb.append(this.spread);
        sb.append(", corner-radius=");
        sb.append(Operators.ARRAY_START_STR + this.radii[0] + "," + this.radii[2] + "," + this.radii[4] + "," + this.radii[6] + Operators.ARRAY_END_STR);
        sb.append(", color=#");
        sb.append(Integer.toHexString(this.color));
        sb.append(", inset=");
        sb.append(this.isInset);
        sb.append(Operators.BLOCK_END);
        return sb.toString();
    }
}
