package io.dcloud.feature.unipush;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import com.igexin.sdk.GTIntentService;
import com.igexin.sdk.message.GTCmdMessage;
import com.igexin.sdk.message.GTNotificationMessage;
import com.igexin.sdk.message.GTTransmitMessage;
import com.taobao.weex.common.Constants;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.aps.APSFeatureImpl;
import io.dcloud.feature.aps.AbsPushService;
import io.dcloud.feature.aps.PushMessage;
import org.json.JSONObject;

public class GTNormalIntentService extends GTIntentService {
    public static final String TAG = GTNormalIntentService.class.getSimpleName();

    @Override // com.igexin.sdk.GTIntentService
    public void onNotificationMessageClicked(Context context, GTNotificationMessage gtNotificationMessage) {
        String appid = BaseInfo.sDefaultBootApp;
        JSONObject params = new JSONObject();
        try {
            params.put("title", gtNotificationMessage.getTitle());
            params.put("content", gtNotificationMessage.getContent());
            PushMessage _pushMessage = new PushMessage(params.toString(), appid, getApplicationName(context));
            if (!APSFeatureImpl.execScript(context, Constants.Event.CLICK, _pushMessage.toJSON())) {
                APSFeatureImpl.addNeedExecMessage(context, _pushMessage);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onNotificationMessageArrived(Context context, GTNotificationMessage gtNotificationMessage) {
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onReceiveServicePid(Context context, int pid) {
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onReceiveMessageData(Context context, GTTransmitMessage msg) {
        String str = TAG;
        Logger.e(str, "onReceiveMessageData -> msg = " + msg);
        byte[] dataBase = msg.getPayload();
        if (dataBase != null) {
            String data = new String(dataBase);
            if (!PdrUtil.isEmpty(data)) {
                String str2 = TAG;
                Logger.e(str2, "onReceiveMessageData -> msg data= " + data);
                boolean isUniPush2 = false;
                String unipushVersionStr = JSONUtil.getString(JSONUtil.createJSONObject(data), "unipush_version");
                if (!PdrUtil.isEmpty(unipushVersionStr) && Double.parseDouble(unipushVersionStr) == 2.0d) {
                    isUniPush2 = true;
                }
                if (isUniPush2) {
                    processForUniPush2(context, data);
                } else {
                    processForUniPush(context, data);
                }
            }
        }
    }

    public String getApplicationName(Context context) {
        ApplicationInfo applicationInfo;
        PackageManager packageManager = null;
        try {
            packageManager = context.getApplicationContext().getPackageManager();
            applicationInfo = packageManager.getApplicationInfo(context.getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            applicationInfo = null;
        }
        return (String) packageManager.getApplicationLabel(applicationInfo);
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onReceiveClientId(Context context, String clientid) {
        String str = TAG;
        Logger.e(str, "onReceiveClientId -> clientid = " + clientid);
        SharedPreferences.Editor ed = context.getSharedPreferences("clientid_unipush", 0).edit();
        ed.putString(AbsPushService.PUSH_CLIENT_ID_NAME, clientid);
        ed.commit();
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onReceiveOnlineState(Context context, boolean online) {
        String str = TAG;
        Logger.e(str, "onReceiveOnlineState -> online = " + online);
    }

    @Override // com.igexin.sdk.GTIntentService
    public void onReceiveCommandResult(Context context, GTCmdMessage cmdMessage) {
        String str = TAG;
        Logger.e(str, "onReceiveCommandResult -> cmdMessage = " + cmdMessage);
    }

    private void processForUniPush(Context context, String data) {
        String appId = BaseInfo.sDefaultBootApp;
        PushMessage pushMessage = new PushMessage(data, appId, getApplicationName(context));
        if (AbsPushService.getAutoNotification(context, appId, GTPushService.ID) && pushMessage.needCreateNotification()) {
            APSFeatureImpl.sendCreateNotificationBroadcast(context, appId, pushMessage);
        } else if (!APSFeatureImpl.execScript(context, "receive", pushMessage.toJSON())) {
            APSFeatureImpl.addNeedExecReceiveMessage(context, pushMessage);
        }
        APSFeatureImpl.addPushMessage(context, appId, pushMessage);
    }

    private void processForUniPush2(Context context, String data) {
        String appId = BaseInfo.sDefaultBootApp;
        JSONObject jsonObject = JSONUtil.createJSONObject(data);
        boolean forceNotification = JSONUtil.getBoolean(jsonObject, "force_notification");
        PushMessage pushMessage = new PushMessage(jsonObject, appId);
        if (forceNotification) {
            APSFeatureImpl.sendCreateNotificationBroadcast(context, appId, pushMessage);
        } else if (!APSFeatureImpl.execScript(context, "receive", pushMessage.toJSON())) {
            APSFeatureImpl.addNeedExecReceiveMessage(context, pushMessage);
        }
        APSFeatureImpl.addPushMessage(context, appId, pushMessage);
    }
}
