package io.dcloud.feature.unipush;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import com.igexin.assist.sdk.AssistPushConsts;
import com.igexin.push.core.b;
import com.igexin.sdk.PushManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.DHInterface.message.AbsActionObserver;
import io.dcloud.common.DHInterface.message.ActionBus;
import io.dcloud.common.DHInterface.message.EnumUniqueID;
import io.dcloud.common.DHInterface.message.IObserveAble;
import io.dcloud.common.DHInterface.message.action.BadgeSyncAction;
import io.dcloud.common.DHInterface.message.action.IAction;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.aps.APSFeatureImpl;
import io.dcloud.feature.aps.AbsPushService;
import io.dcloud.feature.aps.PushMessage;
import java.util.Iterator;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class GTPushService extends AbsPushService implements ISysEventListener, IObserveAble {
    public static final String ID = "unipush";
    boolean isRegisterNewIntent = false;
    IApp mApp;

    @Override // io.dcloud.feature.aps.AbsPushService
    public void onStart(final Context pContext, Bundle pSaveBundle, String[] pArgs) {
        this.id = ID;
        PushManager.getInstance().initialize(pContext.getApplicationContext());
        this.clientid = pContext.getSharedPreferences("clientid_unipush", 0).getString(AbsPushService.PUSH_CLIENT_ID_NAME, this.clientid);
        this.appid = AndroidResources.getMetaValue(b.b);
        this.appkey = AndroidResources.getMetaValue("PUSH_APPKEY");
        this.appsecret = AndroidResources.getMetaValue("PUSH_APPSECRET");
        ActionBus.getInstance().observeAction(new AbsActionObserver(this) {
            /* class io.dcloud.feature.unipush.GTPushService.AnonymousClass1 */

            @Override // io.dcloud.common.DHInterface.message.AbsActionObserver
            public boolean handleMessage(IAction iAction) {
                if (!(iAction instanceof BadgeSyncAction)) {
                    return false;
                }
                BadgeSyncAction badgeSyncAction = (BadgeSyncAction) iAction;
                if (badgeSyncAction.getActionType() != BadgeSyncAction.ENUM_ACTION_TYPE.SYNC_NUM) {
                    return true;
                }
                PushManager.getInstance().setHwBadgeNum(pContext.getApplicationContext(), badgeSyncAction.getSyncNumVal());
                return true;
            }
        });
    }

    @Override // io.dcloud.feature.aps.AbsPushService
    public String getClientInfo(Context context) {
        if (PdrUtil.isEmpty(this.clientid)) {
            initClientId(context);
        }
        return super.getClientInfo(context);
    }

    @Override // io.dcloud.feature.aps.AbsPushService
    public void onStop() {
        super.onStop();
        if (this.isRegisterNewIntent) {
            this.isRegisterNewIntent = false;
            this.mApp.unregisterSysEventListener(this, ISysEventListener.SysEventType.onNewIntent);
            this.mApp = null;
        }
        ActionBus.getInstance().stopObserve(getActionObserverID());
    }

    @Override // io.dcloud.feature.aps.AbsPushService
    public void addEventListener(Context context, IWebview pWebViewImpl, JSONArray pJsArgs) throws JSONException {
        super.addEventListener(context, pWebViewImpl, pJsArgs);
        Intent intent = pWebViewImpl.getActivity().getIntent();
        registerOnNewIntent(pWebViewImpl.obtainApp());
        fireClickEvent(intent);
    }

    private void registerOnNewIntent(IApp app) {
        if (!this.isRegisterNewIntent) {
            this.mApp = app;
            this.isRegisterNewIntent = true;
            app.registerSysEventListener(this, ISysEventListener.SysEventType.onNewIntent);
        }
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        IApp iApp;
        if (!pEventType.equals(ISysEventListener.SysEventType.onNewIntent) || (iApp = this.mApp) == null) {
            return false;
        }
        fireClickEvent(iApp.getActivity().getIntent());
        return false;
    }

    private void fireClickEvent(Intent intent) {
        Exception e;
        if (intent.hasExtra("UP-OL-SU") && this.mApp != null) {
            boolean isUniPush2 = false;
            String unipushVersionStr = intent.getStringExtra("unipush_version");
            if (!PdrUtil.isEmpty(unipushVersionStr) && Double.parseDouble(unipushVersionStr) == 2.0d) {
                isUniPush2 = true;
            }
            JSONObject params = new JSONObject();
            if (isUniPush2) {
                try {
                    params.put("title", intent.getStringExtra("title"));
                    params.put("content", intent.getStringExtra("content"));
                    params.put("unipush_version", intent.getStringExtra("unipush_version"));
                    String payload = intent.getStringExtra(AssistPushConsts.MSG_TYPE_PAYLOAD);
                    JSONObject payloadJsonObject = JSONUtil.createJSONObject(payload);
                    if (payloadJsonObject != null) {
                        try {
                            params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, payloadJsonObject);
                        } catch (Exception e2) {
                            e = e2;
                            e.printStackTrace();
                        }
                    } else if (payload != null) {
                        try {
                            if (payload.startsWith("\"")) {
                                try {
                                    params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, StringUtil.trimString(payload, (char) Operators.QUOTE));
                                } catch (Exception e3) {
                                    e = e3;
                                    e.printStackTrace();
                                }
                            } else {
                                Integer payloadInt = StringUtil.getInt(payload);
                                Double payloadDouble = StringUtil.getDouble(payload);
                                if (payloadInt != null) {
                                    params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, payloadInt);
                                } else if (payloadDouble != null) {
                                    params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, payloadDouble);
                                } else {
                                    try {
                                        if (!payload.equals(AbsoluteConst.TRUE)) {
                                            if (!payload.equals(AbsoluteConst.FALSE)) {
                                                params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, payload);
                                            }
                                        }
                                        params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, Boolean.parseBoolean(payload));
                                    } catch (Exception e4) {
                                        e = e4;
                                        e.printStackTrace();
                                    }
                                }
                            }
                        } catch (Exception e5) {
                            e = e5;
                            e.printStackTrace();
                        }
                    }
                    String key = intent.getStringExtra("unipush_data");
                    JSONObject unipushDataJsonObject = JSONUtil.createJSONObject(key);
                    if (unipushDataJsonObject != null) {
                        Iterator<String> keys = unipushDataJsonObject.keys();
                        while (keys.hasNext()) {
                            String key2 = keys.next();
                            try {
                                params.put(key2, unipushDataJsonObject.get(key2));
                                key = key;
                                unipushVersionStr = unipushVersionStr;
                            } catch (Exception e6) {
                                e = e6;
                                e.printStackTrace();
                            }
                        }
                    }
                    intent.removeExtra("UP-OL-SU");
                    intent.removeExtra("title");
                    intent.removeExtra("content");
                    intent.removeExtra(AssistPushConsts.MSG_TYPE_PAYLOAD);
                    intent.removeExtra("unipush_version");
                    intent.removeExtra("unipush_data");
                    PushMessage _pushMessage = new PushMessage(params, this.mApp.obtainAppId());
                    if (!APSFeatureImpl.execScript(this.mApp.getActivity(), Constants.Event.CLICK, _pushMessage.toJSON())) {
                        APSFeatureImpl.addNeedExecMessage(this.mApp.getActivity(), _pushMessage);
                    }
                } catch (Exception e7) {
                    e = e7;
                    e.printStackTrace();
                }
            } else {
                try {
                    params.put("title", intent.getStringExtra("title"));
                    params.put("content", intent.getStringExtra("content"));
                    params.put(AssistPushConsts.MSG_TYPE_PAYLOAD, intent.getStringExtra(AssistPushConsts.MSG_TYPE_PAYLOAD));
                    intent.removeExtra("UP-OL-SU");
                    intent.removeExtra("title");
                    intent.removeExtra("content");
                    intent.removeExtra(AssistPushConsts.MSG_TYPE_PAYLOAD);
                    PushMessage _pushMessage2 = new PushMessage(params.toString(), this.mApp.obtainAppId(), "");
                    if (!APSFeatureImpl.execScript(this.mApp.getActivity(), Constants.Event.CLICK, _pushMessage2.toJSON())) {
                        APSFeatureImpl.addNeedExecMessage(this.mApp.getActivity(), _pushMessage2);
                    }
                } catch (JSONException e8) {
                    e8.printStackTrace();
                }
            }
        }
    }

    @Override // io.dcloud.common.DHInterface.message.IObserveAble
    public EnumUniqueID getActionObserverID() {
        return EnumUniqueID.FEATURE_APS_UNI_PUSH;
    }
}
