package io.dcloud.feature.weex;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.KeyEvent;
import android.view.ViewGroup;
import com.taobao.weex.WXSDKInstance;
import io.dcloud.common.DHInterface.IKeyHandler;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IUniNView;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.util.ViewOptions;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex.adapter.widget.refresh.DCWeexBaseRefreshLayout;
import io.dcloud.feature.weex.adapter.widget.refresh.WeexDcRefreshLayout;
import java.util.Map;
import org.json.JSONObject;

public class WXBaseWrapper extends WeexDcRefreshLayout implements IUniNView {
    protected static int DE_INDEX = -1;
    protected String mPath = null;
    protected String mSrcPath = null;
    protected WXAnalyzerDelegate mWXAnaly;
    protected WXSDKInstance mWXSDKInstance;
    protected IWebview mWebview;
    protected String mWxId;

    public WXBaseWrapper(Context context) {
        super(context);
        setEnabled(false);
    }

    public void onReady() {
    }

    /* access modifiers changed from: protected */
    public void onRefresh() {
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void initRefresh(JSONObject options) {
        if (options != null) {
            boolean support = Boolean.parseBoolean(JSONUtil.getString(options, AbsoluteConst.PULL_REFRESH_SUPPORT));
            String style = "default";
            if (options != null) {
                style = options.optString("style", style);
            }
            if (!support || !style.equals("circle")) {
                setOnRefreshListener(null);
                setEnabled(false);
                return;
            }
            setEnabled(true);
            setOnRefreshListener(new DCWeexBaseRefreshLayout.OnRefreshListener() {
                /* class io.dcloud.feature.weex.WXBaseWrapper.AnonymousClass1 */

                @Override // io.dcloud.feature.weex.adapter.widget.refresh.DCWeexBaseRefreshLayout.OnRefreshListener
                public void onRefresh() {
                    WXBaseWrapper.this.onRefresh();
                }
            });
            parseData(options);
        }
    }

    private void parseData(JSONObject options) {
        int offset;
        int height;
        int color;
        IWebview iWebview = this.mWebview;
        if (iWebview != null) {
            ViewOptions viewOptions = ((AdaFrameView) iWebview.obtainFrameView()).obtainFrameOptions();
            String offsetStr = options.optString("offset");
            if (!TextUtils.isEmpty(offsetStr)) {
                offset = PdrUtil.convertToScreenInt(offsetStr, viewOptions.height, 0, this.mWebview.getScale());
            } else {
                offset = 0;
            }
            String heightStr = options.optString("height");
            int height2 = (int) this.mTotalDragDistance;
            if (!TextUtils.isEmpty(heightStr)) {
                height = PdrUtil.convertToScreenInt(heightStr, viewOptions.height, height2, this.mWebview.getScale());
            } else {
                height = height2;
            }
            String rangeStr = options.optString(AbsoluteConst.PULL_REFRESH_RANGE);
            int range = (int) this.mSpinnerFinalOffset;
            if (!TextUtils.isEmpty(rangeStr)) {
                range = PdrUtil.convertToScreenInt(rangeStr, viewOptions.height, range, this.mWebview.getScale());
            }
            int range2 = range + this.mOriginalOffsetTop;
            String colorStr = options.optString("color");
            int color2 = Color.parseColor("#2BD009");
            if (!TextUtils.isEmpty(colorStr) && colorStr.startsWith("#")) {
                try {
                    color = Color.parseColor(colorStr);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                setColorSchemeColors(color);
                setProgressViewOffset(false, this.mOriginalOffsetTop, range2, height, offset);
            }
            color = color2;
            setColorSchemeColors(color);
            setProgressViewOffset(false, this.mOriginalOffsetTop, range2, height, offset);
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void beginPullRefresh() {
        beginRefresh();
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void endPullToRefresh() {
        setRefreshing(false);
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void titleNViewRefresh() {
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void reload() {
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public String getType() {
        return null;
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void onDestroy() {
        destroy();
    }

    public void destroy() {
        setEnabled(false);
        recoveryInstance();
    }

    public void recoveryInstance() {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance != null) {
            wXSDKInstance.registerRenderListener(null);
            this.mWXSDKInstance.onActivityDestroy();
            WXAnalyzerDelegate wXAnalyzerDelegate = this.mWXAnaly;
            if (wXAnalyzerDelegate != null) {
                wXAnalyzerDelegate.onDestroy();
                this.mWXAnaly = null;
            }
            this.mWXSDKInstance = null;
            clearTarget();
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public ViewGroup obtainMainView() {
        return this;
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public void loadTemplate(JSONObject info) {
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public boolean fireGlobalEvent(String key, Map<String, Object> params) {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance == null) {
            return false;
        }
        wXSDKInstance.fireGlobalEventCallback(key, params);
        return true;
    }

    @Override // io.dcloud.common.DHInterface.IUniNView
    public String evalJs(String js, int type) {
        return null;
    }

    public void onActivityResume() {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance != null) {
            wXSDKInstance.onActivityResume();
            WXAnalyzerDelegate wXAnalyzerDelegate = this.mWXAnaly;
            if (wXAnalyzerDelegate != null) {
                wXAnalyzerDelegate.onResume();
            }
        }
    }

    public void onActivityPause() {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance != null) {
            wXSDKInstance.onActivityPause();
            WXAnalyzerDelegate wXAnalyzerDelegate = this.mWXAnaly;
            if (wXAnalyzerDelegate != null) {
                wXAnalyzerDelegate.onPause();
            }
        }
    }

    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance != null) {
            wXSDKInstance.onActivityResult(requestCode, resultCode, data);
        }
    }

    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        WXSDKInstance wXSDKInstance = this.mWXSDKInstance;
        if (wXSDKInstance != null) {
            wXSDKInstance.onRequestPermissionsResult(requestCode, permissions, grantResults);
        }
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
        IWebview iWebview;
        boolean ret = super.onKeyDown(keyCode, event);
        if (ret && (iWebview = this.mWebview) != null && (iWebview.getActivity() instanceof IKeyHandler)) {
            ((IKeyHandler) this.mWebview.getActivity()).onKeyEventExecute(ISysEventListener.SysEventType.onKeyDown, keyCode, event);
        }
        return ret;
    }

    public boolean onKeyUp(int keyCode, KeyEvent event) {
        IWebview iWebview;
        boolean ret = super.onKeyUp(keyCode, event);
        if (ret && (iWebview = this.mWebview) != null && (iWebview.getActivity() instanceof IKeyHandler)) {
            ((IKeyHandler) this.mWebview.getActivity()).onKeyEventExecute(ISysEventListener.SysEventType.onKeyUp, keyCode, event);
        }
        return ret;
    }
}
