package io.dcloud.feature.weex;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.taobao.weex.IWXRenderListener;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.WXModuleManager;
import com.taobao.weex.common.WXRenderStrategy;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.feature.uniapp.UniSDKInstance;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONObject;

public class WXServiceWrapper extends WXBaseWrapper implements IWXRenderListener {
    IApp mApp;
    JSONObject mData;
    ViewGroup mRootView;
    ISysEventListener mSysEventListener;
    String mTemplate;
    long time = 0;

    public WXServiceWrapper(IApp app, ViewGroup rootView, String weexId, JSONObject data) {
        super(rootView.getContext());
        this.mApp = app;
        this.mRootView = rootView;
        this.mWxId = weexId;
        this.mData = data;
        this.mSrcPath = data.optString("path");
        String optString = this.mData.optString("template");
        this.mTemplate = optString;
        render(optString, getOptions(), null);
    }

    public IApp obtanApp() {
        return this.mApp;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String evalJs(String js, int type) {
        return null;
    }

    /* access modifiers changed from: package-private */
    public void render(String template, Map<String, Object> options, String jsonInitData) {
        if (this.mWXSDKInstance == null) {
            this.mWXSDKInstance = new UniSDKInstance(this.mRootView.getContext());
            this.mWXSDKInstance.registerRenderListener(this);
            this.mWXSDKInstance.setBundleUrl(this.mSrcPath);
        }
        this.mWXSDKInstance.render(this.mWxId, template, options, jsonInitData, WXRenderStrategy.APPEND_ASYNC);
        com.alibaba.fastjson.JSONObject modules = WXModuleManager.getRegisterJsModules();
        if (modules != null) {
            WeexInstanceMgr.self().setUniNViewModules(modules.toJSONString());
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onViewCreated(WXSDKInstance instance, View view) {
        ViewGroup viewGroup = this.mRootView;
        if (viewGroup != null) {
            viewGroup.addView(this, new ViewGroup.LayoutParams(-1, -1));
            addView(view, new LinearLayout.LayoutParams(-1, -1));
            setVisibility(8);
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void reload() {
        if (this.time == 0 || System.currentTimeMillis() - this.time >= 600) {
            this.time = System.currentTimeMillis();
            if (this.mWXSDKInstance != null) {
                this.mWXSDKInstance.registerRenderListener(null);
                this.mWXSDKInstance.destroy();
                this.mWXSDKInstance = null;
                removeAllViews();
            }
            if (!TextUtils.isEmpty(this.mTemplate)) {
                render(this.mTemplate, getOptions(), null);
            }
        }
    }

    public Map<String, Object> getOptions() {
        Map<String, Object> options = new HashMap<>();
        options.put("plus_appid", this.mApp.obtainAppId());
        options.put("bundleUrl", this.mSrcPath);
        return options;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String getType() {
        return "service";
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void onDestroy() {
        if (this.mApp != null) {
            this.mApp = null;
        }
        ViewGroup viewGroup = this.mRootView;
        if (viewGroup != null) {
            viewGroup.removeView(this);
        }
        if (this.mWXSDKInstance != null) {
            this.mWXSDKInstance.onActivityDestroy();
            this.mWXSDKInstance = null;
        }
        this.mData = null;
    }

    public void findWebViewToLoadUrL(String sp, String id) {
        if (this.mApp != null) {
            WeexInstanceMgr self = WeexInstanceMgr.self();
            IApp iApp = this.mApp;
            IWebview webview = self.findWebview(null, iApp, iApp.obtainAppId(), id);
            if (webview != null) {
                webview.loadUrl(sp);
            }
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRenderSuccess(WXSDKInstance instance, int width, int height) {
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRefreshSuccess(WXSDKInstance instance, int width, int height) {
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onException(WXSDKInstance instance, String errCode, String msg) {
    }
}
