package io.dcloud.feature.weex;

import android.content.Context;
import android.content.DialogInterface;
import android.content.res.Configuration;
import android.net.Uri;
import android.os.Handler;
import android.os.Message;
import android.os.Process;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import androidx.recyclerview.widget.RecyclerView;
import com.alipay.sdk.m.u.i;
import com.taobao.weex.IWXInstanceContainerOnSizeListener;
import com.taobao.weex.IWXRenderListener;
import com.taobao.weex.R;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXParams;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.taobao.weex.ui.view.WXScrollView;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import com.taobao.weex.utils.tools.LogDetail;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IEventCallback;
import io.dcloud.common.DHInterface.IMgr;
import io.dcloud.common.DHInterface.ITitleNView;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.ui.AdaUniWebView;
import io.dcloud.common.adapter.ui.AdaWebview;
import io.dcloud.common.adapter.ui.webview.WebResUtil;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.ViewOptions;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.ErrorDialogUtil;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.common.util.TitleNViewUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.internal.sdk.SDK;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_scroller.view.DCWXScrollView;
import io.dcloud.weex.WXDotDataUtil;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.json.JSONException;
import org.json.JSONObject;

/* access modifiers changed from: package-private */
public class WXViewWrapper extends WXBaseWrapper implements IWXRenderListener, IEventCallback, WeexInstanceMgr.IWXStatisticsCallBack {
    static final int LOAD_JS = 1000;
    String TAG;
    private boolean hasScrollListener;
    private boolean isChlid;
    private boolean isCompilerWithUniapp;
    boolean isDelayRender;
    private boolean isFrameShow;
    private boolean isPre;
    boolean isReady;
    boolean isService;
    JSONObject jsonObject;
    long lastTime;
    List<FireEvent> mFireCaches;
    int mFontSize;
    Handler mHandler;
    IWXInstanceContainerOnSizeListener mInstanceOnSizeListener;
    private float mLastScreenWidth;
    JSONObject mNvueCfgData;
    private List<Message> mRenderCaches;
    LogDetail mServiceLogDetail;
    private String mUniPagePath;
    float mViewPort;
    View mWXSDKView;
    private List<Message> mWaitServiceRenderList;
    private String readyJs;
    long time;

    public List<Message> getWaitServiceRenderList() {
        return this.mWaitServiceRenderList;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper
    public void onReady() {
        this.isReady = true;
        runFireCache();
        if (this.isService) {
            if (!SDK.isUniMPSDK()) {
                WeexInstanceMgr.self().doForFeature(IMgr.MgrType.FeatureMgr, 10, new Object[]{this.mWebview.obtainApp(), WeexInstanceMgr.self().getUniMPFeature(), "onUniMPInit", new Object[0]});
            }
            LogDetail logDetail = this.mServiceLogDetail;
            if (logDetail != null) {
                logDetail.taskEnd();
                WXDotDataUtil.setValue(this.mServiceLogDetail.info.taskName, Long.valueOf(this.mServiceLogDetail.time.execTime));
            }
        }
    }

    private synchronized void runFireCache() {
        if (!this.mFireCaches.isEmpty()) {
            for (int i = 0; i < this.mFireCaches.size(); i++) {
                FireEvent fireEvent = this.mFireCaches.get(i);
                fireGlobalEvent(fireEvent.key, fireEvent.params);
            }
            this.mFireCaches.clear();
        }
    }

    WXViewWrapper(IWebview webview, ViewGroup viewGroup, JSONObject jsonObject2, String wxId, int zIndex, boolean isPre2) {
        super(viewGroup.getContext());
        this.TAG = "WXViewWrapper";
        this.lastTime = 0;
        this.isService = false;
        this.readyJs = ";var plusModule = weex.requireModule('plus'); plusModule.uniReady();";
        this.isReady = false;
        this.mFontSize = -1;
        this.mNvueCfgData = null;
        this.isDelayRender = false;
        this.mRenderCaches = new ArrayList();
        this.mWaitServiceRenderList = new ArrayList();
        this.isFrameShow = false;
        this.isChlid = false;
        this.isPre = false;
        this.isCompilerWithUniapp = true;
        this.mHandler = new Handler() {
            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass1 */

            public void handleMessage(Message msg) {
                super.handleMessage(msg);
                if (msg.what == 1000) {
                    if (!WXViewWrapper.this.isService) {
                        WXViewWrapper.this.delayedRender(msg.obj, (long) 10);
                    } else if (WXViewWrapper.this.mWebview != null) {
                        String nvueLaunchMode = WXViewWrapper.this.mWebview.obtainApp().obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
                        if (TextUtils.isEmpty(nvueLaunchMode) || !nvueLaunchMode.equals("fast") || !WeexInstanceMgr.self().getControl().equals(AbsoluteConst.UNI_V3) || WXEnvironment.sRemoteDebugMode) {
                            WXViewWrapper.this.delayedRender(msg.obj, 10);
                            return;
                        }
                        JSONObject jsonObject = WXViewWrapper.this.mWebview.obtainApp().obtainThridInfo(IApp.ConfigProperty.ThridInfo.LaunchWebviewJsonData);
                        if (jsonObject == null || !jsonObject.has(AbsoluteConst.JSON_KEY_UNINVIEW)) {
                            WXViewWrapper.this.delayedRender(msg.obj, 10);
                        } else {
                            WXViewWrapper.this.delayedRender(msg.obj, 100);
                        }
                    }
                }
            }
        };
        this.mInstanceOnSizeListener = new IWXInstanceContainerOnSizeListener() {
            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass2 */

            @Override // com.taobao.weex.IWXInstanceContainerOnSizeListener
            public void onSizeChanged(String instanceId, float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
                WXViewWrapper.this.updateDeviceDisplay(defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
            }
        };
        this.hasScrollListener = false;
        this.time = 0;
        this.mLastScreenWidth = 0.0f;
        this.lastTime = System.currentTimeMillis();
        String str = this.TAG;
        Logger.e(str, "WXViewWrapper----------isPre=" + isPre2 + "  wxid=" + wxId);
        if (!WeexInstanceMgr.self().isJsFrameworkReady()) {
            WeexInstanceMgr.self().setWXStatisticsCallBack(this);
        }
        this.isCompilerWithUniapp = !WeexInstanceMgr.self().getComplier().equalsIgnoreCase("weex");
        this.mWebview = webview;
        this.isPre = isPre2;
        this.mFireCaches = new ArrayList();
        if (this.mWebview instanceof AdaUniWebView) {
            this.isService = ((AdaUniWebView) this.mWebview).isUniService();
        }
        if (WeexInstanceMgr.self().isJSFKFileNotFound()) {
            boolean isVue3 = WeexInstanceMgr.self().getVueVersion() == 3;
            String string = webview.getContext().getString(R.string.dcloud_feature_weex_jsfk_not_found_tips);
            Object[] objArr = new Object[1];
            objArr[0] = isVue3 ? "VUE3" : "VUE2";
            ErrorDialogUtil.showErrorTipsAlert(webview.getActivity(), StringUtil.format(string, objArr), new DialogInterface.OnClickListener() {
                /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass3 */

                public void onClick(DialogInterface dialog, int which) {
                    Process.killProcess(Process.myPid());
                }
            });
            return;
        }
        viewGroup.addView(this, zIndex, new ViewGroup.LayoutParams(-1, -1));
        ((AdaFrameView) this.mWebview.obtainFrameView()).addFrameViewListener(this);
        this.jsonObject = jsonObject2;
        this.lastTime = System.currentTimeMillis();
        this.mWxId = wxId;
        this.mNvueCfgData = JSONUtil.createJSONObject(this.mWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.UNI_NVUE_DATA));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Map<String, Object> getInitOptions() {
        int p;
        Map<String, Object> options = new HashMap<>();
        if (this.mWebview != null) {
            options.put("plus_appid", this.mWebview.obtainApp().obtainAppId());
        }
        if (this.mWebview != null) {
            options.put("plus_web_id", this.mWebview.obtainFrameId());
        }
        String bundleUrl = this.mSrcPath;
        if (!TextUtils.isEmpty(this.mPath) && bundleUrl.indexOf(Operators.CONDITION_IF_STRING) == -1 && (p = this.mPath.indexOf(Operators.CONDITION_IF_STRING)) > 0) {
            bundleUrl = bundleUrl + this.mPath.substring(p);
        }
        options.put("deviceLanguage", LanguageUtil.getDeviceDefLocalLanguage());
        options.put("deviceCountry", LanguageUtil.getDeviceDefCountry());
        options.put("isInternational", Boolean.valueOf(PdrUtil.checkIntl()));
        options.put("bundleUrl", bundleUrl);
        if (getWxId().equals("__uniapp__service")) {
            options.put("plus_weex_id", "__uniapp__service");
        }
        return options;
    }

    public String getSrcPath() {
        return this.mSrcPath;
    }

    public String getWxId() {
        return this.mWxId;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getInitStringJsonData() {
        JSONObject jsonObject2 = new JSONObject();
        try {
            String href = this.mWebview.getOriginalUrl();
            if (href.startsWith(DeviceInfo.FILE_PROTOCOL)) {
                href = href.substring(DeviceInfo.FILE_PROTOCOL.length());
            }
            jsonObject2.put("Plus_InitURL", this.mWebview.obtainApp().convert2RelPath(href));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jsonObject2.toString();
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String evalJs(String js, int type) {
        if (this.mWXSDKInstance != null) {
            return WXBridgeManager.getInstance().syncExecJsOnInstanceWithResult(this.mWXSDKInstance.getInstanceId(), js, type);
        }
        return "";
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void render(Object template, Map<String, Object> options, String jsonInitData) {
        if (this.mWXSDKInstance != null) {
            recoveryInstance();
        }
        if (this.mWebview != null && this.mWebview.obtainFrameView() != null) {
            if (this.isService && BaseInfo.SyncDebug) {
                if (this.mServiceLogDetail == null) {
                    LogDetail logDetail = new LogDetail();
                    this.mServiceLogDetail = logDetail;
                    logDetail.name("initV3Service");
                }
                this.mServiceLogDetail.taskStart();
            }
            this.isChlid = ((AdaFrameView) this.mWebview.obtainFrameView()).isChildOfFrameView;
            this.isReady = false;
            if (!this.isPre) {
                String replaceTemplate = (String) template;
                if (!WXEnvironment.sRemoteDebugMode) {
                    replaceTemplate = replaceTemplate.replaceFirst(Pattern.quote("\"use weex:vue\""), Matcher.quoteReplacement(""));
                }
                template = replaceTemplate + this.readyJs;
            } else if (WeexInstanceMgr.self().getPreInstanceId() != null) {
                this.mWXSDKInstance = WXSDKManager.getInstance().getSDKInstance(WeexInstanceMgr.self().getPreInstanceId());
                if (this.mWXSDKInstance != null) {
                    this.mWXSDKInstance.init(this.mWebview.getContext());
                    onReady();
                    fireGlobalEvent("launchApp", new HashMap());
                }
            }
            if (!this.isPre) {
                if (this.mWebview.getActivity() instanceof IActivityHandler) {
                    this.mWXSDKInstance = new UniSDKInstance(this.mWebview.getContext(), ((IActivityHandler) this.mWebview.getActivity()).getOriginalContext());
                } else {
                    this.mWXSDKInstance = new UniSDKInstance(this.mWebview.getContext());
                }
            }
            if (this.mFontSize > 0) {
                this.mWXSDKInstance.setDefaultFontSize(this.mFontSize);
            }
            this.mWXSDKInstance.setPageKeepRawCssStyles();
            this.mWXSDKInstance.setImmersive(this.mWebview.obtainApp().obtainStatusBarMgr().isImmersive);
            this.mWXAnaly = new WXAnalyzerDelegate(this.mWebview.getContext());
            this.mWXSDKInstance.registerRenderListener(this);
            this.mWXSDKInstance.setBundleUrl(this.mSrcPath);
            this.mWXSDKInstance.setUniPagePath(this.isService ? "app-service.js" : this.mUniPagePath);
            this.mWXSDKInstance.setWXInstanceContainerOnSizeListener(this.mInstanceOnSizeListener);
            ((UniSDKInstance) this.mWXSDKInstance).setCompilerWithUniapp(this.isCompilerWithUniapp);
            int frameType = this.mWebview.obtainFrameView().getFrameType();
            if ((this.isFrameShow || frameType == 2 || frameType == 4) && this.mWXSDKInstance != null) {
                this.mWXSDKInstance.onShowAnimationEnd();
            }
            if (!this.isPre) {
                this.mWXSDKInstance.render(this.mWxId, String.valueOf(template), options, jsonInitData, WXRenderStrategy.APPEND_ASYNC);
            }
            if (!this.isService && (this.mWebview instanceof AdaWebview)) {
                ((AdaWebview) this.mWebview).dispatchWebviewStateEvent(0, this.mPath);
            }
            initViewPortWidth(false);
            initFlexDirection();
            initTitleNView();
            if (this.isService) {
                WeexInstanceMgr.self().setUniServiceCreated(true, this.mWebview.obtainApp());
            }
        }
    }

    private void initTitleNView() {
        AdaFrameView frame = (AdaFrameView) this.mWebview.obtainFrameView();
        JSONObject titleNView = frame.obtainFrameOptions().titleNView;
        if (titleNView != null && !frame.isChildOfFrameView && titleNView.has("type") && Constant.TRANSPARENT.equals(titleNView.optString("type"))) {
            this.mWXSDKInstance.addOnInstanceVisibleListener(new WXSDKInstance.OnInstanceVisibleListener() {
                /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass4 */

                @Override // com.taobao.weex.WXSDKInstance.OnInstanceVisibleListener
                public void onAppear() {
                    WXViewWrapper.this.addScrollListener(this);
                }

                @Override // com.taobao.weex.WXSDKInstance.OnInstanceVisibleListener
                public void onDisappear() {
                }
            });
        }
    }

    public void addScrollListener(WXSDKInstance.OnInstanceVisibleListener listener) {
        if (this.mWXSDKInstance != null && this.mWXSDKInstance.getRootView() != null && !this.hasScrollListener) {
            boolean isTab = true;
            this.hasScrollListener = true;
            final AdaFrameView frame = (AdaFrameView) this.mWebview.obtainFrameView();
            ViewOptions options = frame.obtainFrameOptions();
            ViewOptions paremtoptions = frame.obtainWebviewParent().obtainFrameOptions();
            final JSONObject titleNView = options.titleNView;
            if (titleNView == null && paremtoptions.titleNView != null) {
                titleNView = paremtoptions.titleNView;
            }
            if (titleNView != null && titleNView.has("type")) {
                AdaFrameItem parentFrame = frame.getParentFrameItem();
                if (!(parentFrame instanceof AdaFrameView) || ((AdaFrameView) parentFrame).obtainWebView() == null || !"tab".equals(((AdaFrameView) parentFrame).obtainWebView().obtainFrameId())) {
                    isTab = false;
                }
                if (titleNView == null) {
                    return;
                }
                if ((!frame.isChildOfFrameView || isTab) && titleNView.has("type") && Constant.TRANSPARENT.equals(titleNView.optString("type")) && this.mWXSDKInstance != null) {
                    View root = this.mWXSDKInstance.getRootView();
                    if (!(root == null || listener == null)) {
                        this.mWXSDKInstance.removeOnInstanceVisibleListener(listener);
                    }
                    if (root instanceof DCWXScrollView) {
                        ((DCWXScrollView) root).addScrollViewListener(new DCWXScrollView.WXScrollViewListener() {
                            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass5 */

                            @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                            public void onScrollChanged(DCWXScrollView scrollView, int x, int t, int oldx, int oldt) {
                                AdaFrameView adaFrameView = frame;
                                if (adaFrameView != null && titleNView != null) {
                                    int coverage = adaFrameView.obtainFrameOptions().coverage;
                                    if (coverage >= oldt || coverage >= t) {
                                        AbsMgr obtainWindowMgr = frame.obtainWindowMgr();
                                        IWebview obtainWebView = frame.obtainWebView();
                                        AdaFrameView adaFrameView2 = frame;
                                        Object titleNViewObj = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView2, TitleNViewUtil.getTitleNViewId(adaFrameView2));
                                        if (titleNViewObj instanceof ITitleNView) {
                                            TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNViewObj, frame.obtainWebView(), (float) t, titleNView, (float) coverage);
                                        }
                                    }
                                }
                            }

                            @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                            public void onScrollToBottom(DCWXScrollView scrollView, int x, int y) {
                            }

                            @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                            public void onScrollToTop(DCWXScrollView scrollView, int x, int y) {
                            }

                            @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                            public void onScrollStopped(DCWXScrollView scrollView, int x, int y) {
                            }

                            @Override // io.dcloud.feature.weex_scroller.view.DCWXScrollView.WXScrollViewListener
                            public void onScroll(DCWXScrollView scrollView, int x, int y) {
                            }
                        });
                    } else if (root instanceof WXScrollView) {
                        ((WXScrollView) root).addScrollViewListener(new WXScrollView.WXScrollViewListener() {
                            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass6 */

                            @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                            public void onScrollChanged(WXScrollView scrollView, int x, int t, int oldx, int oldt) {
                                AdaFrameView adaFrameView = frame;
                                if (adaFrameView != null && titleNView != null) {
                                    int coverage = adaFrameView.obtainFrameOptions().coverage;
                                    if (coverage >= oldt || coverage >= t) {
                                        AbsMgr obtainWindowMgr = frame.obtainWindowMgr();
                                        IWebview obtainWebView = frame.obtainWebView();
                                        AdaFrameView adaFrameView2 = frame;
                                        Object titleNViewObj = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView2, TitleNViewUtil.getTitleNViewId(adaFrameView2));
                                        if (titleNViewObj instanceof ITitleNView) {
                                            TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNViewObj, frame.obtainWebView(), (float) t, titleNView, (float) coverage);
                                        }
                                    }
                                }
                            }

                            @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                            public void onScrollToBottom(WXScrollView scrollView, int x, int y) {
                            }

                            @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                            public void onScrollStopped(WXScrollView scrollView, int x, int y) {
                            }

                            @Override // com.taobao.weex.ui.view.WXScrollView.WXScrollViewListener
                            public void onScroll(WXScrollView scrollView, int x, int y) {
                            }
                        });
                    } else if (root instanceof BounceRecyclerView) {
                        ((WXRecyclerView) ((BounceRecyclerView) root).getInnerView()).addOnScrollListener(new RecyclerView.OnScrollListener() {
                            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass7 */
                            int oldx;
                            int oldy;

                            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
                            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                                int i = this.oldx;
                                int oldY = this.oldy;
                                this.oldx += dx;
                                this.oldy += dy;
                                AdaFrameView adaFrameView = frame;
                                if (adaFrameView != null && titleNView != null) {
                                    int coverage = adaFrameView.obtainFrameOptions().coverage;
                                    if (coverage >= oldY || coverage >= this.oldy) {
                                        AbsMgr obtainWindowMgr = frame.obtainWindowMgr();
                                        IWebview obtainWebView = frame.obtainWebView();
                                        AdaFrameView adaFrameView2 = frame;
                                        Object titleNViewObj = TitleNViewUtil.getTitleNView(obtainWindowMgr, obtainWebView, adaFrameView2, TitleNViewUtil.getTitleNViewId(adaFrameView2));
                                        if (titleNViewObj instanceof ITitleNView) {
                                            TitleNViewUtil.updateTitleNViewStatus((ITitleNView) titleNViewObj, frame.obtainWebView(), (float) this.oldy, titleNView, (float) coverage);
                                        }
                                    }
                                }
                            }
                        });
                    }
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.feature.weex.WXBaseWrapper
    public void onRefresh() {
        if (this.mWebview != null) {
            ((AdaFrameView) this.mWebview.obtainFrameView()).dispatchFrameViewEvents(AbsoluteConst.EVENTS_PULL_DOWN_EVENT, 3);
            ((AdaFrameView) this.mWebview.obtainFrameView()).dispatchFrameViewEvents(AbsoluteConst.EVENTS_PULL_TO_REFRESH, 3);
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void loadTemplate(JSONObject info) {
        JSONObject data;
        try {
            this.jsonObject = info;
            this.mPath = info.optString("js");
            if (!(this.jsonObject == null || !this.jsonObject.has("data") || (data = this.jsonObject.optJSONObject("data")) == null)) {
                this.mFontSize = data.optInt("defaultFontSize");
                if (data.has("delayRender")) {
                    this.isDelayRender = data.optBoolean("delayRender", this.isDelayRender);
                }
                if (data.has("path")) {
                    this.mUniPagePath = data.optString("path", "") + ".nvue";
                }
            }
            if (!PdrUtil.isNetPath(this.mPath)) {
                this.mSrcPath = initSrcPath(this.mPath);
                if (this.isPre) {
                    render(null, getInitOptions(), getInitStringJsonData());
                } else {
                    ThreadPool.self().addThreadTask(new Runnable() {
                        /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass8 */

                        public void run() {
                            InputStream is;
                            if (WXViewWrapper.this.mWebview != null && (is = WebResUtil.getEncryptionInputStream(WXViewWrapper.this.mSrcPath, WXViewWrapper.this.mWebview.obtainApp())) != null) {
                                try {
                                    String template = new String(IOUtil.toString(is));
                                    if (WXViewWrapper.this.isService) {
                                        template = WXViewWrapper.this.getAllUniService(template);
                                    }
                                    Message message = new Message();
                                    message.obj = template;
                                    message.what = 1000;
                                    if (WXViewWrapper.this.isService || WeexInstanceMgr.self().isUniServiceCreated(WXViewWrapper.this.mWebview.obtainApp())) {
                                        if (!WeexInstanceMgr.self().isJsFrameworkReady()) {
                                            if (!WXViewWrapper.this.mRenderCaches.contains(message)) {
                                                WXViewWrapper.this.mRenderCaches.add(message);
                                            }
                                        } else if (!WXViewWrapper.this.isDelayRender || WXViewWrapper.this.isService || WXViewWrapper.this.isFrameShow) {
                                            WXViewWrapper.this.mHandler.sendMessage(message);
                                        } else if (!WXViewWrapper.this.mRenderCaches.contains(message)) {
                                            WXViewWrapper.this.mRenderCaches.add(message);
                                        }
                                        IOUtil.close(is);
                                    }
                                    if (!WXViewWrapper.this.mWaitServiceRenderList.contains(message)) {
                                        WXViewWrapper.this.mWaitServiceRenderList.add(message);
                                    }
                                    IOUtil.close(is);
                                } catch (Exception e) {
                                    e.printStackTrace();
                                }
                            }
                        }
                    }, true);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void titleNViewRefresh() {
        addScrollListener(null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getAllUniService(String template) {
        if (this.mWebview == null || this.mWebview.obtainApp() == null) {
            return "";
        }
        IApp app = this.mWebview.obtainApp();
        String path = initSrcPath("_www/app-config.js");
        String confusion = initSrcPath("_www/app-confusion.js");
        InputStream is = WebResUtil.getEncryptionInputStream(path, app);
        InputStream confusionStream = WebResUtil.getEncryptionInputStream(confusion, app);
        try {
            String configJs = IOUtil.toString(is);
            String confusionJs = IOUtil.toString(confusionStream);
            return configJs + confusionJs + template;
        } catch (IOException e) {
            e.printStackTrace();
            return template;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void delayedRender(final Object template, long delayMilllis) {
        postDelayed(new Runnable() {
            /* class io.dcloud.feature.weex.WXViewWrapper.AnonymousClass9 */

            public void run() {
                if (WXViewWrapper.this.mWebview != null) {
                    WXViewWrapper wXViewWrapper = WXViewWrapper.this;
                    wXViewWrapper.render(template, wXViewWrapper.getInitOptions(), WXViewWrapper.this.getInitStringJsonData());
                }
            }
        }, delayMilllis);
    }

    public String initSrcPath(String path) {
        if (this.mWebview == null) {
            return path;
        }
        int s = path.indexOf(Operators.CONDITION_IF_STRING);
        String p = path;
        if (s > 1) {
            p = path.substring(0, s);
        }
        if (p.startsWith("/")) {
            p = p.substring(1);
        }
        String srcPath = p;
        String[] exName = path.split("\\.");
        if (exName.length == 1) {
            srcPath = srcPath + ".js";
        } else if (exName.length == 2) {
            srcPath = exName[0] + ".js";
        }
        File file = new File(srcPath);
        if (file.exists()) {
            return Uri.fromFile(file).toString();
        }
        byte mode = this.mWebview.obtainApp().obtainRunningAppMode();
        String baseUrl = null;
        if (!(this.mWebview instanceof AdaUniWebView)) {
            baseUrl = this.mWebview.obtainFullUrl();
        }
        if (srcPath.startsWith("/storage") || mode != 1) {
            return this.mWebview.obtainApp().convert2WebviewFullPath(baseUrl, srcPath);
        }
        String url = this.mWebview.obtainApp().convert2AbsFullPath(baseUrl, srcPath);
        if (url.startsWith("/")) {
            url = url.substring(1, url.length());
        }
        return url;
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onViewCreated(WXSDKInstance instance, View view) {
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onWeexViewCreated(instance, view);
        }
        this.mWXSDKView = view;
        addView(this.mWXSDKView, new LinearLayout.LayoutParams(-1, -1));
        this.mWXSDKView.layout(0, 0, getWidth(), getHeight());
        if (isFocusableInTouchMode()) {
            this.mWXSDKView.setFocusable(true);
            this.mWXSDKView.setFocusableInTouchMode(true);
        }
        addScrollListener(null);
    }

    @Override // android.view.View
    public void setFocusable(int focusable) {
        super.setFocusable(focusable);
        View view = this.mWXSDKView;
        if (view != null) {
            view.setFocusable(focusable);
        }
    }

    public void setFocusableInTouchMode(boolean focusableInTouchMode) {
        super.setFocusableInTouchMode(focusableInTouchMode);
        View view = this.mWXSDKView;
        if (view != null) {
            view.setFocusableInTouchMode(focusableInTouchMode);
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRenderSuccess(WXSDKInstance instance, int width, int height) {
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onWeexRenderSuccess(instance);
        }
        if (!this.isService && this.mWebview != null) {
            if (this.mWebview instanceof AdaWebview) {
                ((AdaWebview) this.mWebview).dispatchWebviewStateEvent(1, this.mPath);
            }
            String str_auto = this.mWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.CONFIG_AUTOCLOSE);
            if (PdrUtil.isEmpty(str_auto)) {
                str_auto = AbsoluteConst.TRUE;
            }
            if (Boolean.parseBoolean(str_auto)) {
                this.mWebview.obtainFrameView().obtainWindowMgr().processEvent(IMgr.MgrType.WindowMgr, 11, this.mWebview.obtainFrameView());
            }
        }
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onRefreshSuccess(WXSDKInstance instance, int width, int height) {
    }

    @Override // com.taobao.weex.IWXRenderListener
    public void onException(WXSDKInstance instance, String errCode, String msg) {
        String str = this.TAG;
        Logger.e(str, "onException--errCode=" + errCode + "    msg=" + msg);
        if (this.mWXAnaly != null) {
            this.mWXAnaly.onException(instance, errCode, msg);
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void onDestroy() {
        super.onDestroy();
        WeexInstanceMgr.self().unWXStatisticsCallBack(this);
        this.mWebview = null;
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public void reload() {
        if (this.time == 0 || System.currentTimeMillis() - this.time >= 600) {
            this.time = System.currentTimeMillis();
            recoveryInstance();
            this.isFrameShow = true;
            if (!TextUtils.isEmpty(this.mPath)) {
                loadTemplate(this.jsonObject);
            }
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public String getType() {
        return WXBasicComponentType.VIEW;
    }

    @Override // io.dcloud.common.DHInterface.IEventCallback
    public Object onCallBack(String pEventType, Object pArgs) {
        if (PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CLOSE) && (pArgs instanceof IWebview)) {
            ((AdaFrameView) ((IWebview) pArgs).obtainFrameView()).removeFrameViewListener(this);
            WeexInstanceMgr.self().removeWeexView(this.mWxId);
            onDestroy();
            return null;
        } else if ((!PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_SHOW_ANIMATION_END) && !PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CHILD_INITIALIZE_SHOW)) || this.isFrameShow) {
            return null;
        } else {
            this.isFrameShow = true;
            if (this.mWXSDKInstance != null) {
                this.mWXSDKInstance.onShowAnimationEnd();
            }
            if (!this.isDelayRender) {
                return null;
            }
            runDelayedRenderCaches(this.mRenderCaches);
            return null;
        }
    }

    /* access modifiers changed from: protected */
    public void onConfigurationChanged(Configuration newConfig) {
        super.onConfigurationChanged(newConfig);
        if (this.mWXSDKInstance != null && this.mWebview.getActivity() != null) {
            int angle = this.mWebview.getActivity().getWindowManager().getDefaultDisplay().getRotation();
            int orientation = 0;
            String value = "portrait";
            if (angle == 1) {
                orientation = 90;
                value = "landscape";
            } else if (angle == 2) {
                orientation = 180;
                value = "portraitReverse";
            } else if (angle == 3) {
                orientation = -90;
                value = "landscapeReverse";
            }
            WXUtils.getCache().evictAll();
            Map<String, Object> params = new HashMap<>();
            params.put("value", value);
            params.put("orientation", Integer.valueOf(orientation));
            this.mWXSDKInstance.fireGlobalEventCallback("orientationchange", params);
            if (this.isCompilerWithUniapp) {
                this.mWXSDKInstance.setInstanceViewPortWidth(((float) this.mWebview.obtainApp().getInt(0)) / this.mWebview.getScale(), true);
            }
        }
    }

    private void updateInitDeviceParams(Context context) {
        WXParams params = WXBridgeManager.getInstance().getInitParams();
        if (params != null && !TextUtils.equals(params.getDeviceWidth(), String.valueOf(WXViewUtils.getScreenWidth(context)))) {
            params.setDeviceWidth(String.valueOf(WXViewUtils.getScreenWidth(context)));
            params.setDeviceHeight(String.valueOf(WXViewUtils.getScreenHeight(context)));
            float density = WXEnvironment.sApplication.getResources().getDisplayMetrics().density;
            WXEnvironment.addCustomOptions("scale", Float.toString(density));
            String statusBarHeight = null;
            if (WXViewUtils.getStatusBarHeight(context) > 0) {
                statusBarHeight = String.valueOf(WXViewUtils.getStatusBarHeight(context));
            }
            WXBridgeManager.getInstance().updateInitDeviceParams(params.getDeviceWidth(), params.getDeviceHeight(), Float.toString(density), statusBarHeight);
            WXBridgeManager.getInstance().setDeviceDisplay(this.mWXSDKInstance.getInstanceId(), (float) WXViewUtils.getScreenWidth(context), (float) WXViewUtils.getScreenHeight(context), WXViewUtils.getScreenDensity(context));
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper, io.dcloud.common.DHInterface.IUniNView
    public synchronized boolean fireGlobalEvent(String key, Map<String, Object> params) {
        if (this.isReady) {
            return super.fireGlobalEvent(key, params);
        }
        this.mFireCaches.add(new FireEvent(key, params));
        return true;
    }

    @Override // io.dcloud.feature.weex.WeexInstanceMgr.IWXStatisticsCallBack
    public void onJsFrameworkReady() {
        runDelayedRenderCaches(this.mRenderCaches);
        if (this.mWXSDKInstance != null) {
            initViewPortWidth(true);
            initFlexDirection();
        }
    }

    public void runDelayedRenderCaches(List<Message> list) {
        if (list.size() > 0) {
            for (int i = list.size() - 1; i >= 0; i--) {
                this.mHandler.sendMessage(list.get(i));
            }
            list.clear();
        }
    }

    private void initViewPortWidth(boolean fromMetaModule) {
        if (this.isCompilerWithUniapp && this.mWXSDKInstance != null) {
            int screenWidth = this.mWebview.obtainApp().getInt(0);
            if (fromMetaModule) {
                screenWidth = WXViewUtils.getScreenWidth(getContext());
            }
            this.mViewPort = ((float) screenWidth) / this.mWebview.getScale();
            this.mWXSDKInstance.setInstanceViewPortWidth(this.mViewPort, fromMetaModule);
        }
    }

    private void initFlexDirection() {
        JSONObject jSONObject = this.mNvueCfgData;
        if (jSONObject != null && jSONObject.has(AbsoluteConst.UNI_NVUE_FLEX_DIRECTION)) {
            WXBridgeManager.getInstance().setFlexDirectionDef(this.mNvueCfgData.optString(AbsoluteConst.UNI_NVUE_FLEX_DIRECTION));
        }
    }

    /* access modifiers changed from: package-private */
    public class FireEvent {
        String key;
        Map<String, Object> params;

        public FireEvent(String key2, Map<String, Object> params2) {
            this.key = key2;
            this.params = params2;
        }
    }

    @Override // io.dcloud.feature.weex.WXBaseWrapper
    public void recoveryInstance() {
        View v;
        if (this.mWXSDKView != null) {
            if (!this.isChlid && (v = this.mWebview.getActivity().getCurrentFocus()) != null) {
                DeviceInfo.hideIME(v);
            }
            this.mWXSDKView.clearFocus();
            clearFocus();
            removeView(this.mWXSDKView);
            this.mWXSDKView = null;
            this.isPre = false;
        }
        super.recoveryInstance();
        this.isFrameShow = false;
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
        if (this.mWebview != null && (this.mWebview instanceof AdaUniWebView)) {
            try {
                ((AdaUniWebView) this.mWebview).updateScreenAndDisplay();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateDeviceDisplay(float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
        if (!(this.mWXSDKInstance == null || this.mWebview == null || this.mWebview.getActivity() == null)) {
            int sScreenAllHeight = this.mWebview.obtainApp().getInt(2);
            int sScreenWidth = this.mWebview.obtainApp().getInt(0);
            int sScreenHeight = this.mWebview.obtainApp().getInt(1);
            if (this.mWXSDKInstance.isOnSizeChangedRender() && this.mWXSDKInstance.isOnSizeChangedRender()) {
                Map<String, Object> screen = new HashMap<>();
                float scale = this.mWebview.getScale();
                screen.put("resolutionHeight", Integer.valueOf((int) (((float) sScreenAllHeight) / scale)));
                screen.put("resolutionWidth", Integer.valueOf((int) (((float) sScreenWidth) / scale)));
                screen.put("dpiX", Float.valueOf(DeviceInfo.dpiX));
                screen.put("dpiY", Float.valueOf(DeviceInfo.dpiY));
                Map<String, Object> display = new HashMap<>();
                display.put("resolutionHeight", Integer.valueOf((int) (((float) sScreenHeight) / scale)));
                display.put("resolutionWidth", Integer.valueOf((int) (((float) sScreenWidth) / scale)));
                StringBuilder buffer = new StringBuilder();
                for (String key : screen.keySet()) {
                    buffer.append("plus.screen.");
                    buffer.append(key);
                    buffer.append("=");
                    buffer.append(screen.get(key));
                    buffer.append(i.b);
                }
                for (String key2 : display.keySet()) {
                    buffer.append("plus.display.");
                    buffer.append(key2);
                    buffer.append("=");
                    buffer.append(display.get(key2));
                    buffer.append(i.b);
                }
                this.mWebview.evalJS(buffer.toString());
                if (this.isCompilerWithUniapp) {
                    this.mWXSDKInstance.setInstanceViewPortWidth(((float) sScreenWidth) / this.mWebview.getScale(), true);
                }
                if (!this.isService) {
                    this.mWXSDKInstance.setDeviceDisplayOfPage(sScreenWidth, sScreenHeight);
                    this.mWXSDKInstance.reloadPageLayout();
                    WXBridgeManager.getInstance().setDefaultRootSize(this.mWXSDKInstance.getInstanceId(), defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
                }
            }
        }
    }
}
