package io.dcloud.feature.weex;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.ViewGroup;
import com.alibaba.android.bindingx.plugin.weex.BindingX;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.alipay.sdk.m.u.i;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.taobao.weex.IWXStatisticsListener;
import com.taobao.weex.InitConfig;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.SimpleComponentHolder;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.tencent.liteav.audio.TXEAudioDef;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.DHInterface.IConfusionMgr;
import io.dcloud.common.DHInterface.IMgr;
import io.dcloud.common.DHInterface.INativeAppInfo;
import io.dcloud.common.DHInterface.IUniInstanceMgr;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.io.UnicodeInputStream;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.internal.sdk.SDK;
import io.dcloud.feature.uniapp.UniMoudlesLoader;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex.adapter.DCDefaultConfigAdapter;
import io.dcloud.feature.weex.adapter.DCVueBridgeAdapter;
import io.dcloud.feature.weex.adapter.DCWXHttpAdapter;
import io.dcloud.feature.weex.adapter.DefaultWebSocketAdapterFactory;
import io.dcloud.feature.weex.adapter.Fresco.DCGenericDraweeView;
import io.dcloud.feature.weex.adapter.Fresco.imagepipeline.OkHttpImagePipelineConfigFactory;
import io.dcloud.feature.weex.adapter.FrescoDrawableLoader;
import io.dcloud.feature.weex.adapter.FrescoImageAdapter;
import io.dcloud.feature.weex.adapter.FrescoImageComponent;
import io.dcloud.feature.weex.adapter.FrescoImageComponentU;
import io.dcloud.feature.weex.adapter.JSExceptionAdapter;
import io.dcloud.feature.weex.adapter.PlusUriAdapter;
import io.dcloud.feature.weex.adapter.ScalableViewComponent;
import io.dcloud.feature.weex.adapter.webview.WXDCWeb;
import io.dcloud.feature.weex.extend.DCCoverImageComponent;
import io.dcloud.feature.weex.extend.DCCoverViewComponent;
import io.dcloud.feature.weex.extend.DCTabBarModule;
import io.dcloud.feature.weex.extend.DCUniMPModule;
import io.dcloud.feature.weex.extend.DCWXSlider;
import io.dcloud.feature.weex.extend.DCWXView;
import io.dcloud.feature.weex.extend.PlusModule;
import io.dcloud.feature.weex.extend.PlusStorageModule;
import io.dcloud.feature.weex.extend.RandomBytesModule;
import io.dcloud.feature.weex.extend.WXEventModule;
import io.dcloud.feature.weex_websocket.UniWebSocketModule;
import io.dcloud.weex.MoudlesLoader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class WeexInstanceMgr implements IWXStatisticsListener, IUniInstanceMgr {
    static final String SERVICE_NAME = "weexPlus";
    private static WeexInstanceMgr instance = null;
    String TAG = "WeexInstanceMgr";
    private ArrayList<IWXStatisticsCallBack> callBacks = new ArrayList<>();
    private String complier = "weex";
    private String control = AbsoluteConst.UNI_V3;
    private AbsMgr featureMgr;
    private LinkedHashMap<String, WXViewWrapper> instanceHashMap = new LinkedHashMap<>(16);
    private boolean isAssetsRes = false;
    private boolean isJSFKFileNotFound = false;
    private boolean isJsFrameworkReady = false;
    private boolean isUniServiceCreated = false;
    private boolean isWeexInitEnd = false;
    private String jsSACName = "uni-app-config";
    private Application mApplication = null;
    private IConfusionMgr mConfusionMgr;
    private Handler mHandler;
    private String mPreInstanceId = null;
    private String mPreUniAppid = null;
    private Map<String, ICallBack> mPreUniMPCallBackMap = new HashMap();
    private ArrayList<ICallBack> mReladyCallBacks = new ArrayList<>();
    private ICallBack mRestartReadyCall;
    private String mUniNViewModules = null;
    private int mVueVersion = 2;
    private String render = "auto";
    private StringBuffer sb;
    private HashMap<String, WXServiceWrapper> serviceWrapperMapsCache = new HashMap<>(3);

    /* access modifiers changed from: package-private */
    public interface EachListener<T> {
        void onEach(T t);
    }

    public interface IWXStatisticsCallBack {
        void onJsFrameworkReady();
    }

    public static synchronized WeexInstanceMgr self() {
        WeexInstanceMgr weexInstanceMgr;
        synchronized (WeexInstanceMgr.class) {
            if (instance == null) {
                instance = new WeexInstanceMgr();
            }
            weexInstanceMgr = instance;
        }
        return weexInstanceMgr;
    }

    public void setUniNViewModules(String modules) {
        this.mUniNViewModules = modules;
        if (this.mReladyCallBacks.size() > 0) {
            Iterator<ICallBack> it = this.mReladyCallBacks.iterator();
            while (it.hasNext()) {
                it.next().onCallBack(0, modules);
            }
            this.mReladyCallBacks.clear();
        }
    }

    public String getUniNViewModules() {
        return this.mUniNViewModules;
    }

    public void setUniNViewModuleReladyCallBack(ICallBack callBack) {
        if (!this.mReladyCallBacks.contains(callBack)) {
            this.mReladyCallBacks.add(callBack);
        }
    }

    /* access modifiers changed from: package-private */
    public void init(AbsMgr featureMgr2) {
        this.featureMgr = featureMgr2;
    }

    public String getUniMPFeature() {
        return "UniMP".toLowerCase(Locale.ENGLISH);
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void initWeexEnv(INativeAppInfo info) {
        if (info != null) {
            this.mConfusionMgr = info.getCofusionMgr();
            initWeexEnv(info.getApplication());
        }
    }

    public void initWeexEnv(Application application) {
        if (!SDK.isUniMPSDK()) {
            PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "registerReloadReceiver", null, new Class[]{Application.class}, new Object[]{application});
        }
        self().setApplication(application);
        if (!WXSDKEngine.isInitialized()) {
            InitConfig.Builder weexHuilder = new InitConfig.Builder();
            self().initAppForPath(application, null);
            self().initJSFramework(application, null);
            if (!SDK.isUniMPSDK()) {
                PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "initDebugEnvironment", null, new Class[]{Application.class}, new Object[]{application});
            }
            DCWXHttpAdapter httpAdapter = new DCWXHttpAdapter();
            weexHuilder.setHttpAdapter(httpAdapter);
            Fresco.initialize(application, OkHttpImagePipelineConfigFactory.newBuilder(application, httpAdapter.getImageOkHttpClient()).build());
            JSON.setDefaultTypeKey("@type_ft");
            DCGenericDraweeView.initialize(Fresco.getDraweeControllerBuilderSupplier());
            weexHuilder.setImgAdapter(new FrescoImageAdapter());
            weexHuilder.setDrawableLoader(new FrescoDrawableLoader(application));
            weexHuilder.setURIAdapter(new PlusUriAdapter());
            weexHuilder.setDCVueBridgeAdapter(new DCVueBridgeAdapter());
            weexHuilder.setWebSocketAdapterFactory(new DefaultWebSocketAdapterFactory());
            weexHuilder.setJSExceptionAdapter(new JSExceptionAdapter());
            InitConfig config = weexHuilder.build();
            WXSDKManager.getInstance().setWxConfigAdapter(new DCDefaultConfigAdapter());
            WXSDKEngine.initialize(application, config);
            self().initStatisticsListener();
            try {
                String serviceScript = new String(PlatformUtil.getFileContent("io/dcloud/weexUniJs.js", 1));
                this.sb = new StringBuffer();
                String param = self().getConfigParam();
                StringBuffer stringBuffer = this.sb;
                stringBuffer.append("var plusContext = {};plusContext.getLocationHerf = function(plus){\n    return plus.weex.config.bundleUrl;\n};var param = " + param + i.b);
                this.sb.append(serviceScript);
                WXSDKEngine.registerComponent("image", FrescoImageComponent.class);
                WXSDKEngine.registerComponent("cover-view", DCCoverViewComponent.class);
                WXSDKEngine.registerComponent("u-image", FrescoImageComponentU.class);
                WXSDKEngine.registerComponent("cover-image", DCCoverImageComponent.class);
                WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(ScalableViewComponent.class, new ScalableViewComponent.Ceator()), false, "u-scalable");
                WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(DCWXSlider.class, new DCWXSlider.Creator()), true, WXBasicComponentType.SLIDER);
                WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(DCWXView.class, new DCWXView.Ceator()), false, WXBasicComponentType.VIEW);
                WXSDKEngine.registerComponent("u-web-view", WXDCWeb.class);
                WXSDKEngine.registerModule(IApp.ConfigProperty.CONFIG_PLUS, PlusModule.class);
                WXSDKEngine.registerModule("DCloud-Crypto", RandomBytesModule.class);
                WXSDKEngine.registerModule("plusstorage", PlusStorageModule.class);
                WXSDKEngine.registerModule("uni-tabview", DCTabBarModule.class);
                addComponentByName(WXBasicComponentType.DIV, ScalableViewComponent.class);
                if (PdrUtil.isUniMPHostForUniApp() && !SDK.isUniMPSDK()) {
                    WXSDKEngine.registerModule("uniMP", DCUniMPModule.class);
                }
                WXSDKEngine.registerModule("event", WXEventModule.class);
                if (this.sb != null) {
                    WXSDKEngine.registerService(SERVICE_NAME, this.sb.toString(), new HashMap<>());
                }
                if (!SDK.isUniMPSDK()) {
                    self().registerUniappService(application, "");
                }
                WXEnvironment.setGlobalFontFamily("unincomponents", Typeface.createFromAsset(application.getAssets(), "fonts/unincomponents.ttf"));
                WXSDKEngine.registerModule("uni-webSocket", UniWebSocketModule.class);
                BindingX.register();
                registerReflexWeexPlugin(application);
                setWeexInitEnd(true);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void setApplication(Application mApplication2) {
        this.mApplication = mApplication2;
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void restartWeex(final Application application, final ICallBack callBack, final String appid) {
        if (((getControl().equals(AbsoluteConst.UNI_V3) && isWeexInitEnd() && !BaseInfo.isFirstRun) || (SDK.isUniMPSDK() && isWeexInitEnd())) && this.mPreInstanceId == null) {
            Logger.e(this.TAG, "restartWeex-------");
            if (this.instanceHashMap.size() > 0) {
                onActivityDestroy(false);
            }
            getHandler().post(new Runnable() {
                /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass1 */

                public void run() {
                    WeexInstanceMgr.this.unRegisterUniappService();
                    WeexInstanceMgr.this.mRestartReadyCall = callBack;
                    WeexInstanceMgr.this.mApplication = application;
                    WeexInstanceMgr weexInstanceMgr = WeexInstanceMgr.this;
                    weexInstanceMgr.initAppForPath(weexInstanceMgr.mApplication, appid);
                    WeexInstanceMgr.this.setJsFrameworkReady(false);
                    WeexInstanceMgr.this.initJSFramework(application, appid);
                    WeexInstanceMgr.this.registerUniappService(application, appid);
                    WXSDKEngine.restartWeex();
                }
            });
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void loadWeexToAppid(Context context, String appid, boolean isErrorOpen) {
        int existVueVersion = getVueVersion();
        initAppForPath(context, appid);
        initJSFramework(context, appid);
        if (getVueVersion() != existVueVersion) {
            isErrorOpen = true;
        }
        if (!WXBridgeManager.getInstance().isJSFrameworkInit() || isErrorOpen) {
            setJsFrameworkReady(false);
            WXSDKEngine.restartWeex();
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void onCreateProcess(Application application, Boolean isMainProcess) {
        MoudlesLoader.getInstance().initHooksClass(application, isMainProcess);
    }

    public void initStatisticsListener() {
        WXSDKManager.getInstance().registerStatisticsListener(this);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void initJSFramework(Context application, String appid) {
        JSONObject statisticsJson;
        JSONObject webViewConfig;
        InputStream inputStream = getAppFileStream(application, appid, BaseInfo.sConfigXML);
        if (inputStream != null) {
            try {
                JSONObject configJson = JSON.parseObject(handleEncryptionInputStream(inputStream, application, true));
                if (configJson != null && configJson.containsKey(IApp.ConfigProperty.CONFIG_PLUS)) {
                    JSONObject plusJson = configJson.getJSONObject(IApp.ConfigProperty.CONFIG_PLUS);
                    if (plusJson != null && plusJson.containsKey("uni-app")) {
                        JSONObject uniappconfig = plusJson.getJSONObject("uni-app");
                        self().control = AbsoluteConst.UNI_V3;
                        if (uniappconfig.containsKey("renderer")) {
                            self().render = uniappconfig.getString("renderer");
                        }
                        if (uniappconfig.containsKey("nvueCompiler")) {
                            self().complier = uniappconfig.getString("nvueCompiler");
                        }
                        if (uniappconfig.containsKey("vueVersion")) {
                            self().mVueVersion = uniappconfig.getIntValue("vueVersion");
                        } else {
                            self().mVueVersion = 2;
                        }
                        if (uniappconfig.containsKey("useJSProcess")) {
                            if (AbsoluteConst.FALSE.equals(uniappconfig.getString("useJSProcess"))) {
                                WXBridgeManager.getInstance().setUseSingleProcess(true);
                            } else {
                                WXBridgeManager.getInstance().setUseSingleProcess(false);
                            }
                        }
                        if (uniappconfig.containsKey("webView") && (webViewConfig = uniappconfig.getJSONObject("webView")) != null) {
                            try {
                                if (webViewConfig.containsKey("minUserAgentVersion")) {
                                    BaseInfo.minUserAgentVersion = webViewConfig.getString("minUserAgentVersion");
                                }
                                if (webViewConfig.containsKey("x5")) {
                                    JSONObject x5Config = webViewConfig.getJSONObject("x5");
                                    if (x5Config.containsKey("timeOut")) {
                                        BaseInfo.timeOut = x5Config.getIntValue("timeOut");
                                    }
                                    if (x5Config.containsKey("showTipsWithoutWifi")) {
                                        BaseInfo.showTipsWithoutWifi = x5Config.getBooleanValue("showTipsWithoutWifi");
                                    }
                                    if (x5Config.containsKey("allowDownloadWithoutWiFi")) {
                                        BaseInfo.allowDownloadWithoutWiFi = x5Config.getBooleanValue("allowDownloadWithoutWiFi");
                                    }
                                }
                            } catch (Exception e) {
                            }
                        }
                    }
                    if (!(plusJson == null || !plusJson.containsKey(IApp.ConfigProperty.CONFIG_UNISTATISTICS) || (statisticsJson = plusJson.getJSONObject(IApp.ConfigProperty.CONFIG_UNISTATISTICS)) == null)) {
                        JSONObject us = new JSONObject();
                        try {
                            if (statisticsJson.containsKey("enable")) {
                                us.put("enable", statisticsJson.get("enable"));
                            }
                            if (statisticsJson.containsKey("version")) {
                                us.put("version", statisticsJson.get("version"));
                            }
                            if (statisticsJson.containsKey("uniCloud")) {
                                us.put("uniCloud", (Object) statisticsJson.getJSONObject("uniCloud"));
                            }
                            AppRuntime.setUniStatistics(us.toJSONString());
                        } catch (Exception e2) {
                        }
                    }
                    if (plusJson != null && plusJson.containsKey("renderer")) {
                        BaseInfo.renderer = plusJson.getString("renderer");
                    }
                }
            } catch (Exception e3) {
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0058  */
    /* JADX WARNING: Removed duplicated region for block: B:41:? A[RETURN, SYNTHETIC] */
    private InputStream getAppFileStream(Context context, String appid, String fileName) {
        boolean useSdcardPath;
        String filePath;
        String rootPath;
        InputStream inputStream = null;
        try {
            AndroidResources.initAndroidResources(context);
            if (TextUtils.isEmpty(appid)) {
                BaseInfo.parseControl();
            } else {
                BaseInfo.sDefaultBootApp = appid;
            }
            if (!BaseInfo.ISDEBUG) {
                if (!DHFile.hasFile()) {
                    useSdcardPath = false;
                    filePath = "apps/" + BaseInfo.sDefaultBootApp + "/www/" + fileName;
                    if (this.isAssetsRes && !BaseInfo.SyncDebug && !SDK.isUniMPSDK()) {
                        inputStream = context.getResources().getAssets().open(filePath);
                    }
                    if (inputStream == null) {
                        return inputStream;
                    }
                    if (useSdcardPath) {
                        rootPath = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + context.getPackageName();
                    } else {
                        rootPath = context.getFilesDir().getPath();
                    }
                    File pathFile = new File(rootPath + "/" + filePath);
                    InputStream fcIStream = null;
                    if (pathFile.exists()) {
                        fcIStream = new FileInputStream(pathFile);
                    } else {
                        try {
                            fcIStream = context.getResources().getAssets().open(filePath);
                        } catch (Exception e) {
                        }
                    }
                    return fcIStream != null ? fcIStream : inputStream;
                }
            }
            useSdcardPath = true;
            filePath = "apps/" + BaseInfo.sDefaultBootApp + "/www/" + fileName;
            try {
                inputStream = context.getResources().getAssets().open(filePath);
            } catch (Exception e2) {
            }
            if (inputStream == null) {
            }
        } catch (Exception e3) {
            e3.printStackTrace();
            return null;
        }
    }

    public void initAppForPath(Context context, String appid) {
        this.isAssetsRes = AppRuntime.isAppResourcesInAssetsPath(context, appid);
    }

    private String handleEncryptionInputStream(InputStream inputStream, Context context, boolean isCode) {
        System.currentTimeMillis();
        if (isCode) {
            inputStream = new UnicodeInputStream(inputStream, Charset.defaultCharset().name());
        }
        byte[] bytes = new byte[0];
        try {
            bytes = IOUtil.getBytes(inputStream);
        } catch (IOException e) {
            e.printStackTrace();
        }
        String configStr = null;
        IConfusionMgr iConfusionMgr = this.mConfusionMgr;
        if (iConfusionMgr != null) {
            configStr = iConfusionMgr.handleEncryption(context.getApplicationContext(), bytes);
        }
        if (TextUtils.isEmpty(configStr)) {
            return new String(bytes);
        }
        return configStr;
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void registerUniappService(Context context, String appid) {
        InputStream inputStream;
        if (self().control.equals(AbsoluteConst.UNI_V3) && (inputStream = self().getAppFileStream(context, appid, "app-config-service.js")) != null) {
            try {
                WXSDKEngine.registerService(this.jsSACName, handleEncryptionInputStream(inputStream, context, false), new HashMap<>());
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public boolean isUniAppAssetsRes() {
        return this.isAssetsRes;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void unRegisterUniappService() {
        WXSDKEngine.unRegisterService(this.jsSACName);
    }

    private void registerReflexWeexPlugin(Context context) {
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_amap.AMapPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex.map.google.GoogleMapPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_scroller.DCScrollerPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_barcode.BarcodePlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.utsplugin.UTSPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_livepusher.LivePusherPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_media.VideoPlayerPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_text.DCWXTextPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_input.DCWXInputRegister", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.gcanvas.GCanvasRegister", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_switch.DCWXSwitchPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_ad.DCWXAdPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        Object sMaps = PlatformUtil.invokeFieldValue("com.taobao.weex.devtools.inspector.elements.android.WXComponentDescriptor", "sClassName", null);
        if (sMaps != null && (sMaps instanceof HashMap)) {
            HashMap<Class, String> map = (HashMap) sMaps;
            map.put(FrescoImageComponent.class, "image");
            map.put(FrescoImageComponentU.class, "image");
            map.put(WXDCWeb.class, "web-view");
            map.put(DCWXView.class, WXBasicComponentType.VIEW);
            map.put(DCCoverViewComponent.class, "cover-view");
            map.put(DCWXSlider.class, WXBasicComponentType.SLIDER);
        }
    }

    public void addComponentByName(String name, Class component) {
        try {
            Object sMaps = PlatformUtil.invokeFieldValue("com.taobao.weex.devtools.inspector.elements.android.WXComponentDescriptor", "sClassName", null);
            if (sMaps != null && (sMaps instanceof HashMap)) {
                ((HashMap) sMaps).put(component, name);
            }
        } catch (Exception e) {
        }
    }

    private String getConfigParam() {
        JSONObject param = new JSONObject();
        param.put("__HtMl_Id__", (Object) "__uniapp_webview");
        param.put("platform", (Object) 1);
        param.put("debug", (Object) true);
        JSONObject osParam = new JSONObject();
        osParam.put("language", (Object) LanguageUtil.getDeviceDefLocalLanguage());
        osParam.put("version", (Object) Build.VERSION.RELEASE);
        osParam.put("name", (Object) "Android");
        osParam.put("vendor", (Object) "Google");
        param.put("os", (Object) osParam);
        JSONObject networkinfoParam = new JSONObject();
        networkinfoParam.put("CONNECTION_TYPE", (Object) 0);
        param.put("networkinfo", (Object) networkinfoParam);
        return param.toJSONString();
    }

    public WXViewWrapper createWeexView(IWebview webview, ViewGroup parentView, org.json.JSONObject itme, String weexId, int zIndex) {
        WXViewWrapper wrapper = makeWXViewWrapper(webview, parentView, itme, weexId, zIndex);
        wrapper.loadTemplate(itme);
        return wrapper;
    }

    private WXViewWrapper makeWXViewWrapper(IWebview webview, ViewGroup parentView, org.json.JSONObject itme, String weexId, int zIndex) {
        boolean isPre = false;
        if (!(!weexId.equals("__uniapp__service") || this.mPreUniAppid == null || WXSDKManager.getInstance().getSDKInstance(this.mPreInstanceId) == null)) {
            isPre = true;
        }
        WXViewWrapper listener = new WXViewWrapper(webview, parentView, itme, weexId, zIndex, isPre);
        if (this.instanceHashMap.containsKey(weexId)) {
            this.instanceHashMap.remove(weexId).mWXSDKInstance.destroy();
        }
        this.instanceHashMap.put(weexId, listener);
        return listener;
    }

    public WXServiceWrapper createWeexService(IApp app, ViewGroup parentView, String weexId, org.json.JSONObject data) {
        WXServiceWrapper serviceWrapper = new WXServiceWrapper(app, parentView, weexId, data);
        this.serviceWrapperMapsCache.put(weexId, serviceWrapper);
        return serviceWrapper;
    }

    /* access modifiers changed from: package-private */
    public WXViewWrapper findWXViewWrapper(String weexId) {
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId);
        }
        return null;
    }

    public WXServiceWrapper findWXServiceWrapper(WXSDKInstance instance2) {
        if (this.serviceWrapperMapsCache.size() <= 0) {
            return null;
        }
        for (String key : this.serviceWrapperMapsCache.keySet()) {
            WXServiceWrapper serviceWrapper = this.serviceWrapperMapsCache.get(key);
            if (serviceWrapper != null && serviceWrapper.mWXSDKInstance == instance2) {
                return serviceWrapper;
            }
        }
        return null;
    }

    public void reloadWXServiceWrapper() {
        if (this.serviceWrapperMapsCache.size() > 0) {
            for (String key : this.serviceWrapperMapsCache.keySet()) {
                WXServiceWrapper serviceWrapper = this.serviceWrapperMapsCache.get(key);
                if (serviceWrapper != null) {
                    serviceWrapper.reload();
                }
            }
        }
    }

    public WXSDKInstance findWXSDKInstance(String weexId) {
        if (this.serviceWrapperMapsCache.containsKey(weexId)) {
            return this.serviceWrapperMapsCache.get(weexId).mWXSDKInstance;
        }
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId).mWXSDKInstance;
        }
        return null;
    }

    /* access modifiers changed from: package-private */
    public WXBaseWrapper findWXBaseWrapper(String weexId) {
        if (this.serviceWrapperMapsCache.containsKey(weexId)) {
            return this.serviceWrapperMapsCache.get(weexId);
        }
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId);
        }
        return null;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r9v0, resolved type: io.dcloud.common.DHInterface.IApp */
    /* JADX WARN: Multi-variable type inference failed */
    public IWebview findWebview(IWebview webview, IApp app, String appid, String webviewid) {
        AbsMgr absMgr = this.featureMgr;
        IMgr.MgrType mgrType = IMgr.MgrType.FeatureMgr;
        Object[] objArr = new Object[4];
        objArr[0] = webview != null ? webview : app;
        objArr[1] = AbsoluteConst.F_UI;
        objArr[2] = "findWebview";
        objArr[3] = new String[]{appid, webviewid};
        Object obj = absMgr.processEvent(mgrType, 10, objArr);
        if (obj instanceof IWebview) {
            return (IWebview) obj;
        }
        return null;
    }

    public Object doForFeature(IMgr.MgrType type, int event, Object[] args) {
        AbsMgr absMgr = this.featureMgr;
        if (absMgr != null) {
            return absMgr.processEvent(type, event, args);
        }
        return null;
    }

    public WXBaseWrapper findWXBaseWrapper(WXSDKInstance instance2) {
        WXBaseWrapper wrapper = null;
        for (String webid : this.instanceHashMap.keySet()) {
            WXBaseWrapper item = this.instanceHashMap.get(webid);
            if (item != null && item.mWXSDKInstance == instance2) {
                wrapper = item;
            }
        }
        return wrapper;
    }

    public IWebview findWebview(WXSDKInstance instance2) {
        for (String webid : this.instanceHashMap.keySet()) {
            WXViewWrapper wrapper = this.instanceHashMap.get(webid);
            if (wrapper != null && wrapper.mWXSDKInstance == instance2) {
                return wrapper.mWebview;
            }
        }
        return null;
    }

    public IWebview findWebviewByInstanceId(String instanceId) {
        for (String webid : this.instanceHashMap.keySet()) {
            WXViewWrapper wrapper = this.instanceHashMap.get(webid);
            if (wrapper != null && wrapper.mWXSDKInstance.getInstanceId().equals(instanceId)) {
                return wrapper.mWebview;
            }
        }
        return null;
    }

    public WXViewWrapper findPathByWrapper(String byPath) {
        if (!TextUtils.isEmpty(byPath)) {
            for (String webid : this.instanceHashMap.keySet()) {
                WXViewWrapper wxv = this.instanceHashMap.get(webid);
                String srcPath = wxv.initSrcPath(byPath);
                String path = wxv.getSrcPath();
                if (!(wxv == null || TextUtils.isEmpty(path) || !path.equals(srcPath))) {
                    return wxv;
                }
            }
        }
        return null;
    }

    public void removeWeexView(String weexId) {
        if (this.instanceHashMap.containsKey(weexId)) {
            this.instanceHashMap.remove(weexId).onDestroy();
        }
    }

    /* access modifiers changed from: package-private */
    public void onActivityResume() {
        forEach(new EachListener<WXBaseWrapper>() {
            /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass2 */

            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityResume();
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onActivityPause() {
        forEach(new EachListener<WXBaseWrapper>() {
            /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass3 */

            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityPause();
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onActivityResult(final int requestCode, final int resultCode, final Intent data) {
        forEach(new EachListener<WXBaseWrapper>() {
            /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass4 */

            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityResult(requestCode, resultCode, data);
            }
        });
    }

    /* access modifiers changed from: package-private */
    public void onActivityDestroy() {
        onActivityDestroy(true);
    }

    /* access modifiers changed from: package-private */
    public void onActivityDestroy(boolean isDelay) {
        this.mPreUniAppid = null;
        this.mPreInstanceId = null;
        if (this.instanceHashMap.size() > 0 || this.serviceWrapperMapsCache.size() > 0) {
            if (isDelay) {
                getHandler().postDelayed(new Runnable() {
                    /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass5 */

                    public void run() {
                        WeexInstanceMgr.this.wrapperDestroy();
                    }
                }, 200);
            } else {
                getHandler().post(new Runnable() {
                    /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass6 */

                    public void run() {
                        WeexInstanceMgr.this.wrapperDestroy();
                    }
                });
            }
        }
        this.mPreUniMPCallBackMap.clear();
        this.mApplication = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void wrapperDestroy() {
        forEach(new EachListener<WXBaseWrapper>() {
            /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass7 */

            public void onEach(WXBaseWrapper wrapper) {
                if (wrapper != null) {
                    wrapper.onDestroy();
                }
            }
        });
        this.instanceHashMap.clear();
        this.serviceWrapperMapsCache.clear();
        if (SDK.isUniMPSDK()) {
            reloadWeexEngine();
        }
    }

    private void reloadWeexEngine() {
        unRegisterUniappService();
        WXSDKEngine.reload();
    }

    private void forEach(EachListener listener) {
        try {
            Collection<WXViewWrapper> instances = this.instanceHashMap.values();
            if (instances != null) {
                for (WXViewWrapper wrapper : instances) {
                    if (wrapper != null) {
                        listener.onEach(wrapper);
                    }
                }
            }
            Collection<WXServiceWrapper> serviceWrappers = this.serviceWrapperMapsCache.values();
            if (serviceWrappers != null) {
                for (WXServiceWrapper serviceWrapper : serviceWrappers) {
                    if (serviceWrapper != null) {
                        listener.onEach(serviceWrapper);
                    }
                }
            }
        } catch (Exception e) {
            Logger.e("forEach---" + e.getMessage());
        }
    }

    public void weexDebugReload() {
        LinkedHashMap<String, WXViewWrapper> linkedHashMap = this.instanceHashMap;
        if (linkedHashMap != null && linkedHashMap.size() > 0) {
            Iterator<String> it = this.instanceHashMap.keySet().iterator();
            if (it.hasNext()) {
                this.instanceHashMap.get(it.next()).mWebview.obtainFrameView().obtainWindowMgr().processEvent(IMgr.MgrType.AppMgr, 3, "snc:CID");
            }
        }
    }

    public void onRequestPermissionsResult(final int requestCode, final String[] permissions, final int[] grantResults) {
        forEach(new EachListener<WXBaseWrapper>() {
            /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass8 */

            public void onEach(WXBaseWrapper wrapper) {
                if (wrapper != null) {
                    wrapper.onRequestPermissionsResult(requestCode, permissions, grantResults);
                }
            }
        });
    }

    public String getComplier() {
        return this.complier;
    }

    public String getControl() {
        return this.control;
    }

    public int getVueVersion() {
        return this.mVueVersion;
    }

    public boolean isWeexInitEnd() {
        return this.isWeexInitEnd;
    }

    public void setWeexInitEnd(boolean isEnd) {
        this.isWeexInitEnd = isEnd;
    }

    public void setJsFrameworkReady(boolean isReady) {
        this.isJsFrameworkReady = isReady;
    }

    public boolean isJsFrameworkReady() {
        return this.isJsFrameworkReady;
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onSDKEngineInitialize() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onJsFrameworkStart() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onJsFrameworkReady() {
        this.isJsFrameworkReady = true;
        if (this.mRestartReadyCall != null) {
            MessageHandler.sendMessage(new MessageHandler.IMessages() {
                /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass9 */

                @Override // io.dcloud.common.adapter.util.MessageHandler.IMessages
                public void execute(Object pArgs) {
                    WeexInstanceMgr.this.mRestartReadyCall.onCallBack(1, null);
                    WeexInstanceMgr.this.mRestartReadyCall = null;
                }
            }, null);
        }
        ArrayList<IWXStatisticsCallBack> arrayList = this.callBacks;
        if (arrayList != null) {
            Iterator<IWXStatisticsCallBack> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onJsFrameworkReady();
            }
        }
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onFirstView() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onFirstScreen() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHttpStart() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHeadersReceived() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHttpFinish() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onException(String instanceid, String errCode, String msg) {
    }

    public void setWXStatisticsCallBack(IWXStatisticsCallBack callBack) {
        if (!this.callBacks.contains(callBack)) {
            this.callBacks.add(callBack);
        }
    }

    public void unWXStatisticsCallBack(IWXStatisticsCallBack callBack) {
        if (this.callBacks.contains(callBack)) {
            this.callBacks.remove(callBack);
        }
    }

    public boolean isUniServiceCreated(IApp app) {
        String nvueLaunchMode = app.obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
        if (!TextUtils.isEmpty(nvueLaunchMode) && !nvueLaunchMode.equals("fast") && getControl().equals(AbsoluteConst.UNI_V3)) {
            return this.isUniServiceCreated;
        }
        if (!getControl().equals(Constants.CodeCache.SAVE_PATH)) {
            return true;
        }
        return this.isUniServiceCreated;
    }

    public String getPreInstanceId() {
        return this.mPreInstanceId;
    }

    public String getPreUniAppid() {
        return this.mPreUniAppid;
    }

    public void setUniServiceCreated(boolean is, IApp app) {
        this.isUniServiceCreated = is;
        String nvueLaunchMode = "fast";
        if (app != null) {
            String mode = app.obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
            if (!TextUtils.isEmpty(mode)) {
                nvueLaunchMode = mode;
            }
        }
        if ((getControl().equals(Constants.CodeCache.SAVE_PATH) || (!nvueLaunchMode.equals("fast") && getControl().equals(AbsoluteConst.UNI_V3))) && this.isUniServiceCreated) {
            for (String webid : this.instanceHashMap.keySet()) {
                WXViewWrapper wrapper = this.instanceHashMap.get(webid);
                if (wrapper != null && !wrapper.isService) {
                    wrapper.runDelayedRenderCaches(wrapper.getWaitServiceRenderList());
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void preUniControlService(Application context, String appid) {
        this.isUniServiceCreated = true;
        this.mPreUniAppid = appid;
        WXSDKInstance wxsdkInstance = new UniSDKInstance(context);
        this.mPreInstanceId = wxsdkInstance.getInstanceId();
        String template = getUniFileStr(context, appid, "app-service.js");
        String configJs = getUniFileStr(context, appid, "app-config.js");
        Map<String, Object> options = new HashMap<>();
        options.put("plus_appid", appid);
        options.put("preload", true);
        options.put("bundleUrl", "app-service.js");
        org.json.JSONObject jsonObject = new org.json.JSONObject();
        wxsdkInstance.render("__uniapp__service", (configJs + template + " plus.weexBridge.preloadReady('" + appid + "');").replaceFirst(Pattern.quote("\"use weex:vue\""), Matcher.quoteReplacement("")), options, jsonObject.toString(), WXRenderStrategy.APPEND_ASYNC);
        String str = this.TAG;
        StringBuilder sb2 = new StringBuilder();
        sb2.append("preUniControlService------");
        sb2.append(appid);
        Logger.e(str, sb2.toString());
    }

    private String getUniFileStr(Context context, String appid, String fileName) {
        try {
            return IOUtil.toString(getAppFileStream(context, appid, fileName));
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
    }

    public ICallBack getPreUniMPCallBack(String appid) {
        if (this.mPreUniMPCallBackMap.containsKey(appid)) {
            return this.mPreUniMPCallBackMap.remove(appid);
        }
        return null;
    }

    public void preUniMP(final Application context, final String appid, ICallBack iCallBack) {
        if (TextUtils.isEmpty(this.mPreUniAppid) || iCallBack == null) {
            if (iCallBack != null) {
                this.mPreUniMPCallBackMap.put(appid, iCallBack);
            }
            if (isWeexInitEnd()) {
                restartWeex(context, new ICallBack() {
                    /* class io.dcloud.feature.weex.WeexInstanceMgr.AnonymousClass10 */

                    @Override // io.dcloud.common.DHInterface.ICallBack
                    public Object onCallBack(int pType, Object pArgs) {
                        if (pType != 1) {
                            return null;
                        }
                        WeexInstanceMgr.this.preUniControlService(context, appid);
                        return null;
                    }
                }, appid);
                return;
            }
            initWeexEnv(context);
            preUniControlService(context, appid);
            return;
        }
        iCallBack.onCallBack(TXEAudioDef.TXE_AUDIO_PLAY_ERR_INVALID_STATE, "");
    }

    private Handler getHandler() {
        if (this.mHandler == null) {
            this.mHandler = new Handler(Looper.getMainLooper());
        }
        return this.mHandler;
    }

    private void clearHandler() {
        if (this.mHandler != null) {
            this.mHandler = null;
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void initUniappPlugin(Application application) {
        UniMoudlesLoader.getInstance().onCreate(application);
    }

    public boolean isJSFKFileNotFound() {
        return this.isJSFKFileNotFound;
    }

    public void setJSFKFileNotFound(boolean JSFKFileNotFound) {
        this.isJSFKFileNotFound = JSFKFileNotFound;
    }
}
