package io.dcloud.feature.weex.adapter;

import android.net.Uri;
import android.util.Base64;
import com.alibaba.fastjson.JSONArray;
import com.facebook.imagepipeline.producers.HttpUrlConnectionNetworkFetcher;
import com.igexin.push.core.b;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.http.WXStreamModule;
import com.tencent.connect.common.Constants;
import dc.squareup.okhttp3.ConnectionPool;
import dc.squareup.okhttp3.MediaType;
import dc.squareup.okhttp3.OkHttpClient;
import dc.squareup.okhttp3.Protocol;
import dc.squareup.okhttp3.Request;
import dc.squareup.okhttp3.RequestBody;
import dc.squareup.okhttp3.Response;
import dc.squareup.okhttp3.internal.tls.OkHostnameVerifier;
import io.dcloud.common.adapter.util.DCOKDns;
import io.dcloud.common.adapter.util.DCloudTrustManager;
import io.dcloud.common.util.net.NetWork;
import io.dcloud.feature.weex.config.AndroidTlsConfig;
import io.dcloud.feature.weex.config.UserCustomTrustManager;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.SSLSocketFactory;
import org.apache.http.conn.ssl.X509HostnameVerifier;

public class DCWXHttpAdapter implements IWXHttpAdapter {
    private static ConnectionPool mConnectPool;
    private static SSLSocketFactory sslSocketFactory;
    private ExecutorService mExecutorService;

    private void execute(Runnable runnable) {
        if (this.mExecutorService == null) {
            this.mExecutorService = Executors.newFixedThreadPool(10);
        }
        this.mExecutorService.execute(runnable);
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter
    public void sendRequest(final WXRequest request, final IWXHttpAdapter.OnHttpListener listener) {
        if (listener != null) {
            listener.onHttpStart();
        }
        execute(new Runnable() {
            /* class io.dcloud.feature.weex.adapter.DCWXHttpAdapter.AnonymousClass1 */

            public void run() {
                WXSDKInstance instance = WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId);
                if (instance != null && !instance.isDestroy()) {
                    instance.getApmForInstance().actionNetRequest();
                }
                boolean isNetRequestSucceed = true;
                WXResponse response = new WXResponse();
                try {
                    OkHttpClient.Builder httpBuilder = new OkHttpClient.Builder();
                    Response okResponse = httpBuilder.build().newCall(DCWXHttpAdapter.this.getOKRequest(httpBuilder, request, listener)).execute();
                    Map<String, List<String>> headerMap = okResponse.headers().toMultimap();
                    int responseCode = okResponse.code();
                    response.statusCode = String.valueOf(responseCode);
                    if (listener != null) {
                        listener.onHeadersReceived(responseCode, headerMap);
                    }
                    if (okResponse.isSuccessful()) {
                        response.originalData = DCWXHttpAdapter.this.readInputStreamAsBytes(okResponse.body().byteStream(), listener);
                    } else {
                        response.errorMsg = DCWXHttpAdapter.this.readInputStream(okResponse.body().byteStream(), listener);
                        isNetRequestSucceed = false;
                    }
                    if (listener != null) {
                        listener.onHttpFinish(response);
                    }
                } catch (Exception e) {
                    isNetRequestSucceed = false;
                    e.printStackTrace();
                    response.statusCode = "-1";
                    response.errorCode = "-1";
                    response.errorMsg = e.getMessage();
                    IWXHttpAdapter.OnHttpListener onHttpListener = listener;
                    if (onHttpListener != null) {
                        onHttpListener.onHttpFinish(response);
                    }
                }
                if (instance != null && !instance.isDestroy()) {
                    instance.getApmForInstance().actionNetResult(isNetRequestSucceed, null);
                }
            }
        });
    }

    public Request getOKRequest(OkHttpClient.Builder httpBuilder, WXRequest request, IWXHttpAdapter.OnHttpListener listener) {
        httpBuilder.connectTimeout((long) request.timeoutMs, TimeUnit.MILLISECONDS).readTimeout((long) request.timeoutMs, TimeUnit.MILLISECONDS).writeTimeout((long) request.timeoutMs, TimeUnit.MILLISECONDS).callTimeout((long) request.timeoutMs, TimeUnit.MILLISECONDS).protocols(Collections.singletonList(Protocol.HTTP_1_1));
        if (request.isFirstIpv4) {
            httpBuilder.dns(new DCOKDns());
        }
        String requestHost = Uri.parse(request.url).getHost();
        if (request.tls != null) {
            AndroidTlsConfig androidTlsConfig = new AndroidTlsConfig();
            androidTlsConfig.setKeystore(request.tls.getString("keystore"));
            androidTlsConfig.setStorePass(request.tls.getString("storePass"));
            JSONArray caArray = request.tls.getJSONArray(b.Z);
            String[] caParam = null;
            if (caArray != null) {
                caParam = (String[]) caArray.toArray(new String[0]);
            }
            androidTlsConfig.setCa(caParam);
            httpBuilder.sslSocketFactory(UserCustomTrustManager.getSSLSocketFactory(androidTlsConfig, WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId)));
            httpBuilder.hostnameVerifier(OkHostnameVerifier.INSTANCE);
        } else if (WXStreamModule.certMap != null && WXStreamModule.certMap.containsKey(requestHost)) {
            httpBuilder.sslSocketFactory(UserCustomTrustManager.getSSLSocketFactory(WXStreamModule.certMap.get(requestHost), WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId)));
            httpBuilder.hostnameVerifier(OkHostnameVerifier.INSTANCE);
        } else if (request.sslVerify) {
            try {
                if (sslSocketFactory == null) {
                    sslSocketFactory = DCloudTrustManager.getSSLSocketFactory();
                }
                if (sslSocketFactory != null) {
                    httpBuilder.sslSocketFactory(sslSocketFactory);
                }
            } catch (NoSuchAlgorithmException e) {
                e.printStackTrace();
            } catch (KeyManagementException e2) {
                e2.printStackTrace();
            }
            httpBuilder.hostnameVerifier(getHostnameVerifier(request.sslVerify));
        }
        if (mConnectPool == null) {
            mConnectPool = new ConnectionPool();
        }
        httpBuilder.connectionPool(mConnectPool);
        Request.Builder builder = new Request.Builder();
        builder.url(request.url);
        String contentType = "application/x-www-form-urlencoded";
        if (request.paramMap != null) {
            for (String key : request.paramMap.keySet()) {
                if (key.equalsIgnoreCase(NetWork.CONTENT_TYPE)) {
                    contentType = request.paramMap.get(key);
                }
                builder.addHeader(key, request.paramMap.get(key));
            }
        }
        if (Constants.HTTP_POST.equals(request.method) || "PUT".equals(request.method) || "PATCH".equals(request.method) || "DELETE".equals(request.method)) {
            if (!(request.body == null || listener == null)) {
                listener.onHttpUploadProgress(0);
            }
            if ("BASE64".equalsIgnoreCase(request.inputType)) {
                builder.method(request.method, RequestBody.createWithBytes(MediaType.parse(contentType), Base64.decode(request.body, 2)));
                if (listener != null) {
                    listener.onHttpUploadProgress(100);
                }
            } else {
                builder.method(request.method, RequestBody.create(MediaType.parse(contentType), request.body));
                if (listener != null) {
                    listener.onHttpUploadProgress(100);
                }
            }
        } else if ("HEAD".equals(request.method)) {
            builder.head();
        }
        return builder.build();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private byte[] readInputStreamAsBytes(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        ByteArrayOutputStream buffer = new ByteArrayOutputStream();
        int readCount = 0;
        byte[] data = new byte[2048];
        while (true) {
            int nRead = inputStream.read(data, 0, data.length);
            if (nRead != -1) {
                buffer.write(data, 0, nRead);
                readCount += nRead;
                if (listener != null) {
                    listener.onHttpResponseProgress(readCount);
                }
            } else {
                buffer.flush();
                return buffer.toByteArray();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String readInputStream(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        StringBuilder builder = new StringBuilder();
        BufferedReader localBufferedReader = new BufferedReader(new InputStreamReader(inputStream));
        char[] data = new char[2048];
        while (true) {
            int len = localBufferedReader.read(data);
            if (len != -1) {
                builder.append(data, 0, len);
                if (listener != null) {
                    listener.onHttpResponseProgress(builder.length());
                }
            } else {
                localBufferedReader.close();
                return builder.toString();
            }
        }
    }

    public X509HostnameVerifier getHostnameVerifier(boolean sslVerify) {
        if (!sslVerify) {
            return org.apache.http.conn.ssl.SSLSocketFactory.BROWSER_COMPATIBLE_HOSTNAME_VERIFIER;
        }
        return org.apache.http.conn.ssl.SSLSocketFactory.ALLOW_ALL_HOSTNAME_VERIFIER;
    }

    public OkHttpClient getImageOkHttpClient() {
        OkHttpClient.Builder httpBuilder = new OkHttpClient.Builder();
        httpBuilder.connectTimeout((long) HttpUrlConnectionNetworkFetcher.HTTP_DEFAULT_TIMEOUT, TimeUnit.MILLISECONDS).readTimeout((long) HttpUrlConnectionNetworkFetcher.HTTP_DEFAULT_TIMEOUT, TimeUnit.MILLISECONDS).writeTimeout((long) HttpUrlConnectionNetworkFetcher.HTTP_DEFAULT_TIMEOUT, TimeUnit.MILLISECONDS).callTimeout((long) HttpUrlConnectionNetworkFetcher.HTTP_DEFAULT_TIMEOUT, TimeUnit.MILLISECONDS).protocols(Collections.singletonList(Protocol.HTTP_1_1));
        return httpBuilder.build();
    }
}
