package io.dcloud.feature.weex.adapter;

import android.os.Build;
import android.text.TextUtils;
import android.util.Base64;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.appfram.websocket.IWebSocketAdapter;
import com.taobao.weex.appfram.websocket.WebSocketCloseCodes;
import dc.squareup.okhttp3.ConnectionPool;
import dc.squareup.okhttp3.ConnectionSpec;
import dc.squareup.okhttp3.Headers;
import dc.squareup.okhttp3.OkHttpClient;
import dc.squareup.okhttp3.Request;
import dc.squareup.okhttp3.Response;
import dc.squareup.okhttp3.WebSocket;
import dc.squareup.okhttp3.WebSocketListener;
import dc.squareup.okio.ByteString;
import io.dcloud.common.adapter.util.DCloudTrustManager;
import io.dcloud.common.util.ThrottleUtil;
import java.io.EOFException;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.SSLSocketFactory;

public class DefaultWebSocketAdapter implements IWebSocketAdapter {
    private static ConnectionPool mConnectPool;
    private IWebSocketAdapter.EventListener eventListener;
    private ThrottleUtil throttleUtil = null;
    private WebSocket ws;

    @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter
    public void connect(String url, String protocol, IWebSocketAdapter.EventListener listener) {
        SSLSocketFactory factory;
        this.eventListener = listener;
        OkHttpClient.Builder clientBuilder = new OkHttpClient.Builder();
        try {
            if (Build.VERSION.SDK_INT < 21) {
                factory = DCloudTrustManager.getSSLSocketFactory("TLSv1.2");
                if (factory != null) {
                    clientBuilder.connectionSpecs(Arrays.asList(ConnectionSpec.MODERN_TLS, ConnectionSpec.COMPATIBLE_TLS, ConnectionSpec.CLEARTEXT));
                }
            } else {
                factory = DCloudTrustManager.getSSLSocketFactory();
            }
            if (factory != null) {
                clientBuilder.sslSocketFactory(factory);
            }
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        } catch (KeyManagementException e2) {
            e2.printStackTrace();
        }
        clientBuilder.readTimeout(24, TimeUnit.HOURS);
        clientBuilder.writeTimeout(24, TimeUnit.HOURS);
        clientBuilder.hostnameVerifier(DCloudTrustManager.getHostnameVerifier(false));
        Request.Builder builder = new Request.Builder();
        if (!TextUtils.isEmpty(protocol)) {
            builder.addHeader(IWebSocketAdapter.HEADER_SEC_WEBSOCKET_PROTOCOL, protocol);
        }
        builder.addHeader("Origin", "http://localhost");
        builder.url(url);
        clientBuilder.build().newWebSocket(builder.build(), new WebSocketListener() {
            /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass1 */

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onOpen(WebSocket webSocket, Response response) {
                super.onOpen(webSocket, response);
                DefaultWebSocketAdapter.this.ws = webSocket;
                DefaultWebSocketAdapter.this.eventListener.onOpen();
                Headers wsHeaders = response.headers();
                Map<String, String> headers = new HashMap<>();
                for (String name : wsHeaders.names()) {
                    headers.put(name, wsHeaders.values(name).toString());
                }
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onMessage(WebSocket webSocket, String text) {
                super.onMessage(webSocket, text);
                DefaultWebSocketAdapter.this.eventListener.onMessage(text);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onMessage(WebSocket webSocket, ByteString bytes) {
                super.onMessage(webSocket, bytes);
                String base64Str = Base64.encodeToString(bytes.toByteArray(), 2);
                JSONObject object = new JSONObject();
                object.put("@type", (Object) "binary");
                object.put("base64", (Object) base64Str);
                DefaultWebSocketAdapter.this.eventListener.onMessage(object.toJSONString());
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onClosing(WebSocket webSocket, final int code, final String reason) {
                super.onClosing(webSocket, code, reason);
                if (DefaultWebSocketAdapter.this.throttleUtil == null) {
                    DefaultWebSocketAdapter.this.throttleUtil = new ThrottleUtil();
                }
                DefaultWebSocketAdapter.this.throttleUtil.throttlePost(new Runnable() {
                    /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass1.AnonymousClass1 */

                    public void run() {
                        DefaultWebSocketAdapter.this.eventListener.onClose(code, reason, true);
                    }
                }, 10);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onClosed(WebSocket webSocket, final int code, final String reason) {
                super.onClosed(webSocket, code, reason);
                if (DefaultWebSocketAdapter.this.throttleUtil == null) {
                    DefaultWebSocketAdapter.this.throttleUtil = new ThrottleUtil();
                }
                DefaultWebSocketAdapter.this.throttleUtil.throttlePost(new Runnable() {
                    /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass1.AnonymousClass2 */

                    public void run() {
                        DefaultWebSocketAdapter.this.eventListener.onClose(code, reason, true);
                    }
                }, 10);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onFailure(WebSocket webSocket, Throwable t, Response response) {
                super.onFailure(webSocket, t, response);
                if (t instanceof EOFException) {
                    DefaultWebSocketAdapter.this.eventListener.onClose(WebSocketCloseCodes.CLOSE_NORMAL.getCode(), WebSocketCloseCodes.CLOSE_NORMAL.name(), true);
                } else {
                    DefaultWebSocketAdapter.this.eventListener.onError(t.getMessage());
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter
    public void connect(String url, String protocol, String headerJson, IWebSocketAdapter.EventListener listener) {
        Map<String, String> headMaps;
        SSLSocketFactory factory;
        this.eventListener = listener;
        OkHttpClient.Builder clientBuilder = new OkHttpClient.Builder();
        try {
            if (Build.VERSION.SDK_INT < 21) {
                factory = DCloudTrustManager.getSSLSocketFactory("TLSv1.2");
                if (factory != null) {
                    clientBuilder.connectionSpecs(Arrays.asList(ConnectionSpec.MODERN_TLS, ConnectionSpec.COMPATIBLE_TLS, ConnectionSpec.CLEARTEXT));
                }
            } else {
                factory = DCloudTrustManager.getSSLSocketFactory();
            }
            if (factory != null) {
                clientBuilder.sslSocketFactory(factory);
            }
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        } catch (KeyManagementException e2) {
            e2.printStackTrace();
        }
        clientBuilder.readTimeout(24, TimeUnit.HOURS);
        clientBuilder.writeTimeout(24, TimeUnit.HOURS);
        if (mConnectPool == null) {
            mConnectPool = new ConnectionPool();
        }
        clientBuilder.connectionPool(mConnectPool);
        clientBuilder.hostnameVerifier(DCloudTrustManager.getHostnameVerifier(false));
        Request.Builder builder = new Request.Builder();
        if (!TextUtils.isEmpty(protocol)) {
            builder.addHeader(IWebSocketAdapter.HEADER_SEC_WEBSOCKET_PROTOCOL, protocol);
        }
        boolean hasOrigin = false;
        try {
            if (!TextUtils.isEmpty(headerJson) && (headMaps = (Map) JSON.parse(headerJson)) != null) {
                for (Map.Entry<String, String> entry : headMaps.entrySet()) {
                    String key = entry.getKey();
                    String val = entry.getValue();
                    if ("Origin".equals(key)) {
                        hasOrigin = true;
                    }
                    if (!TextUtils.isEmpty(key)) {
                        builder.addHeader(key, val);
                    }
                }
            }
        } catch (Exception e3) {
            e3.printStackTrace();
        }
        if (!hasOrigin) {
            builder.addHeader("Origin", "http://localhost");
        }
        builder.url(url);
        clientBuilder.build().newWebSocket(builder.build(), new WebSocketListener() {
            /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass2 */

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onOpen(WebSocket webSocket, Response response) {
                super.onOpen(webSocket, response);
                DefaultWebSocketAdapter.this.ws = webSocket;
                DefaultWebSocketAdapter.this.eventListener.onOpen();
                Headers wsHeaders = response.headers();
                Map<String, String> headers = new HashMap<>();
                for (String name : wsHeaders.names()) {
                    headers.put(name, wsHeaders.values(name).toString());
                }
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onMessage(WebSocket webSocket, String text) {
                super.onMessage(webSocket, text);
                DefaultWebSocketAdapter.this.eventListener.onMessage(text);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onMessage(WebSocket webSocket, ByteString bytes) {
                super.onMessage(webSocket, bytes);
                String base64Str = Base64.encodeToString(bytes.toByteArray(), 2);
                JSONObject object = new JSONObject();
                object.put("@type", (Object) "binary");
                object.put("base64", (Object) base64Str);
                DefaultWebSocketAdapter.this.eventListener.onMessage(object.toJSONString());
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onClosing(WebSocket webSocket, final int code, final String reason) {
                super.onClosing(webSocket, code, reason);
                if (DefaultWebSocketAdapter.this.throttleUtil == null) {
                    DefaultWebSocketAdapter.this.throttleUtil = new ThrottleUtil();
                }
                DefaultWebSocketAdapter.this.throttleUtil.throttlePost(new Runnable() {
                    /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass2.AnonymousClass1 */

                    public void run() {
                        DefaultWebSocketAdapter.this.eventListener.onClose(code, reason, true);
                    }
                }, 10);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onClosed(WebSocket webSocket, final int code, final String reason) {
                super.onClosed(webSocket, code, reason);
                if (DefaultWebSocketAdapter.this.throttleUtil == null) {
                    DefaultWebSocketAdapter.this.throttleUtil = new ThrottleUtil();
                }
                DefaultWebSocketAdapter.this.throttleUtil.throttlePost(new Runnable() {
                    /* class io.dcloud.feature.weex.adapter.DefaultWebSocketAdapter.AnonymousClass2.AnonymousClass2 */

                    public void run() {
                        DefaultWebSocketAdapter.this.eventListener.onClose(code, reason, true);
                    }
                }, 10);
            }

            @Override // dc.squareup.okhttp3.WebSocketListener
            public void onFailure(WebSocket webSocket, Throwable t, Response response) {
                super.onFailure(webSocket, t, response);
                if (t instanceof EOFException) {
                    DefaultWebSocketAdapter.this.eventListener.onClose(WebSocketCloseCodes.CLOSE_NORMAL.getCode(), WebSocketCloseCodes.CLOSE_NORMAL.name(), true);
                } else {
                    DefaultWebSocketAdapter.this.eventListener.onError(t.getMessage());
                }
            }
        });
    }

    @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter
    public void send(String data) {
        try {
            JSONObject object = JSON.parseObject(data);
            String type = object.getString("@type");
            if (type != null && type.equals("binary") && object.containsKey("base64")) {
                send(object);
                return;
            }
        } catch (Exception e) {
        }
        WebSocket webSocket = this.ws;
        if (webSocket != null) {
            try {
                webSocket.send(data);
            } catch (Exception e2) {
                e2.printStackTrace();
                reportError(e2.getMessage());
            }
        } else {
            reportError("WebSocket is not ready");
        }
    }

    public void send(JSONObject data) {
        if (this.ws != null) {
            try {
                String type = data.getString("@type");
                if (type == null || !type.equals("binary") || !data.containsKey("base64")) {
                    reportError("some error occur");
                    return;
                }
                byte[] base64Byte = Base64.decode(data.getString("base64"), 0);
                if (base64Byte != null) {
                    this.ws.send(ByteString.of(base64Byte));
                    return;
                }
                reportError("some error occur");
            } catch (Exception e) {
                reportError(e.getMessage());
            }
        } else {
            reportError("WebSocket is not ready");
        }
    }

    @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter
    public void close(int code, String reason) {
        WebSocket webSocket = this.ws;
        if (webSocket != null) {
            try {
                webSocket.close(code, reason);
            } catch (Exception e) {
                e.printStackTrace();
                reportError(e.getMessage());
            }
        }
    }

    @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter
    public void destroy() {
        WebSocket webSocket = this.ws;
        if (webSocket != null) {
            try {
                webSocket.close(WebSocketCloseCodes.CLOSE_GOING_AWAY.getCode(), WebSocketCloseCodes.CLOSE_GOING_AWAY.name());
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    private void reportError(String message) {
        IWebSocketAdapter.EventListener eventListener2 = this.eventListener;
        if (eventListener2 != null) {
            eventListener2.onError(message);
        }
    }
}
