package io.dcloud.feature.weex.adapter;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.ImageView;
import com.facebook.common.executors.UiThreadImmediateExecutorService;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.drawee.backends.pipeline.PipelineDraweeControllerBuilder;
import com.facebook.drawee.controller.BaseControllerListener;
import com.facebook.drawee.interfaces.DraweeController;
import com.facebook.drawee.view.DraweeView;
import com.facebook.imagepipeline.common.ImageDecodeOptions;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.image.CloseableStaticBitmap;
import com.facebook.imagepipeline.image.ImageInfo;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.common.WXImageStrategy;
import com.taobao.weex.dom.WXImageQuality;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.weex.adapter.Fresco.DCGenericDraweeHierarchy;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

public class FrescoImageAdapter implements IWXImgLoaderAdapter {
    @Override // com.taobao.weex.adapter.IWXImgLoaderAdapter
    public void setImage(final String url, final ImageView view, final WXImageQuality quality, final WXImageStrategy strategy) {
        if (PdrUtil.isEmpty(url)) {
            if (view != null) {
                view.setImageBitmap(null);
            }
        } else if (strategy == null || strategy.placeHolder == null) {
            WXSDKManager.getInstance().postOnUiThread(new Runnable() {
                /* class io.dcloud.feature.weex.adapter.FrescoImageAdapter.AnonymousClass2 */

                public void run() {
                    FrescoImageAdapter.setImage(url, view, quality, strategy, null);
                }
            }, 0);
        } else {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.weex.adapter.FrescoImageAdapter.AnonymousClass1 */

                public void run() {
                    Logger.d("FrescoImage", "Thread_setImage--" + url);
                    Bitmap x = null;
                    try {
                        if (strategy.placeHolder.startsWith("file")) {
                            x = BitmapFactory.decodeFile(strategy.placeHolder.replaceFirst(DeviceInfo.FILE_PROTOCOL, ""));
                        } else {
                            HttpURLConnection connection = (HttpURLConnection) new URL(strategy.placeHolder).openConnection();
                            connection.connect();
                            x = BitmapFactory.decodeStream(connection.getInputStream());
                        }
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                    final Drawable placeholderDrawable = new BitmapDrawable(x);
                    WXSDKManager.getInstance().postOnUiThread(new Runnable() {
                        /* class io.dcloud.feature.weex.adapter.FrescoImageAdapter.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            FrescoImageAdapter.setImage(url, view, quality, strategy, placeholderDrawable);
                        }
                    }, 0);
                }
            }, true);
        }
    }

    /* access modifiers changed from: private */
    public static void setImage(final String url, final ImageView view, WXImageQuality quality, final WXImageStrategy strategy, Drawable placeholderDrawable) {
        if (view != null && view.getLayoutParams() != null) {
            if (TextUtils.isEmpty(url)) {
                view.setImageBitmap(null);
                return;
            }
            String temp = url;
            if (url.startsWith("//")) {
                temp = "http:" + url;
            }
            ImageRequestBuilder builder = ImageRequestBuilder.newBuilderWithSource(Uri.parse(temp)).setImageDecodeOptions(ImageDecodeOptions.newBuilder().build()).setAutoRotateEnabled(true).setLocalThumbnailPreviewsEnabled(true).setLowestPermittedRequestLevel(ImageRequest.RequestLevel.FULL_FETCH).setProgressiveRenderingEnabled(false);
            if (!strategy.isAutoCompression()) {
                builder.setResizeOptions(new ResizeOptions(Integer.MAX_VALUE, Integer.MAX_VALUE));
            }
            ImageRequest request = builder.build();
            if (view instanceof DraweeView) {
                DraweeController controller = ((PipelineDraweeControllerBuilder) ((PipelineDraweeControllerBuilder) ((PipelineDraweeControllerBuilder) Fresco.newDraweeControllerBuilder().setAutoPlayAnimations(true)).setControllerListener(new BaseControllerListener<ImageInfo>() {
                    /* class io.dcloud.feature.weex.adapter.FrescoImageAdapter.AnonymousClass3 */

                    public void onFinalImageSet(String id, ImageInfo imageInfo, Animatable anim) {
                        WXImageStrategy wXImageStrategy;
                        if (imageInfo != null && (wXImageStrategy = WXImageStrategy.this) != null && wXImageStrategy.getImageListener() != null) {
                            Map<String, Integer> sizeMap = new HashMap<>();
                            sizeMap.put("width", Integer.valueOf(imageInfo.getWidth()));
                            sizeMap.put("height", Integer.valueOf(imageInfo.getHeight()));
                            if (imageInfo.getWidth() > 0) {
                                WXImageStrategy.this.getImageListener().onImageFinish(url, view, true, sizeMap);
                            } else {
                                WXImageStrategy.this.getImageListener().onImageFinish(url, view, false, sizeMap);
                            }
                        }
                    }

                    public void onIntermediateImageSet(String id, ImageInfo imageInfo) {
                        FLog.d("", "Intermediate image received");
                    }

                    @Override // com.facebook.drawee.controller.ControllerListener, com.facebook.drawee.controller.BaseControllerListener
                    public void onFailure(String id, Throwable throwable) {
                        FLog.e(getClass(), throwable, "Error loading %s", id);
                        WXImageStrategy wXImageStrategy = WXImageStrategy.this;
                        if (wXImageStrategy != null && wXImageStrategy.getImageListener() != null) {
                            WXImageStrategy.this.getImageListener().onImageFinish(url, view, false, null);
                        }
                    }
                })).setImageRequest(request)).build();
                if (placeholderDrawable != null) {
                    ((DCGenericDraweeHierarchy) ((FrescoImageView) view).getHierarchy()).setPlaceholderImage(placeholderDrawable);
                }
                ((DraweeView) view).setController(controller);
                return;
            }
            Fresco.getImagePipeline().fetchDecodedImage(request, new Object()).subscribe(new BaseDataSubscriber<CloseableReference<CloseableImage>>() {
                /* class io.dcloud.feature.weex.adapter.FrescoImageAdapter.AnonymousClass4 */

                @Override // com.facebook.datasource.BaseDataSubscriber
                public void onNewResultImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                    CloseableReference<CloseableImage> imageReference = dataSource.getResult();
                    if (imageReference != null) {
                        try {
                            Preconditions.checkState(CloseableReference.isValid(imageReference));
                            CloseableImage closeableImage = imageReference.get();
                            if (closeableImage instanceof CloseableStaticBitmap) {
                                view.setImageBitmap(((CloseableStaticBitmap) closeableImage).getUnderlyingBitmap());
                            }
                            if (!(strategy == null || strategy.getImageListener() == null)) {
                                strategy.getImageListener().onImageFinish(url, view, true, null);
                            }
                        } finally {
                            imageReference.close();
                        }
                    }
                }

                /* JADX DEBUG: Method arguments types fixed to match base method, original types: [com.facebook.datasource.DataSource] */
                @Override // com.facebook.datasource.BaseDataSubscriber
                public void onFailureImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                    WXImageStrategy wXImageStrategy = strategy;
                    if (wXImageStrategy != null && wXImageStrategy.getImageListener() != null) {
                        strategy.getImageListener().onImageFinish(url, view, false, null);
                    }
                }
            }, UiThreadImmediateExecutorService.getInstance());
        }
    }
}
