package io.dcloud.feature.weex.adapter;

import android.content.Context;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.RectF;
import android.text.TextUtils;
import android.widget.ImageView;
import com.facebook.drawee.drawable.ScalingUtils;
import com.facebook.drawee.generic.RoundingParams;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.feature.weex.adapter.Fresco.DCGenericDraweeHierarchy;
import java.util.Map;

public class FrescoImageComponent extends WXImage {
    private int mBitmapHeight = 0;
    private int mBitmapWidth = 0;
    private String mResizeMode = "scaleToFill";

    public FrescoImageComponent(WXSDKInstance instance, WXVContainer parent, final BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        setContentBoxMeasurement(new ContentBoxMeasurement() {
            /* class io.dcloud.feature.weex.adapter.FrescoImageComponent.AnonymousClass1 */

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                boolean isFlex = basicComponentData.getStyles().containsKey(Constants.Name.FLEX);
                this.mMeasureExactly = false;
                if (widthMeasureMode == 0) {
                    if (FrescoImageComponent.this.mResizeMode.equals("heightFix") && FrescoImageComponent.this.mBitmapHeight > 0 && FrescoImageComponent.this.mBitmapWidth > 0 && !Float.isNaN(height)) {
                        this.mMeasureWidth = ((float) FrescoImageComponent.this.mBitmapWidth) * (height / ((float) FrescoImageComponent.this.mBitmapHeight));
                        this.mMeasureExactly = true;
                    } else if (!isFlex) {
                        this.mMeasureWidth = (float) ((int) WXViewUtils.getRealPxByWidth(320.0f, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat()));
                    }
                }
                if (heightMeasureMode != 0) {
                    return;
                }
                if (FrescoImageComponent.this.mResizeMode.equals("widthFix") && FrescoImageComponent.this.mBitmapHeight > 0 && FrescoImageComponent.this.mBitmapWidth > 0 && !Float.isNaN(width)) {
                    this.mMeasureHeight = ((float) FrescoImageComponent.this.mBitmapHeight) * (width / ((float) FrescoImageComponent.this.mBitmapWidth));
                    this.mMeasureExactly = true;
                } else if (!isFlex) {
                    this.mMeasureHeight = (float) ((int) WXViewUtils.getRealPxByWidth(240.0f, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat()));
                }
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public ImageView initComponentHostView(Context context) {
        FrescoImageView view = new FrescoImageView(context);
        ((DCGenericDraweeHierarchy) view.getHierarchy()).setActualImageScaleType(ScalingUtils.ScaleType.FIT_XY);
        return view;
    }

    @WXComponentProp(name = "fadeShow")
    public void setFadeAnim(String v) {
        if (!TextUtils.isEmpty(v) && getHostView() != null) {
            ((FrescoImageView) getHostView()).setFadeShow(Boolean.valueOf(v).booleanValue());
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:18:0x0038  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x0055  */
    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        int hashCode = key.hashCode();
        if (hashCode != -934437708) {
            if (hashCode != 3357091) {
                if (hashCode == 2049757303 && key.equals(Constants.Name.RESIZE_MODE)) {
                    c = 0;
                    if (c != 0) {
                        String resizeMode = WXUtils.getString(param, null);
                        if (resizeMode != null) {
                            setResizeMode(resizeMode);
                        }
                        return true;
                    } else if (c == 1) {
                        String resize = WXUtils.getString(param, null);
                        if (resize != null) {
                            setResizeMode(resize);
                        }
                        return true;
                    } else if (c != 2) {
                        return super.setProperty(key, param);
                    } else {
                        String mode = WXUtils.getString(param, null);
                        if (mode != null) {
                            setResizeMode(mode);
                        }
                        return true;
                    }
                }
            } else if (key.equals("mode")) {
                c = 2;
                if (c != 0) {
                }
            }
        } else if (key.equals("resize")) {
            c = 1;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    @Override // com.taobao.weex.ui.component.WXImage
    public void setResizeMode(String resizeMode) {
        FrescoImageView frescoImageView = (FrescoImageView) getHostView();
        ScalingUtils.ScaleType scaleType = ScalingUtils.ScaleType.FIT_XY;
        this.mResizeMode = resizeMode;
        if (!TextUtils.isEmpty(resizeMode)) {
            char c = 65535;
            switch (resizeMode.hashCode()) {
                case -1881872635:
                    if (resizeMode.equals("stretch")) {
                        c = 2;
                        break;
                    }
                    break;
                case -1687059567:
                    if (resizeMode.equals("top right")) {
                        c = '\f';
                        break;
                    }
                    break;
                case -1614504594:
                    if (resizeMode.equals("heightFix")) {
                        c = 16;
                        break;
                    }
                    break;
                case -1387149201:
                    if (resizeMode.equals("widthFix")) {
                        c = 15;
                        break;
                    }
                    break;
                case -1383228885:
                    if (resizeMode.equals("bottom")) {
                        c = 7;
                        break;
                    }
                    break;
                case -1364013995:
                    if (resizeMode.equals("center")) {
                        c = '\b';
                        break;
                    }
                    break;
                case -1362001767:
                    if (resizeMode.equals("aspectFit")) {
                        c = 4;
                        break;
                    }
                    break;
                case -1024435214:
                    if (resizeMode.equals("top left")) {
                        c = 11;
                        break;
                    }
                    break;
                case -797304696:
                    if (resizeMode.equals("scaleToFill")) {
                        c = 3;
                        break;
                    }
                    break;
                case -667379492:
                    if (resizeMode.equals("bottom left")) {
                        c = '\r';
                        break;
                    }
                    break;
                case 115029:
                    if (resizeMode.equals("top")) {
                        c = 6;
                        break;
                    }
                    break;
                case 3317767:
                    if (resizeMode.equals("left")) {
                        c = '\t';
                        break;
                    }
                    break;
                case 94852023:
                    if (resizeMode.equals(IApp.ConfigProperty.CONFIG_COVER)) {
                        c = 0;
                        break;
                    }
                    break;
                case 108511772:
                    if (resizeMode.equals("right")) {
                        c = '\n';
                        break;
                    }
                    break;
                case 727618043:
                    if (resizeMode.equals("aspectFill")) {
                        c = 5;
                        break;
                    }
                    break;
                case 791733223:
                    if (resizeMode.equals("bottom right")) {
                        c = 14;
                        break;
                    }
                    break;
                case 951526612:
                    if (resizeMode.equals("contain")) {
                        c = 1;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    scaleType = ScalingUtils.ScaleType.CENTER_CROP;
                    break;
                case 1:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
                case 2:
                    scaleType = ScalingUtils.ScaleType.FIT_XY;
                    break;
                case 3:
                    scaleType = ScalingUtils.ScaleType.FIT_XY;
                    break;
                case 4:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
                case 5:
                    scaleType = ScalingUtils.ScaleType.CENTER_CROP;
                    break;
                case 6:
                    scaleType = new CustomScaleType(0.5f, 0.0f);
                    break;
                case 7:
                    scaleType = new CustomScaleType(0.5f, 1.0f);
                    break;
                case '\b':
                    scaleType = new CustomScaleType(0.5f, 0.5f);
                    break;
                case '\t':
                    scaleType = new CustomScaleType(0.0f, 0.5f);
                    break;
                case '\n':
                    scaleType = new CustomScaleType(1.0f, 0.5f);
                    break;
                case 11:
                    scaleType = new CustomScaleType(0.0f, 0.0f);
                    break;
                case '\f':
                    scaleType = new CustomScaleType(1.0f, 0.0f);
                    break;
                case '\r':
                    scaleType = new CustomScaleType(0.0f, 1.0f);
                    break;
                case 14:
                    scaleType = new CustomScaleType(1.0f, 1.0f);
                    break;
                case 15:
                case 16:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
            }
        }
        ((DCGenericDraweeHierarchy) frescoImageView.getHierarchy()).setActualImageScaleType(scaleType);
    }

    @Override // com.taobao.weex.ui.component.WXImage
    public void onImageFinish(boolean result, Map extra) {
        super.onImageFinish(result, extra);
        if (extra != null) {
            String str = this.mResizeMode;
            char c = 65535;
            int hashCode = str.hashCode();
            if (hashCode != -1614504594) {
                if (hashCode == -1387149201 && str.equals("widthFix")) {
                    c = 0;
                }
            } else if (str.equals("heightFix")) {
                c = 1;
            }
            if (c == 0) {
                this.mBitmapWidth = Integer.parseInt(extra.get("width").toString());
                this.mBitmapHeight = Integer.parseInt(extra.get("height").toString());
                float h = ((float) this.mBitmapHeight) * (getLayoutWidth() / ((float) this.mBitmapWidth));
                if (getLayoutHeight() != h) {
                    setStyleHeight(h);
                }
            } else if (c == 1) {
                this.mBitmapWidth = Integer.parseInt(extra.get("width").toString());
                this.mBitmapHeight = Integer.parseInt(extra.get("height").toString());
                float w = ((float) this.mBitmapWidth) * (getLayoutHeight() / ((float) this.mBitmapHeight));
                if (getLayoutWidth() != w) {
                    setStyleWidth(w);
                }
            }
        }
    }

    private void setStyleHeight(final float height) {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class io.dcloud.feature.weex.adapter.FrescoImageComponent.AnonymousClass2 */

            public void run() {
                if (FrescoImageComponent.this.getInstance() != null) {
                    WXBridgeManager.getInstance().setStyleHeight(FrescoImageComponent.this.getInstanceId(), FrescoImageComponent.this.getRef(), height);
                }
            }
        });
    }

    private void setStyleWidth(final float width) {
        WXBridgeManager.getInstance().post(new Runnable() {
            /* class io.dcloud.feature.weex.adapter.FrescoImageComponent.AnonymousClass3 */

            public void run() {
                if (FrescoImageComponent.this.getInstance() != null) {
                    WXBridgeManager.getInstance().setStyleWidth(FrescoImageComponent.this.getInstanceId(), FrescoImageComponent.this.getRef(), width);
                }
            }
        });
    }

    public class CustomScaleType implements ScalingUtils.ScaleType {
        private float dxf;
        private float dyf;

        public CustomScaleType(float dxf2, float dyf2) {
            this.dxf = dxf2;
            this.dyf = dyf2;
        }

        @Override // com.facebook.drawee.drawable.ScalingUtils.ScaleType
        public Matrix getTransform(Matrix outTransform, Rect parentRect, int childWidth, int childHeight, float focusX, float focusY) {
            float scale = WXViewUtils.getRealPxByWidth((float) childWidth, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat()) / ((float) childWidth);
            outTransform.setScale(scale, scale);
            outTransform.postTranslate(((float) parentRect.left) + ((((float) parentRect.width()) - (((float) childWidth) * scale)) * this.dxf), ((float) parentRect.top) + ((((float) parentRect.height()) - (((float) childHeight) * scale)) * this.dyf));
            return outTransform;
        }
    }

    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        if (getHostView() != null) {
            super.updateProperties(props);
            updateBorderRadius();
        }
    }

    private void updateBorderRadius() {
        float[] borderRadius;
        BorderDrawable borderDrawable = WXViewUtils.getBorderDrawable(getHostView());
        RoundingParams roundingParams = new RoundingParams();
        if (borderDrawable != null) {
            borderRadius = borderDrawable.getBorderInnerRadius(new RectF(0.0f, 0.0f, WXDomUtils.getContentWidth(this), WXDomUtils.getContentHeight(this)));
        } else {
            borderRadius = new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
        }
        roundingParams.setCornersRadii(borderRadius);
        ((DCGenericDraweeHierarchy) ((FrescoImageView) getHostView()).getHierarchy()).setRoundingParams(roundingParams);
    }
}
