package io.dcloud.feature.weex.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import com.facebook.cache.common.CacheKey;
import com.facebook.common.executors.UiThreadImmediateExecutorService;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.imagepipeline.bitmaps.PlatformBitmapFactory;
import com.facebook.imagepipeline.image.CloseableBitmap;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.facebook.imagepipeline.request.Postprocessor;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import java.lang.ref.SoftReference;

public class FrescoLoadUtil implements UniImageLoadAdapter {
    private static FrescoLoadUtil inst;
    Handler mHandler = new Handler(Looper.getMainLooper());

    public static UniImageLoadAdapter getInstance() {
        if (inst == null) {
            inst = new FrescoLoadUtil();
        }
        return inst;
    }

    @Override // io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter
    public final void loadImageBitmap(Context context, String url, BitmapLoadCallback<Bitmap> call) {
        loadImageBitmap(context, url, 0, 0, call);
    }

    @Override // io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter
    public final void loadImageBitmap(Context context, String url, int width, int height, BitmapLoadCallback<Bitmap> call) {
        if (!TextUtils.isEmpty(url)) {
            String temp = url;
            if (url.startsWith("//")) {
                temp = "http:" + url;
            }
            try {
                fetch(context, Uri.parse(temp), width, height, call);
            } catch (Exception e) {
                e.printStackTrace();
                call.onFailure(url, e);
            }
        }
    }

    private void fetch(final Context context, final Uri uri, final int newWidth, final int newHeight, final BitmapLoadCallback<Bitmap> callback) {
        ThreadPool.self().addThreadTask(new Runnable() {
            /* class io.dcloud.feature.weex.adapter.FrescoLoadUtil.AnonymousClass1 */

            public void run() {
                ImageRequestBuilder builder = ImageRequestBuilder.newBuilderWithSource(uri).setProgressiveRenderingEnabled(false);
                builder.setPostprocessor(new Postprocessor() {
                    /* class io.dcloud.feature.weex.adapter.FrescoLoadUtil.AnonymousClass1.AnonymousClass1 */

                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public CloseableReference<Bitmap> process(Bitmap sourceBitmap, PlatformBitmapFactory bitmapFactory) {
                        if (newHeight <= 0 || newHeight <= 0) {
                            return bitmapFactory.createBitmap(sourceBitmap);
                        }
                        int sw = sourceBitmap.getWidth();
                        int sh = sourceBitmap.getHeight();
                        Matrix matrix = new Matrix();
                        matrix.postScale(((float) newWidth) / ((float) sw), ((float) newHeight) / ((float) sh));
                        return bitmapFactory.createBitmap(sourceBitmap, 0, 0, sw, sh, matrix, true);
                    }

                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public String getName() {
                        return null;
                    }

                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public CacheKey getPostprocessorCacheKey() {
                        return null;
                    }
                });
                Fresco.getImagePipeline().fetchDecodedImage(builder.build(), context).subscribe(new BaseDataSubscriber<CloseableReference<CloseableImage>>() {
                    /* class io.dcloud.feature.weex.adapter.FrescoLoadUtil.AnonymousClass1.AnonymousClass2 */

                    /* access modifiers changed from: protected */
                    @Override // com.facebook.datasource.BaseDataSubscriber
                    public void onNewResultImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                        CloseableReference<CloseableImage> closeableReference;
                        if (dataSource.isFinished() && (closeableReference = dataSource.getResult()) != null) {
                            Bitmap bitmap = null;
                            try {
                                if (closeableReference.get() instanceof CloseableBitmap) {
                                    bitmap = ((CloseableBitmap) closeableReference.get()).getUnderlyingBitmap();
                                }
                                if (bitmap != null && !bitmap.isRecycled()) {
                                    SoftReference<Bitmap> copyBitmap = new SoftReference<>(Bitmap.createBitmap(bitmap));
                                    if (callback != null) {
                                        callback.onSuccess(uri.toString(), copyBitmap.get());
                                    }
                                }
                            } finally {
                                closeableReference.close();
                                dataSource.close();
                            }
                        }
                    }

                    /* access modifiers changed from: protected */
                    @Override // com.facebook.datasource.BaseDataSubscriber
                    public void onFailureImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                        if (callback != null) {
                            callback.onSuccess(uri.toString(), null);
                        }
                    }
                }, UiThreadImmediateExecutorService.getInstance());
            }
        }, true);
    }
}
