package io.dcloud.feature.weex.adapter;

import android.net.Uri;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.adapter.URIAdapter;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import io.dcloud.feature.weex.WeexInstanceMgr;

public class PlusUriAdapter implements URIAdapter {
    @Override // io.dcloud.feature.uniapp.adapter.AbsURIAdapter
    public Uri rewrite(WXSDKInstance wxsdkInstance, String type, Uri uri) {
        String srcPath;
        if (TextUtils.isEmpty(wxsdkInstance.getBundleUrl()) || PdrUtil.isEmpty(uri)) {
            return uri;
        }
        String basePath = wxsdkInstance.getBundleUrl();
        String srcPath2 = uri.toString();
        if (!uri.isRelative()) {
            return uri;
        }
        if (uri.getEncodedPath().length() == 0) {
            return Uri.parse(basePath);
        }
        IWebview webview = WeexInstanceMgr.self().findWebview(wxsdkInstance);
        if (webview != null) {
            byte mode = webview.obtainApp().obtainRunningAppMode();
            if (srcPath2.startsWith("/storage") || mode != 1) {
                srcPath = webview.obtainApp().convert2WebviewFullPath(basePath, srcPath2);
            } else {
                String url = webview.obtainApp().convert2AbsFullPath(basePath, srcPath2);
                if ("web".equals(type)) {
                    url = webview.obtainApp().convert2WebviewFullPath(basePath, srcPath2);
                }
                if (url.startsWith("/storage/")) {
                    srcPath = webview.obtainApp().convert2WebviewFullPath(basePath, srcPath2);
                } else {
                    if (url.startsWith("/")) {
                        url = url.substring(1, url.length());
                    }
                    if (type.equals(AbsURIAdapter.FONT)) {
                        srcPath = "local:///" + url;
                    } else {
                        srcPath = "asset:///" + url;
                    }
                }
            }
        } else {
            srcPath = standardizedURL(basePath, srcPath2);
        }
        if (basePath.startsWith("/storage")) {
            srcPath = DeviceInfo.FILE_PROTOCOL + srcPath;
        } else if (basePath.startsWith("storage")) {
            srcPath = "file:///" + srcPath;
        }
        return Uri.parse(srcPath);
    }

    @Override // io.dcloud.feature.uniapp.adapter.AbsURIAdapter
    public Uri rewrite(String bundleURL, String type, Uri uri) {
        String srcPath = uri.toString();
        if (!uri.isRelative()) {
            return uri;
        }
        if (uri.getEncodedPath().length() == 0) {
            return Uri.parse(bundleURL);
        }
        return Uri.parse(standardizedURL(bundleURL, srcPath));
    }

    private String standardizedURL(String basePath, String pPath) {
        if (pPath.startsWith("./")) {
            pPath = pPath.substring("./".length());
            int p = basePath.lastIndexOf(47);
            if (p >= 0) {
                return basePath.substring(0, p + 1) + pPath;
            }
        }
        int pos = pPath.indexOf("../");
        int basePos = basePath.lastIndexOf(47);
        if (!(basePos > -1)) {
            return pPath;
        }
        String basePath2 = basePath.substring(0, basePos);
        while (pos > -1) {
            pPath = pPath.substring("../".length());
            basePath2 = basePath2.substring(0, basePath2.lastIndexOf(47));
            pos = pPath.indexOf("../");
        }
        return basePath2 + '/' + pPath;
    }
}
