package io.dcloud.feature.weex.adapter.webview;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.net.Uri;
import android.net.http.SslError;
import android.os.Build;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.GeolocationPermissions;
import android.webkit.JavascriptInterface;
import android.webkit.JsPromptResult;
import android.webkit.PermissionRequest;
import android.webkit.SslErrorHandler;
import android.webkit.ValueCallback;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceError;
import android.webkit.WebResourceRequest;
import android.webkit.WebResourceResponse;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.FrameLayout;
import androidx.core.content.FileProvider;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.dcloud.android.widget.DCWebViewProgressBar;
import com.dcloud.zxing2.common.StringUtils;
import com.igexin.push.f.r;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.view.IWebView;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.base.R;
import io.dcloud.common.DHInterface.IActivityDelegate;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.FileChooseDialog;
import io.dcloud.common.adapter.ui.webview.WebViewFactory;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.ui.blur.AppEventForBlurManager;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex.adapter.webview.WXDCWeb;
import io.dcloud.feature.weex.adapter.webview.video.FullscreenHolder;
import io.src.dcloud.adapter.DCloudAdapterUtil;
import java.io.File;
import java.lang.ref.WeakReference;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

public class DCWXWebView implements IDCWebView {
    private static final String BRIDGE_NAME = "__dcloud_weex_";
    private static final int POST_MESSAGE = 1;
    private static final int POST_MESSAGE_TO_CONTROL = 2;
    private static final int SDK_VERSION = Build.VERSION.SDK_INT;
    DCWXChromeClient chromeClient;
    private View customView;
    private WebChromeClient.CustomViewCallback customViewCallback;
    private int defaultSystemUI = 0;
    private FrameLayout fullscreenContainer;
    private boolean isStart = false;
    private Context mContext;
    private WeakReference<WXDCWeb> mDCWeb;
    private String mDefUserAgent;
    private Handler mMessageHandler;
    private IWebView.OnErrorListener mOnErrorListener;
    private WXDCWeb.OnDCMessageListener mOnMessageListener;
    private IWebView.OnPageListener mOnPageListener;
    private String mOrigin;
    public int mProgress = 0;
    private FrameLayout mRootView;
    private boolean mShowLoading = true;
    String mSslType = "refuse";
    private DCWebViewProgressBar mWebProgressView;
    private WebView mWebView;

    public DCWXWebView(Context context, String origin, WXDCWeb wxdcWeb) {
        this.mContext = context;
        this.mOrigin = origin;
        this.mDCWeb = new WeakReference<>(wxdcWeb);
        IWebview iwb = WeexInstanceMgr.self().findWebview(wxdcWeb.getInstance());
        if (iwb != null && iwb.obtainApp() != null) {
            this.mSslType = iwb.obtainApp().obtainConfigProperty(IApp.ConfigProperty.CONFIG_UNTRUSTEDCA);
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public View getView() {
        FrameLayout frameLayout = new FrameLayout(this.mContext);
        this.mRootView = frameLayout;
        frameLayout.setBackgroundColor(-1);
        this.mWebView = new WebView(this.mContext) {
            /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.AnonymousClass1 */

            /* access modifiers changed from: protected */
            public void onScrollChanged(int l, int t, int oldl, int oldt) {
                super.onScrollChanged(l, t, oldl, oldt);
                AppEventForBlurManager.onScrollChanged(l, t);
            }
        };
        FrameLayout.LayoutParams wvLayoutParams = new FrameLayout.LayoutParams(-1, -1);
        wvLayoutParams.gravity = 17;
        this.mWebView.setLayoutParams(wvLayoutParams);
        this.mRootView.addView(this.mWebView);
        this.mWebView.setBackgroundColor(0);
        initWebView(this.mWebView);
        this.mMessageHandler = new MessageHandler();
        return this.mRootView;
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void destroy() {
        if (getWebView() != null) {
            hideCustomView();
            getWebView().setWebViewClient(null);
            getWebView().setWebChromeClient(null);
            getWebView().removeAllViews();
            getWebView().destroy();
            this.mWebView = null;
            this.mDCWeb.clear();
            this.mOnMessageListener = null;
            this.mWebProgressView = null;
            this.mOnPageListener = null;
            this.mOnErrorListener = null;
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void loadUrl(String url) {
        if (getWebView() != null) {
            getWebView().loadUrl(url);
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void loadDataWithBaseURL(String source) {
        if (getWebView() != null) {
            getWebView().loadDataWithBaseURL(this.mOrigin, source, "text/html", r.b, null);
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void reload() {
        if (getWebView() != null) {
            getWebView().reload();
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void goBack() {
        if (getWebView() != null) {
            getWebView().goBack();
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void goForward() {
        if (getWebView() != null) {
            getWebView().goForward();
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void postMessage(Object msg) {
        if (getWebView() != null) {
            try {
                JSONObject initData = new JSONObject();
                initData.put("type", (Object) "message");
                initData.put("data", msg);
                evaluateJS("javascript:(function () {var initData = " + initData.toString() + ";try {var event = new MessageEvent('onPostMessage', initData);window.dispatchEvent(event);} catch (e) {}})();");
            } catch (JSONException e) {
                throw new RuntimeException(e);
            }
        }
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void setShowLoading(boolean shown) {
        this.mShowLoading = shown;
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void setOnErrorListener(IWebView.OnErrorListener listener) {
        this.mOnErrorListener = listener;
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void setOnPageListener(IWebView.OnPageListener listener) {
        this.mOnPageListener = listener;
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void setOnMessageListener(IWebView.OnMessageListener listener) {
    }

    @Override // com.taobao.weex.ui.view.IWebView
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        DCWXChromeClient dCWXChromeClient = this.chromeClient;
        if (dCWXChromeClient != null) {
            dCWXChromeClient.onResult(requestCode, resultCode, data);
        }
    }

    public void setOnDCMessageListener(WXDCWeb.OnDCMessageListener listener) {
        this.mOnMessageListener = listener;
    }

    private void showWebView(boolean shown) {
        this.mWebView.setVisibility(shown ? 0 : 4);
    }

    @Override // io.dcloud.feature.weex.adapter.webview.IDCWebView
    public WebView getWebView() {
        return this.mWebView;
    }

    @Override // io.dcloud.feature.weex.adapter.webview.IDCWebView
    public void setUserAgent(String ua, boolean overwrite) {
        WebView webView = this.mWebView;
        if (webView != null) {
            WebSettings settings = webView.getSettings();
            if (!overwrite) {
                if (TextUtils.isEmpty(this.mDefUserAgent)) {
                    this.mDefUserAgent = settings.getUserAgentString();
                }
                ua = ua + this.mDefUserAgent + Operators.SPACE_STR + ua;
            }
            settings.setUserAgentString(ua);
        }
    }

    private void initWebView(WebView wv) {
        WebSettings settings = wv.getSettings();
        WebViewFactory.openJSEnabled(settings, null);
        settings.setAppCacheEnabled(true);
        settings.setUseWideViewPort(true);
        settings.setDomStorageEnabled(true);
        settings.setSupportZoom(false);
        settings.setAllowFileAccess(false);
        settings.setBuiltInZoomControls(false);
        settings.setAllowContentAccess(true);
        settings.setSavePassword(false);
        if (Build.VERSION.SDK_INT >= 21) {
            settings.setMixedContentMode(0);
        }
        wv.removeJavascriptInterface("searchBoxJavaBridge_");
        wv.removeJavascriptInterface("accessibilityTraversal");
        wv.removeJavascriptInterface("accessibility");
        WebViewFactory.setFileAccess(settings, true);
        settings.setDefaultTextEncodingName(StringUtils.GB2312);
        wv.setWebViewClient(new WebViewClient() {
            /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.AnonymousClass2 */

            @Override // android.webkit.WebViewClient
            public boolean shouldOverrideUrlLoading(WebView view, String url) {
                if (PdrUtil.isDeviceRootDir(url) || PdrUtil.isNetPath(url) || url.startsWith(DeviceInfo.FILE_PROTOCOL)) {
                    return false;
                }
                try {
                    if (url.startsWith("intent://")) {
                        Intent intent = Intent.parseUri(url, 1);
                        intent.addCategory("android.intent.category.BROWSABLE");
                        intent.setComponent(null);
                        if (Build.VERSION.SDK_INT >= 15) {
                            intent.setSelector(null);
                        }
                        if (DCWXWebView.this.mContext.getPackageManager().queryIntentActivities(intent, 0).size() > 0) {
                            ((Activity) DCWXWebView.this.mContext).startActivityIfNeeded(intent, -1);
                        }
                    } else {
                        Intent intent2 = new Intent("android.intent.action.VIEW", Uri.parse(url));
                        intent2.setFlags(AMapEngineUtils.MAX_P20_WIDTH);
                        DCWXWebView.this.mContext.startActivity(intent2);
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
                return true;
            }

            public void onPageStarted(WebView view, String url, Bitmap favicon) {
                super.onPageStarted(view, url, favicon);
                WXLogUtils.v("tag", "onPageStarted " + url);
                if (DCWXWebView.this.mOnPageListener != null) {
                    DCWXWebView.this.mOnPageListener.onPageStart(url);
                }
            }

            public void onPageFinished(WebView view, String url) {
                super.onPageFinished(view, url);
                WXLogUtils.v("tag", "onPageFinished " + url);
                if (DCWXWebView.this.isStart) {
                    DCWXWebView.this.isStart = false;
                    if (DCWXWebView.this.mWebProgressView != null) {
                        DCWXWebView.this.mWebProgressView.finishProgress();
                    }
                }
                if (DCWXWebView.this.mOnPageListener != null) {
                    DCWXWebView.this.mOnPageListener.onPageFinish(url, view.canGoBack(), view.canGoForward());
                }
            }

            public void onReceivedError(WebView view, WebResourceRequest request, WebResourceError error) {
                super.onReceivedError(view, request, error);
                if (DCWXWebView.this.mOnErrorListener != null) {
                    DCWXWebView.this.mOnErrorListener.onError("error", "page error");
                }
            }

            public void onReceivedHttpError(WebView view, WebResourceRequest request, WebResourceResponse errorResponse) {
                super.onReceivedHttpError(view, request, errorResponse);
                if (DCWXWebView.this.mOnErrorListener != null) {
                    DCWXWebView.this.mOnErrorListener.onError("error", "http error");
                }
            }

            public void onReceivedSslError(WebView view, final SslErrorHandler handler, final SslError error) {
                if (PdrUtil.isEquals(DCWXWebView.this.mSslType, "refuse")) {
                    handler.cancel();
                } else if (PdrUtil.isEquals(DCWXWebView.this.mSslType, "warning")) {
                    Context context = view.getContext();
                    final AlertDialog ad = new AlertDialog.Builder(context).create();
                    ad.setIcon(17301601);
                    ad.setTitle(R.string.dcloud_common_safety_warning);
                    ad.setCanceledOnTouchOutside(false);
                    String url = null;
                    if (Build.VERSION.SDK_INT >= 14) {
                        url = error.getUrl();
                    }
                    String msg = context.getString(R.string.dcloud_common_certificate_continue);
                    if (!TextUtils.isEmpty(url)) {
                        msg = url + "\n" + msg;
                    }
                    ad.setMessage(msg);
                    DialogInterface.OnClickListener listener = new DialogInterface.OnClickListener() {
                        /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.AnonymousClass2.AnonymousClass1 */

                        public void onClick(DialogInterface dialog, int which) {
                            if (which == -2) {
                                ad.cancel();
                                ad.dismiss();
                            } else if (which == -3) {
                                error.getCertificate().getIssuedBy();
                            } else if (which == -1) {
                                WebViewFactory.setSslHandlerState(handler, 1);
                                ad.dismiss();
                            }
                        }
                    };
                    ad.setButton(-2, context.getResources().getString(17039360), listener);
                    ad.setButton(-1, context.getResources().getString(17039370), listener);
                    ad.show();
                } else {
                    WebViewFactory.setSslHandlerState(handler, 1);
                }
                if (DCWXWebView.this.mOnErrorListener != null) {
                    DCWXWebView.this.mOnErrorListener.onError("error", "ssl error");
                }
            }
        });
        DCWXChromeClient dCWXChromeClient = new DCWXChromeClient();
        this.chromeClient = dCWXChromeClient;
        wv.setWebChromeClient(dCWXChromeClient);
        if (Build.VERSION.SDK_INT > 18) {
            wv.addJavascriptInterface(new Object() {
                /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.AnonymousClass3 */

                @JavascriptInterface
                public void postMessage(String message) {
                    DCWXWebView.this.onMessage(message, 1);
                }

                @JavascriptInterface
                public void postMessageToService(String message) {
                    DCWXWebView.this.onMessage(message, 2);
                }
            }, BRIDGE_NAME);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startWebProgress() {
        if (this.mDCWeb.get() != null && this.mDCWeb.get().getHostView() != null) {
            if (this.mDCWeb.get() == null || this.mDCWeb.get().getWebStyles() == null || this.mDCWeb.get().getWebStyles().getBooleanValue("isProgress")) {
                String url = getWebView().getUrl();
                if (!TextUtils.isEmpty(url) && !url.startsWith("file")) {
                    if (this.mWebProgressView == null) {
                        this.mWebProgressView = new DCWebViewProgressBar(this.mWebView.getContext());
                    }
                    String colorStr = "#00FF00";
                    if (this.mDCWeb.get().getWebStyles().containsKey("progressColor")) {
                        colorStr = this.mDCWeb.get().getWebStyles().getString("progressColor");
                    }
                    int colorInt = PdrUtil.stringToColor(colorStr);
                    int heightInt = PdrUtil.convertToScreenInt("2px", this.mWebView.getMeasuredWidth(), 0, this.mWebView.getScale());
                    this.mWebProgressView.setColorInt(colorInt);
                    this.mWebProgressView.setVisibility(0);
                    this.mWebProgressView.setAlphaInt(255);
                    if (this.mWebProgressView.getParent() == null) {
                        this.mRootView.addView(this.mWebProgressView, new ViewGroup.LayoutParams(-1, heightInt));
                    }
                    this.mWebProgressView.startProgress();
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onMessage(String message, int type) {
        Object m;
        if (message != null && this.mOnMessageListener != null) {
            try {
                m = JSON.parse(message);
            } catch (Exception e) {
                m = message;
            }
            Message threadMessage = new Message();
            threadMessage.what = type;
            threadMessage.obj = m;
            this.mMessageHandler.sendMessage(threadMessage);
        }
    }

    private void evaluateJS(String jsStr) {
        if (SDK_VERSION < 19) {
            this.mWebView.loadUrl(jsStr);
        } else {
            this.mWebView.evaluateJavascript(jsStr, null);
        }
    }

    private static class MessageHandler extends Handler {
        private final WeakReference<DCWXWebView> mWv;

        private MessageHandler(DCWXWebView wv) {
            this.mWv = new WeakReference<>(wv);
        }

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            int i = msg.what;
            if (i != 1) {
                if (i == 2 && this.mWv.get() != null && this.mWv.get().mOnMessageListener != null) {
                    Map<String, Object> map = new HashMap<>();
                    map.put("data", msg.obj);
                    this.mWv.get().mOnMessageListener.onMessage(map, 2);
                }
            } else if (this.mWv.get() != null && this.mWv.get().mOnMessageListener != null) {
                Map<String, Object> initData = new HashMap<>();
                initData.put("detail", msg.obj);
                this.mWv.get().mOnMessageListener.onMessage(initData, 1);
            }
        }
    }

    /* access modifiers changed from: private */
    public class DCWXChromeClient extends WebChromeClient {
        FileChooseDialog dialog;
        ValueCallback<Uri> mUploadMessage;
        ValueCallback<Uri[]> mUploadMessage21Level;

        private DCWXChromeClient() {
        }

        public void onPermissionRequest(PermissionRequest request) {
            request.grant(request.getResources());
        }

        public void onProgressChanged(WebView view, int newProgress) {
            super.onProgressChanged(view, newProgress);
            DCWXWebView.this.mProgress = newProgress;
            if (!DCWXWebView.this.isStart && DCWXWebView.this.mProgress < 100) {
                DCWXWebView.this.startWebProgress();
                DCWXWebView.this.isStart = true;
            }
            if (DCWXWebView.this.mProgress >= 100 && DCWXWebView.this.isStart) {
                DCWXWebView.this.isStart = false;
                if (DCWXWebView.this.mWebProgressView != null) {
                    DCWXWebView.this.mWebProgressView.finishProgress();
                }
            }
            WXLogUtils.v("tag", "onPageProgressChanged " + newProgress);
        }

        public void onReceivedTitle(WebView view, String title) {
            super.onReceivedTitle(view, title);
            if (DCWXWebView.this.mOnPageListener != null) {
                DCWXWebView.this.mOnPageListener.onReceivedTitle(view.getTitle());
            }
        }

        public boolean onJsPrompt(WebView view, String url, String text, String defaultValue, JsPromptResult result) {
            return super.onJsPrompt(view, url, text, defaultValue, result);
        }

        public void onGeolocationPermissionsShowPrompt(final String origin, final GeolocationPermissions.Callback callback) {
            if (DCWXWebView.this.mContext instanceof Activity) {
                PermissionUtil.usePermission((Activity) DCWXWebView.this.mContext, "dc_weexsdk", PermissionUtil.PMS_LOCATION, 2, new PermissionUtil.Request() {
                    /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.DCWXChromeClient.AnonymousClass1 */

                    @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                    public void onGranted(String streamPerName) {
                        callback.invoke(origin, true, false);
                    }

                    @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                    public void onDenied(String streamPerName) {
                        callback.invoke(origin, false, false);
                    }
                });
            } else {
                super.onGeolocationPermissionsShowPrompt(origin, callback);
            }
        }

        @Override // android.webkit.WebChromeClient
        public boolean onShowFileChooser(WebView webView, ValueCallback<Uri[]> filePathCallback, WebChromeClient.FileChooserParams fileChooserParams) {
            openFileChooserLogic(webView, null, filePathCallback, fileChooserParams.getAcceptTypes() != null ? fileChooserParams.getAcceptTypes()[0] : null, "");
            return true;
        }

        private void openFileChooserLogic(final WebView webView, final ValueCallback<Uri> uploadMsg, final ValueCallback<Uri[]> uploadMsg21Level, final String acceptType, final String capture) {
            if (DCWXWebView.this.mContext != null) {
                PermissionUtil.usePermission((Activity) DCWXWebView.this.mContext, "dc_weexsdk", PermissionUtil.PMS_STORAGE, 2, new PermissionUtil.Request() {
                    /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.DCWXChromeClient.AnonymousClass2 */

                    @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                    public void onGranted(String perName) {
                        DCWXChromeClient.this.showOpenFileChooser(webView, uploadMsg, uploadMsg21Level, acceptType, capture);
                    }

                    @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
                    public void onDenied(String perName) {
                    }
                });
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void showOpenFileChooser(WebView webView, ValueCallback<Uri> uploadMsg, ValueCallback<Uri[]> uploadMsg21Level, String acceptType, String capture) {
            this.mUploadMessage = uploadMsg;
            this.mUploadMessage21Level = uploadMsg21Level;
            Intent i = new Intent("android.intent.action.GET_CONTENT");
            i.addCategory("android.intent.category.OPENABLE");
            if (!PdrUtil.isEmpty(acceptType)) {
                i.setType(acceptType);
            } else {
                i.setType("*/*");
            }
            FileChooseDialog fileChooseDialog = new FileChooseDialog(webView.getContext(), (Activity) webView.getContext(), i);
            this.dialog = fileChooseDialog;
            try {
                fileChooseDialog.show();
                this.dialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
                    /* class io.dcloud.feature.weex.adapter.webview.DCWXWebView.DCWXChromeClient.AnonymousClass3 */

                    public void onCancel(DialogInterface dialog) {
                        try {
                            if (DCWXChromeClient.this.mUploadMessage21Level != null) {
                                DCWXChromeClient.this.mUploadMessage21Level.onReceiveValue(null);
                            } else if (DCWXChromeClient.this.mUploadMessage != null) {
                                DCWXChromeClient.this.mUploadMessage.onReceiveValue(null);
                            }
                        } catch (Exception e) {
                        }
                    }
                });
            } catch (Exception e) {
            }
        }

        public void onResult(int requestCode, int resultCode, Intent data) {
            FileChooseDialog fileChooseDialog;
            Cursor cursor;
            FileChooseDialog fileChooseDialog2 = this.dialog;
            if (fileChooseDialog2 != null) {
                fileChooseDialog2.dismiss();
                if (resultCode != 0) {
                    Uri value = null;
                    if (requestCode == 1) {
                        if (data == null) {
                            ValueCallback<Uri[]> valueCallback = this.mUploadMessage21Level;
                            if (valueCallback != null) {
                                valueCallback.onReceiveValue(null);
                            } else {
                                ValueCallback<Uri> valueCallback2 = this.mUploadMessage;
                                if (valueCallback2 != null) {
                                    valueCallback2.onReceiveValue(null);
                                }
                            }
                            this.dialog = null;
                            return;
                        }
                        value = data.getData();
                        if (value != null && Build.VERSION.SDK_INT < 29 && "content".equals(value.getScheme()) && (cursor = DCWXWebView.this.mContext.getContentResolver().query(value, new String[]{"_data"}, null, null, null)) != null) {
                            if (cursor.moveToFirst()) {
                                try {
                                    int columnIndex = cursor.getColumnIndexOrThrow("_data");
                                    if (columnIndex > -1) {
                                        String uriString = cursor.getString(columnIndex);
                                        value = Uri.parse(uriString);
                                        if (PdrUtil.isEmpty(value.getScheme())) {
                                            String scheme = uriString.startsWith("/") ? DeviceInfo.FILE_PROTOCOL : "file:///";
                                            value = Uri.parse(scheme + uriString);
                                        }
                                    }
                                } catch (Exception e) {
                                }
                            }
                            cursor.close();
                        }
                    } else if (requestCode == 2 && (fileChooseDialog = this.dialog) != null && fileChooseDialog.uris != null) {
                        Iterator<File> it = this.dialog.uris.iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                break;
                            }
                            File u = it.next();
                            if (u.exists()) {
                                Context context = DCWXWebView.this.mContext;
                                value = FileProvider.getUriForFile(context, DCWXWebView.this.mContext.getPackageName() + ".dc.fileprovider", u);
                                break;
                            }
                        }
                    }
                    Uri[] uris = null;
                    if (value != null) {
                        uris = new Uri[]{value};
                    }
                    ValueCallback<Uri[]> valueCallback3 = this.mUploadMessage21Level;
                    if (valueCallback3 != null) {
                        valueCallback3.onReceiveValue(uris);
                    } else {
                        ValueCallback<Uri> valueCallback4 = this.mUploadMessage;
                        if (valueCallback4 != null) {
                            valueCallback4.onReceiveValue(value);
                        }
                    }
                } else {
                    ValueCallback<Uri[]> valueCallback5 = this.mUploadMessage21Level;
                    if (valueCallback5 != null) {
                        valueCallback5.onReceiveValue(null);
                    } else {
                        ValueCallback<Uri> valueCallback6 = this.mUploadMessage;
                        if (valueCallback6 != null) {
                            valueCallback6.onReceiveValue(null);
                        }
                    }
                }
                this.dialog = null;
            }
        }

        public void onShowCustomView(View view, WebChromeClient.CustomViewCallback callback) {
            DCWXWebView.this.showCustomView(view, callback);
        }

        public void onHideCustomView() {
            DCWXWebView.this.hideCustomView();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void showCustomView(View view, WebChromeClient.CustomViewCallback callback) {
        if (this.customView != null) {
            callback.onCustomViewHidden();
            return;
        }
        Context context = this.mContext;
        if (context != null && (context instanceof Activity)) {
            Activity activityT = (Activity) context;
            ViewGroup activityContentView = null;
            IActivityHandler iActivityHandler = DCloudAdapterUtil.getIActivityHandler(activityT);
            if (iActivityHandler != null) {
                activityContentView = iActivityHandler.obtainActivityContentView();
                iActivityHandler.closeSideBar();
                iActivityHandler.setSideBarVisibility(8);
            } else if (activityT instanceof IActivityDelegate) {
                activityContentView = ((IActivityDelegate) activityT).obtainActivityContentView();
            }
            this.mWebView.setVisibility(8);
            this.fullscreenContainer = new FullscreenHolder(this.mContext);
            FrameLayout.LayoutParams lp = new FrameLayout.LayoutParams(-1, -1);
            this.fullscreenContainer.addView(view, lp);
            activityContentView.addView(this.fullscreenContainer, lp);
            this.customView = view;
            setStatusBarVisibility(activityT, false);
            this.customViewCallback = callback;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void hideCustomView() {
        Context context;
        if (this.customView != null && (context = this.mContext) != null && (context instanceof Activity)) {
            setStatusBarVisibility((Activity) context, true);
            if (this.fullscreenContainer.getParent() != null) {
                ((ViewGroup) this.fullscreenContainer.getParent()).removeView(this.fullscreenContainer);
                this.fullscreenContainer.removeAllViews();
            }
            this.fullscreenContainer = null;
            this.customView = null;
            WebChromeClient.CustomViewCallback customViewCallback2 = this.customViewCallback;
            if (customViewCallback2 != null) {
                customViewCallback2.onCustomViewHidden();
                this.customViewCallback = null;
            }
            this.mWebView.setVisibility(0);
        }
    }

    private void setStatusBarVisibility(Activity activity, boolean visible) {
        if (visible) {
            activity.getWindow().getDecorView().setSystemUiVisibility(this.defaultSystemUI);
            return;
        }
        this.defaultSystemUI = activity.getWindow().getDecorView().getSystemUiVisibility();
        activity.getWindow().getDecorView().setSystemUiVisibility(5894);
    }
}
