package io.dcloud.feature.weex.adapter.webview;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.view.View;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.WXWeb;
import com.taobao.weex.ui.view.IWebView;
import com.taobao.weex.utils.WXResourceUtils;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaWebview;
import io.dcloud.common.adapter.ui.webview.WebViewFactory;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.feature.internal.sdk.SDK;
import io.dcloud.feature.weex.WeexInstanceMgr;
import java.util.HashMap;
import java.util.Map;

@Component(lazyload = false)
public class WXDCWeb extends WXWeb {
    IDCWebView mDCWebView;
    private JSONObject mWebStyles;

    public interface OnDCMessageListener {
        void onMessage(Map<String, Object> map, int i);
    }

    public WXDCWeb(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXWeb
    public void createWebView() {
        Object ob;
        String origin = null;
        try {
            Uri uri = Uri.parse(WXSDKManager.getInstance().getSDKInstance(getInstanceId()).getBundleUrl());
            String scheme = uri.getScheme();
            String authority = uri.getAuthority();
            if (!TextUtils.isEmpty(scheme) && !TextUtils.isEmpty(authority)) {
                origin = scheme + "://" + authority;
            }
        } catch (Exception e) {
        }
        if (WebViewFactory.isIsOtherInitSuccess() && (ob = PlatformUtil.newInstance("io.dcloud.feature.x5.DCWXX5WebView", new Class[]{Context.class, String.class, WXDCWeb.class}, new Object[]{getInstance().getUIContext(), origin, this})) != null && (ob instanceof IWebView)) {
            IDCWebView iDCWebView = (IDCWebView) ob;
            this.mDCWebView = iDCWebView;
            this.mWebView = iDCWebView;
        }
        if (this.mWebView == null) {
            DCWXWebView dCWXWebView = new DCWXWebView(getInstance().getUIContext(), origin, this);
            this.mDCWebView = dCWXWebView;
            this.mWebView = dCWXWebView;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXWeb, com.taobao.weex.ui.component.WXComponent
    public View initComponentHostView(Context context) {
        OnDCMessageListener listener = new OnDCMessageListener() {
            /* class io.dcloud.feature.weex.adapter.webview.WXDCWeb.AnonymousClass1 */

            @Override // io.dcloud.feature.weex.adapter.webview.WXDCWeb.OnDCMessageListener
            public void onMessage(Map<String, Object> params, int type) {
                WXSDKInstance instance;
                if (type == 1) {
                    WXDCWeb.this.fireEvent("onPostMessage", params);
                } else if (type == 2 && (instance = WeexInstanceMgr.self().findWXSDKInstance("__uniapp__service")) != null) {
                    params.put("ref", WXDCWeb.this.getRef());
                    params.put("id", WXDCWeb.this.getInstance().getInstanceId());
                    instance.fireGlobalEventCallback("WebviewPostMessage", params);
                }
            }
        };
        PlatformUtil.invokeMethod(this.mWebView, "setOnDCMessageListener", new Class[]{OnDCMessageListener.class}, listener);
        this.mWebView.setOnErrorListener(new IWebView.OnErrorListener() {
            /* class io.dcloud.feature.weex.adapter.webview.WXDCWeb.AnonymousClass2 */

            @Override // com.taobao.weex.ui.view.IWebView.OnErrorListener
            public void onError(String type, Object message) {
                WXDCWeb.this.fireEvent((WXDCWeb) type, (String) message);
            }
        });
        this.mWebView.setOnPageListener(new IWebView.OnPageListener() {
            /* class io.dcloud.feature.weex.adapter.webview.WXDCWeb.AnonymousClass3 */

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onReceivedTitle(String title) {
                if (WXDCWeb.this.getEvents().contains(Constants.Event.RECEIVEDTITLE)) {
                    HashMap hashMap = new HashMap();
                    hashMap.put("title", title);
                    Map<String, Object> detail = new HashMap<>();
                    detail.put("detail", hashMap);
                    WXDCWeb.this.fireEvent(Constants.Event.RECEIVEDTITLE, detail);
                }
            }

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onPageStart(String url) {
                if (WXDCWeb.this.getEvents().contains(Constants.Event.PAGESTART)) {
                    HashMap hashMap = new HashMap();
                    hashMap.put("url", url);
                    Map<String, Object> detail = new HashMap<>();
                    detail.put("detail", hashMap);
                    WXDCWeb.this.fireEvent(Constants.Event.PAGESTART, detail);
                }
            }

            @Override // com.taobao.weex.ui.view.IWebView.OnPageListener
            public void onPageFinish(String url, boolean canGoBack, boolean canGoForward) {
                if (WXDCWeb.this.getEvents().contains(Constants.Event.PAGEFINISH)) {
                    HashMap hashMap = new HashMap();
                    hashMap.put("url", url);
                    hashMap.put("canGoBack", Boolean.valueOf(canGoBack));
                    hashMap.put("canGoForward", Boolean.valueOf(canGoForward));
                    Map<String, Object> detail = new HashMap<>();
                    detail.put("detail", hashMap);
                    WXDCWeb.this.fireEvent(Constants.Event.PAGEFINISH, detail);
                }
            }
        });
        this.mWebView.setOnMessageListener(new IWebView.OnMessageListener() {
            /* class io.dcloud.feature.weex.adapter.webview.WXDCWeb.AnonymousClass4 */

            @Override // com.taobao.weex.ui.view.IWebView.OnMessageListener
            public void onMessage(Map<String, Object> params) {
                Map<String, Object> detail = new HashMap<>();
                detail.put("detail", params);
                WXDCWeb.this.fireEvent("message", detail);
            }
        });
        View view = this.mWebView.getView();
        if (!TextUtils.isEmpty(AdaWebview.sCustomUserAgent)) {
            this.mDCWebView.setUserAgent(AdaWebview.sCustomUserAgent, true);
        } else {
            IWebview iWebview = WeexInstanceMgr.self().findWebview(getInstance());
            if (iWebview != null) {
                this.mDCWebView.setUserAgent(iWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.CONFIG_USER_AGENT), !Boolean.parseBoolean(iWebview.obtainApp().obtainConfigProperty(IApp.ConfigProperty.CONFIG_CONCATENATE)));
            }
        }
        return view;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireEvent(String type, Object message) {
        if (getEvents().contains("error")) {
            Map<String, Object> params = new HashMap<>();
            params.put("type", type);
            params.put("errorMsg", message);
            Map<String, Object> detail = new HashMap<>();
            detail.put("detail", params);
            fireEvent("error", detail);
        }
    }

    @JSMethod
    public void evalJs(String js) {
        if (this.mWebView != null) {
            if (!js.startsWith("javascript:(function(){")) {
                js = "javascript:(function(){" + js + ";})();";
            }
            this.mWebView.loadUrl(js);
        }
    }

    @JSMethod
    public void evalJS(String js) {
        evalJs(js);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXWeb
    public void loadUrl(String url) {
        if (!TextUtils.isEmpty(url) && url.startsWith("asset:///")) {
            url = url.replace("asset:///", SDK.ANDROID_ASSET);
        }
        super.loadUrl(url);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (this.mWebView != null) {
            this.mWebView.onActivityResult(requestCode, resultCode, data);
        }
    }

    @WXComponentProp(name = "webviewStyles")
    public void webviewStyles(String styles) {
        if (this.mWebStyles == null) {
            this.mWebStyles = new JSONObject();
        }
        JSONObject object = JSON.parseObject(styles);
        if (object != null && object.containsKey("progress")) {
            Object v = object.get("progress");
            if (v instanceof Boolean) {
                this.mWebStyles.put("isProgress", (Object) Boolean.valueOf(((Boolean) v).booleanValue()));
            } else if (v instanceof JSONObject) {
                JSONObject sj = (JSONObject) v;
                this.mWebStyles.put("isProgress", (Object) true);
                if (sj.containsKey("color")) {
                    this.mWebStyles.put("progressColor", (Object) sj.getString("color"));
                }
            }
        }
    }

    public JSONObject getWebStyles() {
        if (this.mWebStyles == null) {
            JSONObject jSONObject = new JSONObject();
            this.mWebStyles = jSONObject;
            jSONObject.put("isProgress", (Object) true);
        }
        return this.mWebStyles;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setBackgroundColor(String color) {
        super.setBackgroundColor(color);
        if (!TextUtils.isEmpty(color) && this.mDCWebView != null) {
            int colorInt = WXResourceUtils.getColor(color);
            if (this.mDCWebView.getWebView() != null) {
                this.mDCWebView.getWebView().setBackgroundColor(colorInt);
            }
        }
    }

    @Override // com.taobao.weex.ui.component.WXWeb, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        this.mDCWebView = null;
    }
}
