package io.dcloud.feature.weex.config;

import android.net.Uri;
import android.text.TextUtils;
import android.util.Base64;
import com.alipay.sdk.m.u.i;
import com.taobao.weex.WXSDKInstance;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URI;
import java.util.HashSet;

public class MimeInfoParser {
    final String DATA_FLAG = "data:";
    final String ENCODE_FORMAT_FLAG = ",";
    final String FILE_FORMAT_FLAG = i.b;
    final String FILE_TYPE_FLAG = "/";
    HashSet<String> registerEncodeFormatSet = new HashSet<>();
    HashSet<String> registerFileFormatSet = new HashSet<>();
    HashSet<String> registerFileTypeSet = new HashSet<>();

    public static MimeInfoParser getInstance() {
        return new MimeInfoParser();
    }

    private MimeInfoParser() {
        this.registerFileTypeSet.add("keystore");
        this.registerFileTypeSet.add("cert");
        this.registerFileFormatSet.add("p12");
        this.registerFileFormatSet.add("pem");
        this.registerEncodeFormatSet.add("filepath");
        this.registerEncodeFormatSet.add("base64");
        this.registerEncodeFormatSet.add("text");
    }

    public static InputStream getFilePathStream(WXSDKInstance wxsdkInstance, String filePath) {
        if (wxsdkInstance == null) {
            return null;
        }
        try {
            File cerFile = new File(new URI(wxsdkInstance.getURIAdapter().rewrite(wxsdkInstance, "file", Uri.parse(filePath)).toString()));
            if (cerFile.exists()) {
                return new FileInputStream(cerFile);
            }
            File assetFile = new File(UniPathParser.getAndroidPath(filePath));
            if (assetFile.exists()) {
                return new FileInputStream(assetFile);
            }
            return null;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public static class MimeInfo {
        private String dataContent;
        private String encodeFormat;
        private String fileFormat;
        private String fileType;

        public InputStream getDataBytes(WXSDKInstance wxsdkInstance) {
            if ("base64".equals(this.encodeFormat)) {
                return new ByteArrayInputStream(Base64.decode(this.dataContent, 2));
            }
            if ("text".equals(this.encodeFormat)) {
                return new ByteArrayInputStream(this.dataContent.getBytes());
            }
            if (!"filepath".equals(this.encodeFormat) || wxsdkInstance == null) {
                return null;
            }
            try {
                return new FileInputStream(new File(new URI(wxsdkInstance.getURIAdapter().rewrite(wxsdkInstance, "file", Uri.parse(this.dataContent)).toString())));
            } catch (Exception e) {
                e.printStackTrace();
                return null;
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean isValid(MimeInfoParser mimeInfoParser) {
            if (TextUtils.isEmpty(this.fileType) || TextUtils.isEmpty(this.fileFormat) || TextUtils.isEmpty(this.encodeFormat) || TextUtils.isEmpty(this.dataContent) || !mimeInfoParser.registerFileTypeSet.contains(this.fileType) || !mimeInfoParser.registerFileFormatSet.contains(this.fileFormat) || !mimeInfoParser.registerEncodeFormatSet.contains(this.encodeFormat)) {
                return false;
            }
            return true;
        }

        public String getFileType() {
            return this.fileType;
        }

        public void setFileType(String fileType2) {
            this.fileType = fileType2;
        }

        public String getFileFormat() {
            return this.fileFormat;
        }

        public void setFileFormat(String fileFormat2) {
            this.fileFormat = fileFormat2;
        }

        public String getEncodeFormat() {
            return this.encodeFormat;
        }

        public void setEncodeFormat(String encodeFormat2) {
            this.encodeFormat = encodeFormat2;
        }

        public String getDataContent() {
            return this.dataContent;
        }

        public void setDataContent(String dataContent2) {
            this.dataContent = dataContent2;
        }
    }

    public MimeInfo obtainMimeInfo(String mimeEncode) {
        MimeInfo mimeInfo = parseMimeInfo(mimeEncode);
        if (mimeInfo == null || mimeInfo.isValid(this)) {
            return mimeInfo;
        }
        return null;
    }

    private MimeInfo parseMimeInfo(String mimeEncode) {
        MimeInfo ret = new MimeInfo();
        if (!mimeEncode.startsWith("data:") || !mimeEncode.contains("/") || !mimeEncode.contains(i.b) || !mimeEncode.contains(",")) {
            return null;
        }
        String nextEncode = mimeEncode.substring("data:".length());
        String encodeFileType = nextEncode.substring(0, nextEncode.indexOf("/"));
        ret.fileType = encodeFileType;
        String nextEncode2 = nextEncode.substring((encodeFileType + "/").length());
        String encodeFileFormat = nextEncode2.substring(0, nextEncode2.indexOf(i.b));
        ret.fileFormat = encodeFileFormat;
        String nextEncode3 = nextEncode2.substring((encodeFileFormat + i.b).length());
        String encodeFormat = nextEncode3.substring(0, nextEncode3.indexOf(","));
        ret.encodeFormat = encodeFormat;
        ret.dataContent = nextEncode3.substring((encodeFormat + ",").length());
        return ret;
    }
}
