package io.dcloud.feature.weex.extend;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.ui.component.WXBasicComponentType;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.core.ui.TabBarWebview;
import io.dcloud.common.core.ui.TabBarWebviewMgr;
import java.util.HashMap;
import java.util.Map;

public class DCTabBarModule extends WXModule {
    @JSMethod
    public void append(JSONObject op, final JSCallback callback) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.append(op.getString("id"), new ICallBack() {
                /* class io.dcloud.feature.weex.extend.DCTabBarModule.AnonymousClass1 */

                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    Map<String, Object> p = new HashMap<>();
                    p.put("code", Integer.valueOf(pType));
                    callback.invoke(p);
                    return null;
                }
            });
        }
    }

    @JSMethod(uiThread = false)
    public boolean isValid() {
        if (TabBarWebviewMgr.getInstance().getLaunchTabBar() != null) {
            return true;
        }
        return false;
    }

    @JSMethod
    public void hideTabBar(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.hideTabBar(op);
        }
    }

    @JSMethod
    public void showTabBar(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.showTabBar(op);
        }
    }

    @JSMethod
    public void setTabBarStyle(JSONObject style) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setStyle(style);
        }
    }

    @JSMethod
    public void setTabBarItem(JSONObject item) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setItem(item);
            tabBar.updateMidButton(null);
        }
    }

    @JSMethod
    public void setTabBarBadge(JSONObject badge) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setTabBarBadge(badge);
        }
    }

    @JSMethod
    public void removeTabBarBadge(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null && tabBar.isVisible()) {
            tabBar.removeTabBarBadge(op);
        }
    }

    @JSMethod
    public void showTabBarRedDot(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null && tabBar.isVisible()) {
            tabBar.showTabBarRedDot(op);
        }
    }

    @JSMethod
    public void hideTabBarRedDot(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null && tabBar.isVisible()) {
            tabBar.hideTabBarRedDot(op);
        }
    }

    @JSMethod
    public void setMask(JSONObject style) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setMask(style);
        }
    }

    @JSMethod(uiThread = false)
    public boolean isTabBarVisible() {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar == null || !tabBar.isVisible()) {
            return false;
        }
        return true;
    }

    @JSMethod(uiThread = false)
    public String getTabBarHeight() {
        return TabBarWebviewMgr.getInstance().getLaunchTabBar().getTabBarHeight();
    }

    @JSMethod
    public void switchSelect(JSONObject op) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.switchSelect(op.getIntValue("index"));
        }
    }

    @JSMethod
    public void setTabBarItems(JSONObject op) {
        JSONObject midJson;
        JSONArray listJson;
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            if (op.containsKey(WXBasicComponentType.LIST) && (listJson = op.getJSONArray(WXBasicComponentType.LIST)) != null) {
                int styleSize = listJson.size();
                for (int i = 0; i < styleSize; i++) {
                    JSONObject perItem = (JSONObject) listJson.get(i);
                    if (perItem != null) {
                        perItem.put("index", (Object) Integer.valueOf(i));
                        tabBar.setItem(perItem);
                    }
                }
            }
            if (!op.containsKey("midButton") || (midJson = op.getJSONObject("midButton")) == null) {
                tabBar.updateMidButton(null);
            } else {
                tabBar.updateMidButton(midJson);
            }
        }
    }

    @JSMethod
    public void onClick(final JSCallback callback) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setClickCallBack(new ICallBack() {
                /* class io.dcloud.feature.weex.extend.DCTabBarModule.AnonymousClass2 */

                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    JSONObject p = new JSONObject();
                    p.put("index", (Object) Integer.valueOf(pType));
                    callback.invokeAndKeepAlive(p);
                    return null;
                }
            });
        }
    }

    @JSMethod
    public void onDoubleClick(final JSCallback callback) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setDoubleClickCallBack(new ICallBack() {
                /* class io.dcloud.feature.weex.extend.DCTabBarModule.AnonymousClass3 */

                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    JSONObject p = new JSONObject();
                    p.put("index", (Object) Integer.valueOf(pType));
                    callback.invokeAndKeepAlive(p);
                    return null;
                }
            });
        }
    }

    @JSMethod
    public void onMidButtonClick(final JSCallback callback) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setMidButtonClickCallBack(new ICallBack() {
                /* class io.dcloud.feature.weex.extend.DCTabBarModule.AnonymousClass4 */

                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    JSONObject p = new JSONObject();
                    p.put("index", (Object) Integer.valueOf(pType));
                    callback.invokeAndKeepAlive(p);
                    return null;
                }
            });
        }
    }

    @JSMethod
    public void onMaskClick(final JSCallback callback) {
        TabBarWebview tabBar = TabBarWebviewMgr.getInstance().getLaunchTabBar();
        if (tabBar != null) {
            tabBar.setMaskButtonClickCallBack(new ICallBack() {
                /* class io.dcloud.feature.weex.extend.DCTabBarModule.AnonymousClass5 */

                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    callback.invokeAndKeepAlive(new JSONObject());
                    return null;
                }
            });
        }
    }
}
