package io.dcloud.feature.weex.extend;

import android.content.SharedPreferences;
import android.text.TextUtils;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.storage.StorageResultHandler;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class PlusStorageModule extends WXModule {
    HashMap<String, SharedPreferences> mAllAppNStorages = new HashMap<>(1);

    @JSMethod(uiThread = false)
    public void setItem(String key, String value, JSCallback callback) {
        Map<String, Object> data;
        if (TextUtils.isEmpty(key) || value == null) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences bundle = getAppNStorage();
        if (bundle != null) {
            PlatformUtil.setBundleData(bundle, key, value);
            data = StorageResultHandler.setItemResult(true);
        } else {
            data = StorageResultHandler.setItemResult(false);
        }
        if (callback != null) {
            callback.invoke(data);
        }
    }

    @JSMethod(uiThread = false)
    public void getItem(String key, JSCallback callback) {
        Map<String, Object> data;
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences bundle = getAppNStorage();
        if (bundle != null) {
            data = StorageResultHandler.getItemResult(bundle.getString(key, null));
        } else {
            data = StorageResultHandler.getItemResult(null);
        }
        if (callback != null) {
            callback.invoke(data);
        }
    }

    @JSMethod(uiThread = false)
    public void removeItem(String key, JSCallback callback) {
        Map<String, Object> data;
        if (TextUtils.isEmpty(key)) {
            StorageResultHandler.handleInvalidParam(callback);
            return;
        }
        SharedPreferences bundle = getAppNStorage();
        if (bundle != null) {
            PlatformUtil.removeBundleData(bundle, key);
            data = StorageResultHandler.removeItemResult(true);
        } else {
            data = StorageResultHandler.removeItemResult(false);
        }
        if (callback != null) {
            callback.invoke(data);
        }
    }

    @JSMethod(uiThread = false)
    public void length(JSCallback callback) {
        SharedPreferences bundle = getAppNStorage();
        if (bundle != null) {
            Map<String, Object> data = StorageResultHandler.getLengthResult((long) getBundleDataSize(bundle));
            if (callback != null) {
                callback.invoke(data);
                return;
            }
            return;
        }
        StorageResultHandler.handleNoHandlerError(callback);
    }

    @JSMethod(uiThread = false)
    public void getAllKeys(JSCallback callback) {
        SharedPreferences bundle = getAppNStorage();
        if (bundle != null) {
            Map<String, Object> data = StorageResultHandler.getAllkeysResult(getBundleKeys(bundle));
            if (callback != null) {
                callback.invoke(data);
                return;
            }
            return;
        }
        StorageResultHandler.handleNoHandlerError(callback);
    }

    private int getBundleDataSize(SharedPreferences bundle) {
        try {
            return bundle.getAll().size();
        } catch (Exception e) {
            e.printStackTrace();
            return 0;
        }
    }

    private List<String> getBundleKeys(SharedPreferences bundle) {
        Map<String, ?> all = bundle.getAll();
        if (all.size() > 0) {
            return new ArrayList<>(all.keySet());
        }
        return null;
    }

    private SharedPreferences initAppNStorages(String pAppid) {
        return PlatformUtil.getOrCreateBundle(pAppid + "_storages");
    }

    private SharedPreferences getAppNStorage() {
        IWebview webview = WeexInstanceMgr.self().findWebview(this.mWXSDKInstance);
        if (webview == null) {
            return null;
        }
        String _appid = webview.obtainFrameView().obtainApp().obtainAppId();
        SharedPreferences bundle = this.mAllAppNStorages.get(_appid);
        if (bundle != null) {
            return bundle;
        }
        SharedPreferences bundle2 = initAppNStorages(_appid);
        this.mAllAppNStorages.put(_appid, bundle2);
        return bundle2;
    }
}
