package io.dcloud.feature.weex.extend.result;

import android.util.Pair;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXImage;

public abstract class Result {
    public IError cause;
    public JSONObject data;
    public int errCode;
    public String errMsg;
    public String errSubject;

    public interface IError {
        JSONObject toJsonObject();
    }

    public static class SourceError implements IError {
        public static final int EMPTY_CODE = -999999;
        public SourceError cause;
        public int code;
        public String message;
        public String subject;

        public SourceError(String subject2, int code2, String message2, SourceError cause2) {
            this.subject = subject2;
            this.code = code2;
            this.message = message2;
            this.cause = cause2;
        }

        @Override // io.dcloud.feature.weex.extend.result.Result.IError
        public JSONObject toJsonObject() {
            JSONObject result = new JSONObject();
            String str = this.subject;
            if (str != null) {
                result.put("subject", (Object) str);
            }
            int i = this.code;
            if (i != -999999) {
                result.put("code", (Object) Integer.valueOf(i));
            }
            String str2 = this.message;
            if (str2 != null) {
                result.put("message", (Object) str2);
            }
            SourceError sourceError = this.cause;
            if (sourceError != null) {
                result.put("cause", (Object) sourceError.toJsonObject());
            }
            return result;
        }
    }

    public static class AggregateError implements IError {
        public String[] errors;
        public String message;
        public String name = "AggregateError";

        public AggregateError(String name2, String[] errors2, String message2) {
            this.name = name2;
            this.errors = errors2;
            this.message = message2;
        }

        @Override // io.dcloud.feature.weex.extend.result.Result.IError
        public JSONObject toJsonObject() {
            JSONObject result = new JSONObject();
            result.put("name", (Object) this.name);
            if (this.errors != null) {
                StringBuilder errStr = new StringBuilder(Operators.ARRAY_START_STR);
                for (String error : this.errors) {
                    errStr.append(error);
                }
                errStr.append(Operators.ARRAY_END_STR);
                result.put("errors", (Object) errStr);
            }
            String str = this.message;
            if (str != null) {
                result.put("message", (Object) str);
            }
            return result;
        }
    }

    public Result(String subject, int code, String message) {
        this.errSubject = subject;
        this.errCode = code;
        this.errMsg = message;
    }

    @SafeVarargs
    public static JSONObject boxCallBackResult(boolean success, Pair<String, Object>... arg) {
        JSONObject result = new JSONObject();
        if (success) {
            result.put("type", (Object) WXImage.SUCCEED);
        } else {
            result.put("type", (Object) Constants.Event.FAIL);
        }
        for (Pair<String, Object> pair : arg) {
            if (pair != null) {
                result.put((String) pair.first, pair.second);
            }
        }
        return result;
    }

    public static JSONObject boxSuccessResult(Object data2) {
        return boxCallBackResult(true, new Pair("data", data2));
    }

    public static JSONObject boxFailResult(Result result) {
        Pair<String, Object> subjectPair = new Pair<>("errSubject", result.errSubject);
        Pair<String, Object> codePair = new Pair<>(IWXUserTrackAdapter.MONITOR_ERROR_CODE, Integer.valueOf(result.errCode));
        Pair<String, Object> messagePair = new Pair<>(IWXUserTrackAdapter.MONITOR_ERROR_MSG, result.errMsg);
        Pair<String, Object> causePair = null;
        if (result.cause != null) {
            causePair = new Pair<>("cause", result.cause.toJsonObject());
        }
        Pair<String, Object> dataPair = null;
        if (result.data != null) {
            dataPair = new Pair<>("data", result.data);
        }
        return boxCallBackResult(false, subjectPair, codePair, messagePair, causePair, dataPair);
    }
}
