package io.dcloud.feature.weex_amap.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.AMap;
import com.amap.api.maps.TextureMapView;
import com.amap.api.maps.model.CameraPosition;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.cluster.Cluster;
import io.dcloud.feature.weex_amap.adapter.cluster.ClusterItem;
import io.dcloud.feature.weex_amap.adapter.cluster.ClusterOverlay;
import io.dcloud.feature.weex_amap.adapter.cluster.CustomClusterRender;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterClickListener;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterCreateListener;
import io.dcloud.feature.weex_amap.adapter.cluster.RegionItem;
import io.dcloud.feature.weex_amap.adapter.marker.IUniMarker;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class WXMapView extends TextureMapView implements AMap.OnCameraChangeListener, AMap.OnMarkerClickListener {
    private ArrayList<AMap.OnCameraChangeListener> mCameraChangeListeners;
    private ClusterOverlay mClusterOverlay;
    private String mCoverViewCalloutComponetRef;
    private UniSDKInstance mInstance;
    private ArrayList<AMap.OnMarkerClickListener> mMarkerClickListeners;
    private Bitmap transparentBitmap = Bitmap.createBitmap(1, 1, Bitmap.Config.ARGB_8888);

    public WXMapView(Context context, UniSDKInstance instance) {
        super(context);
        this.mInstance = instance;
    }

    public Bitmap getTransparentBitmap() {
        return this.transparentBitmap;
    }

    public void createClusterOverlay(JSONObject data) {
        boolean zoomOnClick;
        int clusterSize = 60;
        if (data.containsKey("gridSize")) {
            clusterSize = UniUtils.getInteger(data.get("gridSize"), 60).intValue();
        }
        int size = WXViewUtils.getRealPxByWidth2((float) clusterSize, this.mInstance.getInstanceViewPortWidthWithFloat());
        boolean enableDefaultStyle = true;
        if (data.containsKey("enableDefaultStyle")) {
            enableDefaultStyle = data.getBooleanValue("enableDefaultStyle");
        }
        if (data.containsKey("zoomOnClick")) {
            zoomOnClick = data.getBooleanValue("zoomOnClick");
        } else {
            zoomOnClick = true;
        }
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay == null) {
            this.mClusterOverlay = new ClusterOverlay(this, this.mInstance, size, enableDefaultStyle, zoomOnClick, getContext());
        } else {
            clusterOverlay.updateClusterOverlay(size, enableDefaultStyle, zoomOnClick);
        }
    }

    public UniSDKInstance getUniSDKInstance() {
        return this.mInstance;
    }

    public ClusterOverlay getClusterOverlay() {
        return this.mClusterOverlay;
    }

    public void addCluster(JSONArray markers) {
        ArrayList<ClusterItem> list = new ArrayList<>();
        for (int i = 0; i < markers.size(); i++) {
            JSONObject item = markers.getJSONObject(i);
            String markerId = String.valueOf(item.hashCode());
            if (item.containsKey("id")) {
                markerId = item.getString("id");
            }
            if (item.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER)) {
                LatLng latLng = MapResourceUtils.crateLatLng(item);
                if (latLng != null) {
                    list.add(new RegionItem(markerId, latLng, item));
                }
            } else if (item.containsKey("clusterId")) {
                this.mClusterOverlay.setClusterRenderer(new CustomClusterRender(item.getString("clusterId"), markerId, item));
            }
        }
        if (list.size() > 0) {
            ClusterOverlay clusterOverlay = this.mClusterOverlay;
            if (clusterOverlay == null) {
                createClusterOverlay(new JSONObject());
            } else {
                clusterOverlay.addClusterItems(list);
            }
        }
    }

    public void removeCluster(JSONArray markerIds) {
        if (this.mClusterOverlay != null && markerIds.size() > 0) {
            this.mClusterOverlay.removeClusterItems(markerIds);
        }
    }

    public JSONObject getClusterInfo(Cluster cluster) {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            return clusterOverlay.getClusterInfo(cluster);
        }
        return new JSONObject();
    }

    public void setClusterClickListener(OnClusterClickListener listener) {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            clusterOverlay.setOnClusterClickListener(listener);
        }
    }

    public void setClusterCreateListener(OnClusterCreateListener listener) {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            clusterOverlay.setClusterCreateListener(listener);
        }
    }

    public void clearCluster() {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            clusterOverlay.reset();
        }
    }

    public void destroy() {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            clusterOverlay.onDestroy();
        }
        super.onDestroy();
        this.transparentBitmap.recycle();
        ArrayList<AMap.OnCameraChangeListener> arrayList = this.mCameraChangeListeners;
        if (arrayList != null) {
            arrayList.clear();
        }
        ArrayList<AMap.OnCameraChangeListener> arrayList2 = this.mCameraChangeListeners;
        if (arrayList2 != null) {
            arrayList2.clear();
        }
    }

    public List<IUniMarker> getClusterAddMarkers() {
        ClusterOverlay clusterOverlay = this.mClusterOverlay;
        if (clusterOverlay != null) {
            return clusterOverlay.getClusterAddMarkers();
        }
        return null;
    }

    public void setCoverViewCalloutComponetRef(String coverViewCalloutComponetRef) {
        this.mCoverViewCalloutComponetRef = coverViewCalloutComponetRef;
    }

    public String getCoverViewCalloutComponetRef() {
        return this.mCoverViewCalloutComponetRef;
    }

    public void addCameraChangeListener(AMap.OnCameraChangeListener cameraChangeListener) {
        if (this.mCameraChangeListeners == null) {
            this.mCameraChangeListeners = new ArrayList<>();
        }
        if (!this.mCameraChangeListeners.contains(cameraChangeListener)) {
            this.mCameraChangeListeners.add(cameraChangeListener);
        }
    }

    public void addMarkerClickListener(AMap.OnMarkerClickListener markerClickListener) {
        if (this.mMarkerClickListeners == null) {
            this.mMarkerClickListeners = new ArrayList<>();
        }
        if (!this.mMarkerClickListeners.contains(markerClickListener)) {
            this.mMarkerClickListeners.add(markerClickListener);
        }
    }

    @Override // com.amap.api.maps.AMap.OnCameraChangeListener
    public void onCameraChange(CameraPosition cameraPosition) {
        ArrayList<AMap.OnCameraChangeListener> arrayList = this.mCameraChangeListeners;
        if (arrayList != null) {
            Iterator<AMap.OnCameraChangeListener> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onCameraChange(cameraPosition);
            }
        }
    }

    @Override // com.amap.api.maps.AMap.OnCameraChangeListener
    public void onCameraChangeFinish(CameraPosition cameraPosition) {
        ArrayList<AMap.OnCameraChangeListener> arrayList = this.mCameraChangeListeners;
        if (arrayList != null) {
            Iterator<AMap.OnCameraChangeListener> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onCameraChangeFinish(cameraPosition);
            }
        }
    }

    @Override // com.amap.api.maps.AMap.OnMarkerClickListener
    public boolean onMarkerClick(Marker marker) {
        ArrayList<AMap.OnMarkerClickListener> arrayList = this.mMarkerClickListeners;
        if (arrayList == null) {
            return false;
        }
        Iterator<AMap.OnMarkerClickListener> it = arrayList.iterator();
        while (it.hasNext()) {
            if (it.next().onMarkerClick(marker)) {
                return true;
            }
        }
        return false;
    }
}
