package io.dcloud.feature.weex_amap.adapter.circle;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.Circle;
import com.amap.api.maps.model.CircleOptions;
import com.amap.api.maps.model.LatLng;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.Iterator;

public class CircleMgr extends MapAbsMgr {
    ArrayList<Circle> mCircleCaches = new ArrayList<>();

    public CircleMgr(WXSDKInstance instance, WXMapView map) {
        super(instance, map);
    }

    public void setCircles(JSONArray circles) {
        clearCircles();
        if (circles != null) {
            for (int i = 0; i < circles.size(); i++) {
                CircleOptions cp = createCircleOptions(circles.getJSONObject(i));
                if (cp != null) {
                    this.mCircleCaches.add(this.mMap.getMap().addCircle(cp));
                }
            }
        }
    }

    private CircleOptions createCircleOptions(JSONObject item) {
        CircleOptions co = null;
        if (item != null) {
            if (!item.containsKey(Constant.JSONKEY.LATITUDE)) {
                return null;
            }
            co = new CircleOptions();
            co.center(new LatLng(UniUtils.getDouble(item.get(Constant.JSONKEY.LATITUDE)), UniUtils.getDouble(item.get(Constant.JSONKEY.LONGITUDE))));
            if (item.containsKey("color")) {
                co.strokeColor(MapResourceUtils.getColor(item.getString("color")));
            }
            if (item.containsKey(Constant.Name.FILL_COLOR)) {
                co.fillColor(MapResourceUtils.getColor(item.getString(Constant.Name.FILL_COLOR)));
            }
            if (item.containsKey(Constant.Name.RADIUS)) {
                co.radius((double) UniUtils.parseFloat(item.get(Constant.Name.RADIUS)));
            }
            if (item.containsKey(Constant.Name.STROKE_WIDTH)) {
                co.strokeWidth((float) WXViewUtils.getRealPxByWidth2(UniUtils.parseFloat(item.get(Constant.Name.STROKE_WIDTH)), this.mInstance.getInstanceViewPortWidthWithFloat()));
            }
        }
        return co;
    }

    public void clearCircles() {
        ArrayList<Circle> arrayList = this.mCircleCaches;
        if (arrayList != null) {
            Iterator<Circle> it = arrayList.iterator();
            while (it.hasNext()) {
                Circle c = it.next();
                if (c != null) {
                    c.remove();
                }
            }
        }
    }
}
