package io.dcloud.feature.weex_amap.adapter.cluster;

import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import io.dcloud.feature.weex_amap.adapter.marker.IUniMarker;
import io.dcloud.feature.weex_amap.adapter.marker.WXMarker;

public class ClusterMarker implements IUniMarker {
    private WXMarker mDiyMarker;
    private Marker mMarker;
    private int mMarkermCount = 0;

    public ClusterMarker(WXMapView mapView, BitmapDescriptor bitmapDescriptor, LatLng latLng, int count) {
        this.mMarkermCount = count;
        MarkerOptions markerOptions = new MarkerOptions();
        markerOptions.anchor(0.5f, 0.5f).icon(bitmapDescriptor).position(latLng);
        this.mMarker = mapView.getMap().addMarker(markerOptions);
    }

    public void updateIcon(BitmapDescriptor bitmapDescriptor, int count) {
        Marker marker;
        if (this.mDiyMarker == null && (marker = this.mMarker) != null) {
            marker.setIcon(bitmapDescriptor);
        }
        this.mMarkermCount = count;
    }

    public void updateClusterForRender(UniSDKInstance instance, WXMapView mapView, ClusterRender render) {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.destroy();
            this.mMarker = null;
        }
        WXMarker wXMarker = this.mDiyMarker;
        if (wXMarker != null) {
            wXMarker.destroy();
        }
        String iconPath = render.getMarkerData().getString(Constant.JSONKEY.ICONPATH);
        if (PdrUtil.isEmpty(iconPath)) {
            render.getMarkerData().put(Constant.JSONKEY.ICONPATH, Constant.TRANSPARENT);
            iconPath = Constant.TRANSPARENT;
        }
        this.mDiyMarker = new WXMarker(instance, mapView, render.getMarkerData(), render.getMarkerId());
        if (Constant.TRANSPARENT.equals(iconPath)) {
            this.mDiyMarker.getInstance().setIcon(BitmapDescriptorFactory.fromBitmap(mapView.getTransparentBitmap()));
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public Marker getInstance() {
        WXMarker wXMarker = this.mDiyMarker;
        if (wXMarker != null) {
            return wXMarker.getInstance();
        }
        return this.mMarker;
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public void destroy() {
        WXMarker wXMarker = this.mDiyMarker;
        if (wXMarker != null) {
            wXMarker.destroy();
            this.mDiyMarker = null;
        }
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.destroy();
            this.mMarker = null;
        }
    }

    public int getMarkerCount() {
        return this.mMarkermCount;
    }
}
