package io.dcloud.feature.weex_amap.adapter.cluster;

import android.content.Context;
import android.graphics.Bitmap;
import android.os.Build;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.util.LruCache;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.AMap;
import com.amap.api.maps.AMapUtils;
import com.amap.api.maps.CameraUpdateFactory;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.CameraPosition;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.animation.AlphaAnimation;
import com.amap.api.maps.model.animation.Animation;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import io.dcloud.feature.weex_amap.adapter.marker.IUniMarker;
import io.dcloud.feature.weex_amap.adapter.marker.WXMarker;
import io.dcloud.feature.weex_amap.ui.ArrowTextView;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;

public class ClusterOverlay implements AMap.OnCameraChangeListener, AMap.OnMarkerClickListener {
    private boolean isEnableDefaultStyle;
    private boolean isZoomOnClick;
    private AlphaAnimation mADDAnimation;
    private List<IUniMarker> mAddMarkers;
    private OnClusterClickListener mClusterClickListener;
    private OnClusterCreateListener mClusterCreateListener;
    private double mClusterDistance;
    private LinkedHashMap<String, ClusterItem> mClusterItems;
    private int mClusterSize;
    private LinkedHashMap<String, Cluster> mClusters;
    private Context mContext;
    private int mDynamicID;
    private UniSDKInstance mInstance;
    private boolean mIsCanceled;
    private LruCache<Integer, BitmapDescriptor> mLruCache;
    private WXMapView mMap;
    private HandlerThread mMarkerHandlerThread;
    private Handler mMarkerhandler;
    private float mPXInMeters;
    private Handler mSignClusterHandler;
    private HandlerThread mSignClusterThread;

    public ClusterOverlay(WXMapView amap, UniSDKInstance instance, int clusterSize, boolean enableDefaultStyle, boolean zoomOnClick, Context context) {
        this(amap, instance, null, clusterSize, enableDefaultStyle, zoomOnClick, context);
    }

    public ClusterOverlay(WXMapView amap, UniSDKInstance instance, LinkedHashMap<String, ClusterItem> clusterItems, int clusterSize, boolean enableDefaultStyle, boolean zoomOnClick, Context context) {
        this.mAddMarkers = Collections.synchronizedList(new ArrayList());
        this.mMarkerHandlerThread = new HandlerThread("addMarker");
        this.mSignClusterThread = new HandlerThread("calculateCluster");
        this.mIsCanceled = false;
        this.mDynamicID = 100;
        this.isEnableDefaultStyle = true;
        this.isZoomOnClick = true;
        this.mADDAnimation = new AlphaAnimation(0.0f, 1.0f);
        this.mLruCache = new LruCache<Integer, BitmapDescriptor>(80) {
            /* class io.dcloud.feature.weex_amap.adapter.cluster.ClusterOverlay.AnonymousClass1 */

            /* access modifiers changed from: protected */
            public void entryRemoved(boolean evicted, Integer key, BitmapDescriptor oldValue, BitmapDescriptor newValue) {
                ClusterOverlay.this.reycleBitmap(oldValue.getBitmap());
            }
        };
        this.mInstance = instance;
        if (clusterItems != null) {
            this.mClusterItems = clusterItems;
        } else {
            this.mClusterItems = new LinkedHashMap<>();
        }
        this.mContext = context;
        this.mClusters = new LinkedHashMap<>();
        this.mMap = amap;
        this.isEnableDefaultStyle = enableDefaultStyle;
        this.isZoomOnClick = zoomOnClick;
        this.mClusterSize = clusterSize;
        float scalePerPixel = amap.getMap().getScalePerPixel();
        this.mPXInMeters = scalePerPixel;
        this.mClusterDistance = (double) (scalePerPixel * ((float) this.mClusterSize));
        this.mMap.addCameraChangeListener(this);
        this.mMap.addMarkerClickListener(this);
        initThreadHandler();
        assignClusters();
    }

    public void updateClusterOverlay(int clusterSize, boolean enableDefaultStyle, boolean zoomOnClick) {
        this.mClusterSize = clusterSize;
        float scalePerPixel = this.mMap.getMap().getScalePerPixel();
        this.mPXInMeters = scalePerPixel;
        this.mClusterDistance = (double) (scalePerPixel * ((float) this.mClusterSize));
        this.isEnableDefaultStyle = enableDefaultStyle;
        this.isZoomOnClick = zoomOnClick;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void reycleBitmap(Bitmap bitmap) {
        if (bitmap != null && Build.VERSION.SDK_INT <= 10 && !bitmap.isRecycled()) {
            bitmap.recycle();
        }
    }

    public void setOnClusterClickListener(OnClusterClickListener clusterClickListener) {
        this.mClusterClickListener = clusterClickListener;
    }

    public void setClusterCreateListener(OnClusterCreateListener clusterCreateListener) {
        this.mClusterCreateListener = clusterCreateListener;
    }

    public void addClusterItem(ClusterItem item) {
        Message message = Message.obtain();
        message.what = 1;
        message.obj = item;
        this.mSignClusterHandler.sendMessage(message);
    }

    public void removeClusterItem(ClusterItem item) {
        Message message = Message.obtain();
        message.what = 2;
        message.obj = item;
        this.mSignClusterHandler.sendMessage(message);
    }

    public void addClusterItems(ArrayList<ClusterItem> items) {
        Message message = Message.obtain();
        message.what = 1;
        message.obj = items;
        this.mSignClusterHandler.sendMessage(message);
    }

    public void removeClusterItems(JSONArray markerIds) {
        Message message = Message.obtain();
        message.what = 2;
        message.obj = markerIds;
        this.mSignClusterHandler.sendMessage(message);
    }

    public void setClusterRenderer(ClusterRender render) {
        if (this.mClusters.containsKey(render.getClusterId())) {
            Cluster cluster = this.mClusters.get(render.getClusterId());
            cluster.setClusterRender(render);
            Message message = Message.obtain();
            message.what = 3;
            message.obj = cluster;
            this.mMarkerhandler.sendMessageDelayed(message, 5);
        }
    }

    public void onDestroy() {
        this.mIsCanceled = true;
        this.mSignClusterHandler.removeCallbacksAndMessages(null);
        this.mMarkerhandler.removeCallbacksAndMessages(null);
        this.mSignClusterThread.quit();
        this.mMarkerHandlerThread.quit();
        for (IUniMarker marker : this.mAddMarkers) {
            marker.destroy();
        }
        this.mDynamicID = 100;
        this.mAddMarkers.clear();
        this.mLruCache.evictAll();
        LinkedHashMap<String, ClusterItem> linkedHashMap = this.mClusterItems;
        if (linkedHashMap != null) {
            linkedHashMap.clear();
        }
        LinkedHashMap<String, Cluster> linkedHashMap2 = this.mClusters;
        if (linkedHashMap2 != null) {
            linkedHashMap2.clear();
        }
    }

    public void reset() {
        this.mIsCanceled = true;
        this.mSignClusterHandler.removeCallbacksAndMessages(null);
        this.mMarkerhandler.removeCallbacksAndMessages(null);
        for (IUniMarker marker : this.mAddMarkers) {
            marker.destroy();
        }
        this.mDynamicID = 100;
        this.mAddMarkers.clear();
        this.mLruCache.evictAll();
        LinkedHashMap<String, ClusterItem> linkedHashMap = this.mClusterItems;
        if (linkedHashMap != null) {
            linkedHashMap.clear();
        }
        LinkedHashMap<String, Cluster> linkedHashMap2 = this.mClusters;
        if (linkedHashMap2 != null) {
            linkedHashMap2.clear();
        }
    }

    private void initThreadHandler() {
        this.mMarkerHandlerThread.start();
        this.mSignClusterThread.start();
        this.mMarkerhandler = new MarkerHandler(this.mMarkerHandlerThread.getLooper());
        this.mSignClusterHandler = new SignClusterHandler(this.mSignClusterThread.getLooper());
    }

    @Override // com.amap.api.maps.AMap.OnCameraChangeListener
    public void onCameraChange(CameraPosition arg0) {
    }

    @Override // com.amap.api.maps.AMap.OnCameraChangeListener
    public void onCameraChangeFinish(CameraPosition arg0) {
        float scalePerPixel = this.mMap.getMap().getScalePerPixel();
        this.mPXInMeters = scalePerPixel;
        this.mClusterDistance = (double) (scalePerPixel * ((float) this.mClusterSize));
        assignClusters();
    }

    @Override // com.amap.api.maps.AMap.OnMarkerClickListener
    public boolean onMarkerClick(Marker arg0) {
        Cluster currentCluster = null;
        if (arg0.getObject() == null) {
            Iterator<Cluster> it = this.mClusters.values().iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                Cluster cluster = it.next();
                if (MapResourceUtils.equalsLatLng(arg0.getPosition(), cluster.getCenterLatLng())) {
                    currentCluster = cluster;
                    break;
                }
            }
        } else if (arg0.getObject() instanceof Cluster) {
            currentCluster = (Cluster) arg0.getObject();
        }
        if (currentCluster != null && (currentCluster.getMarker() instanceof ClusterMarker)) {
            if (this.isZoomOnClick && currentCluster.getClusterCount() > 1) {
                LatLngBounds.Builder builder = new LatLngBounds.Builder();
                for (ClusterItem item : currentCluster.getClusterItems()) {
                    builder.include(item.getPosition());
                }
                this.mMap.getMap().animateCamera(CameraUpdateFactory.newLatLngBounds(builder.build(), 50));
            }
            OnClusterClickListener onClusterClickListener = this.mClusterClickListener;
            if (!(onClusterClickListener == null || currentCluster == null)) {
                onClusterClickListener.onClick(arg0, currentCluster);
                return true;
            }
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addClusterToMap(LinkedHashMap<String, Cluster> clusters) {
        if (clusters.size() != 0) {
            ArrayList<IUniMarker> removeMarkers = new ArrayList<>();
            removeMarkers.addAll(this.mAddMarkers);
            List<Cluster> createClist = new ArrayList<>();
            for (Cluster cluster : clusters.values()) {
                if (cluster.isMultiplexing()) {
                    if (cluster.getClusterCount() > 1 && cluster.isContUpdate()) {
                        createClist.add(cluster);
                    }
                    removeMarkers.remove(cluster.getMarker());
                } else if (cluster.getClusterCount() > 1) {
                    createClist.add(cluster);
                }
            }
            triggerCreateListener(createClist);
            createClist.clear();
            Iterator<IUniMarker> it = removeMarkers.iterator();
            while (it.hasNext()) {
                IUniMarker marker = it.next();
                if (marker != null) {
                    marker.destroy();
                }
            }
            for (Cluster cluster2 : clusters.values()) {
                if (!cluster2.isMultiplexing()) {
                    addSingleClusterToMap(cluster2);
                } else {
                    int clusterCount = cluster2.getClusterCount();
                    if (cluster2.getMarker() instanceof ClusterMarker) {
                        ClusterMarker clusterMarker = (ClusterMarker) cluster2.getMarker();
                        if (clusterCount == 1) {
                            cluster2.setMarker(null);
                            clusterMarker.destroy();
                            addSingleClusterToMap(cluster2);
                        } else if (clusterMarker.getMarkerCount() != cluster2.getClusterCount()) {
                            triggerCreateListener(cluster2);
                            clusterMarker.updateIcon(getBitmapDes(cluster2), cluster2.getClusterCount());
                        }
                    } else if (clusterCount > 1) {
                        if (cluster2.getMarker() != null) {
                            cluster2.getMarker().destroy();
                        }
                        addSingleClusterToMap(cluster2);
                    }
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void triggerCreateListener(Object data) {
        if (!this.isEnableDefaultStyle && this.mClusterCreateListener != null) {
            List<Cluster> list = null;
            if (data instanceof Cluster) {
                list = new ArrayList<>();
                list.add((Cluster) data);
            } else if (data instanceof ArrayList) {
                list = (List) data;
            }
            if (list != null) {
                this.mClusterCreateListener.onClusterCreate(list);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addSingleClusterToMap(Cluster cluster) {
        ClusterItem item;
        String id;
        LatLng latlng = cluster.getCenterLatLng();
        IUniMarker marker = null;
        if (!(cluster.getClusterCount() != 1 || (item = cluster.getClusterItem(0)) == null || item.getData() == null)) {
            if (item.getData().containsKey("id")) {
                id = item.getData().getString("id");
            } else {
                id = String.valueOf(item.hashCode());
            }
            marker = new WXMarker(this.mMap.getUniSDKInstance(), this.mMap, item.getData(), id);
        }
        if (marker == null) {
            marker = new ClusterMarker(this.mMap, getBitmapDes(cluster), latlng, cluster.getClusterCount());
        }
        marker.getInstance().setAnimation(this.mADDAnimation);
        marker.getInstance().setObject(cluster);
        marker.getInstance().startAnimation();
        cluster.setMarker(marker);
        this.mAddMarkers.add(marker);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calculateClusters() {
        this.mIsCanceled = false;
        LinkedHashMap<String, Cluster> clusters = new LinkedHashMap<>();
        clusters.putAll(this.mClusters);
        for (Cluster cluster : clusters.values()) {
            if (cluster != null) {
                cluster.clearClusterItems();
            }
        }
        this.mClusters.clear();
        LinkedHashMap<String, Cluster> temps = new LinkedHashMap<>();
        LatLngBounds visibleBounds = this.mMap.getMap().getProjection().getVisibleRegion().latLngBounds;
        for (ClusterItem clusterItem : this.mClusterItems.values()) {
            if (!this.mIsCanceled) {
                LatLng latlng = clusterItem.getPosition();
                if (visibleBounds.contains(latlng)) {
                    Cluster oldCluster = getCluster(latlng, clusters);
                    if (oldCluster != null) {
                        temps.put(oldCluster.getId(), oldCluster);
                        oldCluster.addClusterItem(clusterItem);
                        oldCluster.setMultiplexing(true);
                    } else {
                        Cluster cluster2 = getCluster(latlng, temps);
                        if (cluster2 == null) {
                            cluster2 = new Cluster(getClusterId(clusterItem), latlng);
                        }
                        temps.put(cluster2.getId(), cluster2);
                        cluster2.addClusterItem(clusterItem);
                    }
                }
            } else {
                return;
            }
        }
        this.mClusters.putAll(temps);
        clusters.clear();
        Message message = Message.obtain();
        message.what = 0;
        message.obj = temps;
        if (!this.mIsCanceled) {
            this.mMarkerhandler.sendMessage(message);
        }
    }

    private String getClusterId(ClusterItem clusterItem) {
        if (clusterItem.getData() != null && clusterItem.getData().containsKey("clusterId")) {
            return clusterItem.getData().getString("clusterId");
        }
        int i = this.mDynamicID + 1;
        this.mDynamicID = i;
        return String.valueOf(i);
    }

    private void assignClusters() {
        this.mIsCanceled = true;
        this.mSignClusterHandler.removeMessages(0);
        this.mSignClusterHandler.sendEmptyMessage(0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calculateSingleCluster(ArrayList<ClusterItem> list) {
        LatLngBounds visibleBounds = this.mMap.getMap().getProjection().getVisibleRegion().latLngBounds;
        Iterator<ClusterItem> it = list.iterator();
        while (it.hasNext()) {
            ClusterItem item = it.next();
            if (visibleBounds.contains(item.getPosition())) {
                this.mClusterItems.put(item.getId(), item);
            }
        }
        this.mSignClusterHandler.removeMessages(0);
        this.mSignClusterHandler.sendEmptyMessage(0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calculateRemoveSingleClusters(ArrayList<ClusterItem> list) {
        Iterator<ClusterItem> it = list.iterator();
        while (it.hasNext()) {
            calculateRemoveSingleCluster(it.next());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calculateRemoveSingleCluster(ClusterItem clusterItem) {
        Cluster cluster;
        LatLngBounds visibleBounds = this.mMap.getMap().getProjection().getVisibleRegion().latLngBounds;
        LatLng latlng = clusterItem.getPosition();
        if (!visibleBounds.contains(latlng) || (cluster = getCluster(latlng, this.mClusters)) == null) {
            return;
        }
        if (cluster.getClusterCount() == 1) {
            cluster.getMarker().destroy();
            return;
        }
        cluster.removeClusterItem(clusterItem);
        Message message = Message.obtain();
        message.what = 2;
        message.obj = cluster;
        this.mMarkerhandler.removeMessages(2);
        this.mMarkerhandler.sendMessageDelayed(message, 5);
    }

    private Cluster getCluster(LatLng latLng, LinkedHashMap<String, Cluster> clusters) {
        for (Cluster cluster : clusters.values()) {
            double distance = (double) AMapUtils.calculateLineDistance(latLng, cluster.getCenterLatLng());
            if (distance <= 0.0d) {
                distance = 20.0d;
            }
            if (distance < this.mClusterDistance && this.mMap.getMap().getCameraPosition().zoom < 21.0f) {
                return cluster;
            }
        }
        return null;
    }

    private BitmapDescriptor getBitmapDes(Cluster cluster) {
        int num = cluster.getClusterCount();
        BitmapDescriptor bitmapDescriptor = this.mLruCache.get(Integer.valueOf(num));
        if (bitmapDescriptor != null) {
            return bitmapDescriptor;
        }
        ArrowTextView textView = new ArrowTextView(this.mContext, false);
        if (num > 1) {
            textView.setText(String.valueOf(num));
        }
        int width = UniViewUtils.dip2px(50.0f);
        textView.setRadius(width / 2);
        textView.setGravity(17);
        textView.setTextColor(-1);
        textView.setIncludeFontPadding(false);
        textView.setTextSize(2, 15.0f);
        textView.setBgColor(-16776961);
        LinearLayout.LayoutParams l = new LinearLayout.LayoutParams(width, width);
        l.setMargins(3, 3, 3, 3);
        LinearLayout rootView = new LinearLayout(this.mContext);
        rootView.addView(textView, l);
        BitmapDescriptor bitmapDescriptor2 = BitmapDescriptorFactory.fromView(rootView);
        this.mLruCache.put(Integer.valueOf(num), bitmapDescriptor2);
        return bitmapDescriptor2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void updateCluster(Cluster cluster) {
        IUniMarker marker = cluster.getMarker();
        if (marker == null) {
            return;
        }
        if (marker instanceof ClusterMarker) {
            ((ClusterMarker) marker).updateIcon(getBitmapDes(cluster), cluster.getClusterCount());
        } else if (marker instanceof WXMarker) {
            if (marker != null) {
                marker.destroy();
                this.mAddMarkers.remove(marker);
            }
            IUniMarker marker2 = new ClusterMarker(this.mMap, getBitmapDes(cluster), cluster.getCenterLatLng(), cluster.getClusterCount());
            cluster.setMarker(marker2);
            this.mAddMarkers.add(marker2);
        }
    }

    class MyAnimationListener implements Animation.AnimationListener {
        private List<IUniMarker> mRemoveMarkers;

        MyAnimationListener(List<IUniMarker> removeMarkers) {
            this.mRemoveMarkers = removeMarkers;
        }

        @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
        public void onAnimationStart() {
        }

        @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
        public void onAnimationEnd() {
            for (IUniMarker marker : this.mRemoveMarkers) {
                marker.destroy();
            }
            this.mRemoveMarkers.clear();
        }
    }

    /* access modifiers changed from: package-private */
    public class MarkerHandler extends Handler {
        static final int ADD_CLUSTER_LIST = 0;
        static final int ADD_SINGLE_CLUSTER = 1;
        static final int UPDATE_SINGLE_CLUSTER = 2;
        static final int UPDATE_SINGLE_CLUSTER_RENDER = 3;

        MarkerHandler(Looper looper) {
            super(looper);
        }

        public void handleMessage(Message message) {
            int i = message.what;
            if (i == 0) {
                ClusterOverlay.this.addClusterToMap((LinkedHashMap) message.obj);
            } else if (i == 1) {
                ClusterOverlay.this.addSingleClusterToMap((Cluster) message.obj);
            } else if (i == 2) {
                Cluster updateCluster = (Cluster) message.obj;
                ClusterOverlay.this.updateCluster(updateCluster);
                ClusterOverlay.this.triggerCreateListener(updateCluster);
            } else if (i == 3) {
                Cluster cluster = (Cluster) message.obj;
                ClusterOverlay.this.mAddMarkers.remove(cluster.getMarker());
                cluster.updateClusterForRender(ClusterOverlay.this.mMap, ClusterOverlay.this.mInstance);
                ClusterOverlay.this.mAddMarkers.add(cluster.getMarker());
            }
        }
    }

    /* access modifiers changed from: package-private */
    public class SignClusterHandler extends Handler {
        static final int CALCULATE_CLUSTER = 0;
        static final int CALCULATE_REMOVE_SINGLE_CLUSTER = 2;
        static final int CALCULATE_SINGLE_CLUSTER = 1;

        SignClusterHandler(Looper looper) {
            super(looper);
        }

        public void handleMessage(Message message) {
            int i = message.what;
            if (i == 0) {
                ClusterOverlay.this.calculateClusters();
            } else if (i == 1) {
                ArrayList<ClusterItem> list = null;
                if (message.obj instanceof ArrayList) {
                    list = (ArrayList) message.obj;
                    for (int i2 = 0; i2 < list.size(); i2++) {
                        ClusterItem item = list.get(i2);
                        ClusterOverlay.this.mClusterItems.put(item.getId(), item);
                    }
                } else if (message.obj instanceof ClusterItem) {
                    ClusterItem item2 = (ClusterItem) message.obj;
                    ClusterOverlay.this.mClusterItems.put(item2.getId(), item2);
                    list = new ArrayList<>();
                    list.add(item2);
                }
                if (list != null) {
                    ClusterOverlay.this.calculateSingleCluster(list);
                }
            } else if (i == 2) {
                if (message.obj instanceof JSONArray) {
                    JSONArray markerIds = (JSONArray) message.obj;
                    ArrayList<ClusterItem> list2 = new ArrayList<>();
                    for (int i3 = 0; i3 < markerIds.size(); i3++) {
                        ClusterItem item3 = (ClusterItem) ClusterOverlay.this.mClusterItems.remove(markerIds.getString(i3));
                        if (item3 != null) {
                            list2.add(item3);
                        }
                    }
                    if (list2.size() > 0) {
                        ClusterOverlay.this.calculateRemoveSingleClusters(list2);
                    }
                } else if (message.obj instanceof ClusterItem) {
                    ClusterItem item4 = (ClusterItem) message.obj;
                    ClusterOverlay.this.mClusterItems.remove(item4);
                    ClusterOverlay.this.calculateRemoveSingleCluster(item4);
                }
            }
        }
    }

    public JSONObject getClusterInfo(Cluster cluster) {
        JSONObject clusterInfo = new JSONObject();
        clusterInfo.put("clusterId", (Object) cluster.getId());
        clusterInfo.put("center", (Object) MapResourceUtils.createJsLatLng(cluster.getCenterLatLng()));
        clusterInfo.put("markerIds", (Object) cluster.getMarkerIds());
        return clusterInfo;
    }

    public List<IUniMarker> getClusterAddMarkers() {
        return this.mAddMarkers;
    }
}
