package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.text.TextUtils;
import android.widget.TextView;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.common.Constants;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.ui.ArrowTextView;

public class AbsMarkerTextView {
    private String bgColor = "#fff";
    private String borderColor;
    private int borderRadius = 0;
    private int borderWidth = 0;
    private String color = "#000";
    private String content;
    private String display;
    private float fontSize = 11.0f;
    private float mViewPort;
    private int padding = 0;
    private int textAlign = 3;

    public AbsMarkerTextView(JSONObject c, float viewPort) {
        this.mViewPort = viewPort;
        setContent(c);
        setColor(c);
        setFontSize(c);
        setBorderRadius(c);
        setBorderWidth(c);
        setBorderColor(c);
        setBgColor(c);
        setPadding(c);
        setDisplay(c);
        setTextAlign(c);
    }

    public void setContent(JSONObject c) {
        if (c.containsKey("content")) {
            this.content = c.getString("content");
        }
    }

    public void setColor(JSONObject c) {
        if (c.containsKey("color")) {
            this.color = c.getString("color");
        }
    }

    public void setFontSize(JSONObject c) {
        if (c.containsKey(Constants.Name.FONT_SIZE)) {
            this.fontSize = UniUtils.getFloat(c.get(Constants.Name.FONT_SIZE), Float.valueOf(10.0f)).floatValue();
        }
    }

    public void setBorderRadius(JSONObject c) {
        if (c.containsKey(Constants.Name.BORDER_RADIUS)) {
            this.borderRadius = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(c.get(Constants.Name.BORDER_RADIUS)), this.mViewPort);
        }
    }

    public void setBorderWidth(JSONObject c) {
        if (c.containsKey(Constants.Name.BORDER_WIDTH)) {
            int i = UniUtils.getInt(c.get(Constants.Name.BORDER_WIDTH));
            this.borderWidth = i;
            this.padding = (int) UniViewUtils.getRealSubPxByWidth((float) i, this.mViewPort);
        }
    }

    public void setBorderColor(JSONObject c) {
        if (c.containsKey(Constants.Name.BORDER_COLOR)) {
            this.borderColor = c.getString(Constants.Name.BORDER_COLOR);
        }
    }

    public void setBgColor(JSONObject c) {
        if (c.containsKey("bgColor")) {
            this.bgColor = c.getString("bgColor");
        }
    }

    public void setPadding(JSONObject c) {
        if (c.containsKey("padding")) {
            int intValue = c.getIntValue("padding");
            this.padding = intValue;
            this.padding = (int) UniViewUtils.getRealSubPxByWidth((float) intValue, this.mViewPort);
        }
    }

    public void setDisplay(JSONObject c) {
        if (c.containsKey("display")) {
            this.display = c.getString("display");
        }
    }

    public boolean isAlwaysDisPlay() {
        if (TextUtils.isEmpty(this.display) || !this.display.equals("ALWAYS")) {
            return false;
        }
        return true;
    }

    public void setTextAlign(JSONObject c) {
        if (c.containsKey(Constants.Name.TEXT_ALIGN)) {
            this.textAlign = 3;
            String align = c.getString(Constants.Name.TEXT_ALIGN);
            char c2 = 65535;
            int hashCode = align.hashCode();
            if (hashCode != -1364013995) {
                if (hashCode == 108511772 && align.equals("right")) {
                    c2 = 0;
                }
            } else if (align.equals("center")) {
                c2 = 1;
            }
            if (c2 == 0) {
                this.textAlign = 5;
            } else if (c2 == 1) {
                this.textAlign = 17;
            }
        }
    }

    public void update(JSONObject c) {
        setContent(c);
        setColor(c);
        setFontSize(c);
        setBorderRadius(c);
        setBorderWidth(c);
        setBorderColor(c);
        setBgColor(c);
        setPadding(c);
        setDisplay(c);
        setTextAlign(c);
    }

    public TextView getTextView(Context context, boolean isSharp) {
        ArrowTextView textView = new ArrowTextView(context, isSharp);
        textView.setBgColor(MapResourceUtils.getColor(this.bgColor));
        textView.setTextPadding(this.padding);
        textView.setGravity(this.textAlign);
        textView.setRadius(this.borderRadius);
        textView.setStrokeWidth(this.borderWidth);
        if (!TextUtils.isEmpty(this.borderColor)) {
            textView.setStrokeColor(MapResourceUtils.getColor(this.borderColor));
        }
        textView.setText(this.content);
        textView.setIncludeFontPadding(false);
        if (!TextUtils.isEmpty(this.color)) {
            textView.setTextColor(MapResourceUtils.getColor(this.color));
        }
        float f = this.fontSize;
        if (f > 0.0f) {
            textView.setTextSize(0, UniViewUtils.getRealPxByWidth(f, this.mViewPort));
        }
        return textView;
    }

    public void destroy() {
    }
}
