package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.view.View;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.utils.overlay.MovingPointOverlay;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.List;

public class MarkerCallout extends AbsMarkerTextView {
    private float anchorX = 0.0f;
    private float anchorY = 0.0f;
    MovingPointOverlay mCalloutSmoothMarker = null;
    Context mContext;
    protected Marker mMarker;
    protected WXMarker mRootMarker;

    public MarkerCallout(Context context, WXMarker rootMarker, JSONObject c, WXMapView mapView, float viewPort) {
        super(c, viewPort);
        this.mContext = context;
        this.mRootMarker = rootMarker;
        createMarker(rootMarker.getInstance().getPosition(), mapView);
        if (c.containsKey("anchorX")) {
            this.anchorX = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(c.getString("anchorX")), viewPort);
        }
        if (c.containsKey("anchorY")) {
            this.anchorY = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(c.getString("anchorY")), viewPort);
        }
    }

    public Marker getInstance() {
        return this.mMarker;
    }

    public void createMarker(LatLng point, WXMapView mapView) {
        MarkerOptions markerOptions = new MarkerOptions();
        markerOptions.position(point);
        markerOptions.visible(false);
        this.mMarker = mapView.getMap().addMarker(markerOptions);
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void update(JSONObject c) {
        super.update(c);
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon());
        }
    }

    public void update() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon());
        }
    }

    /* access modifiers changed from: protected */
    public BitmapDescriptor getIcon() {
        LinearLayout rootView = new LinearLayout(this.mContext);
        rootView.addView(getTextView(this.mContext, true), new LinearLayout.LayoutParams(-1, -1));
        rootView.measure(View.MeasureSpec.makeMeasureSpec(0, 0), View.MeasureSpec.makeMeasureSpec(0, 0));
        initCalloutAnchor((float) rootView.getMeasuredWidth(), (float) rootView.getMeasuredHeight());
        return BitmapDescriptorFactory.fromView(rootView);
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void destroy() {
        MovingPointOverlay movingPointOverlay = this.mCalloutSmoothMarker;
        if (movingPointOverlay != null) {
            movingPointOverlay.setMoveListener(null);
            this.mCalloutSmoothMarker.destroy();
        }
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.remove();
        }
    }

    public boolean isVisible() {
        Marker marker = this.mMarker;
        if (marker != null) {
            return marker.isVisible();
        }
        return false;
    }

    public void setVisible(boolean visible) {
        Marker marker = this.mMarker;
        if (marker == null) {
            return;
        }
        if (visible) {
            if (!marker.isVisible()) {
                this.mMarker.setVisible(true);
            }
            this.mMarker.setIcon(getIcon());
            return;
        }
        marker.setVisible(false);
    }

    public void updateVisible() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setVisible(marker.isVisible());
        }
    }

    public void setPosition(LatLng latLng) {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setPosition(latLng);
        }
    }

    public void setRotateAngle(float var1) {
    }

    public void moveAlongMarker(WXMapView mapView, int duration, List<LatLng> pos) {
        if (this.mCalloutSmoothMarker == null) {
            this.mCalloutSmoothMarker = new MovingPointOverlay(mapView.getMap(), getInstance());
        }
        this.mCalloutSmoothMarker.stopMove();
        this.mCalloutSmoothMarker.setPoints(pos);
        this.mCalloutSmoothMarker.setTotalDuration(duration / 1000);
        this.mCalloutSmoothMarker.startSmoothMove();
    }

    public void initCalloutAnchor(float iconWidth, float iconHeight) {
        int rootHeight = 0;
        int rootWidth = 0;
        float anchorU = 0.5f;
        float anchorV = 1.0f;
        if (this.mRootMarker.getHeight() > 0) {
            rootHeight = this.mRootMarker.getHeight();
            rootWidth = this.mRootMarker.getWidth();
        } else if (this.mRootMarker.getHeight() < 0 && this.mRootMarker.getInstance().getIcons().size() > 0) {
            rootHeight = this.mRootMarker.getInstance().getIcons().get(0).getHeight();
            rootWidth = this.mRootMarker.getInstance().getIcons().get(0).getWidth();
        }
        if (rootWidth > 0) {
            anchorU = 0.5f + ((((float) rootWidth) * (this.mRootMarker.getInstance().getAnchorU() - 0.5f)) / iconWidth);
            float f = this.anchorX;
            if (f != 0.0f) {
                anchorU -= f / iconWidth;
            }
        }
        if (rootHeight > 0) {
            anchorV = 1.0f + ((((float) rootHeight) * this.mRootMarker.getInstance().getAnchorV()) / iconHeight);
            float f2 = this.anchorY;
            if (f2 != 0.0f) {
                anchorV -= f2 / iconHeight;
            }
        }
        this.mMarker.setAnchor(anchorU, anchorV);
    }
}
