package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.utils.overlay.MovingPointOverlay;
import com.taobao.weex.common.Constants;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.List;

public class MarkerLabel extends AbsMarkerTextView {
    Context mContext;
    JSONObject mData;
    private int mHeight = -2;
    MovingPointOverlay mLabelSmoothMarker = null;
    private Marker mMarker;
    private Marker mRootMarker;
    private float mViewProt;
    private int mWidth = -2;
    private float x;
    private float y;

    public MarkerLabel(Context context, Marker rootMarker, JSONObject data, WXMapView mapView, float viewPort) {
        super(data, viewPort);
        this.mContext = context;
        this.mRootMarker = rootMarker;
        this.mViewProt = viewPort;
        setData(data);
        createMarker(this.mRootMarker.getPosition(), mapView);
    }

    public void createMarker(LatLng point, WXMapView mapView) {
        MarkerOptions markerOptions = new MarkerOptions();
        markerOptions.icon(getIcon());
        if (this.mWidth != 0 && this.mHeight != 0) {
            markerOptions.position(point);
            markerOptions.anchor(0.0f - (this.x / ((float) this.mWidth)), 0.0f - (this.y / ((float) this.mHeight)));
            this.mMarker = mapView.getMap().addMarker(markerOptions);
        }
    }

    public Marker getInstance() {
        return this.mMarker;
    }

    private void setData(JSONObject data) {
        this.mData = data;
        if (data.containsKey("anchorX")) {
            this.x = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(data.getString("anchorX")), this.mViewProt);
        } else if (data.containsKey(Constants.Name.X)) {
            this.x = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(data.getString(Constants.Name.X)), this.mViewProt);
        }
        if (data.containsKey("anchorY")) {
            this.y = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(data.getString("anchorY")), this.mViewProt);
        } else if (data.containsKey(Constants.Name.Y)) {
            this.y = WXViewUtils.getRealSubPxByWidth((float) MapResourceUtils.getJSONIntValue(data.getString(Constants.Name.Y)), this.mViewProt);
        }
        if (data.containsKey("width")) {
            this.mWidth = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(data.get("width")), this.mViewProt);
        }
        if (data.containsKey("height")) {
            this.mHeight = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(data.get("height")), this.mViewProt);
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void update(JSONObject data) {
        setData(data);
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon());
        }
    }

    private BitmapDescriptor getIcon() {
        LinearLayout rootView = new LinearLayout(this.mContext);
        rootView.addView(getTextView(this.mContext, false), new LinearLayout.LayoutParams(this.mWidth, this.mHeight));
        BitmapDescriptor bitmapDescriptor = BitmapDescriptorFactory.fromView(rootView);
        if (bitmapDescriptor != null) {
            this.mWidth = bitmapDescriptor.getWidth();
            this.mHeight = bitmapDescriptor.getHeight();
        }
        return bitmapDescriptor;
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.AbsMarkerTextView
    public void destroy() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.remove();
        }
    }

    public void setPosition(LatLng latLng) {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setPosition(latLng);
        }
    }

    public void setRotateAngle(float var1) {
    }

    public void moveAlongMarker(WXMapView mapView, int duration, List<LatLng> pos) {
        if (this.mMarker != null) {
            if (this.mLabelSmoothMarker == null) {
                this.mLabelSmoothMarker = new MovingPointOverlay(mapView.getMap(), getInstance());
            }
            this.mLabelSmoothMarker.stopMove();
            this.mLabelSmoothMarker.setPoints(pos);
            this.mLabelSmoothMarker.setTotalDuration(duration / 1000);
            this.mLabelSmoothMarker.startSmoothMove();
        }
    }
}
