package io.dcloud.feature.weex_amap.adapter.marker;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.Marker;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

public class MarkerMgr extends MapAbsMgr {
    ConcurrentHashMap<String, WXMarker> mMarkerCaches = new ConcurrentHashMap<>();
    ConcurrentHashMap<String, WXMarker> mMarkerTemporary = new ConcurrentHashMap<>();

    public MarkerMgr(WXSDKInstance instance, WXMapView map) {
        super(instance, map);
    }

    public synchronized void setMarkers(JSONArray markers, boolean isClear) throws Exception {
        if (markers != null) {
            try {
                if (markers.size() > 0) {
                    this.mMarkerTemporary.clear();
                    this.mMap.addCluster(markers);
                    for (int i = 0; i < markers.size(); i++) {
                        JSONObject item = markers.getJSONObject(i);
                        if (!item.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER)) {
                            if (!item.containsKey("clusterId")) {
                                String id = String.valueOf(item.hashCode());
                                if (item.containsKey("id")) {
                                    id = item.getString("id");
                                }
                                if (this.mMarkerCaches.containsKey(id)) {
                                    WXMarker marker = this.mMarkerCaches.remove(id);
                                    marker.updateMarkerOptions(item);
                                    marker.initCalloutAndLabel(this.mInstance.getContext(), this.mMap, item);
                                    this.mMarkerTemporary.put(id, marker);
                                } else if (this.mMarkerTemporary.containsKey(id)) {
                                    WXMarker marker2 = this.mMarkerTemporary.remove(id);
                                    marker2.updateMarkerOptions(item);
                                    marker2.initCalloutAndLabel(this.mInstance.getContext(), this.mMap, item);
                                    this.mMarkerTemporary.put(id, marker2);
                                } else {
                                    this.mMarkerTemporary.put(id, new WXMarker(this.mInstance, this.mMap, item, id));
                                }
                            }
                        }
                    }
                    if (isClear) {
                        destroyMarkers(this.mMarkerCaches);
                    }
                    this.mMarkerCaches.putAll(this.mMarkerTemporary);
                }
            } finally {
            }
        }
        if (isClear) {
            destroyMarkers(this.mMarkerCaches);
            this.mMarkerTemporary.clear();
        }
    }

    public WXMarker getWXMarker(Marker m) {
        if (m == null) {
            return null;
        }
        for (String key : this.mMarkerCaches.keySet()) {
            WXMarker marker = this.mMarkerCaches.get(key);
            if (m.equals(marker.getInstance())) {
                return marker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker item : this.mMap.getClusterAddMarkers()) {
            if (item instanceof WXMarker) {
                WXMarker marker2 = (WXMarker) item;
                if (m.equals(marker2.getInstance())) {
                    return marker2;
                }
            }
        }
        return null;
    }

    public WXMarker getCalloutToWXMarker(Marker m) {
        if (m == null) {
            return null;
        }
        for (String key : this.mMarkerCaches.keySet()) {
            WXMarker marker = this.mMarkerCaches.get(key);
            if (marker.getCallout() != null && m.equals(marker.getCallout().getInstance())) {
                return marker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker item : this.mMap.getClusterAddMarkers()) {
            if (item instanceof WXMarker) {
                WXMarker marker2 = (WXMarker) item;
                if (marker2.getCallout() != null && m.equals(marker2.getCallout().getInstance())) {
                    return marker2;
                }
            }
        }
        return null;
    }

    public WXMarker getLabelToWXMarker(Marker m) {
        if (m == null) {
            return null;
        }
        for (String key : this.mMarkerCaches.keySet()) {
            WXMarker marker = this.mMarkerCaches.get(key);
            if (marker.getLabel() != null && m.equals(marker.getLabel().getInstance())) {
                return marker;
            }
        }
        if (this.mMap == null || this.mMap.getClusterAddMarkers() == null) {
            return null;
        }
        for (IUniMarker item : this.mMap.getClusterAddMarkers()) {
            if (item instanceof WXMarker) {
                WXMarker marker2 = (WXMarker) item;
                if (marker2.getLabel() != null && m.equals(marker2.getLabel().getInstance())) {
                    return marker2;
                }
            }
        }
        return null;
    }

    private void destroyMarkers(Map<String, WXMarker> markers) {
        for (String id : markers.keySet()) {
            WXMarker marker = markers.get(id);
            if (marker != null) {
                marker.destroy();
            }
        }
        markers.clear();
    }

    public void removeMarkers(JSONArray ids) {
        if (ids != null) {
            for (int i = 0; i < ids.size(); i++) {
                this.mMap.removeCluster(ids);
                WXMarker marker = getMarker(ids.getString(i));
                if (marker != null) {
                    marker.destroy();
                }
            }
        }
    }

    private WXMarker getMarker(String id) {
        if (this.mMarkerTemporary.containsKey(id)) {
            return this.mMarkerTemporary.get(id);
        }
        if (this.mMarkerCaches.containsKey(id)) {
            return this.mMarkerCaches.get(id);
        }
        return null;
    }

    public void destroy() {
        ConcurrentHashMap<String, WXMarker> concurrentHashMap = this.mMarkerCaches;
        if (concurrentHashMap != null) {
            for (String key : concurrentHashMap.keySet()) {
                WXMarker marker = this.mMarkerCaches.get(key);
                if (marker != null) {
                    marker.destroy();
                }
            }
            this.mMarkerCaches.clear();
        }
        if (this.mMap != null) {
            this.mMap.clearCluster();
        }
    }

    public void hideMarkerCallout() {
        WXMarker marker;
        try {
            if (this.mMarkerCaches != null) {
                for (String key : this.mMarkerCaches.keySet()) {
                    WXMarker marker2 = this.mMarkerCaches.get(key);
                    if (marker2 != null) {
                        if (marker2.getCallout() != null) {
                            if (!marker2.getCallout().isAlwaysDisPlay()) {
                                marker2.getCallout().setVisible(false);
                            }
                        } else if (marker2.getInstance().isInfoWindowShown()) {
                            marker2.getInstance().hideInfoWindow();
                        }
                    }
                }
            }
            if (!(this.mMap == null || this.mMap.getClusterAddMarkers() == null)) {
                for (IUniMarker item : this.mMap.getClusterAddMarkers()) {
                    if ((item instanceof WXMarker) && (marker = (WXMarker) item) != null) {
                        if (marker.getCallout() != null && !marker.getCallout().isAlwaysDisPlay()) {
                            marker.getCallout().setVisible(false);
                        } else if (marker.getInstance().isInfoWindowShown()) {
                            marker.getInstance().hideInfoWindow();
                        }
                    }
                }
            }
        } catch (Exception e) {
        }
    }

    public void refreshCalloutVisible() {
        try {
            if (this.mMarkerCaches != null) {
                for (String key : this.mMarkerCaches.keySet()) {
                    WXMarker marker = this.mMarkerCaches.get(key);
                    if (!(marker == null || marker.getCallout() == null)) {
                        marker.getCallout().updateVisible();
                    }
                }
            }
            if (!(this.mMap == null || this.mMap.getClusterAddMarkers() == null)) {
                for (IUniMarker item : this.mMap.getClusterAddMarkers()) {
                    if (item instanceof WXMarker) {
                        WXMarker marker2 = (WXMarker) item;
                        if (marker2.getCallout() != null) {
                            marker2.getCallout().updateVisible();
                        }
                    }
                }
            }
        } catch (Exception e) {
        }
    }

    public void translateMarker(JSONObject data, JSCallback callback) {
        if (data != null) {
            WXMarker marker = getMarker(data.getString("markerId"));
            if (marker != null) {
                marker.translateMarker(data, callback);
            }
        } else if (callback != null) {
            Map<String, Object> params = new HashMap<>();
            params.put("type", Constants.Event.FAIL);
            callback.invokeAndKeepAlive(params);
        }
    }

    public void moveAlongMarker(JSONObject data, JSCallback callback) {
        if (data != null) {
            WXMarker marker = getMarker(data.getString("markerId"));
            Map<String, Object> params = new HashMap<>();
            if (marker != null) {
                marker.moveAlongMarker(this.mMap, data, callback);
                return;
            }
            params.put("type", Constants.Event.FAIL);
            if (callback != null) {
                callback.invoke(params);
            }
        } else if (callback != null) {
            Map<String, Object> params2 = new HashMap<>();
            params2.put("type", Constants.Event.FAIL);
            callback.invokeAndKeepAlive(params2);
        }
    }

    public void updateMarkerCallout(String markerId) {
        WXMarker wxMarker = getMarker(markerId);
        if (wxMarker != null && wxMarker.getCallout() != null) {
            wxMarker.getCallout().update();
        }
    }
}
