package io.dcloud.feature.weex_amap.adapter.marker;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.ImageView;
import android.widget.LinearLayout;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.animation.Animation;
import com.amap.api.maps.model.animation.AnimationSet;
import com.amap.api.maps.model.animation.RotateAnimation;
import com.amap.api.maps.model.animation.TranslateAnimation;
import com.amap.api.maps.utils.overlay.MovingPointOverlay;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import io.dcloud.feature.weex.adapter.FrescoLoadUtil;
import io.dcloud.feature.weex_amap.R;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class WXMarker implements IUniMarker {
    private MarkerCallout mCallout;
    private int mHeight = -1;
    private WXSDKInstance mInstance;
    private boolean mJoinCluster = false;
    private MarkerLabel mLabel;
    private Marker mMarker;
    MovingPointOverlay mSmoothMarker = null;
    private int mWidth = -1;
    private String mid;

    public int getWidth() {
        return this.mWidth;
    }

    public boolean isJoinCluster() {
        return this.mJoinCluster;
    }

    public int getHeight() {
        return this.mHeight;
    }

    public WXMarker(WXSDKInstance instance, WXMapView mapView, JSONObject data, String id) {
        this.mInstance = instance;
        this.mid = id;
        this.mMarker = mapView.getMap().addMarker(createMarkerOptions(data));
        initCalloutAndLabel(this.mInstance.getContext(), mapView, data);
    }

    public String getId() {
        return this.mid;
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public Marker getInstance() {
        return this.mMarker;
    }

    public void setCallout(MarkerCallout mCallout2) {
        this.mCallout = mCallout2;
    }

    public MarkerCallout getCallout() {
        return this.mCallout;
    }

    public MarkerLabel getLabel() {
        return this.mLabel;
    }

    public void isShowInfoWindow() {
        MarkerCallout markerCallout = this.mCallout;
        if (markerCallout != null && markerCallout.isAlwaysDisPlay()) {
            this.mCallout.setVisible(true);
        }
    }

    private MarkerOptions createMarkerOptions(JSONObject m) {
        MarkerOptions options = new MarkerOptions();
        setPosition(m, options);
        setTitle(m, options);
        setZIndex(m, options);
        setIconInfo(m, options);
        setRotate(m, options);
        setAlphe(m, options);
        setAnchor(m, options);
        setSnippet(m, options);
        if (m.containsKey(Constant.JSONKEY.JOIN_CLUSTER)) {
            this.mJoinCluster = m.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER);
        }
        return options;
    }

    public void updateMarkerOptions(JSONObject m) {
        if (getInstance() != null) {
            setPosition(m, null);
            setTitle(m, null);
            setZIndex(m, null);
            setIconInfo(m, null);
            setRotate(m, null);
            setAlphe(m, null);
            setAnchor(m, null);
            setSnippet(m, null);
            if (m.containsKey(Constant.JSONKEY.JOIN_CLUSTER)) {
                this.mJoinCluster = m.getBooleanValue(Constant.JSONKEY.JOIN_CLUSTER);
            }
        }
    }

    private void setPosition(JSONObject m, MarkerOptions options) {
        LatLng latLng = new LatLng(m.getDouble(Constant.JSONKEY.LATITUDE).doubleValue(), m.getDouble(Constant.JSONKEY.LONGITUDE).doubleValue());
        if (getInstance() != null) {
            try {
                getInstance().setPosition(latLng);
                if (this.mCallout != null) {
                    this.mCallout.setPosition(latLng);
                }
                if (this.mLabel != null) {
                    this.mLabel.setPosition(latLng);
                }
            } catch (Exception e) {
            }
        } else if (options != null) {
            options.position(latLng);
        }
    }

    private void setTitle(JSONObject m, MarkerOptions options) {
        if (m.containsKey("title")) {
            String title = m.getString("title");
            if (getInstance() != null && !TextUtils.isEmpty(getInstance().getTitle()) && !getInstance().getTitle().equals(title)) {
                getInstance().setTitle(title);
            } else if (options != null) {
                options.title(title);
            }
        }
    }

    private void setZIndex(JSONObject m, MarkerOptions options) {
        if (m.containsKey(Constant.JSONKEY.ZINDEX)) {
            float zIndex = m.getFloat(Constant.JSONKEY.ZINDEX).floatValue();
            if (getInstance() != null && zIndex != getInstance().getZIndex()) {
                getInstance().setZIndex(zIndex);
            } else if (options != null) {
                options.zIndex(zIndex);
            }
            if (getCallout() != null) {
                getCallout().getInstance().setZIndex(zIndex + 1.0f);
            }
            if (getLabel() != null) {
                getLabel().getInstance().setZIndex(1.0f + zIndex);
            }
        }
    }

    private void setIconInfo(JSONObject m, MarkerOptions options) {
        if (m.containsKey("width")) {
            this.mWidth = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(m.get("width")), this.mInstance.getInstanceViewPortWidthWithFloat());
        }
        if (m.containsKey("height")) {
            this.mHeight = (int) WXViewUtils.getRealSubPxByWidth((float) UniUtils.getInt(m.get("height")), this.mInstance.getInstanceViewPortWidthWithFloat());
        }
        if (this.mHeight == 0 || this.mWidth == 0) {
            loadImageViewIcon(null, 1, 1, options);
        } else if (m.containsKey(Constant.JSONKEY.ICONPATH)) {
            String path = m.getString(Constant.JSONKEY.ICONPATH);
            if (!Constant.TRANSPARENT.equals(path)) {
                loadImageToIcon(this.mInstance.rewriteUri(Uri.parse(path), "image"), this.mWidth, this.mHeight, options, m);
            }
        } else {
            loadImageViewIcon(BitmapFactory.decodeResource(this.mInstance.getContext().getResources(), R.drawable.dcloud_map_marker_ic), this.mWidth, this.mHeight, options);
        }
    }

    private void setRotate(JSONObject m, MarkerOptions options) {
        if (m.containsKey("rotate")) {
            float rotate = -m.getFloat("rotate").floatValue();
            if (getInstance() != null && getInstance().getRotateAngle() != rotate) {
                getInstance().setRotateAngle(rotate);
                MarkerLabel markerLabel = this.mLabel;
                if (markerLabel != null) {
                    markerLabel.setRotateAngle(rotate);
                }
                MarkerCallout markerCallout = this.mCallout;
                if (markerCallout != null) {
                    markerCallout.setRotateAngle(rotate);
                }
            } else if (options != null) {
                options.rotateAngle(rotate);
            }
        }
    }

    private void setAlphe(JSONObject m, MarkerOptions options) {
        if (m.containsKey(Constant.JSONKEY.ALPHE)) {
            float alphe = m.getFloat(Constant.JSONKEY.ALPHE).floatValue();
            if (getInstance() != null && getInstance().getAlpha() != alphe) {
                getInstance().setAlpha(alphe);
            } else if (options != null) {
                options.alpha(alphe);
            }
        }
    }

    private void setAnchor(JSONObject m, MarkerOptions options) {
        JSONObject j;
        if (m.containsKey("anchor") && (j = m.getJSONObject("anchor")) != null) {
            if (getInstance() != null) {
                getInstance().setAnchor(j.getFloat(Constants.Name.X).floatValue(), j.getFloat(Constants.Name.Y).floatValue());
            } else {
                options.anchor(j.getFloat(Constants.Name.X).floatValue(), j.getFloat(Constants.Name.Y).floatValue());
            }
        }
    }

    private void setSnippet(JSONObject m, MarkerOptions options) {
        if (m.containsKey(Constant.JSONKEY.ARIA_LABEL)) {
            String s = m.getString(Constant.JSONKEY.ARIA_LABEL);
            if (getInstance() != null) {
                getInstance().setSnippet(s);
            } else {
                options.snippet(s);
            }
        }
    }

    private void loadImageToIcon(Uri uri, int width, int height, final MarkerOptions options, final JSONObject m) {
        FrescoLoadUtil.getInstance().loadImageBitmap(this.mInstance.getContext(), uri.toString(), width, height, new BitmapLoadCallback<Bitmap>() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass1 */

            public void onSuccess(String url, Bitmap result) {
                WXMarker.this.loadIcon(result, options, m);
            }

            @Override // io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback
            public void onFailure(String url, Throwable throwable) {
            }
        });
    }

    private void loadImageViewIcon(Bitmap bitmap, int width, int height, MarkerOptions options) {
        ImageView view = new ImageView(this.mInstance.getContext());
        view.setScaleType(ImageView.ScaleType.FIT_XY);
        view.setLayoutParams(new LinearLayout.LayoutParams(width, height));
        if (bitmap != null) {
            view.setImageBitmap(bitmap);
        }
        BitmapDescriptor descriptor = BitmapDescriptorFactory.fromView(view);
        if (getInstance() != null) {
            getInstance().setIcon(descriptor);
        } else if (options != null) {
            options.icon(descriptor);
        }
        if (getCallout() != null) {
            getCallout().update();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void loadIcon(Bitmap bitmap, MarkerOptions options, JSONObject m) {
        BitmapDescriptor descriptor = BitmapDescriptorFactory.fromBitmap(bitmap);
        if (getInstance() != null) {
            getInstance().setIcon(descriptor);
        } else if (options != null) {
            options.icon(descriptor);
        }
        if (getCallout() != null && m != null) {
            getCallout().update();
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.marker.IUniMarker
    public void destroy() {
        MovingPointOverlay movingPointOverlay = this.mSmoothMarker;
        if (movingPointOverlay != null) {
            movingPointOverlay.setMoveListener(null);
            this.mSmoothMarker.destroy();
        }
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.destroy();
        }
        MarkerCallout markerCallout = this.mCallout;
        if (markerCallout != null) {
            markerCallout.destroy();
        }
        MarkerLabel markerLabel = this.mLabel;
        if (markerLabel != null) {
            markerLabel.destroy();
        }
    }

    public void initCalloutAndLabel(Context context, WXMapView mapView, JSONObject item) {
        if (getCallout() == null) {
            setCallout(createMarkerCallout(context, mapView, item));
        } else if (item.containsKey(Constant.JSONKEY.CALLOUT)) {
            getCallout().update(item.getJSONObject(Constant.JSONKEY.CALLOUT));
        } else {
            getCallout().destroy();
            this.mCallout = null;
        }
        isShowInfoWindow();
        if (item.containsKey(Constant.JSONKEY.LABEL)) {
            MarkerLabel markerLabel = this.mLabel;
            if (markerLabel != null) {
                markerLabel.update(item.getJSONObject(Constant.JSONKEY.LABEL));
            } else {
                this.mLabel = new MarkerLabel(context, this.mMarker, item.getJSONObject(Constant.JSONKEY.LABEL), mapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            }
            this.mLabel.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
        }
    }

    private MarkerCallout createMarkerCallout(Context context, WXMapView mapView, JSONObject m) {
        if (m.containsKey(Constant.JSONKEY.CUSTOM_CALLOUT)) {
            MarkerCallout callout = new MarkerCustomCallout(context, this, m.getJSONObject(Constant.JSONKEY.CUSTOM_CALLOUT), mapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            callout.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
            return callout;
        } else if (!m.containsKey(Constant.JSONKEY.CALLOUT)) {
            return null;
        } else {
            MarkerCallout callout2 = new MarkerCallout(context, this, m.getJSONObject(Constant.JSONKEY.CALLOUT), mapView, this.mInstance.getInstanceViewPortWidthWithFloat());
            callout2.getInstance().setZIndex(getInstance().getZIndex() + 1.0f);
            return callout2;
        }
    }

    public void moveAlongMarker(WXMapView mapView, JSONObject data, final JSCallback callback) {
        JSONArray pointsJson;
        int duration = UniUtils.getInteger(data.get("duration"), 0).intValue();
        if (duration < 1000) {
            duration = 1000;
        }
        final Map<String, Object> params = new HashMap<>();
        if (duration > 0) {
            if (this.mSmoothMarker == null) {
                this.mSmoothMarker = new MovingPointOverlay(mapView.getMap(), getInstance());
            }
            this.mSmoothMarker.stopMove();
            List<LatLng> points = null;
            if (data.containsKey("path") && (pointsJson = data.getJSONArray("path")) != null && (points = getMovePoints(pointsJson)) != null && points.size() > 0) {
                this.mSmoothMarker.setPoints(points);
            }
            if (points != null) {
                this.mSmoothMarker.setTotalDuration(duration / 1000);
                this.mSmoothMarker.setMoveListener(new MovingPointOverlay.MoveListener() {
                    /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass2 */

                    @Override // com.amap.api.maps.utils.overlay.MovingPointOverlay.MoveListener
                    public void move(double v) {
                        if (v <= 0.0d) {
                            if (callback != null) {
                                params.put("type", WXImage.SUCCEED);
                                callback.invoke(params);
                            }
                            WXMarker.this.mSmoothMarker.setMoveListener(null);
                        }
                    }
                });
                MarkerLabel markerLabel = this.mLabel;
                if (markerLabel != null) {
                    markerLabel.moveAlongMarker(mapView, duration, points);
                }
                MarkerCallout markerCallout = this.mCallout;
                if (markerCallout != null) {
                    markerCallout.moveAlongMarker(mapView, duration, points);
                }
                this.mSmoothMarker.startSmoothMove();
                return;
            }
        }
        params.put("type", Constants.Event.FAIL);
        if (callback != null) {
            callback.invoke(params);
        }
    }

    public void translateMarker(JSONObject data, JSCallback callback) {
        boolean moveWithRotate;
        long duration;
        LatLng d = MapResourceUtils.crateLatLng(data.getJSONObject("destination"));
        if (data.containsKey("moveWithRotate")) {
            moveWithRotate = data.getBoolean("moveWithRotate").booleanValue();
        } else {
            moveWithRotate = false;
        }
        if (data.containsKey("duration")) {
            duration = UniUtils.getLong(data.get("duration"));
        } else {
            duration = 1000;
        }
        Marker m = getInstance();
        if (data.containsKey("rotate")) {
            float rotate = -UniUtils.parseFloat(data.get("rotate"));
            rotateToTranslateAnimation(m, rotate, duration, d, moveWithRotate, callback);
            MarkerLabel markerLabel = this.mLabel;
            if (markerLabel != null) {
                rotateToTranslateAnimation(markerLabel.getInstance(), rotate, duration, d, moveWithRotate, null);
            }
            MarkerCallout markerCallout = this.mCallout;
            if (markerCallout != null) {
                rotateToTranslateAnimation(markerCallout.getInstance(), this.mCallout.getInstance().getRotateAngle(), duration, d, moveWithRotate, null);
            }
        } else {
            translateAnimation(d, duration, m, callback);
            MarkerLabel markerLabel2 = this.mLabel;
            if (markerLabel2 != null) {
                translateAnimation(d, duration, markerLabel2.getInstance(), null);
            }
            MarkerCallout markerCallout2 = this.mCallout;
            if (markerCallout2 != null) {
                translateAnimation(d, duration, markerCallout2.getInstance(), null);
            }
        }
        if (callback != null) {
            Map<String, Object> params = new HashMap<>();
            params.put("type", WXImage.SUCCEED);
            callback.invokeAndKeepAlive(params);
        }
    }

    private void rotateToTranslateAnimation(final Marker m, float rotate, long duration, final LatLng d, boolean moveWithRotate, final JSCallback callback) {
        if (moveWithRotate) {
            RotateAnimation rotateAnimation = new RotateAnimation(m.getRotateAngle(), rotate);
            rotateAnimation.setDuration(duration);
            TranslateAnimation translateAnimation = new TranslateAnimation(d);
            translateAnimation.setDuration(duration);
            AnimationSet animationSet = new AnimationSet(true);
            animationSet.addAnimation(rotateAnimation);
            animationSet.addAnimation(translateAnimation);
            animationSet.setAnimationListener(new Animation.AnimationListener() {
                /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass3 */

                @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
                public void onAnimationStart() {
                }

                @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
                public void onAnimationEnd() {
                    if (callback != null) {
                        Map<String, Object> params = new HashMap<>();
                        params.put("type", "animationEnd");
                        callback.invokeAndKeepAlive(params);
                    }
                }
            });
            m.setAnimation(animationSet);
            m.startAnimation();
            return;
        }
        long rotateDuration = (long) (((double) duration) * 0.3d);
        final long translateDuration = duration - rotateDuration;
        RotateAnimation rotateAnimation2 = new RotateAnimation(m.getRotateAngle(), rotate);
        rotateAnimation2.setDuration(rotateDuration);
        rotateAnimation2.setAnimationListener(new Animation.AnimationListener() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass4 */

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationStart() {
            }

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationEnd() {
                WXMarker.this.translateAnimation(d, translateDuration, m, callback);
            }
        });
        m.setAnimation(rotateAnimation2);
        m.startAnimation();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void translateAnimation(LatLng d, long duration, Marker m, final JSCallback callback) {
        TranslateAnimation translateAnimation = new TranslateAnimation(d);
        translateAnimation.setDuration(duration);
        translateAnimation.setAnimationListener(new Animation.AnimationListener() {
            /* class io.dcloud.feature.weex_amap.adapter.marker.WXMarker.AnonymousClass5 */

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationStart() {
            }

            @Override // com.amap.api.maps.model.animation.Animation.AnimationListener
            public void onAnimationEnd() {
                if (callback != null) {
                    Map<String, Object> params = new HashMap<>();
                    params.put("type", "animationEnd");
                    callback.invokeAndKeepAlive(params);
                }
            }
        });
        m.setAnimation(translateAnimation);
        m.startAnimation();
    }

    public boolean isCalloutShown() {
        if (getCallout() != null) {
            return getCallout().getInstance().isVisible();
        }
        return false;
    }

    public void showCallout() {
        if (getCallout() != null && !getCallout().isAlwaysDisPlay()) {
            getCallout().setVisible(true);
        }
    }

    public void hideCallout() {
        if (getCallout() != null && !getCallout().isAlwaysDisPlay()) {
            getCallout().setVisible(false);
        }
    }

    private List<LatLng> getMovePoints(JSONArray points) {
        List<LatLng> ps = new ArrayList<>();
        if (points.size() > 0) {
            for (int i = 0; i < points.size(); i++) {
                JSONObject item = points.getJSONObject(i);
                if (item != null) {
                    ps.add(new LatLng(Double.valueOf(item.getDoubleValue(Constant.JSONKEY.LATITUDE)).doubleValue(), Double.valueOf(item.getDoubleValue(Constant.JSONKEY.LONGITUDE)).doubleValue()));
                }
            }
        }
        return ps;
    }

    public void setToTop() {
        MarkerLabel markerLabel = this.mLabel;
        if (markerLabel != null) {
            markerLabel.getInstance().setToTop();
        }
        MarkerCallout markerCallout = this.mCallout;
        if (markerCallout != null && markerCallout.isVisible()) {
            this.mCallout.getInstance().setToTop();
        }
    }
}
