package io.dcloud.feature.weex_amap.adapter.polygon;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.Polygon;
import com.amap.api.maps.model.PolygonOptions;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.Iterator;

public class PolygonMgr extends MapAbsMgr {
    ArrayList<Polygon> mPolygonCaches = new ArrayList<>();

    public PolygonMgr(WXSDKInstance instance, WXMapView map) {
        super(instance, map);
    }

    public void setPolygon(JSONArray polygons) {
        if (polygons == null || polygons.size() <= 0) {
            clearPolygon();
            return;
        }
        ArrayList<Polygon> polygonList = new ArrayList<>();
        for (int i = 0; i < polygons.size(); i++) {
            PolygonOptions p = createPolygonOptions(polygons.getJSONObject(i));
            if (p != null) {
                polygonList.add(this.mMap.getMap().addPolygon(p));
            }
        }
        clearPolygon();
        if (polygonList.size() > 0) {
            this.mPolygonCaches.addAll(polygonList);
        }
    }

    private PolygonOptions createPolygonOptions(JSONObject item) {
        PolygonOptions p = null;
        if (item != null) {
            if (!item.containsKey("points")) {
                return null;
            }
            p = new PolygonOptions();
            p.addAll(MapResourceUtils.crateLatLngs(item.getJSONArray("points")));
            if (item.containsKey(Constant.Name.STROKE_WIDTH)) {
                p.strokeWidth(WXViewUtils.getRealSubPxByWidth(UniUtils.getFloat(item.get(Constant.Name.STROKE_WIDTH)), this.mInstance.getInstanceViewPortWidthWithFloat()));
            }
            if (item.containsKey(Constant.Name.STROKE_COLOR)) {
                p.strokeColor(MapResourceUtils.getColor(item.getString(Constant.Name.STROKE_COLOR)));
            }
            if (item.containsKey(Constant.Name.FILL_COLOR)) {
                p.fillColor(MapResourceUtils.getColor(item.getString(Constant.Name.FILL_COLOR)));
            }
            if (item.containsKey(Constant.JSONKEY.ZINDEX)) {
                p.zIndex(item.getFloat(Constant.JSONKEY.ZINDEX).floatValue());
            }
        }
        return p;
    }

    public void clearPolygon() {
        ArrayList<Polygon> arrayList = this.mPolygonCaches;
        if (arrayList != null) {
            Iterator<Polygon> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().remove();
            }
            this.mPolygonCaches.clear();
        }
    }
}
