package io.dcloud.feature.weex_amap.adapter.polyline;

import android.net.Uri;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.Polyline;
import com.amap.api.maps.model.PolylineOptions;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.weex_amap.R;
import io.dcloud.feature.weex_amap.adapter.MapAbsMgr;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class PolylineMgr extends MapAbsMgr {
    ArrayList<Polyline> mPolylineCaches = new ArrayList<>();

    public PolylineMgr(WXSDKInstance instance, WXMapView map) {
        super(instance, map);
    }

    public void setPolyline(JSONArray polylines) {
        Polyline p;
        if (polylines == null || polylines.size() <= 0) {
            clearPolylines();
            return;
        }
        ArrayList<Polyline> lines = new ArrayList<>();
        for (int i = 0; i < polylines.size(); i++) {
            PolylineOptions polylineOptions = createPolylineOptions(polylines.getJSONObject(i));
            if (!(polylineOptions == null || (p = this.mMap.getMap().addPolyline(polylineOptions)) == null)) {
                lines.add(p);
            }
        }
        clearPolylines();
        if (lines.size() > 0) {
            this.mPolylineCaches.addAll(lines);
        }
    }

    public PolylineOptions createPolylineOptions(JSONObject item) {
        PolylineOptions polylineOptions = null;
        if (item != null) {
            if (!item.containsKey("points")) {
                return null;
            }
            polylineOptions = new PolylineOptions();
            polylineOptions.setPoints(MapResourceUtils.crateLatLngs(item.getJSONArray("points")));
            if (item.containsKey("width")) {
                polylineOptions.width(WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(item.getString("width")), this.mInstance.getInstanceViewPortWidthWithFloat()));
            }
            if (item.containsKey("colorList")) {
                JSONArray list = item.getJSONArray("colorList");
                if (list != null && list.size() > 0) {
                    List<Integer> colorList = new ArrayList<>();
                    Iterator<Object> it = list.iterator();
                    while (it.hasNext()) {
                        colorList.add(Integer.valueOf(MapResourceUtils.getColor(it.next().toString())));
                    }
                    polylineOptions.colorValues(colorList).useGradient(true);
                }
            } else if (item.containsKey("color")) {
                polylineOptions.color(MapResourceUtils.getColor(item.getString("color")));
            }
            if (!item.containsKey("dottedLine") || !item.getBoolean("dottedLine").booleanValue()) {
                polylineOptions.setDottedLine(false);
            } else {
                polylineOptions.setDottedLine(true);
                polylineOptions.setDottedLineType(0);
            }
            if (!item.containsKey("arrowLine") || !item.getBoolean("arrowLine").booleanValue()) {
                polylineOptions.setUseTexture(false);
            } else {
                polylineOptions.setUseTexture(true);
                if (item.containsKey("arrowIconPath")) {
                    BitmapDescriptor bitmap = BitmapDescriptorFactory.fromPath(this.mInstance.rewriteUri(Uri.parse(item.getString("arrowIconPath")), "image").getPath());
                    if (bitmap != null) {
                        polylineOptions.setCustomTexture(bitmap);
                    }
                } else {
                    BitmapDescriptor bitmap2 = BitmapDescriptorFactory.fromResource(R.drawable.dcloud_traffic_texture_blue);
                    if (bitmap2 != null) {
                        polylineOptions.setCustomTexture(bitmap2);
                    }
                }
            }
        }
        return polylineOptions;
    }

    public void clearPolylines() {
        ArrayList<Polyline> arrayList = this.mPolylineCaches;
        if (arrayList != null) {
            Iterator<Polyline> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().remove();
            }
            this.mPolylineCaches.clear();
        }
    }
}
