package io.dcloud.feature.weex_amap.component;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.location.Location;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.MotionEvent;
import android.view.View;
import android.widget.FrameLayout;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.amap.api.location.AMapLocationClient;
import com.amap.api.location.AMapLocationClientOption;
import com.amap.api.maps.AMap;
import com.amap.api.maps.CameraUpdateFactory;
import com.amap.api.maps.MapsInitializer;
import com.amap.api.maps.UiSettings;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.CameraPosition;
import com.amap.api.maps.model.CustomMapStyleOptions;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MyLocationStyle;
import com.amap.api.maps.model.Poi;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import io.dcloud.feature.uniapp.dom.UniCSSConstants;
import io.dcloud.feature.uniapp.layout.UniContentBoxMeasurement;
import io.dcloud.feature.uniapp.ui.action.AbsComponentData;
import io.dcloud.feature.uniapp.ui.component.AbsVContainer;
import io.dcloud.feature.uniapp.ui.component.UniComponentProp;
import io.dcloud.feature.uniapp.ui.component.UniVContainer;
import io.dcloud.feature.uniapp.utils.UniLogUtils;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import io.dcloud.feature.weex.adapter.FrescoLoadUtil;
import io.dcloud.feature.weex.adapter.IWeexMap;
import io.dcloud.feature.weex.extend.DCCoverViewComponent;
import io.dcloud.feature.weex.extend.IDCCoverViewUpdate;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.feature.weex_amap.adapter.MapInterface;
import io.dcloud.feature.weex_amap.adapter.MapResourceUtils;
import io.dcloud.feature.weex_amap.adapter.WXMapView;
import io.dcloud.feature.weex_amap.adapter.circle.CircleMgr;
import io.dcloud.feature.weex_amap.adapter.cluster.Cluster;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterClickListener;
import io.dcloud.feature.weex_amap.adapter.cluster.OnClusterCreateListener;
import io.dcloud.feature.weex_amap.adapter.control.ControlMgr;
import io.dcloud.feature.weex_amap.adapter.ground.GroundMgr;
import io.dcloud.feature.weex_amap.adapter.marker.MarkerMgr;
import io.dcloud.feature.weex_amap.adapter.marker.WXMarker;
import io.dcloud.feature.weex_amap.adapter.polygon.PolygonMgr;
import io.dcloud.feature.weex_amap.adapter.polyline.PolylineMgr;
import io.dcloud.feature.weex_amap.ui.MapLayout;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.concurrent.atomic.AtomicBoolean;

public class WXAMapViewComponent extends UniVContainer<FrameLayout> implements IWeexMap, MapInterface, IDCCoverViewUpdate {
    private static final int REQUEST_CODE_MAPVIEW = 11224;
    private static final String TAG = "WXAMapViewComponent";
    private static String[] permissions = {"android.permission.ACCESS_FINE_LOCATION", "android.permission.ACCESS_COARSE_LOCATION"};
    private String defBackgroundColor;
    private boolean isBuilding3D;
    private boolean isChangeStart;
    private boolean isCompassEnable;
    private boolean isEnableIndoorMap;
    private boolean isEnablePoi;
    private boolean isEnableSatellite;
    private boolean isEnableTraffic;
    private AtomicBoolean isInited;
    private AtomicBoolean isMapLoaded;
    private boolean isMyLocationEnable;
    private boolean isOverLookingEnable;
    private boolean isRotateEnable;
    private boolean isScrollEnable;
    boolean isSetUpdate;
    private boolean isShowAnimationEnd;
    private boolean isShowScale;
    private boolean isZoomEnable;
    private AMap mAMap;
    private Activity mActivity;
    String mCameraType;
    private CircleMgr mCircleMgr;
    private ControlMgr mControlMgr;
    private float mDefHeight;
    private float mDefWidth;
    boolean mDragged;
    private GroundMgr mGroundMgr;
    private long mLoadTime;
    private AMapLocationClient mLocationClient;
    private AMapLocationClientOption mLocationOption;
    private Point mMapCenterPoint;
    private FrameLayout mMapContainer;
    private WXMapView mMapView;
    private MarkerMgr mMarkerMgr;
    private Location mMyLocation;
    AMap.OnMyLocationChangeListener mMyLocationCallBack;
    private PolygonMgr mPolygonMgr;
    private PolylineMgr mPolylineMgr;
    private UiSettings mUiSettings;
    private float mZoomLevel;
    private MyLocationStyle myLocationStyle;
    private Queue<MapOperationTask> paddingTasks;

    /* access modifiers changed from: package-private */
    public interface MapOperationTask {
        void execute(WXMapView wXMapView);
    }

    public WXAMapViewComponent(UniSDKInstance instance, AbsVContainer parent, AbsComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.isZoomEnable = true;
        this.isBuilding3D = true;
        this.isCompassEnable = false;
        this.isScrollEnable = true;
        this.isRotateEnable = false;
        this.isMyLocationEnable = false;
        this.isOverLookingEnable = false;
        this.isEnableSatellite = false;
        this.isEnableTraffic = false;
        this.isShowScale = false;
        this.isEnablePoi = true;
        this.isEnableIndoorMap = false;
        this.mZoomLevel = 16.0f;
        this.isMapLoaded = new AtomicBoolean(false);
        this.isInited = new AtomicBoolean(false);
        this.paddingTasks = new LinkedList();
        this.defBackgroundColor = "#f1f1f1";
        this.mLoadTime = 0;
        this.isChangeStart = false;
        this.mDragged = false;
        this.mCameraType = "drag";
        this.isSetUpdate = false;
        this.mDefHeight = 0.0f;
        this.mDefWidth = 0.0f;
        this.isShowAnimationEnd = false;
        this.mLoadTime = System.currentTimeMillis();
        this.mDefHeight = UniViewUtils.getRealPxByWidth(150.0f, getInstance().getInstanceViewPortWidthWithFloat());
        this.mDefWidth = UniViewUtils.getRealPxByWidth(300.0f, getInstance().getInstanceViewPortWidthWithFloat());
        if (!basicComponentData.getStyles().containsKey("backgroundColor")) {
            basicComponentData.getStyles().put("backgroundColor", (Object) this.defBackgroundColor);
        }
        if (!basicComponentData.getStyles().containsKey(Constants.Name.FLEX)) {
            setContentBoxMeasurement(new UniContentBoxMeasurement() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass1 */

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                    if (UniCSSConstants.isUndefined(height)) {
                        height = WXAMapViewComponent.this.mDefHeight;
                    }
                    this.mMeasureHeight = height;
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutBefore() {
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutAfter(float computedWidth, float computedHeight) {
                }
            });
        }
        getInstance().addFrameViewEventListener(new WXSDKInstance.FrameViewEventListener() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass2 */

            @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
            public void onShowAnimationEnd() {
                WXAMapViewComponent.this.isShowAnimationEnd = true;
                if (WXAMapViewComponent.this.mMapView != null) {
                    WXAMapViewComponent.this.mMapView.setVisibility(0);
                    UniLogUtils.e(WXAMapViewComponent.TAG, "Map VISIBLE");
                }
                WXAMapViewComponent.this.getInstance().removeFrameViewEventListener(this);
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public FrameLayout initComponentHostView(Context context) {
        AppRuntime.checkPrivacyComplianceAndPrompt(context, "nvue-map");
        this.mMapContainer = new MapLayout(context);
        if (context instanceof Activity) {
            this.mActivity = (Activity) context;
        }
        createMap();
        return this.mMapContainer;
    }

    private void createMap() {
        FrameLayout frameLayout = this.mMapContainer;
        if (frameLayout != null) {
            int index = -1;
            if (frameLayout.getChildCount() > 0) {
                index = 0;
            }
            try {
                MapsInitializer.initialize(getContext());
                boolean shown = !AppRuntime.hasPrivacyForNotShown(getContext());
                PlatformUtil.invokeMethod("com.amap.api.maps.MapsInitializer", "updatePrivacyShow", null, new Class[]{Context.class, Boolean.TYPE, Boolean.TYPE}, new Object[]{getContext(), true, Boolean.valueOf(shown)});
                PlatformUtil.invokeMethod("com.amap.api.maps.MapsInitializer", "updatePrivacyAgree", null, new Class[]{Context.class, Boolean.TYPE}, new Object[]{getContext(), Boolean.valueOf(shown)});
                this.mMapView = new WXMapView(getContext(), getInstance());
                if (this.mMarkerMgr == null) {
                    this.mMarkerMgr = new MarkerMgr(getInstance(), this.mMapView);
                }
                this.mMapContainer.addView(this.mMapView, index, new FrameLayout.LayoutParams(-1, -1));
                this.mMapView.onCreate(null);
                this.mMapView.setVisibility(4);
                UniLogUtils.e(TAG, "Create MapView " + this.mMapView.toString());
                initMap();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    /* access modifiers changed from: protected */
    public void setHostLayoutParams(FrameLayout host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((View) host, width, height, left, right, top, bottom);
        if (!this.isMapLoaded.get() && !this.isInited.get()) {
            this.isInited.set(true);
            this.mMapContainer.postDelayed(new Runnable() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass3 */

                public void run() {
                    if (WXAMapViewComponent.this.getInstance() == null) {
                        return;
                    }
                    if (WXAMapViewComponent.this.isShowAnimationEnd || WXAMapViewComponent.this.getInstance().isFrameViewShow()) {
                        WXAMapViewComponent.this.mMapView.setVisibility(0);
                    }
                }
            }, 0);
        }
    }

    @Override // io.dcloud.feature.weex_amap.adapter.MapInterface
    public void initMap() {
        this.isMapLoaded.set(false);
        if (this.mAMap == null) {
            this.mMapCenterPoint = new Point();
            AMap map = this.mMapView.getMap();
            this.mAMap = map;
            map.setMinZoomLevel(3.0f);
            this.mAMap.setMaxZoomLevel(20.0f);
            String language = LanguageUtil.getCurrentLocaleLanguage(getContext());
            if (TextUtils.isEmpty(language) || language.startsWith("zh")) {
                this.mAMap.setMapLanguage("zh_cn");
            } else {
                this.mAMap.setMapLanguage("en");
            }
            setCenter(getAttrs().get(Constant.JSONKEY.LATITUDE), getAttrs().get(Constant.JSONKEY.LONGITUDE));
            this.mAMap.setOnMapLoadedListener(new AMap.OnMapLoadedListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass4 */

                @Override // com.amap.api.maps.AMap.OnMapLoadedListener
                public void onMapLoaded() {
                    UniLogUtils.e(WXAMapViewComponent.TAG, "Map loaded");
                    WXAMapViewComponent.this.isMapLoaded.set(true);
                    WXAMapViewComponent.this.mMapView.postDelayed(new Runnable() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass4.AnonymousClass1 */

                        public void run() {
                            WXAMapViewComponent.this.execPaddingTasks();
                        }
                    }, 16);
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.UPDATED, null);
                }
            });
            this.mAMap.setOnMapClickListener(new AMap.OnMapClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass5 */

                @Override // com.amap.api.maps.AMap.OnMapClickListener
                public void onMapClick(LatLng latLng) {
                    WXAMapViewComponent.this.mMarkerMgr.hideMarkerCallout();
                    JSONObject data = new JSONObject();
                    data.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(latLng.longitude));
                    data.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(latLng.latitude));
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDTAP, data);
                }
            });
            this.mAMap.setOnMarkerClickListener(new AMap.OnMarkerClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass6 */

                @Override // com.amap.api.maps.AMap.OnMarkerClickListener
                public boolean onMarkerClick(Marker m) {
                    if (m == null) {
                        return false;
                    }
                    if (WXAMapViewComponent.this.mMapView != null && WXAMapViewComponent.this.mMapView.onMarkerClick(m)) {
                        return true;
                    }
                    JSONObject data = new JSONObject();
                    WXMarker marker = WXAMapViewComponent.this.mMarkerMgr.getWXMarker(m);
                    if (marker != null) {
                        marker.setToTop();
                        data.put("markerId", MapResourceUtils.getId(marker.getId()));
                        if (marker.getCallout() != null) {
                            WXAMapViewComponent.this.mMarkerMgr.hideMarkerCallout();
                            if (!marker.getCallout().isAlwaysDisPlay()) {
                                if (marker.isCalloutShown()) {
                                    marker.hideCallout();
                                } else {
                                    marker.showCallout();
                                }
                            }
                        } else if (m.isInfoWindowShown()) {
                            m.hideInfoWindow();
                        } else {
                            m.showInfoWindow();
                        }
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_MARKER_TAP, data);
                        return true;
                    }
                    WXMarker marker2 = WXAMapViewComponent.this.mMarkerMgr.getCalloutToWXMarker(m);
                    if (marker2 != null) {
                        data.put("markerId", MapResourceUtils.getId(marker2.getId()));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_CALLOUT_TAP, data);
                        return true;
                    }
                    WXMarker marker3 = WXAMapViewComponent.this.mMarkerMgr.getLabelToWXMarker(m);
                    if (marker3 != null) {
                        data.put("markerId", MapResourceUtils.getId(marker3.getId()));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_LABEL_TAP, data);
                        return true;
                    } else if (marker3 != null || !WXAMapViewComponent.this.equalsMyLocationMarker(m.getPosition())) {
                        return false;
                    } else {
                        JSONObject point = new JSONObject();
                        point.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(m.getPosition().longitude));
                        point.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(m.getPosition().latitude));
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP, point);
                        return true;
                    }
                }
            });
            this.mAMap.setOnCameraChangeListener(new AMap.OnCameraChangeListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass7 */

                @Override // com.amap.api.maps.AMap.OnCameraChangeListener
                public void onCameraChange(CameraPosition cameraPosition) {
                    if (WXAMapViewComponent.this.mMapView != null) {
                        WXAMapViewComponent.this.mMapView.onCameraChange(cameraPosition);
                    }
                    WXAMapViewComponent.this.mMapCenterPoint.update(cameraPosition.target.latitude, cameraPosition.target.longitude);
                    if (!WXAMapViewComponent.this.isChangeStart && WXAMapViewComponent.this.isMapLoaded.get()) {
                        if (WXAMapViewComponent.this.mDragged) {
                            WXAMapViewComponent.this.mCameraType = Constant.Name.GESTURE;
                        } else {
                            WXAMapViewComponent.this.mCameraType = "update";
                        }
                        WXAMapViewComponent.this.mZoomLevel = cameraPosition.zoom;
                        WXAMapViewComponent.this.isChangeStart = true;
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDREGION_CHANGE, "begin");
                    }
                }

                @Override // com.amap.api.maps.AMap.OnCameraChangeListener
                public void onCameraChangeFinish(CameraPosition cameraPosition) {
                    if (WXAMapViewComponent.this.isChangeStart && WXAMapViewComponent.this.isMapLoaded.get()) {
                        if (WXAMapViewComponent.this.mMapView != null) {
                            WXAMapViewComponent.this.mMapView.onCameraChangeFinish(cameraPosition);
                        }
                        WXAMapViewComponent.this.isChangeStart = false;
                        if (WXAMapViewComponent.this.isSetUpdate) {
                            WXAMapViewComponent.this.mCameraType = "update";
                        } else if (cameraPosition.zoom != WXAMapViewComponent.this.mZoomLevel) {
                            WXAMapViewComponent.this.mCameraType = "scale";
                        } else {
                            WXAMapViewComponent.this.mCameraType = "drag";
                        }
                        WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BINDREGION_CHANGE, "end");
                    }
                    WXAMapViewComponent.this.isSetUpdate = false;
                }
            });
            this.mAMap.setOnMapTouchListener(new AMap.OnMapTouchListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass8 */

                @Override // com.amap.api.maps.AMap.OnMapTouchListener
                public void onTouch(MotionEvent motionEvent) {
                    int action = motionEvent.getAction();
                    if (action == 1) {
                        if (WXAMapViewComponent.this.mDragged) {
                            WXAMapViewComponent.this.getInstance().fireEvent(WXAMapViewComponent.this.getRef(), Constant.EVENT.DRAG_CHANGE);
                        }
                        WXAMapViewComponent.this.mDragged = false;
                    } else if (action == 2) {
                        WXAMapViewComponent.this.mDragged = true;
                        WXAMapViewComponent.this.isSetUpdate = false;
                    }
                }
            });
            this.mAMap.setOnPOIClickListener(new AMap.OnPOIClickListener() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass9 */

                @Override // com.amap.api.maps.AMap.OnPOIClickListener
                public void onPOIClick(Poi poi) {
                    JSONObject data = new JSONObject();
                    data.put("name", (Object) poi.getName());
                    data.put(Constant.JSONKEY.LONGITUDE, (Object) Double.valueOf(poi.getCoordinate().longitude));
                    data.put(Constant.JSONKEY.LATITUDE, (Object) Double.valueOf(poi.getCoordinate().latitude));
                    WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_POI_TAP, data);
                }
            });
            setUpMap();
        }
    }

    private void setUpMap() {
        this.mAMap.showBuildings(this.isBuilding3D);
        this.mAMap.moveCamera(CameraUpdateFactory.zoomTo(this.mZoomLevel));
        UiSettings uiSettings = this.mAMap.getUiSettings();
        this.mUiSettings = uiSettings;
        uiSettings.setZoomGesturesEnabled(this.isZoomEnable);
        this.mUiSettings.setCompassEnabled(this.isCompassEnable);
        this.mUiSettings.setRotateGesturesEnabled(this.isRotateEnable);
        this.mUiSettings.setScrollGesturesEnabled(this.isScrollEnable);
        this.mUiSettings.setZoomControlsEnabled(false);
        this.mUiSettings.setTiltGesturesEnabled(this.isOverLookingEnable);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateAttrs(Map<String, Object> attrs) {
        super.updateAttrs(attrs);
        if (attrs.containsKey(Constant.JSONKEY.LONGITUDE) || attrs.containsKey(Constant.JSONKEY.LATITUDE)) {
            updateCenter(getAttrs().get(Constant.JSONKEY.LATITUDE), getAttrs().get(Constant.JSONKEY.LONGITUDE));
        }
    }

    public void updateCenter(final Object latitude, final Object longitude) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass10 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.setCenter(latitude, longitude);
            }
        });
    }

    @Override // io.dcloud.feature.weex_amap.adapter.MapInterface
    public void setCenter(Object latitude, Object longitude) {
        LatLng latLng = MapResourceUtils.crateLatLng(latitude, longitude);
        if (latLng != null) {
            this.mMapCenterPoint.update(latLng.latitude, latLng.longitude);
            this.mAMap.moveCamera(CameraUpdateFactory.changeLatLng(latLng));
        }
    }

    @UniComponentProp(name = "scale")
    public void setScale(final float level) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass11 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.mZoomLevel = level;
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.zoomTo(level));
                WXAMapViewComponent.this.mMarkerMgr.refreshCalloutVisible();
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SHOW_COMPASS)
    public void setCompass(final boolean compass) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass12 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isCompassEnable = compass;
                WXAMapViewComponent.this.mUiSettings.setCompassEnabled(compass);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_SATELLITE)
    public void setEnableSatellite(final boolean is) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass13 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isEnableSatellite = is;
                if (WXAMapViewComponent.this.isEnableSatellite) {
                    AMap aMap = WXAMapViewComponent.this.mAMap;
                    AMap unused = WXAMapViewComponent.this.mAMap;
                    aMap.setMapType(2);
                    return;
                }
                WXAMapViewComponent.this.mAMap.setMapType(1);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_TRAFFIC)
    public void setEnableTraffic(final boolean is) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass14 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isEnableTraffic = is;
                WXAMapViewComponent.this.mAMap.setTrafficEnabled(WXAMapViewComponent.this.isEnableTraffic);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SHOW_SCALE)
    public void showScale(final boolean is) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass15 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isShowScale = is;
                WXAMapViewComponent.this.mUiSettings.setScaleControlsEnabled(WXAMapViewComponent.this.isShowScale);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_ZOOM)
    public void setZoomEnable(final boolean zoomEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass16 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isZoomEnable = zoomEnable;
                WXAMapViewComponent.this.mUiSettings.setZoomGesturesEnabled(zoomEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_SCROLL)
    public void setScrollEnable(final boolean scrollEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass17 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isScrollEnable = scrollEnable;
                WXAMapViewComponent.this.mUiSettings.setScrollGesturesEnabled(scrollEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_ROTATE)
    public void setRotateEnable(final boolean rotateEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass18 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isRotateEnable = rotateEnable;
                WXAMapViewComponent.this.mUiSettings.setRotateGesturesEnabled(rotateEnable);
            }
        });
    }

    @UniComponentProp(name = "rotate")
    public void setRotate(final float rotate) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass19 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.changeBearing(rotate));
            }
        });
    }

    @UniComponentProp(name = Constant.Name.SKEW)
    public void setSkew(final float skew) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass20 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isSetUpdate = true;
                WXAMapViewComponent.this.mAMap.moveCamera(CameraUpdateFactory.changeTilt(skew));
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_OVERLOOKING)
    public void setOverLookingEnable(final boolean isEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass21 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isOverLookingEnable = isEnable;
                WXAMapViewComponent.this.mUiSettings.setTiltGesturesEnabled(isEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_POI)
    public void setEnablePoi(final boolean isEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass22 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isEnablePoi = isEnable;
                mapView.getMap().showMapText(isEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_BUILDING)
    public void setEnableBuilding(final boolean isEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass23 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isBuilding3D = isEnable;
                mapView.getMap().showBuildings(isEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.ENABLE_INDOOR_MAP)
    public void setEnableIndoorMap(final boolean isEnable) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass24 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                WXAMapViewComponent.this.isEnableIndoorMap = isEnable;
                mapView.getMap().showIndoorMap(isEnable);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.KEYS)
    public void setApiKey(String keys) throws Exception {
        String key = JSON.parseObject(keys).getString(WXEnvironment.OS);
        if (!TextUtils.isEmpty(key)) {
            MapsInitializer.setApiKey(key);
            AMapLocationClient.setApiKey(key);
            UniLogUtils.d(TAG, "Set API key success");
        }
    }

    @UniComponentProp(name = Constant.Name.MARKERS)
    public void setMarkers(final JSONArray markers) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass25 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mMarkerMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mMarkerMgr = new MarkerMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                try {
                    WXAMapViewComponent.this.mMarkerMgr.setMarkers(markers, true);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.POLYLINE)
    public void setPolyline(final JSONArray polylines) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass26 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mPolylineMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mPolylineMgr = new PolylineMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mPolylineMgr.setPolyline(polylines);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.POLYGONS)
    public void setPolygon(final JSONArray polygons) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass27 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mPolygonMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mPolygonMgr = new PolygonMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mPolygonMgr.setPolygon(polygons);
            }
        });
    }

    @UniComponentProp(name = Constant.Name.CIRCLES)
    public void setCircles(final JSONArray circles) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass28 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mCircleMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mCircleMgr = new CircleMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.mMapView);
                }
                WXAMapViewComponent.this.mCircleMgr.setCircles(circles);
            }
        });
    }

    @UniComponentProp(name = "controls")
    public void setcontrols(final JSONArray controls) throws Exception {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass29 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mControlMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mControlMgr = new ControlMgr(wXAMapViewComponent.getInstance(), WXAMapViewComponent.this.getRef(), WXAMapViewComponent.this.mMapView, WXAMapViewComponent.this.mMapContainer);
                }
                WXAMapViewComponent.this.mControlMgr.setControls(controls);
            }
        });
    }

    @UniComponentProp(name = "setting")
    public void setSetting(final JSONObject setting) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass30 */

            /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
            /* JADX WARNING: Removed duplicated region for block: B:55:0x00c5 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:56:0x00c7 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:57:0x00d4 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:58:0x00e1 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:59:0x00ee A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:60:0x00fb A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:61:0x0108 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:62:0x0114 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:63:0x0120 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:64:0x012c A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:65:0x013b A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:66:0x0147 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:67:0x0153 A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:68:0x015f A[Catch:{ Exception -> 0x008c }] */
            /* JADX WARNING: Removed duplicated region for block: B:69:0x016b A[Catch:{ Exception -> 0x008c }] */
            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                Iterator<String> it;
                char c;
                Iterator<String> it2 = setting.keySet().iterator();
                while (it2.hasNext()) {
                    String str = it2.next();
                    try {
                        it = it2;
                        switch (str.hashCode()) {
                            case -1914923955:
                                if (str.equals(Constant.Name.SHOW_SCALE)) {
                                    c = 3;
                                    switch (c) {
                                        case 0:
                                            WXAMapViewComponent.this.setSkew(setting.getFloatValue(Constant.Name.SKEW));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 1:
                                            WXAMapViewComponent.this.setRotate(setting.getFloatValue("rotate"));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 2:
                                            WXAMapViewComponent.this.showMyLocation(setting.getBooleanValue(Constant.Name.SHOW_LOCATION));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 3:
                                            WXAMapViewComponent.this.showScale(setting.getBooleanValue(Constant.Name.SHOW_SCALE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 4:
                                            WXAMapViewComponent.this.setApiKey(setting.getString(Constant.Name.KEYS));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 5:
                                            WXAMapViewComponent.this.setLayerStyle(setting.getString("styleId"));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 6:
                                            WXAMapViewComponent.this.setZoomEnable(setting.getBooleanValue(Constant.Name.ENABLE_ZOOM));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 7:
                                            WXAMapViewComponent.this.setScrollEnable(setting.getBooleanValue(Constant.Name.ENABLE_SCROLL));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\b':
                                            WXAMapViewComponent.this.setRotateEnable(setting.getBooleanValue(Constant.Name.ENABLE_ROTATE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\t':
                                            WXAMapViewComponent.this.setCompass(setting.getBooleanValue(Constant.Name.SHOW_COMPASS));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\n':
                                            WXAMapViewComponent.this.setEnableBuilding(setting.getBooleanValue(Constant.Name.ENABLE_BUILDING));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case 11:
                                            WXAMapViewComponent.this.setOverLookingEnable(setting.getBooleanValue(Constant.Name.ENABLE_OVERLOOKING));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\f':
                                            WXAMapViewComponent.this.setEnableSatellite(setting.getBooleanValue(Constant.Name.ENABLE_SATELLITE));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        case '\r':
                                            WXAMapViewComponent.this.setEnableTraffic(setting.getBooleanValue(Constant.Name.ENABLE_TRAFFIC));
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                        default:
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                            continue;
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1720352578:
                                if (str.equals(Constant.Name.ENABLE_ROTATE)) {
                                    c = '\b';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1702852048:
                                if (str.equals(Constant.Name.ENABLE_SCROLL)) {
                                    c = 7;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -1086756521:
                                if (str.equals(Constant.Name.ENABLE_BUILDING)) {
                                    c = '\n';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -925180581:
                                if (str.equals("rotate")) {
                                    c = 1;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -891537377:
                                if (str.equals(Constant.Name.KEYS)) {
                                    c = 4;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case -58850592:
                                if (str.equals(Constant.Name.LAYER_STYLE)) {
                                    c = 5;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 3532042:
                                if (str.equals(Constant.Name.SKEW)) {
                                    c = 0;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 52161274:
                                if (str.equals(Constant.Name.ENABLE_TRAFFIC)) {
                                    c = '\r';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 491538168:
                                if (str.equals(Constant.Name.ENABLE_SATELLITE)) {
                                    c = '\f';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1049072082:
                                if (str.equals(Constant.Name.SHOW_LOCATION)) {
                                    c = 2;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1302710284:
                                if (str.equals(Constant.Name.ENABLE_OVERLOOKING)) {
                                    c = 11;
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1338643285:
                                if (str.equals(Constant.Name.SHOW_COMPASS)) {
                                    c = '\t';
                                    switch (c) {
                                    }
                                }
                                c = 65535;
                                switch (c) {
                                }
                            case 1893417974:
                                try {
                                    if (str.equals(Constant.Name.ENABLE_ZOOM)) {
                                        c = 6;
                                        switch (c) {
                                        }
                                    }
                                    c = 65535;
                                    switch (c) {
                                    }
                                } catch (Exception e) {
                                    break;
                                }
                                break;
                            default:
                                c = 65535;
                                switch (c) {
                                }
                        }
                    } catch (Exception e2) {
                        it = it2;
                    }
                    it2 = it;
                }
                WXAMapViewComponent.this.isSetUpdate = true;
            }
        });
    }

    @UniComponentProp(name = Constant.Name.MIN_SCALE)
    public void setMinScale(final String scale) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass31 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                int s = WXUtils.getInt(scale);
                if (s >= 3 && s < 20) {
                    mapView.getMap().setMinZoomLevel((float) s);
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.MAX_SCALE)
    public void setMaxScale(final String scale) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass32 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                int s = WXUtils.getInt(scale);
                if (s > 3 && s <= 20) {
                    mapView.getMap().setMaxZoomLevel((float) s);
                }
            }
        });
    }

    @UniComponentProp(name = Constant.Name.LAYER_STYLE)
    public void setLayerStyle(final String styleId) {
        if (!PdrUtil.isEmpty(styleId)) {
            postTask(new MapOperationTask() {
                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass33 */

                @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
                public void execute(WXMapView mapView) {
                    CustomMapStyleOptions op = new CustomMapStyleOptions();
                    op.setEnable(true);
                    op.setStyleId(styleId);
                    mapView.getMap().setCustomMapStyle(op);
                }
            });
        }
    }

    @UniComponentProp(name = Constant.Name.SHOW_LOCATION)
    public void showMyLocation(final boolean isShow) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass34 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (!isShow) {
                    mapView.getMap().setMyLocationEnabled(false);
                    mapView.getMap().setOnMyLocationChangeListener(null);
                } else if (WXAMapViewComponent.this.mMyLocationCallBack == null && WXAMapViewComponent.this.requestPermissions()) {
                    WXAMapViewComponent.this.mMyLocationCallBack = new AMap.OnMyLocationChangeListener() {
                        /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass34.AnonymousClass1 */

                        @Override // com.amap.api.maps.AMap.OnMyLocationChangeListener
                        public void onMyLocationChange(Location location) {
                            if (!WXAMapViewComponent.this.equalsLocation(WXAMapViewComponent.this.mMyLocation, location)) {
                                WXAMapViewComponent.this.mMyLocation = location;
                                WXAMapViewComponent.this.fireEventMapEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE, location);
                            }
                        }
                    };
                    mapView.getMap().setMyLocationEnabled(true);
                    mapView.getMap().setOnMyLocationChangeListener(WXAMapViewComponent.this.mMyLocationCallBack);
                    if (WXAMapViewComponent.this.myLocationStyle == null) {
                        WXAMapViewComponent.this.myLocationStyle = new MyLocationStyle();
                    }
                    mapView.getMap().setMyLocationStyle(WXAMapViewComponent.this.myLocationStyle.myLocationType(5));
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean equalsLocation(Location a, Location b) {
        if (a != null && b != null && a.getLatitude() == b.getLatitude() && a.getLongitude() == b.getLongitude() && a.getBearing() == b.getBearing()) {
            return true;
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean equalsMyLocationMarker(LatLng a) {
        AMap aMap;
        if (a == null || (aMap = this.mAMap) == null || !aMap.isMyLocationEnabled()) {
            return false;
        }
        Location l = this.mAMap.getMyLocation();
        if (a.latitude == l.getLatitude() && a.longitude == l.getLongitude()) {
            return true;
        }
        return false;
    }

    @UniComponentProp(name = Constant.Name.INCLUDE_POINTS)
    public void setincludePoints(JSONArray points) throws Exception {
        setincludePoints(points, 0);
    }

    public void setincludePoints(final JSONArray points, final int padding) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass35 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                ArrayList<LatLng> latLngs = MapResourceUtils.crateLatLngs(points);
                if (latLngs.size() > 0) {
                    LatLngBounds.Builder builder = new LatLngBounds.Builder();
                    Iterator<LatLng> it = latLngs.iterator();
                    while (it.hasNext()) {
                        builder.include(it.next());
                    }
                    mapView.getMap().animateCamera(CameraUpdateFactory.newLatLngBounds(builder.build(), padding));
                }
                WXAMapViewComponent.this.isSetUpdate = true;
            }
        });
    }

    /* access modifiers changed from: private */
    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: public */
    private void fireEventMapEvent(String event, Object data) {
        char c;
        Map<String, Object> params = new HashMap<>();
        switch (event.hashCode()) {
            case -1959236561:
                if (event.equals(Constant.EVENT.BIND_LABEL_TAP)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -1903828621:
                if (event.equals(Constant.EVENT.BIND_CALLOUT_TAP)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1777599032:
                if (event.equals(Constant.EVENT.BIND_ANCHOR_POINT_TAP)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case -1185205340:
                if (event.equals(Constant.EVENT.BINDREGION_CHANGE)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -982748903:
                if (event.equals(Constant.EVENT.BIND_POI_TAP)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case -933820119:
                if (event.equals(Constant.EVENT.BIND_MARKER_TAP)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -234430277:
                if (event.equals(Constant.EVENT.UPDATED)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 114595:
                if (event.equals(Constant.EVENT.BINDTAP)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 599278640:
                if (event.equals(Constant.EVENT.BIND_USER_LOCATION_CHANGE)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                if (containsEvent(Constant.EVENT.BINDREGION_CHANGE)) {
                    params.put("type", data);
                    params.put("causedBy", this.mCameraType);
                    if (((String) data).equals("end")) {
                        JSONObject detail = new JSONObject();
                        detail.put("rotate", (Object) Float.valueOf(this.mAMap.getCameraPosition().bearing));
                        detail.put(Constant.Name.SKEW, (Object) Float.valueOf(this.mAMap.getCameraPosition().tilt));
                        params.put("detail", detail);
                    }
                    fireEvent(Constant.EVENT.BINDREGION_CHANGE, params);
                    return;
                }
                return;
            case 1:
                if (data != null) {
                    params.put("detail", data);
                }
                fireEvent(Constant.EVENT.BIND_MARKER_TAP, params);
                return;
            case 2:
                if (data != null) {
                    params.put("detail", data);
                }
                fireEvent(Constant.EVENT.BIND_CALLOUT_TAP, params);
                return;
            case 3:
                if (containsEvent(Constant.EVENT.BIND_LABEL_TAP)) {
                    if (data != null) {
                        params.put("detail", data);
                    }
                    fireEvent(Constant.EVENT.BIND_LABEL_TAP, params);
                    return;
                }
                return;
            case 4:
                if (containsEvent(Constant.EVENT.BINDTAP)) {
                    if (data != null) {
                        params.put("detail", data);
                    }
                    params.put("type", Constant.EVENT.BINDTAP);
                    fireEvent(Constant.EVENT.BINDTAP, params);
                    return;
                }
                return;
            case 5:
                if (containsEvent(Constant.EVENT.UPDATED)) {
                    params.put("timeStamp", Long.valueOf(System.currentTimeMillis() - this.mLoadTime));
                    params.put("type", Constant.EVENT.UPDATED);
                    fireEvent(Constant.EVENT.UPDATED, params);
                    return;
                }
                return;
            case 6:
                if (containsEvent(Constant.EVENT.BIND_POI_TAP)) {
                    params.put("detail", data);
                    fireEvent(Constant.EVENT.BIND_POI_TAP, params);
                    return;
                }
                return;
            case 7:
                if (containsEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE) && data != null && (data instanceof Location)) {
                    params.put(Constant.JSONKEY.LATITUDE, Double.valueOf(((Location) data).getLatitude()));
                    params.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(((Location) data).getLongitude()));
                    fireEvent(Constant.EVENT.BIND_USER_LOCATION_CHANGE, params);
                    return;
                }
                return;
            case '\b':
                if (containsEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP) && data != null) {
                    params.put("detail", data);
                    fireEvent(Constant.EVENT.BIND_ANCHOR_POINT_TAP, params);
                    return;
                }
                return;
            default:
                return;
        }
    }

    @UniJSMethod
    public void getCenterLocation(UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        if (this.isMapLoaded.get()) {
            params.put("type", WXImage.SUCCEED);
            params.put(Constant.JSONKEY.LATITUDE, Double.valueOf(this.mMapCenterPoint.latitude));
            params.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(this.mMapCenterPoint.longitude));
        } else {
            params.put("type", Constants.Event.FAIL);
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void getRegion(UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        if (this.isMapLoaded.get()) {
            LatLngBounds latLngBounds = this.mAMap.getProjection().getVisibleRegion().latLngBounds;
            params.put("type", WXImage.SUCCEED);
            params.put("northeast", latLngBounds.northeast);
            params.put("southwest", latLngBounds.southwest);
        } else {
            params.put("type", Constants.Event.FAIL);
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void getScale(UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        if (this.isMapLoaded.get()) {
            params.put("type", WXImage.SUCCEED);
            params.put("scale", Float.valueOf(this.mAMap.getCameraPosition().zoom));
        } else {
            params.put("type", Constants.Event.FAIL);
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void getRotate(UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        if (this.isMapLoaded.get()) {
            params.put("type", WXImage.SUCCEED);
            params.put("rotate", Float.valueOf(this.mAMap.getCameraPosition().bearing));
        } else {
            params.put("type", Constants.Event.FAIL);
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void getSkew(UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        if (this.isMapLoaded.get()) {
            params.put("type", WXImage.SUCCEED);
            params.put(Constant.Name.SKEW, Float.valueOf(this.mAMap.getCameraPosition().tilt));
        } else {
            params.put("type", Constants.Event.FAIL);
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void includePoints(JSONObject data, UniJSCallback callback) throws Exception {
        Map<String, Object> params = new HashMap<>();
        if (!this.isMapLoaded.get() || data == null) {
            params.put("type", Constants.Event.FAIL);
        } else {
            JSONArray points = data.getJSONArray("points");
            JSONArray paddings = data.getJSONArray("padding");
            int padding = 20;
            if (paddings != null) {
                padding = paddings.getIntValue(0);
            }
            setincludePoints(points, padding);
            params.put("type", WXImage.SUCCEED);
            params.put("scale", Float.valueOf(this.mZoomLevel));
        }
        if (callback != null) {
            callback.invoke(params);
        }
    }

    @UniJSMethod
    public void moveToLocation(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass36 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                Map<String, Object> params = new HashMap<>();
                Location l = mapView.getMap().getMyLocation();
                LatLng latLng = null;
                JSONObject jSONObject = data;
                if (jSONObject != null) {
                    latLng = MapResourceUtils.crateLatLng(jSONObject);
                } else if (l != null) {
                    latLng = new LatLng(l.getLatitude(), l.getLongitude());
                }
                if (latLng != null) {
                    mapView.getMap().animateCamera(CameraUpdateFactory.changeLatLng(latLng));
                    params.put("type", WXImage.SUCCEED);
                } else {
                    params.put("type", Constants.Event.FAIL);
                }
                UniJSCallback uniJSCallback = callback;
                if (uniJSCallback != null) {
                    uniJSCallback.invoke(params);
                }
            }
        });
    }

    @UniJSMethod
    public void translateMarker(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass37 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    WXAMapViewComponent.this.mMarkerMgr.translateMarker(data, callback);
                }
            }
        });
    }

    @UniJSMethod
    public void initMarkerCluster(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass38 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                Map<String, Object> params = new HashMap<>();
                if (mapView.getClusterOverlay() == null) {
                    mapView.createClusterOverlay(data);
                    params.put("type", WXImage.SUCCEED);
                    UniJSCallback uniJSCallback = callback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(params);
                        return;
                    }
                    return;
                }
                params.put("type", WXImage.SUCCEED);
                UniJSCallback uniJSCallback2 = callback;
                if (uniJSCallback2 != null) {
                    uniJSCallback2.invoke(params);
                }
            }
        });
    }

    @UniJSMethod
    public void addMarkers(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass39 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mMarkerMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mMarkerMgr = new MarkerMgr(wXAMapViewComponent.getInstance(), mapView);
                }
                Map<String, Object> params = new HashMap<>();
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    if (data.containsKey("clear") && data.getBoolean("clear").booleanValue()) {
                        WXAMapViewComponent.this.mMarkerMgr.destroy();
                    }
                    if (data.containsKey(Constant.Name.MARKERS)) {
                        try {
                            WXAMapViewComponent.this.mMarkerMgr.setMarkers(data.getJSONArray(Constant.Name.MARKERS), false);
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                    params.put("type", WXImage.SUCCEED);
                    UniJSCallback uniJSCallback = callback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(params);
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void removeMarkers(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass40 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    Map<String, Object> params = new HashMap<>();
                    if (data.containsKey("markerIds")) {
                        try {
                            WXAMapViewComponent.this.mMarkerMgr.removeMarkers(data.getJSONArray("markerIds"));
                            params.put("type", WXImage.SUCCEED);
                            if (callback != null) {
                                callback.invoke(params);
                            }
                        } catch (Exception e) {
                            e.printStackTrace();
                            params.put("type", Constants.Event.FAIL);
                            UniJSCallback uniJSCallback = callback;
                            if (uniJSCallback != null) {
                                uniJSCallback.invoke(params);
                            }
                        }
                    } else {
                        params.put("type", Constants.Event.FAIL);
                        UniJSCallback uniJSCallback2 = callback;
                        if (uniJSCallback2 != null) {
                            uniJSCallback2.invoke(params);
                        }
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void on(final String event, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41 */

            /* JADX WARNING: Removed duplicated region for block: B:12:0x0029  */
            /* JADX WARNING: Removed duplicated region for block: B:14:0x0035  */
            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(final WXMapView mapView) {
                char c;
                String str = event;
                int hashCode = str.hashCode();
                if (hashCode != -273840772) {
                    if (hashCode == 1653559560 && str.equals("markerClusterClick")) {
                        c = 1;
                        if (c == 0) {
                            mapView.setClusterCreateListener(new OnClusterCreateListener() {
                                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41.AnonymousClass1 */
                                String mCreateCallBackData;

                                @Override // io.dcloud.feature.weex_amap.adapter.cluster.OnClusterCreateListener
                                public void onClusterCreate(List<Cluster> clusters) {
                                    if (clusters.size() > 0) {
                                        JSONArray array = new JSONArray();
                                        for (Cluster cluster : clusters) {
                                            array.add(mapView.getClusterInfo(cluster));
                                        }
                                        if (this.mCreateCallBackData == null) {
                                            JSONObject value = new JSONObject();
                                            value.put("clusters", (Object) array);
                                            callback.invokeAndKeepAlive(value);
                                            this.mCreateCallBackData = array.toJSONString();
                                        } else if (!array.toJSONString().equals(this.mCreateCallBackData)) {
                                            JSONObject value2 = new JSONObject();
                                            value2.put("clusters", (Object) array);
                                            callback.invokeAndKeepAlive(value2);
                                            this.mCreateCallBackData = array.toJSONString();
                                        }
                                    } else {
                                        this.mCreateCallBackData = null;
                                    }
                                }
                            });
                            return;
                        } else if (c == 1) {
                            mapView.setClusterClickListener(new OnClusterClickListener() {
                                /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass41.AnonymousClass2 */

                                @Override // io.dcloud.feature.weex_amap.adapter.cluster.OnClusterClickListener
                                public void onClick(Marker marker, Cluster cluster) {
                                    if (callback != null) {
                                        callback.invokeAndKeepAlive(mapView.getClusterInfo(cluster));
                                    }
                                }
                            });
                            return;
                        } else {
                            return;
                        }
                    }
                } else if (str.equals("markerClusterCreate")) {
                    c = 0;
                    if (c == 0) {
                    }
                }
                c = 65535;
                if (c == 0) {
                }
            }
        });
    }

    @UniJSMethod
    public void moveAlong(final JSONObject data, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass42 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mMarkerMgr != null) {
                    Map<String, Object> params = new HashMap<>();
                    if (data.containsKey("markerId")) {
                        WXAMapViewComponent.this.mMarkerMgr.moveAlongMarker(data, callback);
                        return;
                    }
                    params.put("type", Constants.Event.FAIL);
                    UniJSCallback uniJSCallback = callback;
                    if (uniJSCallback != null) {
                        uniJSCallback.invoke(params);
                    }
                }
            }
        });
    }

    @UniJSMethod
    public void getUserLocation(final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass43 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                Location c = mapView.getMap().getMyLocation();
                Map<String, Object> params = new HashMap<>();
                if (c != null) {
                    params.put("type", WXImage.SUCCEED);
                    params.put(Constant.JSONKEY.LATITUDE, Double.valueOf(c.getLatitude()));
                    params.put(Constant.JSONKEY.LONGITUDE, Double.valueOf(c.getLongitude()));
                    callback.invoke(params);
                    return;
                }
                params.put("type", Constants.Event.FAIL);
                callback.invoke(params);
            }
        });
    }

    @UniJSMethod
    public void addCustomLayer(String styleId, UniJSCallback callback) {
    }

    @UniJSMethod
    public void removeCustomLayer(JSONObject op, UniJSCallback callback) {
    }

    @UniJSMethod
    public void addGroundOverlay(final JSONObject ops, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass44 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mGroundMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), mapView);
                }
                WXAMapViewComponent.this.mGroundMgr.addGroundOverlay(ops, callback);
            }
        });
    }

    @UniJSMethod
    public void updateGroundOverlay(final JSONObject ops, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass45 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                if (WXAMapViewComponent.this.mGroundMgr == null) {
                    WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                    wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), mapView);
                }
                WXAMapViewComponent.this.mGroundMgr.updateGroundOverlay(ops, callback);
            }
        });
    }

    @UniJSMethod
    public void removeGroundOverlay(final JSONObject op, final UniJSCallback callback) {
        postTask(new MapOperationTask() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass46 */

            @Override // io.dcloud.feature.weex_amap.component.WXAMapViewComponent.MapOperationTask
            public void execute(WXMapView mapView) {
                JSONObject jSONObject = op;
                if (jSONObject != null && jSONObject.containsKey("id")) {
                    if (WXAMapViewComponent.this.mGroundMgr == null) {
                        WXAMapViewComponent wXAMapViewComponent = WXAMapViewComponent.this;
                        wXAMapViewComponent.mGroundMgr = new GroundMgr(wXAMapViewComponent.getInstance(), mapView);
                    }
                    WXAMapViewComponent.this.mGroundMgr.removeGroundOverlay(op.getString("id"), callback);
                } else if (callback != null) {
                    Map<String, Object> params = new HashMap<>();
                    params.put("type", Constants.Event.FAIL);
                    params.put("msg", "Parameter exception");
                    callback.invoke(params);
                }
            }
        });
    }

    @UniJSMethod
    public void openMapApp(JSONObject data, UniJSCallback callback) {
        Map<String, Object> params = new HashMap<>();
        try {
            StringBuffer sb = new StringBuffer();
            sb.append("geo:");
            sb.append(data.getDoubleValue(Constant.JSONKEY.LATITUDE));
            sb.append(",");
            sb.append(data.getDoubleValue(Constant.JSONKEY.LATITUDE));
            sb.append(Operators.CONDITION_IF_STRING);
            sb.append("q=");
            sb.append(data.getString("destination"));
            getInstance().getContext().startActivity(new Intent("android.intent.action.VIEW", Uri.parse(sb.toString())));
            params.put("type", WXImage.SUCCEED);
            if (callback != null) {
                callback.invoke(params);
            }
        } catch (Exception e) {
            params.put("type", Constants.Event.FAIL);
            if (callback != null) {
                callback.invoke(params);
            }
        }
    }

    @UniJSMethod
    public void setLocMarkerIcon(JSONObject data, final UniJSCallback callback) {
        final Map<String, Object> params = new HashMap<>();
        String iconPath = data.getString(Constant.JSONKEY.ICONPATH);
        if (PdrUtil.isEmpty(iconPath)) {
            params.put("type", Constants.Event.FAIL);
            params.put("msg", "iconPath is null");
            if (callback != null) {
                callback.invoke(params);
                return;
            }
            return;
        }
        Uri uri = getInstance().rewriteUri(Uri.parse(iconPath), "image");
        if (uri == null) {
            params.put("type", Constants.Event.FAIL);
            params.put("msg", "iconPath exception");
            if (callback != null) {
                callback.invoke(params);
                return;
            }
            return;
        }
        FrescoLoadUtil.getInstance().loadImageBitmap(getContext(), uri.toString(), new BitmapLoadCallback<Bitmap>() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass47 */

            public void onSuccess(String url, final Bitmap result) {
                MessageHandler.post(new Runnable() {
                    /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass47.AnonymousClass1 */

                    public void run() {
                        if (WXAMapViewComponent.this.myLocationStyle == null || result == null || WXAMapViewComponent.this.mMapView == null || WXAMapViewComponent.this.mMapView.getMap() == null) {
                            params.put("type", Constants.Event.FAIL);
                            params.put("msg", "unknown error");
                            if (callback != null) {
                                callback.invoke(params);
                                return;
                            }
                            return;
                        }
                        WXAMapViewComponent.this.myLocationStyle.myLocationIcon(BitmapDescriptorFactory.fromBitmap(result));
                        WXAMapViewComponent.this.mMapView.getMap().setMyLocationStyle(WXAMapViewComponent.this.myLocationStyle.myLocationType(5));
                        params.put("type", WXImage.SUCCEED);
                        if (callback != null) {
                            callback.invoke(params);
                        }
                    }
                });
            }

            @Override // io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback
            public void onFailure(String url, Throwable throwable) {
                params.put("type", Constants.Event.FAIL);
                params.put("msg", throwable.toString());
                UniJSCallback uniJSCallback = callback;
                if (uniJSCallback != null) {
                    uniJSCallback.invoke(params);
                }
            }
        });
        if (this.myLocationStyle == null) {
            this.myLocationStyle = new MyLocationStyle();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityCreate() {
        super.onActivityCreate();
        UniLogUtils.e(TAG, "onActivityCreate");
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.onPause();
        }
        UniLogUtils.e(TAG, "onActivityPause");
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.onResume();
        }
        UniLogUtils.e(TAG, "onActivityResume");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean requestPermissions() {
        if (Build.VERSION.SDK_INT < 23) {
            return true;
        }
        Activity activity = this.mActivity;
        if (activity == null) {
            return false;
        }
        if (checkPermissions(activity, permissions)) {
            return true;
        }
        PermissionUtil.requestSystemPermissions(this.mActivity, permissions, REQUEST_CODE_MAPVIEW, new PermissionUtil.Request() {
            /* class io.dcloud.feature.weex_amap.component.WXAMapViewComponent.AnonymousClass48 */

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onGranted(String perName) {
                for (int i = 0; i < WXAMapViewComponent.permissions.length; i++) {
                    if ("android.permission.ACCESS_FINE_LOCATION".equals(WXAMapViewComponent.permissions[i])) {
                        WXAMapViewComponent.this.showMyLocation(true);
                    }
                }
            }

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onDenied(String perName) {
            }
        });
        return false;
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityDestroy() {
        destroy();
        UniLogUtils.e(TAG, "onActivityDestroy");
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        onActivityPause();
        WXMapView wXMapView = this.mMapView;
        if (wXMapView != null) {
            wXMapView.setVisibility(8);
            MarkerMgr markerMgr = this.mMarkerMgr;
            if (markerMgr != null) {
                markerMgr.destroy();
            }
            GroundMgr groundMgr = this.mGroundMgr;
            if (groundMgr != null) {
                groundMgr.destroy();
            }
            this.mMapView.destroy();
            this.mMapContainer.removeView(this.mMapView);
            this.mMyLocation = null;
            this.mAMap.clear();
        }
        AMapLocationClient aMapLocationClient = this.mLocationClient;
        if (aMapLocationClient != null) {
            aMapLocationClient.onDestroy();
        }
    }

    public boolean checkPermissions(Activity context, String[] permissions2) {
        boolean granted = true;
        if (permissions2 != null && permissions2.length > 0) {
            for (String permission : permissions2) {
                if (ContextCompat.checkSelfPermission(context, permission) != 0) {
                    granted = false;
                    ActivityCompat.shouldShowRequestPermissionRationale(context, permission);
                }
            }
        }
        return granted;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void execPaddingTasks() {
        WXMapView wXMapView;
        if (getInstance() != null && getHostView() != null) {
            while (!this.paddingTasks.isEmpty()) {
                MapOperationTask task = this.paddingTasks.poll();
                if (!(task == null || (wXMapView = this.mMapView) == null || wXMapView.getMap() == null)) {
                    UniLogUtils.d(TAG, "Exec padding task " + task.toString());
                    task.execute(this.mMapView);
                }
            }
        }
    }

    public void postTask(MapOperationTask task) {
        if (this.mMapView == null || !this.isMapLoaded.get()) {
            UniLogUtils.d(TAG, "Padding task " + task.toString());
            this.paddingTasks.offer(task);
            return;
        }
        UniLogUtils.d(TAG, "Exec task " + task.toString());
        task.execute(this.mMapView);
    }

    /* access modifiers changed from: package-private */
    public class Point {
        private double latitude;
        private double longitude;

        public Point() {
        }

        public void update(double latitude2, double longitude2) {
            this.latitude = latitude2;
            this.longitude = longitude2;
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
        int index2;
        if (child != null && getRealView() != null) {
            int count = getRealView().getChildCount();
            if (count < 1 || !(getRealView().getChildAt(0) instanceof WXMapView)) {
                index2 = index >= count ? -1 : index;
            } else {
                index2 = index >= count ? 1 : index + 1;
            }
            if (index2 == -1) {
                getRealView().addView(child);
            } else {
                getRealView().addView(child, index2);
            }
            UniSDKInstance instance = getInstance();
            if (instance != null) {
                instance.getApmForInstance().hasAddView = true;
            }
        }
    }

    @Override // io.dcloud.feature.weex.extend.IDCCoverViewUpdate
    public void update(Map info) {
        if (this.mMarkerMgr != null) {
            for (Object o : info.keySet()) {
                this.mMarkerMgr.updateMarkerCallout(o.toString());
            }
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        Object slot;
        super.addChild(child, index);
        if ((child instanceof DCCoverViewComponent) && child != null && child.getAttrs() != null && child.getAttrs().containsKey("slot") && this.mMapView != null && (slot = child.getAttrs().get("slot")) != null && slot.equals(Constant.JSONKEY.CALLOUT)) {
            this.mMapView.setCoverViewCalloutComponetRef(child.getRef());
        }
    }
}
