package io.dcloud.feature.weex_amap.ui;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.RectF;
import android.widget.TextView;

public class ArrowTextView extends TextView {
    private int defPadding = 10;
    private boolean isSharp = true;
    private int mPadding = 0;
    private int mRadius = 0;
    private int mStrokeColor = 0;
    private int mStrokeWidth = 0;
    private int mTextBgColor = -16777216;

    public ArrowTextView(Context context, boolean isSharp2) {
        super(context);
        this.isSharp = isSharp2;
        if (!isSharp2) {
            this.defPadding = 0;
        }
    }

    public void setRadius(int r) {
        this.mRadius = r;
        invalidate();
    }

    public void setBgColor(int color) {
        this.mTextBgColor = color;
        invalidate();
    }

    public void setTextPadding(int padding) {
        this.mPadding = padding;
        int p = this.defPadding + padding + this.mStrokeWidth;
        setPadding(p, p, p, p);
        invalidate();
    }

    public void setStrokeWidth(int strokeWidth) {
        this.mStrokeWidth = strokeWidth * 2;
        setTextPadding(this.mPadding);
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        int height = getHeight();
        int width = getWidth();
        paint.setStrokeWidth(1.0f);
        int contentPading = this.defPadding + this.mStrokeWidth;
        RectF contentRect = new RectF((float) contentPading, (float) contentPading, (float) (width - contentPading), (float) (height - contentPading));
        if (this.mStrokeWidth > 0) {
            int i = this.defPadding;
            RectF rectStrok = new RectF((float) i, (float) i, (float) (width - i), (float) (height - i));
            paint.setColor(this.mStrokeColor);
            int i2 = this.mRadius;
            canvas.drawRoundRect(rectStrok, (float) i2, (float) i2, paint);
        }
        paint.setColor(this.mTextBgColor);
        int i3 = this.mRadius;
        canvas.drawRoundRect(contentRect, (float) i3, (float) i3, paint);
        if (this.isSharp) {
            if (this.mStrokeWidth > 0) {
                Path pathStrok = new Path();
                pathStrok.moveTo((float) (width / 2), (float) height);
                int i4 = this.defPadding;
                pathStrok.lineTo((float) ((width / 2) - i4), (float) (height - i4));
                int i5 = this.defPadding;
                pathStrok.lineTo((float) ((width / 2) + i5), (float) (height - i5));
                paint.setColor(this.mStrokeColor);
                pathStrok.close();
                canvas.drawPath(pathStrok, paint);
            }
            Path path = new Path();
            path.moveTo((float) (width / 2), (float) (height - this.mStrokeWidth));
            path.lineTo((float) ((width / 2) - this.defPadding), (float) (height - contentPading));
            path.lineTo((float) ((width / 2) + this.defPadding), (float) (height - contentPading));
            paint.setColor(this.mTextBgColor);
            path.close();
            canvas.drawPath(path, paint);
        }
        super.onDraw(canvas);
    }

    public void setStrokeColor(int strokeColor) {
        this.mStrokeColor = strokeColor;
    }
}
