package io.dcloud.feature.weex_barcode;

import android.content.Context;
import android.view.View;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.utils.WXResourceUtils;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.PdrUtil;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;

public class BarcodeComponent extends WXComponent<BarcodeView> {
    private boolean isAnimationEnd = false;
    private AtomicBoolean isLoad = new AtomicBoolean(false);

    public BarcodeComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
    }

    public BarcodeComponent(WXSDKInstance instance, WXVContainer parent, int type, BasicComponentData basicComponentData) {
        super(instance, parent, type, basicComponentData);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BarcodeView initComponentHostView(Context context) {
        AppRuntime.checkPrivacyComplianceAndPrompt(context, "nvue-Barcode");
        return new BarcodeView(context, this, getInstance());
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        if (getHostView() != null && !getAttrs().containsKey("background")) {
            ((BarcodeView) getHostView()).setBackgroundColor(-16777216);
        }
    }

    @WXComponentProp(name = "frameColor")
    public void setFrameColor(String color) {
        ((BarcodeView) getHostView()).setFrameColor(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "autoDecodeCharset")
    public void setAutoDecodeCharset(boolean autoDecodeCharset) {
        ((BarcodeView) getHostView()).setAutoDecodeCharset(autoDecodeCharset);
    }

    @WXComponentProp(name = "autoZoom")
    public void setAutoZoom(boolean autoZoom) {
        ((BarcodeView) getHostView()).setAutoZoom(autoZoom);
    }

    @WXComponentProp(name = "background")
    public void setBackground(String color) {
        ((BarcodeView) getHostView()).setBackground(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "scanbarColor")
    public void setScanbarColor(String color) {
        ((BarcodeView) getHostView()).setScanBarColor(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "filters")
    public void setFilters(JSONArray filters) {
        ((BarcodeView) getHostView()).initDecodeFormats(filters);
    }

    @WXComponentProp(name = "autostart")
    public void setSutoStart(final boolean isstart) {
        if (!this.isAnimationEnd) {
            getInstance().addFrameViewEventListener(new WXSDKInstance.FrameViewEventListener() {
                /* class io.dcloud.feature.weex_barcode.BarcodeComponent.AnonymousClass1 */

                @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
                public void onShowAnimationEnd() {
                    BarcodeComponent.this.isAnimationEnd = true;
                    if (isstart) {
                        BarcodeComponent.this.start(null);
                    }
                    BarcodeComponent.this.getInstance().removeFrameViewEventListener(this);
                }
            });
        } else if (isstart) {
            start(null);
        }
    }

    @JSMethod
    public void start(JSONObject option) {
        if (option != null) {
            boolean z = false;
            ((BarcodeView) getHostView()).setConserve(option.containsKey("conserve") ? option.getBoolean("conserve").booleanValue() : false);
            ((BarcodeView) getHostView()).setFilename(PdrUtil.getDefaultPrivateDocPath(option.getString("filename"), "png"));
            ((BarcodeView) getHostView()).setVibrate(option.containsKey("vibrate") ? option.getBoolean("vibrate").booleanValue() : true);
            BarcodeView barcodeView = (BarcodeView) getHostView();
            if (!option.containsKey("sound") || option.getString("sound").equals("default")) {
                z = true;
            }
            barcodeView.setPlayBeep(z);
        }
        ((BarcodeView) getHostView()).start();
    }

    /* access modifiers changed from: protected */
    public void setHostLayoutParams(BarcodeView host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((View) host, width, height, left, right, top, bottom);
        if (!this.isLoad.get()) {
            this.isLoad.set(true);
            ((BarcodeView) getHostView()).initBarcodeView(width, height);
            return;
        }
        ((BarcodeView) getHostView()).updateStyles(width, height);
    }

    @JSMethod
    public void cancel() {
        ((BarcodeView) getHostView()).cancelScan();
    }

    @JSMethod
    public void close() {
    }

    @JSMethod
    public void setFlash(boolean open) {
        if (!PdrUtil.isEmpty(Boolean.valueOf(open))) {
            ((BarcodeView) getHostView()).setFlash(open);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        ((BarcodeView) getHostView()).closeScan();
        ((BarcodeView) getHostView()).onDestory();
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        super.onActivityResume();
        ((BarcodeView) getHostView()).onResume(true);
    }

    @Override // com.taobao.weex.IWXActivityStateListener, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        super.onActivityPause();
        ((BarcodeView) getHostView()).onPause();
    }
}
