package io.dcloud.feature.weex_barcode;

import android.app.Activity;
import android.content.Context;
import android.content.res.AssetFileDescriptor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.Rect;
import android.graphics.SurfaceTexture;
import android.graphics.YuvImage;
import android.graphics.drawable.BitmapDrawable;
import android.hardware.Camera;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Build;
import android.os.Handler;
import android.os.Message;
import android.os.Vibrator;
import android.text.TextPaint;
import android.text.TextUtils;
import android.view.TextureView;
import android.view.ViewGroup;
import android.widget.AbsoluteLayout;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.dcloud.zxing2.BarcodeFormat;
import com.dcloud.zxing2.Result;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import io.dcloud.base.R;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.barcode2.camera.CameraManager;
import io.dcloud.feature.barcode2.decoding.CaptureActivityHandler;
import io.dcloud.feature.barcode2.decoding.IBarHandler;
import io.dcloud.feature.barcode2.decoding.InactivityTimer;
import io.dcloud.feature.barcode2.view.DetectorViewConfig;
import io.dcloud.feature.barcode2.view.ViewfinderView;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Vector;

public class BarcodeView extends AbsoluteLayout implements IBarHandler, TextureView.SurfaceTextureListener {
    static final int AZTEC = 3;
    private static final float BEEP_VOLUME = 0.8f;
    static final int CODABAR = 7;
    static final int CODE128 = 10;
    static final int CODE39 = 8;
    static final int CODE93 = 9;
    static final int DATAMATRIX = 4;
    static final int EAN13 = 1;
    static final int EAN8 = 2;
    private static final int ID_ADD_VIEW = 201;
    private static final int ID_START_SCAN = 203;
    private static final int ID_UPDATE_VIEW = 202;
    static final int ITF = 11;
    static final int MAXICODE = 12;
    static final int PDF417 = 13;
    static final int QR = 0;
    static final int RSS14 = 14;
    static final int RSSEXPANDED = 15;
    static final int UNKOWN = -1000;
    static final int UPCA = 5;
    static final int UPCE = 6;
    private static final long VIBRATE_DURATION = 200;
    public boolean autoDecodeCharset = false;
    private final MediaPlayer.OnCompletionListener beepListener = new MediaPlayer.OnCompletionListener() {
        /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass5 */

        public void onCompletion(MediaPlayer mediaPlayer) {
            mediaPlayer.seekTo(0);
        }
    };
    private String characterSet;
    private WXComponent component;
    private Context context;
    private Vector<BarcodeFormat> decodeFormats;
    public String errorMsg = null;
    private CaptureActivityHandler handler;
    private boolean hasSurface = false;
    private InactivityTimer inactivityTimer;
    private boolean isCancelScan = false;
    private boolean isSurfaceAvaliable = false;
    private boolean isVerticalScreen = false;
    private Bitmap lastBiptmap;
    private boolean mConserve = false;
    private String mFilename;
    Handler mHandler = new Handler() {
        /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass1 */

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            if (msg.what == 201) {
                AbsoluteLayout.LayoutParams param = (AbsoluteLayout.LayoutParams) msg.obj;
                if (BarcodeView.this.surfaceView != null) {
                    if (BarcodeView.this.surfaceView.getParent() != null) {
                        ((ViewGroup) BarcodeView.this.surfaceView.getParent()).removeView(BarcodeView.this.surfaceView);
                    }
                    BarcodeView barcodeView = BarcodeView.this;
                    barcodeView.addView(barcodeView.surfaceView, param);
                }
                BarcodeView barcodeView2 = BarcodeView.this;
                barcodeView2.addView(barcodeView2.viewfinderView);
            } else if (msg.what == 202) {
                if (BarcodeView.this.surfaceView != null && BarcodeView.this.surfaceView.getParent() != null) {
                    BarcodeView.this.surfaceView.setLayoutParams((AbsoluteLayout.LayoutParams) msg.obj);
                    BarcodeView.this.viewfinderView.drawViewfinder();
                }
            } else if (msg.what == 203 && BarcodeView.this.surfaceView != null && BarcodeView.this.surfaceView.getParent() != null) {
                BarcodeView.this.surfaceView.setLayoutParams((AbsoluteLayout.LayoutParams) msg.obj);
                BarcodeView.this.viewfinderView.drawViewfinder();
                BarcodeView.this.startP();
            }
        }
    };
    private WXSDKInstance mInstance;
    int mOrientationState;
    private boolean mRunning = false;
    private MediaPlayer mediaPlayer;
    private boolean nopermission;
    private boolean playBeep;
    private TextureView surfaceView;
    private boolean vibrate;
    private int viewHeight;
    private int viewWidth;
    private ViewfinderView viewfinderView;

    public BarcodeView(Context context2, WXComponent component2, WXSDKInstance mInstance2) {
        super(context2);
        this.component = component2;
        this.mInstance = mInstance2;
        this.surfaceView = new TextureView(context2);
        this.viewfinderView = new ViewfinderView(context2, this);
        this.inactivityTimer = new InactivityTimer((Activity) context2);
        this.context = context2;
        saveOrientationState();
        CameraManager.init(this.context, false);
        int rotation = ((Activity) context2).getWindowManager().getDefaultDisplay().getRotation();
        if (rotation != 0) {
            if (rotation == 1) {
                CameraManager.get().setHorizontalOrientation(false);
                ((Activity) this.context).setRequestedOrientation(0);
            } else if (rotation != 2) {
                if (rotation == 3) {
                    CameraManager.get().setHorizontalOrientation(true);
                    ((Activity) this.context).setRequestedOrientation(8);
                }
            }
            onResume(false);
            this.hasSurface = false;
        }
        ((Activity) this.context).setRequestedOrientation(7);
        CameraManager.init(context2, true);
        this.isVerticalScreen = true;
        onResume(false);
        this.hasSurface = false;
    }

    private void saveOrientationState() {
        this.mOrientationState = ((Activity) this.context).getRequestedOrientation();
    }

    private void resumeOrientationState() {
        ((Activity) this.context).setRequestedOrientation(this.mOrientationState);
    }

    public void initBarcodeView(int width, int height) {
        this.viewWidth = width;
        this.viewHeight = height;
        ThreadPool.self().addThreadTask(new Runnable() {
            /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass2 */

            public void run() {
                BarcodeView.this.addBarcodeView();
            }
        });
    }

    public void updateStyles(int viewWidth2, int viewHeight2) {
        if (this.viewHeight != viewHeight2 || this.viewWidth != viewWidth2) {
            this.viewWidth = viewWidth2;
            this.viewHeight = viewHeight2;
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass3 */

                public void run() {
                    AbsoluteLayout.LayoutParams params = BarcodeView.this.setLayoutParams();
                    if (params != null) {
                        Message msg = new Message();
                        msg.what = 202;
                        msg.obj = params;
                        BarcodeView.this.mHandler.sendMessage(msg);
                    }
                }
            });
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addBarcodeView() {
        AbsoluteLayout.LayoutParams lllp = setLayoutParams();
        if (lllp != null) {
            Message msg = new Message();
            msg.what = 201;
            msg.obj = lllp;
            this.mHandler.sendMessage(msg);
        }
    }

    private void initCamera() {
        try {
            CameraManager.get().openDriver(this.surfaceView.getSurfaceTexture());
            CaptureActivityHandler captureActivityHandler = this.handler;
            if (captureActivityHandler == null) {
                CaptureActivityHandler captureActivityHandler2 = new CaptureActivityHandler(this, this.decodeFormats, this.characterSet, this.autoDecodeCharset);
                this.handler = captureActivityHandler2;
                if (this.mRunning) {
                    captureActivityHandler2.restartPreviewAndDecode();
                    return;
                }
                return;
            }
            captureActivityHandler.resume();
        } catch (IOException e) {
            this.errorMsg = e.getMessage();
        }
    }

    public void setFrameColor(int color) {
        DetectorViewConfig.cornerColor = color != -1 ? color : DetectorViewConfig.laserColor;
    }

    public void setAutoDecodeCharset(boolean autoDecodeCharsetParam) {
        this.autoDecodeCharset = autoDecodeCharsetParam;
    }

    public void setAutoZoom(boolean isAutoZoomParam) {
        CaptureActivityHandler.isAutoZoom = isAutoZoomParam;
    }

    public void setBackground(int color) {
        setBackgroundColor(color != -1 ? color : DetectorViewConfig.laserColor);
    }

    public void setScanBarColor(int color) {
        DetectorViewConfig.laserColor = color != -1 ? color : DetectorViewConfig.laserColor;
    }

    public void setPlayBeep(boolean playBeep2) {
        this.playBeep = playBeep2;
    }

    public void setVibrate(boolean vibrate2) {
        this.vibrate = vibrate2;
    }

    public void setConserve(boolean mConserve2) {
        this.mConserve = mConserve2;
    }

    public void setFilename(String mFilename2) {
        this.mFilename = mFilename2;
    }

    public void setFlash(boolean enable) {
        CameraManager.get().setFlashlight(enable);
    }

    public void cancelScan() {
        if (this.mRunning) {
            CaptureActivityHandler captureActivityHandler = this.handler;
            if (captureActivityHandler != null) {
                captureActivityHandler.quitSynchronously();
                this.handler = null;
            }
            getViewfinderView().stopUpdateScreenTimer();
            CameraManager.get().removeAutoFocus();
            CameraManager.get().stopPreview();
            byte[] lastBitmapData = CameraManager.get().getLastBitmapData();
            Camera camera = CameraManager.get().getCameraHandler();
            if (!(lastBitmapData == null || camera == null)) {
                this.lastBiptmap = byte2bitmap(lastBitmapData, camera);
            }
            CameraManager.get().closeDriver();
            this.mRunning = false;
            this.isCancelScan = true;
        }
    }

    public void closeScan() {
        onPause();
        CameraManager.get().closeDriver();
        DetectorViewConfig.clearData();
        this.surfaceView = null;
        Bitmap bitmap = this.lastBiptmap;
        if (bitmap != null && !bitmap.isRecycled()) {
            this.lastBiptmap.recycle();
            this.lastBiptmap = null;
        }
        CameraManager.get().clearLastBitmapData();
        System.gc();
    }

    public void onPause() {
        CaptureActivityHandler captureActivityHandler = this.handler;
        if (captureActivityHandler != null) {
            captureActivityHandler.quitSynchronously();
            this.handler = null;
        }
        if (!this.nopermission) {
            CameraManager.get().closeDriver();
        }
        boolean t = this.mRunning;
        cancel();
        this.mRunning = t;
    }

    public void onDestory() {
        resumeOrientationState();
        this.inactivityTimer.shutdown();
        this.hasSurface = false;
        this.decodeFormats = null;
        this.characterSet = null;
    }

    private Bitmap byte2bitmap(byte[] data, Camera mCamera) {
        Exception e;
        Bitmap bmp = null;
        try {
            Camera.Size size = mCamera.getParameters().getPreviewSize();
            YuvImage image = new YuvImage(data, 17, size.width, size.height, null);
            ByteArrayOutputStream stream = new ByteArrayOutputStream();
            image.compressToJpeg(new Rect(0, 0, size.width, size.height), 80, stream);
            Bitmap bmp2 = BitmapFactory.decodeByteArray(stream.toByteArray(), 0, stream.size());
            try {
                stream.close();
                Matrix m = new Matrix();
                m.postRotate(90.0f);
                return Bitmap.createBitmap(bmp2, 0, 0, bmp2.getWidth(), bmp2.getHeight(), m, true);
            } catch (Exception e2) {
                e = e2;
                bmp = bmp2;
                e.printStackTrace();
                return bmp;
            }
        } catch (Exception e3) {
            e = e3;
            e.printStackTrace();
            return bmp;
        }
    }

    public void start() {
        PermissionUtil.useSystemPermissions((Activity) this.context, new String[]{"android.permission.CAMERA"}, new PermissionUtil.Request() {
            /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass4 */

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onGranted(String streamPerName) {
                BarcodeView.this.postDelayed(new Runnable() {
                    /* class io.dcloud.feature.weex_barcode.BarcodeView.AnonymousClass4.AnonymousClass1 */

                    public void run() {
                        if (!BarcodeView.this.isSurfaceAvaliable) {
                            BarcodeView.this.postDelayed(this, 100);
                            return;
                        }
                        AbsoluteLayout.LayoutParams params = BarcodeView.this.setLayoutParams();
                        if (params != null) {
                            Message msg = new Message();
                            msg.what = 203;
                            msg.obj = params;
                            BarcodeView.this.mHandler.sendMessage(msg);
                        }
                    }
                }, BarcodeView.this.isSurfaceAvaliable ? 0 : 200);
            }

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onDenied(String streamPerName) {
                BarcodeView.this.nopermission = true;
                BarcodeView.this.setBackground(-16777216);
                BarcodeView.this.invalidate();
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startP() {
        initCamera();
        if (this.decodeFormats == null) {
            initDecodeFormats(null);
        }
        if (!TextUtils.isEmpty(this.errorMsg)) {
            Map<String, Object> error = new HashMap<>();
            error.put("code", 8);
            error.put("message", this.errorMsg);
            error.put("type", Constants.Event.FAIL);
            fireEvent("error", error);
        } else if (!this.mRunning) {
            getViewfinderView().startUpdateScreenTimer();
            CaptureActivityHandler captureActivityHandler = this.handler;
            if (captureActivityHandler != null) {
                captureActivityHandler.restartPreviewAndDecode();
            } else {
                onResume(false);
            }
            if (this.isCancelScan) {
                this.surfaceView.setBackgroundDrawable(null);
                Bitmap bitmap = this.lastBiptmap;
                if (bitmap != null && !bitmap.isRecycled()) {
                    this.lastBiptmap.recycle();
                    this.lastBiptmap = null;
                }
                CameraManager.get().clearLastBitmapData();
                this.surfaceView.postInvalidate();
                initCamera();
            }
            this.mRunning = true;
            this.isCancelScan = false;
        }
    }

    public void onResume(boolean isSysEvent) {
        if (this.lastBiptmap != null && this.isCancelScan && isSysEvent) {
            this.surfaceView.setBackgroundDrawable(new BitmapDrawable(this.context.getResources(), this.lastBiptmap));
        }
        if (!this.hasSurface) {
            this.surfaceView.setSurfaceTextureListener(this);
        }
        if (((AudioManager) this.context.getSystemService("audio")).getRingerMode() != 2) {
            this.playBeep = false;
        }
        initBeepSound();
        if (isSysEvent && this.mRunning) {
            this.mRunning = false;
            start();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private AbsoluteLayout.LayoutParams setLayoutParams() {
        Point camearResolution;
        int surfaceViewHeight;
        int surfaceViewWidth;
        CameraManager.sScreenWidth = this.context.getResources().getDisplayMetrics().widthPixels;
        CameraManager.sScreenAllHeight = this.context.getResources().getDisplayMetrics().heightPixels;
        Rect gatherRect = DetectorViewConfig.getInstance().gatherRect;
        gatherRect.left = 0;
        gatherRect.top = 0;
        gatherRect.right = this.viewWidth;
        gatherRect.bottom = this.viewHeight;
        if (this.isVerticalScreen) {
            camearResolution = CameraManager.getCR(gatherRect.height(), gatherRect.width());
        } else {
            camearResolution = CameraManager.getCR(gatherRect.width(), gatherRect.height());
        }
        if (camearResolution == null) {
            camearResolution = new Point(this.viewWidth, this.viewHeight);
        }
        int left = 0;
        int top = 0;
        if (this.isVerticalScreen) {
            surfaceViewWidth = this.viewWidth;
            if ((camearResolution.x * surfaceViewWidth) / camearResolution.y < this.viewHeight) {
                surfaceViewHeight = this.viewHeight;
                surfaceViewWidth = (camearResolution.y * surfaceViewHeight) / camearResolution.x;
                left = (this.viewWidth - surfaceViewWidth) / 2;
                DetectorViewConfig.detectorRectOffestLeft = left;
                DetectorViewConfig.detectorRectOffestTop = 0;
            } else {
                surfaceViewHeight = (camearResolution.x * surfaceViewWidth) / camearResolution.y;
                top = (this.viewHeight - surfaceViewHeight) / 2;
                DetectorViewConfig.detectorRectOffestTop = top;
                DetectorViewConfig.detectorRectOffestLeft = 0;
            }
        } else {
            surfaceViewHeight = this.viewHeight;
            if ((camearResolution.x * surfaceViewHeight) / camearResolution.y < this.viewWidth) {
                surfaceViewWidth = this.viewWidth;
                surfaceViewHeight = (camearResolution.y * surfaceViewWidth) / camearResolution.x;
                top = (this.viewHeight - surfaceViewHeight) / 2;
                DetectorViewConfig.detectorRectOffestTop = top;
                DetectorViewConfig.detectorRectOffestLeft = 0;
            } else {
                surfaceViewWidth = (camearResolution.x * surfaceViewHeight) / camearResolution.y;
                left = (this.viewWidth - surfaceViewWidth) / 2;
                DetectorViewConfig.detectorRectOffestLeft = left;
                DetectorViewConfig.detectorRectOffestTop = 0;
            }
        }
        AbsoluteLayout.LayoutParams lllp = new AbsoluteLayout.LayoutParams(surfaceViewWidth, surfaceViewHeight, left, top);
        DetectorViewConfig.getInstance().initSurfaceViewRect(left, top, surfaceViewWidth, surfaceViewHeight);
        return lllp;
    }

    public void initDecodeFormats(JSONArray filters) {
        this.decodeFormats = new Vector<>();
        if (filters == null || filters.size() == 0) {
            this.decodeFormats.add(BarcodeFormat.EAN_13);
            this.decodeFormats.add(BarcodeFormat.EAN_8);
            this.decodeFormats.add(BarcodeFormat.QR_CODE);
            return;
        }
        int size = filters.size();
        for (int i = 0; i < size; i++) {
            int filter = -1;
            try {
                filter = filters.getInteger(i).intValue();
            } catch (JSONException e) {
                e.printStackTrace();
            }
            if (filter != -1) {
                this.decodeFormats.add(convertNumToBarcodeFormat(filter));
            }
        }
    }

    private BarcodeFormat convertNumToBarcodeFormat(int num) {
        switch (num) {
            case 0:
                return BarcodeFormat.QR_CODE;
            case 1:
                return BarcodeFormat.EAN_13;
            case 2:
                return BarcodeFormat.EAN_8;
            case 3:
                return BarcodeFormat.AZTEC;
            case 4:
                return BarcodeFormat.DATA_MATRIX;
            case 5:
                return BarcodeFormat.UPC_A;
            case 6:
                return BarcodeFormat.UPC_E;
            case 7:
                return BarcodeFormat.CODABAR;
            case 8:
                return BarcodeFormat.CODE_39;
            case 9:
                return BarcodeFormat.CODE_93;
            case 10:
                return BarcodeFormat.CODE_128;
            case 11:
                return BarcodeFormat.ITF;
            case 12:
                return BarcodeFormat.MAXICODE;
            case 13:
                return BarcodeFormat.PDF_417;
            case 14:
                return BarcodeFormat.RSS_14;
            case 15:
                return BarcodeFormat.RSS_EXPANDED;
            default:
                return null;
        }
    }

    private int convertTypestrToNum(BarcodeFormat format) {
        if (format == BarcodeFormat.QR_CODE) {
            return 0;
        }
        if (format == BarcodeFormat.EAN_13) {
            return 1;
        }
        if (format == BarcodeFormat.EAN_8) {
            return 2;
        }
        if (format == BarcodeFormat.AZTEC) {
            return 3;
        }
        if (format == BarcodeFormat.DATA_MATRIX) {
            return 4;
        }
        if (format == BarcodeFormat.UPC_A) {
            return 5;
        }
        if (format == BarcodeFormat.UPC_E) {
            return 6;
        }
        if (format == BarcodeFormat.CODABAR) {
            return 7;
        }
        if (format == BarcodeFormat.CODE_39) {
            return 8;
        }
        if (format == BarcodeFormat.CODE_93) {
            return 9;
        }
        if (format == BarcodeFormat.CODE_128) {
            return 10;
        }
        if (format == BarcodeFormat.ITF) {
            return 11;
        }
        if (format == BarcodeFormat.MAXICODE) {
            return 12;
        }
        if (format == BarcodeFormat.PDF_417) {
            return 13;
        }
        if (format == BarcodeFormat.RSS_14) {
            return 14;
        }
        if (format == BarcodeFormat.RSS_EXPANDED) {
            return 15;
        }
        return -1000;
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public ViewfinderView getViewfinderView() {
        return this.viewfinderView;
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public void autoFocus() {
        this.handler.autoFocus();
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public void handleDecode(Result obj, Bitmap barcode) {
        this.inactivityTimer.onActivity();
        playBeepSoundAndVibrate();
        boolean saveSuc = false;
        String realPath = null;
        if (this.mConserve) {
            if (!PdrUtil.isEmpty(this.mFilename) && !PdrUtil.isDeviceRootDir(this.mFilename) && !this.mFilename.startsWith(BaseInfo.REL_PRIVATE_DOC_DIR)) {
                this.mFilename = BaseInfo.REL_PRIVATE_DOC_DIR + this.mFilename;
            }
            realPath = this.mInstance.rewriteUri(Uri.parse(this.mFilename), "image").getPath();
            saveSuc = PdrUtil.saveBitmapToFile(barcode, realPath);
        }
        int num = convertTypestrToNum(obj.getBarcodeFormat());
        Map<String, Object> params = new HashMap<>();
        params.put("code", Integer.valueOf(num));
        params.put("message", obj.getText());
        if (saveSuc && !PdrUtil.isEmpty(realPath)) {
            params.put("file", realPath);
        }
        params.put("type", WXImage.SUCCEED);
        params.put("charSet", obj.textCharset);
        fireEvent("marked", params);
        cancelScan();
    }

    private void cancel() {
        if (this.mRunning) {
            CaptureActivityHandler captureActivityHandler = this.handler;
            if (captureActivityHandler != null) {
                captureActivityHandler.stopDecode();
            }
            getViewfinderView().stopUpdateScreenTimer();
            this.mRunning = false;
        }
    }

    private void initBeepSound() {
        if (this.mediaPlayer == null) {
            ((Activity) this.context).setVolumeControlStream(3);
            MediaPlayer mediaPlayer2 = new MediaPlayer();
            this.mediaPlayer = mediaPlayer2;
            mediaPlayer2.setAudioStreamType(3);
            this.mediaPlayer.setOnCompletionListener(this.beepListener);
            try {
                AssetFileDescriptor file = this.context.getResources().getAssets().openFd(AbsoluteConst.RES_BEEP);
                this.mediaPlayer.setDataSource(file.getFileDescriptor(), file.getStartOffset(), file.getLength());
                file.close();
                this.mediaPlayer.setVolume(BEEP_VOLUME, BEEP_VOLUME);
                this.mediaPlayer.prepare();
            } catch (IOException e) {
                this.mediaPlayer = null;
            }
        }
    }

    private void playBeepSoundAndVibrate() {
        MediaPlayer mediaPlayer2;
        if (this.playBeep && (mediaPlayer2 = this.mediaPlayer) != null) {
            mediaPlayer2.start();
        }
        if (this.vibrate) {
            try {
                ((Vibrator) this.context.getSystemService("vibrator")).vibrate(200);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public void drawViewfinder() {
        this.viewfinderView.drawViewfinder();
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public boolean isRunning() {
        return this.mRunning;
    }

    @Override // io.dcloud.feature.barcode2.decoding.IBarHandler
    public Handler getHandler() {
        return this.handler;
    }

    public void onSurfaceTextureAvailable(SurfaceTexture surface, int width, int height) {
        this.isSurfaceAvaliable = true;
        if (!this.hasSurface) {
            this.hasSurface = true;
        }
    }

    public void onSurfaceTextureSizeChanged(SurfaceTexture surface, int width, int height) {
    }

    public boolean onSurfaceTextureDestroyed(SurfaceTexture surface) {
        this.hasSurface = false;
        return false;
    }

    public void onSurfaceTextureUpdated(SurfaceTexture surface) {
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        String language;
        super.onDraw(canvas);
        if (this.nopermission) {
            Paint paint = new TextPaint();
            paint.setColor(-1);
            paint.setTextSize((float) PdrUtil.pxFromDp(18.0f, this.context.getResources().getDisplayMetrics()));
            paint.setTextAlign(Paint.Align.CENTER);
            Paint.FontMetrics fontMetrics = paint.getFontMetrics();
            int baseLineY = (int) (((((float) this.viewHeight) / 2.0f) - (fontMetrics.top / 2.0f)) - (fontMetrics.bottom / 2.0f));
            int pl2 = this.viewWidth / 2;
            if (Build.VERSION.SDK_INT >= 24) {
                language = getResources().getConfiguration().getLocales().get(0).getLanguage();
                getResources().getConfiguration().getLocales().get(0).getScript();
            } else {
                language = getResources().getConfiguration().locale.getLanguage();
                getResources().getConfiguration().getLocales().get(0).getScript();
            }
            String noPermissionText = getResources().getString(R.string.dcloud_scan_no_permission_text);
            if (language.equalsIgnoreCase("ja")) {
                canvas.drawText("カメラ権限がありません", (float) pl2, (float) baseLineY, paint);
            } else if (language.equalsIgnoreCase("ru")) {
                canvas.drawText("Требуется разрешение камеры.", (float) pl2, (float) baseLineY, paint);
            } else {
                canvas.drawText(noPermissionText, (float) pl2, (float) baseLineY, paint);
            }
        }
    }

    private void fireEvent(String type, Map<String, Object> params) {
        if (this.component.containsEvent(type)) {
            Map<String, Object> detail = new HashMap<>();
            detail.put("detail", params);
            this.component.fireEvent(type, detail);
        }
    }
}
