package io.dcloud.feature.weex_livepusher;

import android.app.Activity;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.widget.LinearLayout;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXImage;
import com.tencent.rtmp.ITXLivePushListener;
import com.tencent.rtmp.TXLiveConstants;
import com.tencent.rtmp.TXLivePushConfig;
import com.tencent.rtmp.TXLivePusher;
import com.tencent.rtmp.ui.TXCloudVideoView;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.adapter.util.PermissionUtil;
import io.dcloud.common.util.PdrUtil;
import java.io.File;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class TCPusherView extends LinearLayout implements ITXLivePushListener, TXLivePusher.OnBGMNotify {
    private String BGMPath;
    private final List<Runnable> actions = new ArrayList();
    private boolean autoPush;
    private int beautyLevel = 0;
    private boolean cameraType = true;
    private WXComponent component;
    private boolean isAutoFocus;
    private boolean isPermissionGranted = false;
    private boolean isPreview = false;
    private Handler mHandler = new Handler() {
        /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass1 */

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            if (msg.what == 1) {
                TCPusherView.this.init();
            }
        }
    };
    private WXSDKInstance mInstance;
    private TXLivePushConfig mLivePushConfig;
    private TXLivePusher mLivePusher;
    private String mSrc;
    private List<String> permissions = new ArrayList();
    private TXCloudVideoView pusherView;
    private final String[] requestPermissions;
    private boolean torchIsOn = false;
    private int videoQulity = 6;
    private int videoResolution;
    private int whiteLevel = 0;

    public void setAutoPush(boolean autoPush2) {
        this.autoPush = autoPush2;
    }

    public TCPusherView(Context context, WXComponent component2, boolean isFront) {
        super(context);
        this.component = component2;
        this.mInstance = component2.getInstance();
        TXLivePushConfig tXLivePushConfig = new TXLivePushConfig();
        this.mLivePushConfig = tXLivePushConfig;
        tXLivePushConfig.setVideoEncodeGop(5);
        this.mLivePushConfig.enableNearestIP(false);
        this.mLivePushConfig.setFrontCamera(isFront);
        this.cameraType = isFront;
        if (!isFront) {
            this.mLivePushConfig.setTouchFocus(false);
        }
        this.mLivePushConfig.setPauseFlag(3);
        TXCloudVideoView tXCloudVideoView = new TXCloudVideoView(getContext());
        this.pusherView = tXCloudVideoView;
        addView(tXCloudVideoView, new LinearLayout.LayoutParams(-1, -1));
        ((Activity) getContext()).getWindow().addFlags(128);
        if (Build.VERSION.SDK_INT >= 30) {
            this.requestPermissions = new String[]{"android.permission.RECORD_AUDIO", "android.permission.CAMERA", "android.permission.READ_PHONE_STATE"};
        } else {
            this.requestPermissions = new String[]{"android.permission.RECORD_AUDIO", "android.permission.CAMERA"};
        }
        requestPermission();
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (PdrUtil.isEmpty(this.component.getStyles().getBackgroundColor())) {
            setBackgroundColor(-16777216);
        }
    }

    public void init() {
        TXLivePusher tXLivePusher = new TXLivePusher(this.component.getContext());
        this.mLivePusher = tXLivePusher;
        tXLivePusher.setConfig(this.mLivePushConfig);
        this.mLivePusher.setPushListener(this);
        this.mLivePusher.setBGMNofify(this);
        this.mLivePusher.setVideoQuality(this.videoQulity, false, false);
    }

    public void switchCamera(String type) {
        this.cameraType = type.equals("front");
        if (this.mLivePusher.isPushing()) {
            this.mLivePusher.switchCamera();
        }
        this.mLivePushConfig.setFrontCamera(this.cameraType);
        this.mLivePusher.setConfig(this.mLivePushConfig);
    }

    public void sCamera(final JSCallback callback) {
        this.cameraType = !this.cameraType;
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass2 */

            public void run() {
                Map<String, Object> data = new HashMap<>();
                TCPusherView.this.mLivePusher.switchCamera();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void autoFocus(boolean isAuto) {
        if (!this.cameraType) {
            this.isAutoFocus = isAuto;
            this.mLivePushConfig.setTouchFocus(isAuto);
        }
    }

    public void setMute(final boolean mote) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass3 */

            public void run() {
                TCPusherView.this.mLivePusher.setMute(mote);
            }
        });
    }

    public void preview(final JSCallback callback) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass4 */

            public void run() {
                TCPusherView.this.mLivePushConfig.setFrontCamera(TCPusherView.this.cameraType);
                TCPusherView.this.mLivePusher.setConfig(TCPusherView.this.mLivePushConfig);
                TCPusherView.this.isPreview = true;
                TCPusherView.this.mLivePusher.startCameraPreview(TCPusherView.this.pusherView);
                Map<String, Object> data = new HashMap<>();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void stopPreview(final JSCallback callback) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass5 */

            public void run() {
                TCPusherView.this.isPreview = false;
                TCPusherView.this.mLivePusher.stopCameraPreview(false);
                Map<String, Object> data = new HashMap<>();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void setBGMute(boolean ismute) {
        this.mLivePushConfig.setPauseFlag(3);
    }

    public void setMode(final String mode) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass6 */

            /* JADX WARNING: Removed duplicated region for block: B:22:0x0047  */
            /* JADX WARNING: Removed duplicated region for block: B:27:0x006e  */
            public void run() {
                char c;
                String str = mode;
                int hashCode = str.hashCode();
                if (hashCode != 2300) {
                    if (hashCode != 2641) {
                        if (hashCode != 69570) {
                            if (hashCode == 81473 && str.equals("RTC")) {
                                c = 4;
                                if (c == 0) {
                                    TCPusherView.this.videoQulity = 1;
                                    TCPusherView.this.videoResolution = 0;
                                    TCPusherView.this.mLivePushConfig.setAutoAdjustBitrate(false);
                                    TCPusherView.this.mLivePushConfig.setVideoBitrate(700);
                                    TCPusherView.this.mLivePusher.setConfig(TCPusherView.this.mLivePushConfig);
                                } else if (c == 1) {
                                    TCPusherView.this.videoQulity = 2;
                                    TCPusherView.this.videoResolution = 1;
                                } else if (c != 2) {
                                    TCPusherView.this.videoQulity = 6;
                                    TCPusherView.this.videoResolution = 0;
                                } else {
                                    TCPusherView.this.videoQulity = 3;
                                    TCPusherView.this.videoResolution = 2;
                                }
                                TCPusherView.this.mLivePusher.setVideoQuality(TCPusherView.this.videoQulity, false, false);
                                TCPusherView.this.mLivePushConfig.setVideoResolution(TCPusherView.this.videoResolution);
                            }
                        } else if (str.equals("FHD")) {
                            c = 2;
                            if (c == 0) {
                            }
                            TCPusherView.this.mLivePusher.setVideoQuality(TCPusherView.this.videoQulity, false, false);
                            TCPusherView.this.mLivePushConfig.setVideoResolution(TCPusherView.this.videoResolution);
                        }
                    } else if (str.equals("SD")) {
                        c = 0;
                        if (c == 0) {
                        }
                        TCPusherView.this.mLivePusher.setVideoQuality(TCPusherView.this.videoQulity, false, false);
                        TCPusherView.this.mLivePushConfig.setVideoResolution(TCPusherView.this.videoResolution);
                    }
                } else if (str.equals("HD")) {
                    c = 1;
                    if (c == 0) {
                    }
                    TCPusherView.this.mLivePusher.setVideoQuality(TCPusherView.this.videoQulity, false, false);
                    TCPusherView.this.mLivePushConfig.setVideoResolution(TCPusherView.this.videoResolution);
                }
                c = 65535;
                if (c == 0) {
                }
                TCPusherView.this.mLivePusher.setVideoQuality(TCPusherView.this.videoQulity, false, false);
                TCPusherView.this.mLivePushConfig.setVideoResolution(TCPusherView.this.videoResolution);
            }
        });
    }

    public void setOritation(final String oritation) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass7 */

            public void run() {
                if (oritation.equals("vertical")) {
                    TCPusherView.this.mLivePushConfig.setHomeOrientation(1);
                    TCPusherView.this.mLivePusher.setRenderRotation(0);
                } else if (oritation.equals(Constants.Value.HORIZONTAL)) {
                    TCPusherView.this.mLivePushConfig.setHomeOrientation(0);
                    TCPusherView.this.mLivePusher.setRenderRotation(0);
                }
            }
        });
    }

    public void setBeauty(int level) {
        if (level < 0) {
            level = 0;
        } else if (level > 9) {
            level = 9;
        }
        this.beautyLevel = level;
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass8 */

            public void run() {
                TCPusherView.this.mLivePushConfig.setBeautyFilter(TCPusherView.this.beautyLevel, TCPusherView.this.whiteLevel, 0);
                TCPusherView.this.mLivePusher.setBeautyFilter(0, TCPusherView.this.beautyLevel, TCPusherView.this.whiteLevel, 0);
            }
        });
    }

    public void setWhite(int level) {
        if (level < 0) {
            level = 0;
        } else if (level > 9) {
            level = 9;
        }
        this.whiteLevel = level;
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass9 */

            public void run() {
                TCPusherView.this.mLivePushConfig.setBeautyFilter(TCPusherView.this.beautyLevel, TCPusherView.this.whiteLevel, 0);
                TCPusherView.this.mLivePusher.setBeautyFilter(0, TCPusherView.this.beautyLevel, TCPusherView.this.whiteLevel, 0);
            }
        });
    }

    public void setMinBitrate(int bitrate) {
        this.mLivePushConfig.setMinVideoBitrate(bitrate);
    }

    public void setMaxBitrate(int bitrate) {
        this.mLivePushConfig.setMaxVideoBitrate(bitrate);
    }

    public void setWaintImage(String imagePath) {
        Bitmap bitmap = decodeResource(this.component.getInstance().rewriteUri(Uri.parse(imagePath), "image").getPath());
        if (bitmap != null) {
            this.mLivePushConfig.setPauseImg(bitmap);
            this.mLivePushConfig.setPauseFlag(1);
        }
    }

    private Bitmap decodeResource(String id) {
        return BitmapFactory.decodeFile(id, new BitmapFactory.Options());
    }

    public void enableCamera(boolean isEnable) {
        this.mLivePushConfig.enablePureAudioPush(!isEnable);
    }

    public void setZoom(boolean isZoom) {
        this.mLivePushConfig.setEnableZoom(isZoom);
    }

    public void start(final JSCallback callback) {
        final Map<String, Object> data = new HashMap<>();
        if (PdrUtil.isEmpty(this.mSrc)) {
            data.put("type", Constants.Event.FAIL);
            if (callback != null) {
                callback.invoke(data);
                return;
            }
            return;
        }
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass10 */

            public void run() {
                TCPusherView.this.mLivePushConfig.setFrontCamera(TCPusherView.this.cameraType);
                TCPusherView.this.mLivePushConfig.setBeautyFilter(TCPusherView.this.beautyLevel, TCPusherView.this.whiteLevel, 0);
                TCPusherView.this.mLivePusher.setConfig(TCPusherView.this.mLivePushConfig);
                if (!TCPusherView.this.isPreview) {
                    TCPusherView.this.mLivePusher.startCameraPreview(TCPusherView.this.pusherView);
                }
                if (TCPusherView.this.mLivePusher.startPusher(TCPusherView.this.mSrc) == 0) {
                    data.put("type", WXImage.SUCCEED);
                } else {
                    data.put("type", Constants.Event.FAIL);
                }
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void pause(final JSCallback callback) {
        this.pusherView.onPause();
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass11 */

            public void run() {
                TCPusherView.this.mLivePusher.pausePusher();
                Map<String, Object> data = new HashMap<>();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void resume(final JSCallback callback) {
        this.pusherView.onResume();
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass12 */

            public void run() {
                TCPusherView.this.mLivePusher.resumePusher();
                Map<String, Object> data = new HashMap<>();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void onResume() {
        if (!this.isPermissionGranted && PermissionUtil.checkPermissions(getContext(), this.requestPermissions)) {
            handlePermissionGranted();
        }
    }

    public void setSrc(String src) {
        if ((PdrUtil.isEmpty(this.mSrc) && !PdrUtil.isEmpty(src)) || !this.mSrc.equals(src)) {
            this.mSrc = src;
        }
    }

    private void changeSrc(String src) {
        this.mLivePushConfig.setCustomModeType(0);
        this.mLivePushConfig.setPauseImg(300, 5);
        this.mLivePusher.startPusher(src);
    }

    public void stopPusher(final JSCallback callback) {
        ((Activity) getContext()).getWindow().clearFlags(128);
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass13 */

            public void run() {
                TCPusherView.this.mLivePusher.stopBGM();
                TCPusherView.this.mLivePusher.stopCameraPreview(false);
                TCPusherView.this.mLivePusher.stopScreenCapture();
                TCPusherView.this.mLivePusher.stopPusher();
                Map<String, Object> data = new HashMap<>();
                data.put("type", WXImage.SUCCEED);
                JSCallback jSCallback = callback;
                if (jSCallback != null) {
                    jSCallback.invoke(data);
                }
            }
        });
    }

    public void destory() {
        this.pusherView.stop(true);
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass14 */

            public void run() {
                TCPusherView.this.mLivePusher.setPushListener(null);
                TCPusherView.this.mLivePusher.setBGMNofify(null);
            }
        });
    }

    public void playBGM(String url, JSCallback success) {
        Map<String, Object> data = new HashMap<>();
        if (PdrUtil.isEmpty(url)) {
            data.put("type", Constants.Event.FAIL);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        if (PdrUtil.isNetPath(url)) {
            this.BGMPath = url;
        } else {
            this.BGMPath = this.mInstance.rewriteUri(Uri.parse(url), "image").getPath();
        }
        if (this.mLivePusher.playBGM(this.BGMPath)) {
            data.put("type", WXImage.SUCCEED);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        data.put("type", Constants.Event.FAIL);
        if (success != null) {
            success.invoke(data);
        }
    }

    public void setBGNVolume(int volume, JSCallback success) {
        if (this.mLivePusher.setBGMVolume((float) volume)) {
            Map<String, Object> data = new HashMap<>();
            data.put("type", WXImage.SUCCEED);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        Map<String, Object> data2 = new HashMap<>();
        data2.put("type", Constants.Event.FAIL);
        if (success != null) {
            success.invoke(data2);
        }
    }

    public void pauseBGM(JSCallback success) {
        if (this.mLivePusher.pauseBGM()) {
            Map<String, Object> data = new HashMap<>();
            data.put("type", WXImage.SUCCEED);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        Map<String, Object> data2 = new HashMap<>();
        data2.put("type", Constants.Event.FAIL);
        if (success != null) {
            success.invoke(data2);
        }
    }

    public void resumeBGM(JSCallback success) {
        if (this.mLivePusher.resumeBGM()) {
            Map<String, Object> data = new HashMap<>();
            data.put("type", WXImage.SUCCEED);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        Map<String, Object> data2 = new HashMap<>();
        data2.put("type", Constants.Event.FAIL);
        if (success != null) {
            success.invoke(data2);
        }
    }

    public void stopBGM(JSCallback success) {
        if (this.mLivePusher.stopBGM()) {
            Map<String, Object> data = new HashMap<>();
            data.put("type", WXImage.SUCCEED);
            if (success != null) {
                success.invoke(data);
                return;
            }
            return;
        }
        Map<String, Object> data2 = new HashMap<>();
        data2.put("type", Constants.Event.FAIL);
        if (success != null) {
            success.invoke(data2);
        }
    }

    public void snapShot(final JSCallback success) {
        handleAction(new Runnable() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass15 */

            public void run() {
                TCPusherView.this.mLivePusher.snapshot(new TXLivePusher.ITXSnapshotListener() {
                    /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass15.AnonymousClass1 */

                    @Override // com.tencent.rtmp.TXLivePusher.ITXSnapshotListener
                    public void onSnapshot(Bitmap bitmap) {
                        if (bitmap != null) {
                            String path = TCPusherView.this.mInstance.rewriteUri(Uri.parse("_doc/snapshot/snapshot_" + System.currentTimeMillis() + ".jpg"), "image").getPath();
                            try {
                                File snapImage = new File(path);
                                if (!snapImage.exists()) {
                                    if (!snapImage.getParentFile().exists()) {
                                        snapImage.getParentFile().mkdirs();
                                    }
                                    snapImage.createNewFile();
                                }
                                FileOutputStream fos = new FileOutputStream(snapImage);
                                bitmap.compress(Bitmap.CompressFormat.JPEG, 100, fos);
                                fos.flush();
                                fos.close();
                                Map<String, Object> values = new HashMap<>();
                                HashMap<String, Object> message = new HashMap<>();
                                message.put("width", Integer.valueOf(bitmap.getWidth()));
                                message.put("height", Integer.valueOf(bitmap.getHeight()));
                                message.put("tempImagePath", path);
                                values.put("message", message);
                                values.put("type", WXImage.SUCCEED);
                                values.put("code", 0);
                                if (success != null) {
                                    success.invoke(values);
                                }
                            } catch (Exception e) {
                                Map<String, Object> error = new HashMap<>();
                                error.put("code", "-99");
                                error.put("message", e.getMessage());
                                error.put("type", Constants.Event.FAIL);
                                if (success != null) {
                                    success.invoke(error);
                                }
                            }
                        } else {
                            Map<String, Object> data = new HashMap<>();
                            data.put("type", Constants.Event.FAIL);
                            data.put("code", "-99");
                            data.put("message", "data error");
                            if (success != null) {
                                success.invoke(data);
                            }
                        }
                    }
                });
            }
        });
    }

    public void toggleTorch(JSCallback callback) {
        boolean z = !this.torchIsOn;
        this.torchIsOn = z;
        if (this.mLivePusher.turnOnFlashLight(z)) {
            Map<String, Object> data = new HashMap<>();
            data.put("type", WXImage.SUCCEED);
            if (callback != null) {
                callback.invoke(data);
                return;
            }
            return;
        }
        Map<String, Object> data2 = new HashMap<>();
        data2.put("type", Constants.Event.FAIL);
        if (callback != null) {
            callback.invoke(data2);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireEvent(String event, Map<String, Object> params) {
        if (this.component.containsEvent(event)) {
            this.component.fireEvent(event, params);
        }
    }

    @Override // com.tencent.rtmp.ITXLivePushListener
    public void onPushEvent(int i, Bundle bundle) {
        HashMap hashMap = new HashMap();
        hashMap.put("code", Integer.valueOf(i));
        String str = "";
        if (!(bundle == null || bundle.getString(TXLiveConstants.EVT_DESCRIPTION) == null)) {
            str = bundle.getString(TXLiveConstants.EVT_DESCRIPTION);
        }
        hashMap.put("message", str);
        HashMap<String, Object> detail = new HashMap<>(1);
        detail.put("detail", hashMap);
        fireEvent("statechange", detail);
    }

    @Override // com.tencent.rtmp.ITXLivePushListener
    public void onNetStatus(Bundle bundle) {
        HashMap hashMap = new HashMap();
        HashMap hashMap2 = new HashMap();
        try {
            hashMap2.put("videoBitrate", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_VIDEO_BITRATE)));
            hashMap2.put("audioBitrate", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_AUDIO_BITRATE)));
            hashMap2.put("videoFPS", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_VIDEO_FPS)));
            hashMap2.put("videoGOP", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_VIDEO_GOP)));
            hashMap2.put("netSpeed", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_NET_SPEED)));
            hashMap2.put("netJitter", 0);
            hashMap2.put("videoWidth", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_VIDEO_WIDTH)));
            hashMap2.put("videoHeight", Integer.valueOf(bundle.getInt(TXLiveConstants.NET_STATUS_VIDEO_HEIGHT)));
        } catch (Exception e) {
        }
        hashMap.put("info", hashMap2);
        HashMap<String, Object> detail = new HashMap<>(1);
        detail.put("detail", hashMap);
        fireEvent("netstatus", detail);
    }

    @Override // com.tencent.rtmp.TXLivePusher.OnBGMNotify
    public void onBGMStart() {
        fireEvent("bgmstart", new HashMap());
    }

    @Override // com.tencent.rtmp.TXLivePusher.OnBGMNotify
    public void onBGMProgress(long l, long l1) {
        HashMap hashMap = new HashMap();
        hashMap.put("progress", Long.valueOf(l));
        hashMap.put("duration", Long.valueOf(l1));
        HashMap<String, Object> detail = new HashMap<>(1);
        detail.put("detail", hashMap);
        fireEvent("bgmprogress", detail);
    }

    @Override // com.tencent.rtmp.TXLivePusher.OnBGMNotify
    public void onBGMComplete(int i) {
        fireEvent("bgmcomplete", new HashMap());
    }

    private void requestPermission() {
        PermissionUtil.useSystemPermissions((Activity) this.mInstance.getContext(), this.requestPermissions, new PermissionUtil.Request() {
            /* class io.dcloud.feature.weex_livepusher.TCPusherView.AnonymousClass16 */

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onGranted(String streamPerName) {
                TCPusherView.this.permissions.add(streamPerName);
                if (TCPusherView.this.permissions.size() == TCPusherView.this.requestPermissions.length) {
                    TCPusherView.this.handlePermissionGranted();
                }
            }

            @Override // io.dcloud.common.adapter.util.PermissionUtil.Request
            public void onDenied(String streamPerName) {
                HashMap hashMap = new HashMap();
                if (streamPerName.equals(PermissionUtil.PMS_CAMERA)) {
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, 10001);
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_weex_livepusher_msg_user_permission_loss_camera));
                } else if (streamPerName.equals(PermissionUtil.PMS_RECORD)) {
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, 10002);
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_weex_livepusher_msg_user_permission_loss_record));
                } else if (streamPerName.equals("android.permission.READ_PHONE_STATE")) {
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, 10003);
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_weex_livepusher_msg_user_permission_loss_read_phone_state));
                }
                HashMap<String, Object> detail = new HashMap<>(1);
                detail.put("detail", hashMap);
                TCPusherView.this.fireEvent("error", detail);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handlePermissionGranted() {
        this.isPermissionGranted = true;
        init();
        for (Runnable action : this.actions) {
            action.run();
        }
        if (this.autoPush) {
            if (this.mSrc == null) {
                this.mSrc = (String) this.component.getAttrs().get("url");
            }
            start(null);
        }
    }

    private void handleAction(Runnable action) {
        if (!this.isPermissionGranted) {
            this.actions.add(action);
        } else {
            action.run();
        }
    }
}
