package io.dcloud.feature.weex_media;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.CSSConstants;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.WXBaseRefreshLayout;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex.adapter.ScalableViewComponent;
import io.dcloud.feature.weex_media.option.EnumPlayStrategy;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;

public class VideoComponent extends WXVContainer<VideoPlayerView> implements ISysEventListener {
    private WXAttr attrs;
    private AtomicBoolean isLoad = new AtomicBoolean(false);
    private IApp mApp;
    private Map<String, Object> params;

    public VideoComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.attrs = basicComponentData.getAttrs();
        if (!basicComponentData.getStyles().containsKey(Constants.Name.FLEX)) {
            setContentBoxMeasurement(new ContentBoxMeasurement() {
                /* class io.dcloud.feature.weex_media.VideoComponent.AnonymousClass1 */

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                    if (CSSConstants.isUndefined(width)) {
                        this.mMeasureWidth = WXViewUtils.getRealPxByWidth(300.0f, VideoComponent.this.getInstance().getInstanceViewPortWidthWithFloat());
                    }
                    if (CSSConstants.isUndefined(height)) {
                        this.mMeasureHeight = WXViewUtils.getRealPxByWidth(225.0f, VideoComponent.this.getInstance().getInstanceViewPortWidthWithFloat());
                    }
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutBefore() {
                }

                @Override // com.taobao.weex.layout.ContentBoxMeasurement
                public void layoutAfter(float computedWidth, float computedHeight) {
                }
            });
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public VideoPlayerView initComponentHostView(Context context) {
        IWebview webview = WeexInstanceMgr.self().findWebview(getInstance());
        if (webview != null) {
            IApp obtainApp = webview.obtainApp();
            this.mApp = obtainApp;
            obtainApp.registerSysEventListener(this, ISysEventListener.SysEventType.onKeyUp);
        }
        return new VideoPlayerView(getContext(), this);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public ViewGroup getRealView() {
        if (getHostView() != null) {
            return ((VideoPlayerView) getHostView()).getPlayerView();
        }
        return null;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        if (child instanceof ScalableViewComponent) {
            ((ScalableViewComponent) child).setScalable(true);
            super.addChild(child, index);
        }
    }

    public IApp getIApp() {
        IWebview webview;
        if (this.mApp == null && (webview = WeexInstanceMgr.self().findWebview(getInstance())) != null) {
            this.mApp = webview.obtainApp();
        }
        return this.mApp;
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
        if (child != null && getRealView() != null && !(child instanceof WXBaseRefreshLayout)) {
            int index1 = index >= getRealView().getChildCount() ? -1 : index;
            if (getRealView().indexOfChild(child) == -1) {
                if (index1 == -1) {
                    getRealView().addView(child);
                } else {
                    getRealView().addView(child, index1);
                }
            }
            child.bringToFront();
        }
    }

    @WXComponentProp(name = "src")
    public void setSrc(String src) {
        if (!PdrUtil.isEmpty(src)) {
            ((VideoPlayerView) getHostView()).setSrc(src);
        }
    }

    @WXComponentProp(name = "header")
    public void setHeader(String header) {
        if (!PdrUtil.isEmpty(header)) {
            ((VideoPlayerView) getHostView()).setHeader(header);
        }
    }

    @WXComponentProp(name = Constants.Name.AUTOPLAY)
    public void setAutoPlay(boolean autoPlay) {
        if (!PdrUtil.isEmpty(Boolean.valueOf(autoPlay))) {
            ((VideoPlayerView) getHostView()).setAutoplay(autoPlay);
        }
    }

    @WXComponentProp(name = "initialTime")
    public void setInitTime(float time) {
        ((VideoPlayerView) getHostView()).setInitialTime(time);
    }

    @WXComponentProp(name = "duration")
    public void setDuration(float duration) {
        ((VideoPlayerView) getHostView()).setDuration(duration);
    }

    @WXComponentProp(name = "danmuList")
    public void setDanmuList(JSONArray list) {
        ((VideoPlayerView) getHostView()).setDanmuList(list);
    }

    @WXComponentProp(name = "loop")
    public void setLoop(boolean isloop) {
        ((VideoPlayerView) getHostView()).setLoop(isloop);
    }

    @WXComponentProp(name = "muted")
    public void setMute(boolean isMute) {
        ((VideoPlayerView) getHostView()).setMuted(isMute);
    }

    @WXComponentProp(name = "direction")
    public void setDirection(int direction) {
        ((VideoPlayerView) getHostView()).setDirection(direction);
    }

    @WXComponentProp(name = "playStrategy")
    public void setPlayStrategy(int playStrategy) {
        EnumPlayStrategy enumPlayStrategy = EnumPlayStrategy.DEFAULT;
        if (playStrategy == EnumPlayStrategy.PLAY_SMOOTH.getFlagVal()) {
            enumPlayStrategy = EnumPlayStrategy.PLAY_SMOOTH;
        } else if (playStrategy == EnumPlayStrategy.START_QUICK.getFlagVal()) {
            enumPlayStrategy = EnumPlayStrategy.START_QUICK;
        } else if (playStrategy == EnumPlayStrategy.M3U8_SMOOTH.getFlagVal()) {
            enumPlayStrategy = EnumPlayStrategy.M3U8_SMOOTH;
        } else if (playStrategy == EnumPlayStrategy.DEFAULT.getFlagVal()) {
            enumPlayStrategy = EnumPlayStrategy.DEFAULT;
        }
        ((VideoPlayerView) getHostView()).setFlowStrategy(enumPlayStrategy);
    }

    @WXComponentProp(name = "objectFit")
    public void setFit(String type) {
        if (!PdrUtil.isEmpty(type)) {
            ((VideoPlayerView) getHostView()).setObjectFit(type);
        }
    }

    @WXComponentProp(name = "showMuteBtn")
    public void isShowMuteBtn(boolean isshow) {
        ((VideoPlayerView) getHostView()).setMuteBtn(isshow);
    }

    @WXComponentProp(name = "playBtnPosition")
    public void setPlayBtnPosition(String position) {
        if (!PdrUtil.isEmpty(position)) {
            ((VideoPlayerView) getHostView()).setPlayBtnPosition(position);
        }
    }

    @WXComponentProp(name = "title")
    public void setTitle(String title) {
        if (!PdrUtil.isEmpty(title)) {
            ((VideoPlayerView) getHostView()).setTitle(title);
        }
    }

    @WXComponentProp(name = "httpCache")
    public void httpCache(boolean cacheEnable) {
        ((VideoPlayerView) getHostView()).setHttpCacheEnable(cacheEnable);
    }

    @WXComponentProp(name = "codec")
    public void setCodeMode(String codeMode) {
        ((VideoPlayerView) getHostView()).setCodec(codeMode);
    }

    @WXComponentProp(name = "showLoading")
    public void showLoading(boolean isShow) {
        ((VideoPlayerView) getHostView()).setShowLoading(isShow);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        if (props.size() > 0 && getHostView() != null) {
            this.params = combinMap(this.params, props);
            boolean z = false;
            ((VideoPlayerView) getHostView()).setProgress(!this.params.containsKey("showProgress") || Boolean.parseBoolean(this.params.get("showProgress").toString()));
            ((VideoPlayerView) getHostView()).setShowFullScreenBtn(!this.params.containsKey("showFullscreenBtn") || Boolean.parseBoolean(this.params.get("showFullscreenBtn").toString()));
            ((VideoPlayerView) getHostView()).setPlayBtnVisibility(!this.params.containsKey("showPlayBtn") || Boolean.parseBoolean(this.params.get("showPlayBtn").toString()));
            ((VideoPlayerView) getHostView()).setEnableProgressGesture(!this.params.containsKey("enableProgressGesture") || Boolean.parseBoolean(this.params.get("enableProgressGesture").toString()));
            if (props.containsKey("src")) {
                ((VideoPlayerView) getHostView()).setSrc((String) props.get("src"));
            }
            ((VideoPlayerView) getHostView()).setShowCenterPlayBtn(!this.params.containsKey("showCenterPlayBtn") || Boolean.parseBoolean(this.params.get("showCenterPlayBtn").toString()));
            VideoPlayerView videoPlayerView = (VideoPlayerView) getHostView();
            if (!this.params.containsKey("controls") || Boolean.parseBoolean(this.params.get("controls").toString())) {
                z = true;
            }
            videoPlayerView.setControls(z);
            if (this.params.containsKey("vslideGestureInFullscreen")) {
                ((VideoPlayerView) getHostView()).setFullScreenPageGesture(Boolean.parseBoolean(this.params.get("vslideGestureInFullscreen").toString()));
            }
            if (this.params.containsKey("vslideGesture")) {
                ((VideoPlayerView) getHostView()).setPageGesture(Boolean.parseBoolean(this.params.get("vslideGesture").toString()));
            }
            if (this.params.containsKey("showScreenLockButton")) {
                ((VideoPlayerView) getHostView()).setLockScreen(Boolean.parseBoolean(this.params.get("showScreenLockButton").toString()));
            }
            if (this.params.containsKey("enablePlayGesture")) {
                ((VideoPlayerView) getHostView()).setEnablePlayGesture(Boolean.parseBoolean(this.params.get("enablePlayGesture").toString()));
            }
        }
        super.updateProperties(props);
        if (props.size() > 0 && props.containsKey("src")) {
            ((VideoPlayerView) getHostView()).onLayoutFinished((String) props.get("src"));
        }
    }

    private Map<String, Object> combinMap(Map<String, Object> main, Map<String, Object> second) {
        if (main == null && second == null) {
            return new HashMap();
        }
        if (main == null) {
            return second;
        }
        if (second == null) {
            return main;
        }
        main.putAll(second);
        return main;
    }

    @WXComponentProp(name = "poster")
    public void setPoster(String poster) {
        ((VideoPlayerView) getHostView()).setPoster(poster);
    }

    @JSMethod
    public void requestFullScreen(JSONObject param) {
        int direction;
        try {
            direction = param.getInteger("direction").intValue();
        } catch (Exception e) {
            direction = -90;
        }
        ((VideoPlayerView) getHostView()).requestFullScreen(direction);
    }

    @JSMethod
    public void play() {
        ((VideoPlayerView) getHostView()).play();
    }

    @JSMethod
    public void pause() {
        ((VideoPlayerView) getHostView()).pause();
    }

    @JSMethod
    public void stop() {
        ((VideoPlayerView) getHostView()).stop();
    }

    @JSMethod
    public void seek(int position) {
        if (!PdrUtil.isEmpty(Integer.valueOf(position))) {
            ((VideoPlayerView) getHostView()).seek(position * 1000);
        }
    }

    @JSMethod
    public void sendDanmu(JSONObject danmu) {
        if (danmu != null) {
            ((VideoPlayerView) getHostView()).sendDanmu(danmu);
        }
    }

    @JSMethod
    public void playbackRate(float rate) {
        if (!PdrUtil.isEmpty(Float.valueOf(rate))) {
            ((VideoPlayerView) getHostView()).sendPlayBackRate(String.valueOf(rate));
        }
    }

    @JSMethod
    public void exitFullScreen() {
        ((VideoPlayerView) getHostView()).exitFullScreen();
    }

    /* access modifiers changed from: protected */
    public void onHostViewInitialized(VideoPlayerView host) {
        super.onHostViewInitialized((View) host);
        WXAttr wXAttr = this.attrs;
        if (wXAttr != null && wXAttr.size() > 0) {
            boolean z = true;
            ((VideoPlayerView) getHostView()).setEnableDanmu(this.attrs.containsKey("enableDanmu") && Boolean.parseBoolean(this.attrs.get("enableDanmu").toString()));
            VideoPlayerView videoPlayerView = (VideoPlayerView) getHostView();
            if (!this.attrs.containsKey("danmuBtn") || !Boolean.parseBoolean(this.attrs.get("danmuBtn").toString())) {
                z = false;
            }
            videoPlayerView.setDanmuBtn(z);
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityResume() {
        super.onActivityResume();
        if (getHostView() != null) {
            ((VideoPlayerView) getHostView()).onActivityResume();
        }
    }

    @Override // com.taobao.weex.IWXActivityStateListener, io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void onActivityPause() {
        super.onActivityPause();
        if (getHostView() != null) {
            ((VideoPlayerView) getHostView()).pause();
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        if (getHostView() != null) {
            ((VideoPlayerView) getHostView()).destory();
        }
        IApp iApp = this.mApp;
        if (iApp != null) {
            iApp.unregisterSysEventListener(this, ISysEventListener.SysEventType.onKeyUp);
        }
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        if (pEventType != ISysEventListener.SysEventType.onKeyUp || ((Integer) ((Object[]) pArgs)[0]).intValue() != 4 || !((VideoPlayerView) getHostView()).isFullScreen() || getHostView() == null) {
            return false;
        }
        return ((VideoPlayerView) getHostView()).onBackPress();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        if (!type.equals(Constants.Event.CLICK)) {
            super.addEvent(type);
        }
    }
}
