package io.dcloud.feature.weex_media;

import android.content.Context;
import android.graphics.Canvas;
import android.net.Uri;
import android.text.TextUtils;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.bumptech.glide.Glide;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.weex.adapter.ScalableViewComponent;
import io.dcloud.feature.weex_media.option.EnumPlayStrategy;
import io.dcloud.media.weex.weex_video.ijkplayer.OnPlayerChangedListener;
import io.dcloud.media.weex.weex_video.ijkplayer.media.AssetsDataSourceProvider;
import io.dcloud.media.weex.weex_video.ijkplayer.media.IjkPlayerView;
import java.util.HashMap;
import java.util.Map;
import tv.danmaku.ijk.media.player.IMediaPlayer;

public class VideoPlayerView extends FrameLayout implements IMediaPlayer.OnInfoListener, OnPlayerChangedListener, IMediaPlayer.OnBufferingUpdateListener {
    private boolean autoplay = false;
    private float duration = -1.0f;
    private float initialTime = 0.0f;
    private boolean isCreate = false;
    private boolean isEnableDanmu = false;
    private boolean isEnableDanmuBtn = false;
    private boolean isFinishLayout = false;
    private boolean loop = false;
    private VideoComponent mComponent;
    private Context mContext;
    private String mHeader = "";
    public boolean mIsFullScreen = false;
    public IjkPlayerView mPlayerView;
    private String mSrc = "";
    private String poster = "";
    private int seek = 0;
    private FrameLayout subViewContainer;

    public interface IOnPlayerViewChangeListener {
        void onChanged(boolean z);
    }

    public VideoPlayerView(Context context, VideoComponent component) {
        super(context);
        this.mContext = context;
        this.mComponent = component;
        FrameLayout frameLayout = new FrameLayout(context);
        this.subViewContainer = frameLayout;
        addView(frameLayout, new FrameLayout.LayoutParams(-1, -1));
        createVideoView();
        this.subViewContainer.bringToFront();
        this.mPlayerView.setChangeListener(new IOnPlayerViewChangeListener() {
            /* class io.dcloud.feature.weex_media.VideoPlayerView.AnonymousClass1 */

            @Override // io.dcloud.feature.weex_media.VideoPlayerView.IOnPlayerViewChangeListener
            public void onChanged(boolean isFullScreen) {
                VideoPlayerView.this.mIsFullScreen = isFullScreen;
            }
        });
        if (component.getInstance().isFrameViewShow()) {
            this.mPlayerView.setVideoVisibility();
        } else {
            component.getInstance().addFrameViewEventListener(new WXSDKInstance.FrameViewEventListener() {
                /* class io.dcloud.feature.weex_media.VideoPlayerView.AnonymousClass2 */

                @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
                public void onShowAnimationEnd() {
                    if (VideoPlayerView.this.mPlayerView != null) {
                        VideoPlayerView.this.mPlayerView.setVideoVisibility();
                    }
                    if (VideoPlayerView.this.mComponent != null && VideoPlayerView.this.mComponent.getInstance() != null) {
                        VideoPlayerView.this.mComponent.getInstance().removeFrameViewEventListener(this);
                    }
                }
            });
        }
    }

    public void createVideoView() {
        if (!this.isCreate) {
            this.isCreate = true;
            IjkPlayerView ijkPlayerView = new IjkPlayerView(this.mContext, null, this);
            this.mPlayerView = ijkPlayerView;
            ijkPlayerView.setComponent(this.mComponent);
            addView(this.mPlayerView, new FrameLayout.LayoutParams(-1, -1));
            this.mPlayerView.init().setPlayerRootView(this);
            this.mPlayerView.setOnInfoListener(this);
            this.mPlayerView.setOnPlayerChangedListener(this);
            this.mPlayerView.setOnBufferingUpdateListener(this);
        }
    }

    public ViewGroup getPlayerView() {
        return this.subViewContainer;
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        if (PdrUtil.isEmpty(this.mComponent.getStyles().getBackgroundColor())) {
            setBackgroundColor(-16777216);
        }
    }

    public synchronized void onLayoutFinished(String willBeSetSrc) {
        Uri fileUri;
        if (this.mPlayerView != null) {
            if (!TextUtils.isEmpty(this.mSrc) || !TextUtils.isEmpty(willBeSetSrc)) {
                AssetsDataSourceProvider fd = null;
                if (!TextUtils.isEmpty(willBeSetSrc) && !PdrUtil.isNetPath(willBeSetSrc)) {
                    willBeSetSrc = this.mComponent.getInstance().rewriteUri(Uri.parse(willBeSetSrc), "video").getPath();
                    if (willBeSetSrc != null && !PdrUtil.isDeviceRootDir(willBeSetSrc)) {
                        try {
                            if (this.mComponent.getIApp() != null) {
                                if (!willBeSetSrc.startsWith("/")) {
                                    willBeSetSrc = "/" + willBeSetSrc;
                                }
                                willBeSetSrc = this.mComponent.getInstance().rewriteUri(Uri.parse(this.mComponent.getIApp().checkPrivateDirAndCopy2Temp(willBeSetSrc)), "video").getPath();
                            } else {
                                if (willBeSetSrc.startsWith("/")) {
                                    willBeSetSrc = willBeSetSrc.replaceFirst("/", "");
                                }
                                fd = new AssetsDataSourceProvider(this.mComponent.getContext().getAssets().openFd(willBeSetSrc));
                            }
                        } catch (Exception e) {
                            e.printStackTrace();
                        }
                    }
                    if (!FileUtil.checkPrivatePath(getContext(), willBeSetSrc) && (fileUri = FileUtil.getVideoFileUri(getContext(), willBeSetSrc)) != null) {
                        willBeSetSrc = fileUri.toString();
                    }
                }
                if (TextUtils.isEmpty(this.mSrc)) {
                    if (fd == null) {
                        this.mPlayerView.setVideoPath(willBeSetSrc);
                    } else {
                        this.mPlayerView.setVideoFileDescriptor(fd);
                    }
                    this.mPlayerView.clearDanma();
                } else if (!this.mSrc.equalsIgnoreCase(willBeSetSrc)) {
                    if (fd == null) {
                        this.mPlayerView.switchVideoPath(willBeSetSrc);
                    } else {
                        this.mPlayerView.switchVideoFileDescriptor(fd);
                    }
                    this.mPlayerView.clearDanma();
                    this.mPlayerView.setMutePlayer(this.mPlayerView.isMutePlayer());
                }
                this.mSrc = willBeSetSrc;
                this.mPlayerView.setDuration((int) this.duration);
                if (this.initialTime > 0.0f) {
                    this.mPlayerView.seekTo((int) this.initialTime);
                }
                this.mPlayerView.enableDanmaku(this.isEnableDanmu);
                this.mPlayerView.enableDanmuBtn(this.isEnableDanmuBtn);
                this.isFinishLayout = true;
                if (this.autoplay) {
                    play();
                }
            }
        }
    }

    public void requestFullScreen(int oritation) {
        if (PdrUtil.isEmpty(Integer.valueOf(oritation))) {
            oritation = 90;
        }
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.fullScreen(oritation);
        }
    }

    public void exitFullScreen() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.exitFullScreen();
        }
    }

    public void play() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.start();
        }
    }

    public void pause() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.pause();
        }
    }

    public void resume() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.onResume();
        }
    }

    public void stop() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.stop();
        }
    }

    public void seek(int position) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            this.seek = position;
            ijkPlayerView.seekTo(position);
        }
    }

    public void sendDanmu(JSONObject danmu) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.sendDanmaku(new org.json.JSONObject(danmu), true);
        }
    }

    public void sendPlayBackRate(String rate) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.playbackRate(rate);
        }
    }

    public void destory() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.onDestroy();
            this.mPlayerView = null;
        }
    }

    public void setSrc(String mSrc2) {
        if (!TextUtils.isEmpty(mSrc2) && this.isFinishLayout) {
            onLayoutFinished(mSrc2);
        }
    }

    public void setHeader(String header) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setHeader(header);
            if (this.isFinishLayout) {
                onLayoutFinished("");
            }
        }
    }

    public void onActivityResume() {
        if (!TextUtils.isEmpty(this.poster)) {
            Glide.with(this).load(this.poster).into(this.mPlayerView.mPlayerThumb);
        }
    }

    public void setAutoplay(boolean autoplay2) {
        this.autoplay = autoplay2;
    }

    public void setLoop(boolean loop2) {
        this.loop = loop2;
    }

    public void setPoster(String poster2) {
        if (this.mPlayerView != null && !TextUtils.isEmpty(poster2) && !this.poster.equalsIgnoreCase(poster2)) {
            Glide.with(this).load(poster2).into(this.mPlayerView.mPlayerThumb);
            this.poster = poster2;
        }
    }

    public void setProgress(boolean isShow) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setProgressVisibility(isShow);
        }
    }

    public void setPlayBtnVisibility(boolean isshow) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setPlayBntVisibility(isshow);
        }
    }

    public void setMuted(boolean muted) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setMutePlayer(muted);
        }
    }

    public void setControls(boolean controls) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setControls(controls);
        }
    }

    public void setPageGesture(boolean pageGesture) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setPageGesture(pageGesture);
        }
    }

    public void setLockScreen(boolean lockScreen) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setIsShowScreenLockButton(lockScreen);
        }
    }

    public void setEnablePlayGesture(boolean enable) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setmIsDoubleTapEnable(enable);
        }
    }

    public void setFullScreenPageGesture(boolean pageGesture) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setFullScreenPageGesture(pageGesture);
        }
    }

    public void setShowFullScreenBtn(boolean showFullScreenBtn) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setFullscreenBntVisibility(showFullScreenBtn);
        }
    }

    public void setEnableProgressGesture(boolean enableProgressGesture) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setIsEnableProgressGesture(enableProgressGesture);
        }
    }

    public void setDirection(int direction) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setDirection(direction);
        }
    }

    public void setEnableDanmu(boolean enableDanmu) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            this.isEnableDanmu = enableDanmu;
            ijkPlayerView.enableDanmaku(enableDanmu);
        }
    }

    public void setDanmuBtn(boolean danmuBtn) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            this.isEnableDanmuBtn = danmuBtn;
            ijkPlayerView.enableDanmuBtn(danmuBtn);
        }
    }

    public void setDanmuList(JSONArray danmuList) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setmDanmuList(danmuList.toString());
        }
    }

    public void setObjectFit(String objectFit) {
        IjkPlayerView ijkPlayerView;
        if (!TextUtils.isEmpty(objectFit) && (ijkPlayerView = this.mPlayerView) != null) {
            ijkPlayerView.setScaleType(objectFit);
        }
    }

    public void setMuteBtn(boolean isshow) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.isMuteBtnShow(isshow);
        }
    }

    public void setTitle(String title) {
        IjkPlayerView ijkPlayerView;
        if (!PdrUtil.isEmpty(title) && (ijkPlayerView = this.mPlayerView) != null) {
            ijkPlayerView.setTitle(title);
        }
    }

    public void setHttpCacheEnable(boolean cacheEnable) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setHttpCacheEnable(cacheEnable);
        }
    }

    public void setFlowStrategy(EnumPlayStrategy intFlowStrategy) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setFlowStrategy(intFlowStrategy);
        }
    }

    public void setShowLoading(boolean isShow) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setLoadingVisibility(isShow);
        }
    }

    public void setPlayBtnPosition(String position) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setPlayBtnPosition(position);
        }
    }

    public void setShowCenterPlayBtn(boolean showCenterPlayBtn) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.setCenterPlayBtnVisibility(showCenterPlayBtn);
        }
    }

    public void setCodec(String codec) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.isUseMediaCodec(codec.equals("hardware"));
        }
    }

    public void setDuration(float duration2) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            float f = 1000.0f * duration2;
            this.duration = f;
            if (this.isFinishLayout) {
                ijkPlayerView.setDuration((int) f);
            }
        }
    }

    public void setInitialTime(float initialTime2) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null && initialTime2 > 0.0f) {
            float f = 1000.0f * initialTime2;
            this.initialTime = f;
            if (this.isFinishLayout) {
                ijkPlayerView.seekTo((int) f);
            }
        }
    }

    @Override // io.dcloud.media.weex.weex_video.ijkplayer.OnPlayerChangedListener
    public void onChanged(String type, String msg) {
        Map<String, Object> values = new HashMap<>();
        if (!TextUtils.isEmpty(msg)) {
            try {
                values.put("detail", JSON.parse(msg));
            } catch (Exception e) {
                values.put("detail", msg);
            }
        }
        execCallBack(type, values);
        if (this.mPlayerView == null || !(this.mComponent.getChild(0) instanceof ScalableViewComponent) || !type.equals("fullscreenchange")) {
            return;
        }
        if (isFullScreen()) {
            removeView(this.subViewContainer);
            this.mPlayerView.addView(this.subViewContainer);
            this.subViewContainer.bringToFront();
            return;
        }
        this.mPlayerView.removeView(this.subViewContainer);
        removeView(this.subViewContainer);
        addView(this.subViewContainer);
        this.subViewContainer.bringToFront();
    }

    public boolean isFullScreen() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        return ijkPlayerView != null && ijkPlayerView.isFullscreen();
    }

    public boolean onBackPress() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        return ijkPlayerView != null && ijkPlayerView.onBackPressed();
    }

    @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnInfoListener
    public boolean onInfo(IMediaPlayer iMediaPlayer, int status, int i1) {
        if (status != 331) {
            if (status != 332 && status != 701) {
                switch (status) {
                    case 334:
                        execCallBack(Constants.Value.PLAY, new HashMap<>());
                        break;
                    case 335:
                        execCallBack("pause", new HashMap<>());
                        break;
                    case 336:
                        if (this.loop) {
                            float f = this.initialTime;
                            if (f > 0.0f) {
                                this.mPlayerView.seekTo((int) f);
                            }
                            play();
                        }
                        execCallBack("ended", new HashMap<>());
                        break;
                    case 337:
                        Object[] objArr = new Object[1];
                        IjkPlayerView ijkPlayerView = this.mPlayerView;
                        objArr[0] = Integer.valueOf(ijkPlayerView != null ? ijkPlayerView.getCurPosition() : 0);
                        String detail = StringUtil.format("{'position':%d}", objArr);
                        HashMap seekResultMap = new HashMap();
                        seekResultMap.put("detail", detail);
                        execCallBack("seekcomplete", seekResultMap);
                        break;
                }
            } else {
                execCallBack(IApp.ConfigProperty.CONFIG_WAITING, new HashMap<>());
            }
        } else {
            execCallBack("error", new HashMap<>());
        }
        return false;
    }

    private void execCallBack(String type, Map<String, Object> values) {
        if (this.mComponent.getEvents().contains(type)) {
            this.mComponent.fireEvent(type, values);
        }
    }

    @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnBufferingUpdateListener
    public void onBufferingUpdate(IMediaPlayer iMediaPlayer, int i) {
        Map<String, Object> values = new HashMap<>();
        Map<String, Object> detail = new HashMap<>();
        detail.put("buffered", Integer.valueOf(i));
        values.put("detail", detail);
        execCallBack("progress", values);
    }

    public int getDirection() {
        VideoComponent videoComponent = this.mComponent;
        if (videoComponent == null || !videoComponent.getAttrs().containsKey("direction")) {
            return Integer.MIN_VALUE;
        }
        try {
            return Integer.parseInt(String.valueOf(this.mComponent.getAttrs().get("direction")));
        } catch (Exception e) {
            return Integer.MIN_VALUE;
        }
    }
}
