package io.dcloud.feature.weex_websocket;

import android.os.Looper;
import android.text.TextUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.igexin.push.f.r;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.websocket.IWebSocketAdapter;
import com.taobao.weex.appfram.websocket.WebSocketCloseCodes;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.utils.WXLogUtils;
import java.util.HashMap;
import java.util.Map;

public class UniWebSocketModule extends WXSDKEngine.DestroyableModule {
    private static final String KEY_CODE = "code";
    private static final String KEY_DATA = "data";
    private static final String KEY_ID = "id";
    private static final String KEY_REASON = "reason";
    private static final String KEY_WAS_CLEAN = "wasClean";
    private static final String TAG = "WebSocketModule";
    private JSCallback callback_onclose;
    private JSCallback callback_onerror;
    private JSCallback callback_onmessage;
    private JSCallback callback_onopen;
    private String currentId;
    private Map<String, IWebSocketAdapter> webSocketAdapterMap;
    private Map<String, WebSocketEventListener> webSocketEventListenerMap;

    public UniWebSocketModule() {
        WXLogUtils.e(TAG, "create new instance");
    }

    @JSMethod(uiThread = false)
    public void WebSocket(String param) {
        if (!TextUtils.isEmpty(param)) {
            try {
                JSONObject jsObj = JSON.parseObject(new String(param.getBytes(), r.b));
                String id = jsObj.getString("id");
                String url = jsObj.getString("url");
                String protocol = jsObj.getString("protocol");
                String headerJson = jsObj.getString("header");
                if (this.webSocketAdapterMap == null) {
                    this.webSocketAdapterMap = new HashMap();
                    this.webSocketEventListenerMap = new HashMap();
                }
                if (this.webSocketAdapterMap.get(id) == null || this.webSocketEventListenerMap.get(id) == null) {
                    if (this.webSocketAdapterMap.get(id) != null && this.webSocketEventListenerMap.get(id) == null) {
                        this.webSocketAdapterMap.remove(id);
                    }
                    IWebSocketAdapter webSocketAdapter = this.mWXSDKInstance.getWXWebSocketAdapter();
                    WebSocketEventListener eventListener = new WebSocketEventListener(id);
                    eventListener.onOpen = this.callback_onopen;
                    eventListener.onMessage = this.callback_onmessage;
                    eventListener.onClose = this.callback_onclose;
                    eventListener.onError = this.callback_onerror;
                    webSocketAdapter.connect(url, protocol, headerJson, eventListener);
                    this.webSocketEventListenerMap.put(id, eventListener);
                    this.currentId = id;
                    this.webSocketAdapterMap.put(id, webSocketAdapter);
                }
            } catch (Exception e) {
                WXLogUtils.e("[UniWebSocketModule] alert param parse error ", e);
            }
        }
    }

    @JSMethod(uiThread = false)
    public void send(String param) {
        if (!TextUtils.isEmpty(param)) {
            try {
                JSONObject jsObj = JSON.parseObject(new String(param.getBytes(), r.b));
                String id = jsObj.getString("id");
                this.webSocketAdapterMap.get(id).send(jsObj.getString("data"));
            } catch (Exception e) {
                WXLogUtils.e("[UniWebSocketModule] alert param parse error ", e);
            }
        }
    }

    @JSMethod(uiThread = false)
    public void close(String param) {
        if (!TextUtils.isEmpty(param)) {
            try {
                JSONObject jsObj = JSON.parseObject(new String(param.getBytes(), r.b));
                String id = jsObj.getString("id");
                String code = jsObj.getString("code");
                String reason = jsObj.getString(KEY_REASON);
                int codeNumber = WebSocketCloseCodes.CLOSE_NORMAL.getCode();
                if (code != null) {
                    try {
                        codeNumber = Integer.parseInt(code);
                    } catch (NumberFormatException e) {
                    }
                }
                this.webSocketAdapterMap.get(id).close(codeNumber, reason);
            } catch (Exception e2) {
                WXLogUtils.e("[UniWebSocketModule] alert param parse error ", e2);
            }
        }
    }

    @JSMethod(uiThread = false)
    public void onopen(JSCallback callback) {
        this.callback_onopen = callback;
        Map<String, WebSocketEventListener> map = this.webSocketEventListenerMap;
        if (map != null) {
            for (Map.Entry<String, WebSocketEventListener> entry : map.entrySet()) {
                entry.getValue().onOpen = this.callback_onopen;
            }
        }
    }

    @JSMethod(uiThread = false)
    public void onmessage(JSCallback callback) {
        this.callback_onmessage = callback;
        Map<String, WebSocketEventListener> map = this.webSocketEventListenerMap;
        if (map != null) {
            for (Map.Entry<String, WebSocketEventListener> entry : map.entrySet()) {
                entry.getValue().onMessage = this.callback_onmessage;
            }
        }
    }

    @JSMethod(uiThread = false)
    public void onclose(JSCallback callback) {
        this.callback_onclose = callback;
        Map<String, WebSocketEventListener> map = this.webSocketEventListenerMap;
        if (map != null) {
            for (Map.Entry<String, WebSocketEventListener> entry : map.entrySet()) {
                entry.getValue().onClose = this.callback_onclose;
            }
        }
    }

    @JSMethod(uiThread = false)
    public void onerror(JSCallback callback) {
        this.callback_onerror = callback;
        Map<String, WebSocketEventListener> map = this.webSocketEventListenerMap;
        if (map != null) {
            for (Map.Entry<String, WebSocketEventListener> entry : map.entrySet()) {
                entry.getValue().onError = this.callback_onerror;
            }
        }
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        Runnable destroyTask = new Runnable() {
            /* class io.dcloud.feature.weex_websocket.UniWebSocketModule.AnonymousClass1 */

            public void run() {
                WXLogUtils.w(UniWebSocketModule.TAG, "close session with instance id " + UniWebSocketModule.this.mWXSDKInstance.getInstanceId());
                if (UniWebSocketModule.this.webSocketAdapterMap != null) {
                    for (Map.Entry<String, IWebSocketAdapter> entry : UniWebSocketModule.this.webSocketAdapterMap.entrySet()) {
                        entry.getValue().destroy();
                    }
                    UniWebSocketModule.this.webSocketAdapterMap.clear();
                    UniWebSocketModule.this.webSocketAdapterMap = null;
                }
                if (UniWebSocketModule.this.webSocketEventListenerMap != null) {
                    UniWebSocketModule.this.webSocketEventListenerMap.clear();
                }
                UniWebSocketModule.this.webSocketEventListenerMap = null;
            }
        };
        if (Looper.myLooper() == Looper.getMainLooper()) {
            WXBridgeManager.getInstance().post(destroyTask);
        } else {
            destroyTask.run();
        }
    }

    /* access modifiers changed from: private */
    public class WebSocketEventListener implements IWebSocketAdapter.EventListener {
        private String id;
        private JSCallback onClose;
        private JSCallback onError;
        private JSCallback onMessage;
        private JSCallback onOpen;

        public WebSocketEventListener(String id2) {
            this.id = id2;
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onOpen() {
            if (this.onOpen != null) {
                Map<String, Object> msg = new HashMap<>();
                msg.put("id", this.id);
                this.onOpen.invokeAndKeepAlive(msg);
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onMessage(String data) {
            if (this.onMessage != null) {
                Map<String, Object> msg = new HashMap<>(2);
                msg.put("id", this.id);
                try {
                    JSONObject object = JSON.parseObject(data);
                    if (!object.containsKey("@type") || !object.containsKey("base64")) {
                        msg.put("data", data);
                    } else {
                        msg.put("data", object);
                    }
                } catch (Exception e) {
                    msg.put("data", data);
                }
                this.onMessage.invokeAndKeepAlive(msg);
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onClose(int code, String reason, boolean wasClean) {
            if (this.onClose != null) {
                Map<String, Object> msg = new HashMap<>(4);
                msg.put("id", this.id);
                msg.put("code", Integer.valueOf(code));
                msg.put(UniWebSocketModule.KEY_REASON, reason);
                msg.put(UniWebSocketModule.KEY_WAS_CLEAN, Boolean.valueOf(wasClean));
                this.onClose.invokeAndKeepAlive(msg);
                if (UniWebSocketModule.this.webSocketEventListenerMap != null) {
                    UniWebSocketModule.this.webSocketEventListenerMap.remove(this.id);
                }
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onError(String msg) {
            if (this.onError != null) {
                Map<String, String> info = new HashMap<>(2);
                info.put("id", this.id);
                info.put("data", msg);
                this.onError.invokeAndKeepAlive(info);
                if (UniWebSocketModule.this.webSocketEventListenerMap != null) {
                    UniWebSocketModule.this.webSocketEventListenerMap.remove(this.id);
                }
            }
        }
    }
}
