package io.dcloud.feature.x5;

import android.app.Application;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;
import com.tencent.smtt.sdk.CookieManager;
import com.tencent.smtt.sdk.QbSdk;
import com.tencent.smtt.sdk.TbsListener;
import com.tencent.smtt.sdk.WebView;
import dc.squareup.cookie.CookieCenter;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.adapter.ui.webview.WebViewFactory;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.NetworkTypeUtil;

public class X5InitImpl {
    private static Boolean x5Loaded = null;

    public static void init(final Application pContext, Boolean allowDownloadWithoutWifi, ICallBack allowCallBack) {
        Logger.e("X5InitImpl", "x5 init");
        Runnable runnable = new Runnable() {
            /* class io.dcloud.feature.x5.X5InitImpl.AnonymousClass1 */

            public void run() {
                WebViewFactory.initOther(true, (long) BaseInfo.timeOut);
                if (AppRuntime.hasPrivacyForNotShown(pContext)) {
                    QbSdk.disableSensitiveApi();
                }
                QbSdk.PreInitCallback cb = new QbSdk.PreInitCallback() {
                    /* class io.dcloud.feature.x5.X5InitImpl.AnonymousClass1.AnonymousClass1 */

                    @Override // com.tencent.smtt.sdk.QbSdk.PreInitCallback
                    public void onViewInitFinished(boolean arg0) {
                        Logger.e("X5InitImpl", " onViewInitFinished is " + arg0 + "  TbsSdkVersion=" + QbSdk.getTbsSdkVersion());
                        WebViewFactory.setOtherState(arg0, X5WebViewFactory.getInstance());
                        X5InitImpl.resetX5Status(pContext);
                        if (arg0) {
                            X5InitImpl.cookieCenterSetting();
                        }
                    }

                    @Override // com.tencent.smtt.sdk.QbSdk.PreInitCallback
                    public void onCoreInitFinished() {
                    }
                };
                QbSdk.setTbsListener(new TbsListener() {
                    /* class io.dcloud.feature.x5.X5InitImpl.AnonymousClass1.AnonymousClass2 */

                    @Override // com.tencent.smtt.sdk.TbsListener
                    public void onDownloadFinish(int i) {
                        Log.d("X5InitImpl", "onDownloadFinish()" + i);
                        if (WebViewFactory.getWebViewInstallListener() != null) {
                            WebViewFactory.getWebViewInstallListener().onDownloadFinish(i);
                        }
                    }

                    @Override // com.tencent.smtt.sdk.TbsListener
                    public void onInstallFinish(int i) {
                        Log.d("X5InitImpl", "onInstallFinish()" + i);
                        if (WebViewFactory.getWebViewInstallListener() != null) {
                            WebViewFactory.getWebViewInstallListener().onInstallFinish(i);
                        }
                    }

                    @Override // com.tencent.smtt.sdk.TbsListener
                    public void onDownloadProgress(int i) {
                        Log.d("X5InitImpl", "onDownloadProgress()" + i);
                        WebViewFactory.removeDelayRunnable();
                        if (WebViewFactory.getWebViewInstallListener() != null) {
                            WebViewFactory.getWebViewInstallListener().onDownloadProgress(i);
                        }
                    }
                });
                QbSdk.initX5Environment(pContext.getApplicationContext(), cb);
            }
        };
        int i = 1;
        if (isExistX5(pContext)) {
            WebViewFactory.setOtherState(true, X5WebViewFactory.getInstance());
            cookieCenterSetting();
            runnable.run();
            Logger.d("X5InitImpl", "x5 existing");
            return;
        }
        Logger.d("X5InitImpl", "x5 nonentity");
        if (allowDownloadWithoutWifi.booleanValue()) {
            QbSdk.setDownloadWithoutWifi(true);
        }
        if (allowCallBack != null) {
            if (NetworkTypeUtil.getNetworkType(pContext) == 3 || allowDownloadWithoutWifi.booleanValue()) {
                i = 0;
            }
            allowCallBack.onCallBack(i, null);
        }
        runnable.run();
    }

    /* access modifiers changed from: private */
    public static void cookieCenterSetting() {
        CookieCenter.registerProvider(new CookieCenter.ICookieProvider() {
            /* class io.dcloud.feature.x5.X5InitImpl.AnonymousClass2 */

            @Override // dc.squareup.cookie.CookieCenter.ICookieProvider
            public String getCookieByUrl(String url) {
                return CookieManager.getInstance().getCookie(url);
            }

            @Override // dc.squareup.cookie.CookieCenter.ICookieProvider
            public boolean addCookie(String url, String headerValue) {
                try {
                    CookieManager cookieManager = CookieManager.getInstance();
                    if (TextUtils.isEmpty(url) || TextUtils.isEmpty(headerValue)) {
                        return false;
                    }
                    cookieManager.setCookie(url, headerValue);
                    cookieManager.flush();
                    return true;
                } catch (Exception e) {
                    return false;
                }
            }

            @Override // dc.squareup.cookie.CookieCenter.ICookieProvider
            public boolean removeAllCookie() {
                CookieManager cookieManager = CookieManager.getInstance();
                cookieManager.removeAllCookie();
                cookieManager.flush();
                return true;
            }

            @Override // dc.squareup.cookie.CookieCenter.ICookieProvider
            public boolean removeSessionCookie() {
                CookieManager cookieManager = CookieManager.getInstance();
                cookieManager.removeSessionCookie();
                cookieManager.flush();
                return true;
            }
        });
    }

    public static void preInit(Application application) {
        if (isExistX5(application)) {
            WebViewFactory.setOtherState(true, X5WebViewFactory.getInstance());
            cookieCenterSetting();
            Logger.d("X5InitImpl", "x5 pre init success");
        }
    }

    private static boolean isExistX5(Context context) {
        Boolean bool = x5Loaded;
        if (bool != null) {
            return bool.booleanValue();
        }
        WebView webView = new WebView(context);
        boolean exist = webView.getX5WebViewExtension() != null;
        x5Loaded = Boolean.valueOf(exist);
        webView.destroy();
        return exist;
    }

    /* access modifiers changed from: private */
    public static void resetX5Status(Context context) {
        x5Loaded = null;
        isExistX5(context);
    }
}
