package io.dcloud.js.geolocation.amap;

import android.content.Context;
import com.amap.api.location.AMapLocation;
import com.amap.api.location.AMapLocationClient;
import com.amap.api.location.AMapLocationClientOption;
import com.amap.api.location.AMapLocationListener;
import com.amap.api.services.district.DistrictSearchQuery;
import com.igexin.push.core.b;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IEventCallback;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.adapter.util.SP;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.NetTool;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.js.geolocation.GeoManagerBase;
import java.io.PrintStream;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONException;
import org.json.JSONObject;

public class AMapGeoManager extends GeoManagerBase {
    public static final String TAG = AMapGeoManager.class.getSimpleName();
    static AMapGeoManager mInstance;
    boolean hasAppkey = false;
    boolean isGeocode = true;
    boolean isStreamApp = false;
    AMapLocationClient mClient = null;
    HashMap<String, AMapLocationClient> mContinuousMap = new HashMap<>();
    AMapLocationClientOption mOption = null;
    HashMap<String, AMapLocationClient> mSingleTimeMap = new HashMap<>();

    public AMapGeoManager(Context pContext) {
        super(pContext);
        boolean shown = !AppRuntime.hasPrivacyForNotShown(pContext);
        this.hasAppkey = !PdrUtil.isEmpty(AndroidResources.getMetaValue("com.amap.api.v2.apikey"));
        PlatformUtil.invokeMethod("com.amap.api.location.AMapLocationClient", "updatePrivacyShow", null, new Class[]{Context.class, Boolean.TYPE, Boolean.TYPE}, new Object[]{pContext, true, Boolean.valueOf(shown)});
        PlatformUtil.invokeMethod("com.amap.api.location.AMapLocationClient", "updatePrivacyAgree", null, new Class[]{Context.class, Boolean.TYPE}, new Object[]{pContext, Boolean.valueOf(shown)});
    }

    public static AMapGeoManager getInstance(Context pContext) {
        Context pContext2 = pContext.getApplicationContext();
        AMapGeoManager aMapGeoManager = mInstance;
        if (aMapGeoManager != null) {
            return aMapGeoManager;
        }
        AMapGeoManager aMapGeoManager2 = new AMapGeoManager(pContext2);
        mInstance = aMapGeoManager2;
        return aMapGeoManager2;
    }

    @Override // io.dcloud.js.geolocation.GeoManagerBase
    public String execute(IWebview pWebViewImpl, String pActionName, String[] pJsArgs) {
        int timeout;
        int interval;
        try {
            String t = pJsArgs.length > 7 ? pJsArgs[6] : b.m;
            if (!b.m.equals(t)) {
                timeout = Integer.parseInt(t);
            } else {
                timeout = Integer.MAX_VALUE;
            }
            String intervals = pJsArgs.length > 8 ? pJsArgs[7] : "5000";
            if (!intervals.equals(b.m)) {
                int interval2 = Integer.parseInt(intervals);
                if (interval2 < 1000) {
                    interval = 1000;
                } else {
                    interval = interval2;
                }
            } else {
                interval = 5000;
            }
            if (pActionName.startsWith("getCurrentPosition")) {
                this.isGeocode = Boolean.parseBoolean(pJsArgs[5]);
                startLocating(pWebViewImpl, pJsArgs[0], null, Boolean.parseBoolean(pJsArgs[1]), timeout, -1, pActionName.endsWith("DLGEO"), false);
            } else if (pActionName.startsWith("watchPosition")) {
                this.isGeocode = Boolean.parseBoolean(pJsArgs[5]);
                boolean _enableHighAccuracy = Boolean.parseBoolean(pJsArgs[2]);
                pWebViewImpl.obtainFrameView().addFrameViewListener(new IEventCallback() {
                    /* class io.dcloud.js.geolocation.amap.AMapGeoManager.AnonymousClass1 */

                    @Override // io.dcloud.common.DHInterface.IEventCallback
                    public Object onCallBack(String pEventType, Object pArgs) {
                        if ((!PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_WINDOW_CLOSE) && !PdrUtil.isEquals(pEventType, AbsoluteConst.EVENTS_CLOSE)) || !(pArgs instanceof IWebview)) {
                            return null;
                        }
                        AMapGeoManager.this.stopContinuousLocating();
                        ((AdaFrameView) ((IWebview) pArgs).obtainFrameView()).removeFrameViewListener(this);
                        return null;
                    }
                });
                startLocating(pWebViewImpl, pJsArgs[0], pJsArgs[1], _enableHighAccuracy, timeout, interval, pActionName.endsWith("DLGEO"), true);
            } else if (pActionName.startsWith("clearWatch")) {
                this.keySet.remove(pJsArgs[0]);
                AMapLocationClient client = this.mContinuousMap.remove(pJsArgs[0]);
                if (client != null) {
                    client.setLocationListener(null);
                    client.stopLocation();
                }
            }
            return "";
        } catch (Exception e) {
            Logger.e(TAG, e.getMessage());
            return "";
        }
    }

    public void startLocating(final IWebview pWebViewImpl, final String pCallbackId, String key, boolean enableHighAccuracy, int timeOut, int intervals, final boolean isDLGeo, final boolean continuous) {
        if (this.hasAppkey) {
            try {
                this.mClient = new AMapLocationClient(pWebViewImpl.getContext());
                AMapLocationClientOption aMapLocationClientOption = new AMapLocationClientOption();
                this.mOption = aMapLocationClientOption;
                aMapLocationClientOption.setOnceLocationLatest(false);
                if (PdrUtil.isEmpty(key)) {
                    this.mOption.setOnceLocation(true);
                    try {
                        this.mSingleTimeMap.put(pCallbackId, this.mClient);
                    } catch (Exception e) {
                    }
                } else {
                    try {
                        this.mOption.setInterval((long) intervals);
                        this.keySet.add(key);
                        this.mContinuousMap.put(key, this.mClient);
                    } catch (Exception e2) {
                        return;
                    }
                }
                if (NetTool.isNetworkAvailable(this.mContext)) {
                    if (enableHighAccuracy) {
                        this.mOption.setLocationMode(AMapLocationClientOption.AMapLocationMode.Hight_Accuracy);
                        this.mOption.setOnceLocationLatest(true);
                    } else {
                        this.mOption.setLocationMode(AMapLocationClientOption.AMapLocationMode.Battery_Saving);
                        this.mOption.setOnceLocationLatest(false);
                    }
                    this.mOption.setLocationCacheEnable(false);
                    this.mOption.setHttpTimeOut((long) timeOut);
                } else {
                    this.mOption.setLocationMode(AMapLocationClientOption.AMapLocationMode.Device_Sensors);
                    this.mOption.setOnceLocationLatest(false);
                    if (Integer.MAX_VALUE == timeOut) {
                        this.mOption.setHttpTimeOut(com.alipay.sdk.m.u.b.a);
                    } else {
                        this.mOption.setHttpTimeOut((long) timeOut);
                    }
                }
                this.mClient.setLocationOption(this.mOption);
                this.mClient.setLocationListener(new AMapLocationListener() {
                    /* class io.dcloud.js.geolocation.amap.AMapGeoManager.AnonymousClass2 */

                    @Override // com.amap.api.location.AMapLocationListener
                    public void onLocationChanged(AMapLocation aMapLocation) {
                        if (aMapLocation.getAddress() != null) {
                            FeatureMessageDispatcher.dispatchMessage("record_address", aMapLocation.getAddress() != null ? aMapLocation.getAddress() : null);
                        }
                        AMapGeoManager.this.callBack2Front(aMapLocation, pWebViewImpl, pCallbackId, isDLGeo, continuous);
                    }
                });
                this.mClient.startLocation();
            } catch (Exception e3) {
            }
        } else {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, 16, DOMException.MSG_GEOLOCATION_HASNT_AMAP_KEY), JSUtil.ERROR, true, false);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void stopContinuousLocating() {
        for (Map.Entry<String, AMapLocationClient> entry : this.mContinuousMap.entrySet()) {
            PrintStream printStream = System.out;
            printStream.println("key= " + entry.getKey() + " and value= " + entry.getValue());
            if (!PdrUtil.isEmpty(entry.getValue())) {
                entry.getValue().stopLocation();
            }
        }
    }

    private JSONObject makeJSON(AMapLocation pLoc) {
        JSONObject json = new JSONObject();
        try {
            json.put(Constant.JSONKEY.LATITUDE, pLoc.getLatitude());
            json.put(Constant.JSONKEY.LONGITUDE, pLoc.getLongitude());
            json.put("altitude", pLoc.getAltitude());
            json.put("accuracy", (double) pLoc.getAccuracy());
            json.put("altitudeAccuracy", 0);
            json.put("heading", (double) pLoc.getBearing());
            json.put("velocity", (double) pLoc.getSpeed());
            json.put("coordsType", "gcj02");
            json.put("timestamp", pLoc.getTime());
            if (this.isGeocode) {
                JSONObject address = new JSONObject();
                json.put("address", address);
                address.put("country", pLoc.getCountry());
                address.put(DistrictSearchQuery.KEYWORDS_PROVINCE, pLoc.getProvince());
                address.put(DistrictSearchQuery.KEYWORDS_CITY, pLoc.getCity());
                address.put(DistrictSearchQuery.KEYWORDS_DISTRICT, pLoc.getDistrict());
                address.put("street", pLoc.getStreet());
                address.put("streetNum", pLoc.getStreetNum());
                address.put("poiName", pLoc.getPoiName());
                address.put("postalCode", (Object) null);
                address.put("cityCode", pLoc.getCityCode());
                json.put("addresses", pLoc.getAddress());
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
        saveGeoData(pLoc, "gcj02");
        return json;
    }

    @Override // io.dcloud.js.geolocation.GeoManagerBase
    public void onDestroy() {
        for (Map.Entry<String, AMapLocationClient> entry : this.mContinuousMap.entrySet()) {
            if (!PdrUtil.isEmpty(entry.getValue())) {
                entry.getValue().onDestroy();
            }
        }
        this.mContinuousMap.clear();
        for (Map.Entry<String, AMapLocationClient> entry2 : this.mSingleTimeMap.entrySet()) {
            if (!PdrUtil.isEmpty(entry2.getValue())) {
                entry2.getValue().onDestroy();
            }
        }
        this.mSingleTimeMap.clear();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void callBack2Front(AMapLocation location, IWebview pWebViewImpl, String callbackId, boolean isDLGeo, boolean continuous) {
        String _json;
        if (!continuous && !PdrUtil.isEmpty(this.mSingleTimeMap.get(callbackId))) {
            this.mSingleTimeMap.get(callbackId).stopLocation();
        }
        if (location == null || location.getErrorCode() != 0) {
            if (location == null) {
                _json = StringUtil.format(DOMException.JSON_ERROR_INFO, 17, DOMException.toString(17, "geolocation", DOMException.MSG_GEOLOCATION_PROVIDER_ERROR, (String) null));
            } else {
                _json = StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf(convertGeolocationErrorCode(location.getErrorCode())), DOMException.toString(location.getErrorCode(), "geolocation", location.getErrorInfo(), (String) null));
            }
            callback(pWebViewImpl, callbackId, _json, JSUtil.ERROR, true, continuous, isDLGeo);
            return;
        }
        callback(pWebViewImpl, callbackId, makeJSON(location).toString(), JSUtil.OK, true, continuous, isDLGeo);
    }

    private int convertGeolocationErrorCode(int sdkCode) {
        if (sdkCode != 2) {
            if (sdkCode == 4) {
                return 3;
            }
            switch (sdkCode) {
                case 12:
                    return 1;
                case 13:
                case 14:
                case 15:
                    break;
                default:
                    return 4;
            }
        }
        return 2;
    }

    private void saveGeoData(AMapLocation pLoc, String coordsType) {
        if (!this.isStreamApp) {
            JSONObject jsonObject = new JSONObject();
            JSONObject coordsJson = new JSONObject();
            try {
                coordsJson.put(Constant.JSONKEY.LATITUDE, pLoc.getLatitude());
                coordsJson.put(Constant.JSONKEY.LONGITUDE, pLoc.getLongitude());
                jsonObject.put("coords", coordsJson);
                jsonObject.put("coordsType", coordsType);
                if (this.isGeocode) {
                    jsonObject.put("addresses", pLoc.getAddress());
                }
                SP.setBundleData(SP.getOrCreateBundle(AbsoluteConst.START_STATISTICS_DATA), AbsoluteConst.GEO_DATA, jsonObject.toString());
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void callback(IWebview webview, String callId, String json, int code, boolean isJson, boolean keback, boolean isDLGeo) {
        if (isDLGeo) {
            JSUtil.execGEOCallback(webview, callId, json, code, isJson, keback);
        } else {
            Deprecated_JSUtil.execCallback(webview, callId, json, code, isJson, keback);
        }
    }
}
