package io.dcloud.js.map.amap;

import android.text.TextUtils;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IMgr;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.feature.weex_amap.adapter.Constant;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class JsMapManager {
    private static JsMapManager mJsMapManager;
    private AbsMgr mFeatureMgr;
    private HashMap<String, JsMapObject> mJsMapObjects = new HashMap<>();
    private HashMap<String, LinkedHashMap<String, JsMapView>> mJsMapViews = new HashMap<>();
    private HashMap<String, JsMapRoute> mMapRoutes = new HashMap<>();

    public void setFeatureMgr(AbsMgr pFeatureMgr) {
        this.mFeatureMgr = pFeatureMgr;
    }

    private JsMapManager() {
    }

    public static JsMapManager getJsMapManager() {
        if (mJsMapManager == null) {
            mJsMapManager = new JsMapManager();
        }
        return mJsMapManager;
    }

    public void dispose(String appid) {
        LinkedHashMap<String, JsMapView> maps = this.mJsMapViews.remove(appid);
        if (maps != null) {
            for (String key : maps.keySet()) {
                maps.get(key).dispose();
            }
            maps.clear();
        }
    }

    public JsMapView getJsMapViewById(String appid, String id) {
        if (!this.mJsMapViews.containsKey(appid)) {
            return null;
        }
        LinkedHashMap<String, JsMapView> maps = this.mJsMapViews.get(appid);
        for (String key : maps.keySet()) {
            String itmeId = maps.get(key).mJsId;
            if (!TextUtils.isEmpty(itmeId) && id.equals(itmeId)) {
                return maps.get(key);
            }
        }
        return null;
    }

    public JsMapView getJsMapViewByUuid(String appid, String uuid) {
        if (!this.mJsMapViews.containsKey(appid)) {
            return null;
        }
        LinkedHashMap<String, JsMapView> maps = this.mJsMapViews.get(appid);
        if (maps.containsKey(uuid)) {
            return maps.get(uuid);
        }
        return null;
    }

    public void putJsMapView(String appid, String uuid, JsMapView mapView) {
        if (!this.mJsMapViews.containsKey(appid)) {
            this.mJsMapViews.put(appid, new LinkedHashMap<>());
        }
        if (!this.mJsMapViews.get(appid).containsKey(uuid)) {
            this.mJsMapViews.get(appid).put(uuid, mapView);
        }
    }

    public void removeJsMapView(String appid, String uuid) {
        if (this.mJsMapViews.containsKey(appid)) {
            LinkedHashMap<String, JsMapView> maps = this.mJsMapViews.get(appid);
            if (maps.containsKey(uuid)) {
                maps.remove(uuid);
            }
        }
    }

    public void putJsObject(String pId, JsMapObject pJsMapObjects) {
        this.mJsMapObjects.put(pId, pJsMapObjects);
    }

    public JsMapObject getJsObject(String pId) {
        return this.mJsMapObjects.get(pId);
    }

    public JsMapObject removeJsObject(String appid, String uuid) {
        JsMapObject jsObject = this.mJsMapObjects.remove(uuid);
        if (jsObject instanceof JsMapView) {
            removeJsMapView(appid, uuid);
        }
        return jsObject;
    }

    public JsMapPoint getMapPoint(IWebview pWebview, JSONObject _json) {
        if (_json == null) {
            return null;
        }
        try {
            return new JsMapPoint(pWebview, _json.getString(Constant.JSONKEY.LATITUDE), _json.getString(Constant.JSONKEY.LONGITUDE));
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }
    }

    public ArrayList<JsMapPoint> getJsToPointArry(IWebview pWebview, String pJson) {
        ArrayList<JsMapPoint> arry = new ArrayList<>();
        if (pJson != null) {
            try {
                JSONArray _jsonA = new JSONArray(pJson);
                for (int i = 0; i < _jsonA.length(); i++) {
                    _jsonA.get(i);
                    arry.add(getMapPoint(pWebview, JSONUtil.getJSONObject(_jsonA, i)));
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return arry;
    }

    public static ArrayList<String> getStrToStrArry(String pJson) {
        String _p;
        ArrayList<String> arry = new ArrayList<>();
        if (pJson != null) {
            try {
                JSONArray _jsonA = new JSONArray(pJson);
                for (int i = 0; i < _jsonA.length(); i++) {
                    if (_jsonA.get(i) instanceof String) {
                        _p = (String) _jsonA.get(i);
                    } else {
                        _p = _jsonA.get(i).toString();
                    }
                    arry.add(_p);
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        return arry;
    }

    public static int hexString2Int(String pString) {
        if (pString == null) {
            return 0;
        }
        String pString2 = pString.trim();
        if (pString2.startsWith("#")) {
            pString2 = pString2.substring(1);
        }
        if (pString2.length() == 8) {
            pString2 = pString2.substring(2);
        }
        try {
            return Integer.valueOf(pString2, 16).intValue();
        } catch (NumberFormatException e) {
            return 0;
        }
    }

    public IWebview findWebviewByUuid(IWebview webview, String uuid) {
        Object object;
        AbsMgr absMgr = this.mFeatureMgr;
        if (absMgr == null || (object = absMgr.processEvent(IMgr.MgrType.FeatureMgr, 10, new Object[]{webview, AbsoluteConst.F_UI, "findWebview", new String[]{webview.obtainApp().obtainAppId(), uuid}})) == null) {
            return null;
        }
        return (IWebview) object;
    }
}
