package io.dcloud.js.map.amap.adapter;

import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.view.ViewGroup;
import android.widget.LinearLayout;
import com.amap.api.maps.model.LatLng;
import com.tencent.connect.common.Constants;
import com.umeng.analytics.pro.d;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.ITypeofAble;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.ui.AdaFrameView;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.ViewRect;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.weex_amap.adapter.Constant;
import io.dcloud.js.map.amap.IFMapDispose;
import io.dcloud.js.map.amap.JsMapManager;
import io.dcloud.js.map.amap.JsMapObject;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DHMapFrameItem extends AdaFrameItem implements IFMapDispose, ISysEventListener, ITypeofAble {
    public static final int MSG_ADD_OVERLAY = 3;
    public static final int MSG_APPEND = 12;
    public static final int MSG_CENTER_ZOOM = 11;
    public static final int MSG_CLEAR_OVERLAY = 5;
    public static final int MSG_CREATE = 0;
    public static final int MSG_REMOVE_OVERLAY = 4;
    public static final int MSG_RESET = 6;
    public static final int MSG_SCALE = 1;
    public static final int MSG_SET_MAPTYPE = 8;
    public static final int MSG_SHOWLOCATION = 7;
    public static final int MSG_SHOWZOOMCONTROLS = 10;
    public static final int MSG_UPDATE_CENTER = 2;
    public static final int MSG_VISIBLE = 9;
    private String PERCENTAGE = "%";
    private MapPoint mCenter;
    private IWebview mContainerWebview;
    JsMapObject mJsMapView = null;
    private MapHandler mMapHandler;
    private DHMapView mMapView;
    private JSONArray mOptions;
    private ArrayList<Object> mOverlaysId;
    private String mPosition = "static";
    private LinearLayout mRootView;
    private boolean mShowUserLocation;
    private boolean mShowZoomControls;
    private boolean mTraffic;
    public String mUUID;
    private IWebview mWebview;
    private int mZoom = 12;
    private String mapType;

    public DHMapFrameItem(Context pContext, IWebview pWebview, JsMapObject jsMapObject) {
        super(pContext);
        this.mWebview = pWebview;
        this.mContainerWebview = pWebview;
        this.mJsMapView = jsMapObject;
        LinearLayout linearLayout = new LinearLayout(pContext);
        this.mRootView = linearLayout;
        setMainView(linearLayout);
        this.mMapHandler = new MapHandler(Looper.getMainLooper());
        this.mOverlaysId = new ArrayList<>();
        IApp app = this.mWebview.obtainFrameView().obtainApp();
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onPause);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onResume);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onStop);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onSaveInstanceState);
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        if (PdrUtil.isEmpty(this.mMapView)) {
            return false;
        }
        if (pEventType == ISysEventListener.SysEventType.onPause) {
            this.mMapView.onPause();
            this.mMapView.locationStop();
            return true;
        } else if (pEventType == ISysEventListener.SysEventType.onResume) {
            this.mMapView.onResume();
            this.mMapView.locationReStart();
            return true;
        } else if (pEventType == ISysEventListener.SysEventType.onStop) {
            this.mMapView.onDestroy();
            return true;
        } else if (pEventType != ISysEventListener.SysEventType.onSaveInstanceState) {
            return false;
        } else {
            if (pArgs instanceof Bundle) {
                this.mMapView.onSaveInstanceState((Bundle) pArgs);
            }
            return true;
        }
    }

    private void setMapView(DHMapView pMapView) {
        this.mMapView = pMapView;
        this.mRootView.addView(pMapView);
        this.mJsMapView.onAddToMapView(this.mMapView);
        this.mMapView.onCreate(null);
    }

    public DHMapView getMapView() {
        return this.mMapView;
    }

    public void setCenter(MapPoint pCenter) {
        if (pCenter != null) {
            this.mCenter = pCenter;
            Message m = Message.obtain();
            m.what = 2;
            m.obj = this.mCenter;
            this.mMapHandler.sendMessage(m);
        }
    }

    public void setZoom(String pZoom) {
        try {
            int _zoom = Integer.parseInt(pZoom == null ? Constants.VIA_REPORT_TYPE_SET_AVATAR : pZoom);
            this.mZoom = _zoom;
            Message m = Message.obtain();
            m.what = 1;
            m.obj = Integer.valueOf(_zoom);
            this.mMapHandler.sendMessage(m);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void centerAndZoom(MapPoint pCenter, String pZoom) {
        try {
            int _zoom = Integer.parseInt(pZoom == null ? Constants.VIA_REPORT_TYPE_SET_AVATAR : pZoom);
            if (pCenter != null) {
                this.mCenter = pCenter;
            }
            this.mZoom = _zoom;
            Message m = Message.obtain();
            m.what = 11;
            m.obj = new Object[]{Integer.valueOf(this.mZoom), this.mCenter};
            this.mMapHandler.sendMessage(m);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setMapType(String pMapType) {
        this.mapType = pMapType;
        Message m = Message.obtain();
        m.what = 8;
        if ("MAPTYPE_SATELLITE".equals(pMapType)) {
            m.obj = 1;
        } else {
            m.obj = 0;
        }
        this.mMapHandler.sendMessage(m);
    }

    public boolean isShowUserLocation() {
        return this.mShowUserLocation;
    }

    public void setShowUserLocation(String pShowUserLocation) {
        this.mShowUserLocation = Boolean.parseBoolean(pShowUserLocation);
        Message m = Message.obtain();
        m.what = 7;
        m.obj = Boolean.valueOf(this.mShowUserLocation);
        this.mMapHandler.sendMessage(m);
    }

    public void getUserLocation(IWebview webview, String callBackId) {
        this.mMapView.getUserLocation(webview, callBackId);
    }

    public void getCurrentCenter(IWebview webview, String callBackId) {
        this.mMapView.getCurrentCenter(webview, callBackId);
    }

    public boolean isShowZoomControls() {
        return this.mShowZoomControls;
    }

    public void setShowZoomControls(String pShowZoomControls) {
        this.mShowZoomControls = Boolean.parseBoolean(pShowZoomControls);
        Message m = Message.obtain();
        m.what = 10;
        m.obj = Boolean.valueOf(this.mShowZoomControls);
        this.mMapHandler.sendMessage(m);
    }

    public boolean isTraffic() {
        return this.mTraffic;
    }

    public void setTraffic(boolean traffic) {
        this.mTraffic = traffic;
        int _type = 1002;
        if (traffic) {
            _type = 1001;
        }
        Message m = Message.obtain();
        m.what = 8;
        m.obj = Integer.valueOf(_type);
        this.mMapHandler.sendMessage(m);
    }

    public void addOverlay(Object pMapOverlay) {
        if (pMapOverlay != null) {
            this.mOverlaysId.add(pMapOverlay);
            Message m = Message.obtain();
            m.what = 3;
            m.obj = pMapOverlay;
            this.mMapHandler.sendMessage(m);
        }
    }

    public void removeOverlay(Object pMapOverlay) {
        if (pMapOverlay != null) {
            this.mOverlaysId.remove(pMapOverlay);
            Message m = Message.obtain();
            m.what = 4;
            m.obj = pMapOverlay;
            this.mMapHandler.sendMessage(m);
        }
    }

    public void clearOverlays() {
        Message m = Message.obtain();
        m.what = 5;
        this.mMapHandler.sendMessage(m);
    }

    public void reset() {
        if (this.mCenter != null) {
            Message m = Message.obtain();
            m.what = 6;
            m.obj = new Object[]{Integer.valueOf(this.mZoom), this.mCenter};
            this.mMapHandler.sendMessage(m);
        }
    }

    public void show() {
        Message m = Message.obtain();
        m.what = 9;
        m.obj = true;
        this.mMapHandler.sendMessage(m);
    }

    public void hide() {
        Message m = Message.obtain();
        m.what = 9;
        m.obj = false;
        this.mMapHandler.sendMessage(m);
    }

    public void createMap(JSONArray array) {
        this.mOptions = array;
        createMapFrameItem(array);
    }

    public void resize(JSONArray pJsArgs) {
        ViewRect webParentViewRect = ((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions();
        JSONObject option = this.mOptions.optJSONObject(0);
        if (this.mOptions.length() > 4) {
            try {
                this.mOptions.put(1, pJsArgs.optInt(0));
                this.mOptions.put(2, pJsArgs.optInt(1));
                this.mOptions.put(3, pJsArgs.optInt(2));
                this.mOptions.put(4, pJsArgs.optInt(3));
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        obtainMainView().setLayoutParams(getMapLayoutParams(webParentViewRect, option, this.mOptions));
    }

    public void appendToFrameView(AdaFrameView frameView) {
        if (!(getMapView() == null || getMapView().getParent() == null)) {
            removeMapFrameItem(this.mContainerWebview);
        }
        this.mContainerWebview = frameView.obtainWebView();
        addToFrameItem(this.mOptions);
    }

    public void removeMapFrameItem(IWebview pFrame) {
        if (this.mPosition.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
            pFrame.obtainFrameView().removeFrameItem(this);
        } else {
            pFrame.removeFrameItem(this);
        }
    }

    public void setStyles(JSONObject styles) {
        JSONUtil.combinJSONObject(JSONUtil.getJSONObject(this.mOptions, 0), styles);
        if (this.mMapView != null) {
            if (styles.has("center")) {
                this.mMapView.setCenter(new MapPoint(styles.optJSONObject("center").optString(Constant.JSONKEY.LATITUDE), styles.optJSONObject("center").optString(Constant.JSONKEY.LONGITUDE)));
            }
            if (styles.has("zoom")) {
                this.mMapView.setZoom(styles.optInt("zoom"));
            }
            if (styles.has("type")) {
                int type = 0;
                if (styles.optString("type").equals("MAPTYPE_SATELLITE")) {
                    type = 1;
                }
                this.mMapView.setMapType(type);
            }
            if (styles.has(d.F)) {
                setTraffic(styles.optBoolean(d.F));
            }
            if (styles.has("zoomControls")) {
                this.mMapView.showZoomControls(styles.optBoolean("zoomControls"));
            }
            if (styles.has("top") || styles.has("left") || styles.has("width") || styles.has("height") || styles.has("position")) {
                ViewGroup.LayoutParams _lp = getMapLayoutParams(((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions(), JSONUtil.getJSONObject(this.mOptions, 0), this.mOptions);
                if (styles.has("position")) {
                    String position = styles.optString("position", this.mPosition);
                    if (!position.equals(this.mPosition)) {
                        if (this.mPosition.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
                            this.mContainerWebview.obtainFrameView().removeFrameItem(this);
                            this.mContainerWebview.addFrameItem(this, _lp);
                        } else {
                            this.mContainerWebview.removeFrameItem(this);
                            this.mContainerWebview.obtainFrameView().addFrameItem(this, _lp);
                        }
                        this.mPosition = position;
                        return;
                    }
                    obtainMainView().setLayoutParams(_lp);
                    return;
                }
                obtainMainView().setLayoutParams(_lp);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public class MapHandler extends Handler {
        public MapHandler(Looper looper) {
            super(looper);
        }

        public void handleMessage(Message m) {
            switch (m.what) {
                case 0:
                    DHMapFrameItem.this.createMapFrameItem((JSONArray) m.obj);
                    break;
                case 1:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setZoom(((Integer) m.obj).intValue());
                        break;
                    }
                    break;
                case 2:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setCenter((MapPoint) m.obj);
                        break;
                    }
                    break;
                case 3:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.addOverlay(m.obj);
                        break;
                    }
                    break;
                case 4:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.removeOverlay(m.obj);
                        break;
                    }
                    break;
                case 5:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.clearOverlays();
                        break;
                    }
                    break;
                case 6:
                case 11:
                    if (DHMapFrameItem.this.mMapView != null) {
                        Object[] czobjs = (Object[]) m.obj;
                        DHMapFrameItem.this.mMapView.setCenterAndZoom((MapPoint) czobjs[1], ((Integer) czobjs[0]).intValue());
                        break;
                    }
                    break;
                case 7:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.showUserLocation(((Boolean) m.obj).booleanValue());
                        break;
                    }
                    break;
                case 8:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setMapType(((Integer) m.obj).intValue());
                        break;
                    }
                    break;
                case 9:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.setVisible(((Boolean) m.obj).booleanValue());
                        break;
                    }
                    break;
                case 10:
                    if (DHMapFrameItem.this.mMapView != null) {
                        DHMapFrameItem.this.mMapView.showZoomControls(((Boolean) m.obj).booleanValue());
                        break;
                    }
                    break;
                case 12:
                    DHMapFrameItem.this.addToFrameItem(m.obj);
                    break;
            }
            if (DHMapFrameItem.this.mMapView != null) {
                DHMapFrameItem.this.mMapView.refreshDrawableState();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void createMapFrameItem(JSONArray jsonArray) {
        int type;
        JSONObject option = jsonArray.optJSONObject(0);
        LatLng center = null;
        if (option.optJSONObject("center") != null) {
            center = new LatLng(option.optJSONObject("center").optDouble(Constant.JSONKEY.LATITUDE), option.optJSONObject("center").optDouble(Constant.JSONKEY.LONGITUDE));
        }
        this.mPosition = option.optString("position", this.mPosition);
        int zoom = option.optInt("zoom");
        boolean isTraffic = option.optBoolean(d.F);
        boolean isZoomControls = option.optBoolean("zoomControls");
        if (option.optString("type").equals("MAPTYPE_SATELLITE")) {
            type = 2;
        } else {
            type = 1;
        }
        DHMapView _mapView = new DHMapView(getActivity(), this.mWebview, center, zoom, type, isTraffic, isZoomControls, this.mRootView);
        _mapView.mUUID = this.mUUID;
        setMapView(_mapView);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void addToFrameItem(Object obj) {
        JSONArray jsonArray = (JSONArray) obj;
        JSONObject option = jsonArray.optJSONObject(0);
        AdaFrameItem frameView = (AdaFrameItem) this.mContainerWebview.obtainFrameView();
        ViewGroup.LayoutParams _lp = getMapLayoutParams(frameView.obtainFrameOptions(), option, jsonArray);
        this.mContainerWebview.obtainFrameView().setNeedRender(true);
        if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.mPosition)) {
            if (frameView instanceof AdaFrameView) {
                int index = -1;
                if (((ViewGroup) frameView.obtainMainView()).getChildCount() > 0) {
                    index = 1;
                }
                ((AdaFrameView) frameView).addFrameItem(this, index, _lp);
            } else {
                this.mContainerWebview.obtainFrameView().addFrameItem(this, _lp);
            }
            Logger.d(Logger.MAP_TAG, "addMapView webview_name=" + this.mWebview.obtainFrameId());
            return;
        }
        if (DeviceInfo.sDeviceSdkVer >= 11) {
            this.mContainerWebview.obtainWindowView().setLayerType(0, null);
        }
        this.mContainerWebview.addFrameItem(this, _lp);
    }

    private ViewGroup.LayoutParams getMapLayoutParams(ViewRect rect, JSONObject option, JSONArray jsonArray) {
        float scale = this.mContainerWebview.getScale();
        if (jsonArray == null || jsonArray.length() <= 4) {
            return AdaFrameItem.LayoutParamsUtil.createLayoutParams(PdrUtil.convertToScreenInt(JSONUtil.getString(option, "left"), rect.width, 0, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(option, "top"), rect.height, 0, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(option, "width"), rect.width, rect.width, scale, true), PdrUtil.convertToScreenInt(JSONUtil.getString(option, "height"), rect.height, rect.height, scale, true));
        }
        int _l = (int) (((float) jsonArray.optInt(1)) * scale);
        int _t = (int) (((float) jsonArray.optInt(2)) * scale);
        int _w = Math.min((int) (((float) jsonArray.optInt(3)) * scale), rect.width);
        int _h = Math.min((int) (((float) jsonArray.optInt(4)) * scale), rect.height);
        updateViewRect((AdaFrameItem) this.mWebview.obtainFrameView(), new int[]{_l, _t, _w, _h}, new int[]{rect.width, rect.height});
        Logger.d("mapview", "_l=" + _l + ";_t=" + _t + ";_w=" + _w + ";_h=" + _h);
        return AdaFrameItem.LayoutParamsUtil.createLayoutParams(_l, _t, _w, _h);
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onPopFromStack(boolean autoPop) {
        super.onPopFromStack(autoPop);
        if (autoPop) {
            this.mMapView.mAutoPopFromStack = true;
        }
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onPushToStack(boolean autoPush) {
        super.onPushToStack(autoPush);
        if (autoPush) {
            this.mMapView.mAutoPopFromStack = false;
            this.mMapView.onResume();
        }
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem, io.dcloud.js.map.amap.IFMapDispose
    public void dispose() {
        if (!PdrUtil.isEmpty(this.mMapView)) {
            this.mMapView.dispose();
            this.mRootView.setVisibility(8);
            this.mMapView.onDestroy();
            JsMapManager.getJsMapManager().removeJsMapView(this.mContainerWebview.obtainApp().obtainAppId(), this.mUUID);
            if (this.mPosition.equals("static")) {
                this.mContainerWebview.removeFrameItem(this);
            } else {
                this.mContainerWebview.obtainFrameView().removeFrameItem(this);
            }
            this.mMapView.mAutoPopFromStack = false;
            this.mMapView = null;
            this.mContainerWebview = null;
        }
    }

    @Override // io.dcloud.js.map.amap.IFMapDispose
    public void close() {
        if (!PdrUtil.isEmpty(this.mMapView)) {
            this.mMapView.dispose();
            this.mRootView.setVisibility(8);
            this.mRootView.post(new Runnable() {
                /* class io.dcloud.js.map.amap.adapter.DHMapFrameItem.AnonymousClass1 */

                public void run() {
                    DHMapFrameItem.this.mMapView.onDestroy();
                    JsMapManager.getJsMapManager().removeJsMapView(DHMapFrameItem.this.mContainerWebview.obtainApp().obtainAppId(), DHMapFrameItem.this.mUUID);
                    if (DHMapFrameItem.this.mPosition.equals("static")) {
                        DHMapFrameItem.this.mContainerWebview.removeFrameItem(DHMapFrameItem.this);
                    } else {
                        DHMapFrameItem.this.mContainerWebview.obtainFrameView().removeFrameItem(DHMapFrameItem.this);
                    }
                    DHMapFrameItem.this.mMapView.mAutoPopFromStack = false;
                    DHMapFrameItem.this.mMapView = null;
                    DHMapFrameItem.this.mContainerWebview = null;
                }
            });
        }
    }

    public String getBounds() {
        return this.mMapView.getBounds();
    }

    public JSONObject getMapOptions() {
        JSONArray jSONArray = this.mOptions;
        if (jSONArray == null) {
            return null;
        }
        JSONObject data = jSONArray.optJSONObject(0);
        try {
            data.put("zoom", this.mZoom);
            JSONObject centerJson = new JSONObject();
            if (this.mCenter != null) {
                centerJson.put(Constant.JSONKEY.LONGITUDE, this.mCenter.getLongitude());
                centerJson.put(Constant.JSONKEY.LATITUDE, this.mCenter.getLatitude());
                data.put("center", centerJson);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return data;
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onResize() {
        super.onResize();
        if (this.mOptions != null && getMapView().getParent() != null) {
            JSONObject option = this.mOptions.optJSONObject(0);
            if (option == null || option.has("width") || option.has("height") || option.has("top") || option.has("left")) {
                String width = JSONUtil.getString(option, "width");
                String height = JSONUtil.getString(option, "height");
                String top = JSONUtil.getString(option, "top");
                String left = JSONUtil.getString(option, "left");
                boolean isResize = false;
                if (!PdrUtil.isEmpty(width) && width.endsWith(this.PERCENTAGE)) {
                    isResize = true;
                }
                if (!PdrUtil.isEmpty(height) && height.endsWith(this.PERCENTAGE)) {
                    isResize = true;
                }
                if (!PdrUtil.isEmpty(top) && top.endsWith(this.PERCENTAGE)) {
                    isResize = true;
                }
                if (!PdrUtil.isEmpty(left) && left.endsWith(this.PERCENTAGE)) {
                    isResize = true;
                }
                if (isResize) {
                    obtainMainView().setLayoutParams(getMapLayoutParams(((AdaFrameItem) this.mContainerWebview.obtainFrameView()).obtainFrameOptions(), option, this.mOptions));
                }
            }
        }
    }
}
