package io.dcloud.js.map.amap.adapter;

import com.amap.api.maps.model.Circle;
import com.amap.api.maps.model.CircleOptions;

public class MapCircleProxy {
    private MapPoint mCenter;
    private int mFillColor = -16777216;
    private double mFillOpacity;
    private String mJsId;
    private double mLineWidth = 5.0d;
    Circle mMapCircle = null;
    private double mRadius;
    private int mStrokeColor = -16777216;
    private double mStrokeOpacity = 1.0d;

    public MapCircleProxy(MapPoint pCen, double pRad) {
        this.mCenter = pCen;
        this.mRadius = pRad;
    }

    public double getRadius() {
        return this.mRadius;
    }

    public void setRadius(double pRadius) {
        this.mRadius = pRadius;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setRadius(pRadius);
        }
    }

    public int getStrokeColor() {
        return this.mStrokeColor;
    }

    public void setStrokeColor(int pStrokeColor) {
        int i = -16777216 | pStrokeColor;
        this.mStrokeColor = i;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeColor(combineOpacity(i, this.mStrokeOpacity));
        }
    }

    public MapPoint getCenter() {
        return this.mCenter;
    }

    public void setCenter(MapPoint pCenter) {
        this.mCenter = pCenter;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setCenter(pCenter.getLatLng());
        }
    }

    public double getStrokeOpacity() {
        return this.mStrokeOpacity;
    }

    public void setStrokeOpacity(double pStrokeOpacity) {
        this.mStrokeOpacity = pStrokeOpacity;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeColor(combineOpacity(this.mStrokeColor, pStrokeOpacity));
        }
    }

    public int getFillColor() {
        return this.mFillColor;
    }

    public void setFillColor(int pFillColor) {
        this.mFillColor = pFillColor;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setFillColor(combineOpacity(pFillColor, this.mFillOpacity));
        }
    }

    public double getFillOpacity() {
        return this.mFillOpacity;
    }

    public void setFillOpacity(double pFillOpacity) {
        this.mFillOpacity = pFillOpacity;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setFillColor(combineOpacity(this.mFillColor, pFillOpacity));
        }
    }

    private int combineOpacity(int color, double opacity) {
        return (((int) (255.0d * opacity)) << 24) + color;
    }

    public double getLineWidth() {
        return this.mLineWidth;
    }

    public void setLineWidth(double pLineWidth) {
        this.mLineWidth = pLineWidth;
        Circle circle = this.mMapCircle;
        if (circle != null) {
            circle.setStrokeWidth((float) ((int) pLineWidth));
        }
    }

    public void initMapCircle(DHMapView mapview) {
        this.mMapCircle = mapview.getMap().addCircle(getCircleOptions());
    }

    private CircleOptions getCircleOptions() {
        return new CircleOptions().center(this.mCenter.getLatLng()).radius(this.mRadius).strokeColor(combineOpacity(this.mStrokeColor, this.mStrokeOpacity)).fillColor(combineOpacity(this.mFillColor, this.mFillOpacity)).strokeWidth((float) ((int) this.mLineWidth));
    }

    public Circle getCircle() {
        return this.mMapCircle;
    }
}
