package io.dcloud.js.map.amap.adapter;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.Drawable;
import android.text.TextUtils;
import android.util.Base64;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.CanvasHelper;
import io.dcloud.common.adapter.util.PlatformUtil;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;

public class MapMarker {
    private boolean isDraggable = false;
    private boolean isPop = false;
    private boolean isToTop = false;
    private String mBubbleIcon;
    private String mBubbleLabel;
    private IWebview mIWebview;
    private String mIcon;
    ArrayList<BitmapDescriptor> mIcons;
    private String mLabel;
    private String mLoadImagePath;
    private String mLoadImageUrlData;
    private MapPoint mMapPoint;
    private Marker mMarker;
    private int mPeriod;
    private String uuid;

    public IWebview getWebview() {
        return this.mIWebview;
    }

    public Marker getMarker() {
        return this.mMarker;
    }

    public MapMarker(MapPoint pMapPoint, IWebview webview) {
        this.mMapPoint = pMapPoint;
        this.mIWebview = webview;
    }

    public void setPop(boolean isPop2) {
        this.isPop = isPop2;
    }

    public void initMapMarker(DHMapView mapView) {
        this.mMarker = mapView.getMap().addMarker(getMapMarkOptions());
        if (this.isToTop) {
            bringToTop();
        }
    }

    public String getIcon() {
        return this.mIcon;
    }

    public void setIcon(String pIcon) {
        this.mIcon = pIcon;
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon(pIcon));
        }
    }

    public String getLabel() {
        return this.mLabel;
    }

    public void setLabel(String pLabel) {
        this.mLabel = pLabel;
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setIcon(getIcon(this.mIcon));
        }
    }

    public MapPoint getMapPoint() {
        return this.mMapPoint;
    }

    public void setMapPoint(MapPoint pMapPoint) {
        this.mMapPoint = pMapPoint;
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setPosition(pMapPoint.getLatLng());
        }
    }

    public void setBubbleIcon(String pBubbleIcon) {
        this.mBubbleIcon = pBubbleIcon;
    }

    public String getUuid() {
        return this.uuid;
    }

    public void setUuid(String uuid2) {
        this.uuid = uuid2;
    }

    public String getBubbleIcon() {
        return this.mBubbleIcon;
    }

    public void setBubbleLabel(String pBubbleLabel) {
        this.mBubbleLabel = pBubbleLabel;
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setSnippet(pBubbleLabel);
        }
    }

    public String getBubbleLabel() {
        return this.mBubbleLabel;
    }

    private MarkerOptions getMapMarkOptions() {
        MarkerOptions markerOptions = new MarkerOptions();
        MapPoint mapPoint = this.mMapPoint;
        if (mapPoint != null) {
            markerOptions.position(mapPoint.getLatLng());
        }
        String str = this.mBubbleLabel;
        if (str != null) {
            markerOptions.snippet(str);
        }
        if (!TextUtils.isEmpty(this.mLabel)) {
            markerOptions.title(this.mLabel);
        }
        ArrayList<BitmapDescriptor> arrayList = this.mIcons;
        if (arrayList != null) {
            markerOptions.icons(arrayList);
            int i = this.mPeriod;
            if (i > 0) {
                markerOptions.period(i);
            }
        } else {
            String str2 = this.mIcon;
            if (str2 != null) {
                markerOptions.icon(getIcon(str2));
            } else {
                markerOptions.icon(getDefaultMarkerIcon());
            }
        }
        boolean z = this.isDraggable;
        if (z) {
            markerOptions.draggable(z);
        }
        return markerOptions;
    }

    public BitmapDescriptor getIcon(String path) {
        if (TextUtils.isEmpty(path)) {
            return null;
        }
        String iconPath = this.mIWebview.obtainFrameView().obtainApp().convert2AbsFullPath(this.mIWebview.obtainFullUrl(), path);
        if (TextUtils.isEmpty(this.mLabel)) {
            return BitmapDescriptorFactory.fromBitmap(CanvasHelper.getBitmap(iconPath));
        }
        LinearLayout layout = new LinearLayout(this.mIWebview.getActivity());
        layout.setOrientation(1);
        layout.setGravity(16);
        ImageView imageView = new ImageView(this.mIWebview.getActivity());
        imageView.setImageBitmap(CanvasHelper.getBitmap(iconPath));
        TextView textView = new TextView(this.mIWebview.getActivity());
        textView.setTextColor(-16777216);
        textView.setText(this.mLabel);
        textView.setTextSize(12.0f);
        layout.addView(imageView);
        layout.addView(textView);
        return BitmapDescriptorFactory.fromView(layout);
    }

    public void hide() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setVisible(false);
        }
    }

    public void show() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setVisible(true);
        }
    }

    public void bringToTop() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setToTop();
        } else {
            this.isToTop = true;
        }
    }

    public void setDraggable(boolean draggable) {
        this.isDraggable = draggable;
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.setDraggable(draggable);
        }
    }

    public boolean isDraggable() {
        Marker marker = this.mMarker;
        if (marker != null) {
            return marker.isDraggable();
        }
        return this.isDraggable;
    }

    public void setIcons(JSONArray jsonArray, int period) {
        Marker marker;
        if (jsonArray != null) {
            this.mIcons = new ArrayList<>();
            for (int i = 0; i < jsonArray.length(); i++) {
                try {
                    this.mIcons.add(getIcon(jsonArray.getString(i)));
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
            if (period > 0) {
                this.mPeriod = period;
            }
            if (this.mIcons.size() > 0 && (marker = this.mMarker) != null) {
                marker.setIcons(this.mIcons);
                int i2 = this.mPeriod;
                if (i2 > 0) {
                    this.mMarker.setPeriod(i2);
                }
            }
        }
    }

    public Drawable getPopIcon() {
        Drawable _ret = null;
        if (!(this.mBubbleIcon == null || (_ret = CanvasHelper.getDrawable(this.mIWebview.obtainFrameView().obtainApp().convert2AbsFullPath(this.mIWebview.obtainFullUrl(), this.mBubbleIcon))) == null)) {
            int width = _ret.getIntrinsicWidth();
            _ret.setBounds((-width) / 2, -_ret.getIntrinsicHeight(), width / 2, 0);
        }
        return _ret;
    }

    public void setBubble(String label, String icon, boolean isPop2) {
        this.mBubbleLabel = label;
        this.mBubbleIcon = icon;
        this.isPop = isPop2;
    }

    public void hideBubble() {
        Marker marker = this.mMarker;
        if (marker != null) {
            marker.hideInfoWindow();
        }
    }

    public void checkPop() {
        if (this.isPop) {
            this.mMarker.showInfoWindow();
        }
    }

    public void loadImage(String path) {
        this.mLoadImagePath = path;
    }

    public void loadImageDataURL(String base64) {
        this.mLoadImageUrlData = base64;
    }

    public String getLoadImage() {
        return this.mLoadImagePath;
    }

    public String getLoadImageDataURL() {
        return this.mLoadImageUrlData;
    }

    public void loadImageBitmap(ImageView imageView) {
        imageView.setImageBitmap(CanvasHelper.getBitmap(this.mIWebview.obtainFrameView().obtainApp().convert2AbsFullPath(this.mIWebview.obtainFullUrl(), this.mLoadImagePath)));
        imageView.setBackgroundColor(0);
    }

    public void base64ToBitmap(ImageView imageView) {
        byte[] bytes = Base64.decode(this.mLoadImageUrlData.split(",")[1], 1);
        imageView.setImageBitmap(BitmapFactory.decodeByteArray(bytes, 0, bytes.length));
        imageView.setBackgroundColor(0);
    }

    private BitmapDescriptor getDefaultMarkerIcon() {
        Bitmap bg0 = BitmapFactory.decodeResourceStream(this.mIWebview.getActivity().getResources(), null, PlatformUtil.getResInputStream("res/point.png"), null, null);
        if (bg0 == null) {
            return null;
        }
        if (TextUtils.isEmpty(this.mLabel)) {
            return BitmapDescriptorFactory.fromBitmap(bg0);
        }
        LinearLayout layout = new LinearLayout(this.mIWebview.getActivity());
        layout.setOrientation(1);
        layout.setGravity(16);
        ImageView imageView = new ImageView(this.mIWebview.getActivity());
        imageView.setImageBitmap(bg0);
        TextView textView = new TextView(this.mIWebview.getActivity());
        textView.setTextColor(-16777216);
        textView.setText(this.mLabel);
        textView.setTextSize(12.0f);
        layout.addView(imageView);
        layout.addView(textView);
        return BitmapDescriptorFactory.fromView(layout);
    }
}
