package io.dcloud.js.map.amap.adapter;

import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Polygon;
import com.amap.api.maps.model.PolygonOptions;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class MapPolygonProxy {
    private int mFillColor = 0;
    private float mFillOpacity = 0.0f;
    private String mJsId;
    private float mLineWidth = 5.0f;
    private ArrayList<MapPoint> mMapPoints;
    Polygon mMapPolygonImpl = null;
    private float mScale = 1.0f;
    private int mStrokeColor = -16777216;
    private float mStrokeOpacity = 1.0f;

    public MapPolygonProxy(ArrayList<MapPoint> pMapPoints, float scale) {
        this.mMapPoints = pMapPoints;
        this.mScale = scale;
    }

    public Polygon getPolygon() {
        return this.mMapPolygonImpl;
    }

    public void initMapPolygon(DHMapView mapview) {
        this.mMapPolygonImpl = mapview.getMap().addPolygon(getPolygonOptions());
    }

    private int combineOpacity(int color, double opacity) {
        return (((int) (255.0d * opacity)) << 24) + color;
    }

    public void setPath(ArrayList<MapPoint> pAryPoint) {
        this.mMapPoints = pAryPoint;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setPoints(createRectangle());
        }
    }

    public int getStrokeColor() {
        return this.mStrokeColor;
    }

    public void setStrokeColor(int pStrokeColor) {
        int i = -16777216 + pStrokeColor;
        this.mStrokeColor = i;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeColor(combineOpacity(i, (double) this.mStrokeOpacity));
        }
    }

    public float getStrokeOpacity() {
        return this.mStrokeOpacity;
    }

    public void setStrokeOpacity(float pStrokeOpacity) {
        this.mStrokeOpacity = pStrokeOpacity;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeColor(combineOpacity(this.mStrokeColor, (double) pStrokeOpacity));
        }
    }

    public float getLineWidth() {
        return this.mLineWidth;
    }

    public void setLineWidth(float pLineWidth) {
        this.mLineWidth = pLineWidth;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setStrokeWidth(this.mScale * pLineWidth);
        }
    }

    public int getFillColor() {
        return this.mFillColor;
    }

    public void setFillColor(int pFillColor) {
        int i = -16777216 | pFillColor;
        this.mFillColor = i;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setFillColor(combineOpacity(i, (double) this.mFillOpacity));
        }
    }

    public float getFillOpacity() {
        return this.mFillOpacity;
    }

    public void setFillOpacity(float pFillOpacity) {
        this.mFillOpacity = pFillOpacity;
        Polygon polygon = this.mMapPolygonImpl;
        if (polygon != null) {
            polygon.setFillColor(combineOpacity(this.mFillColor, (double) pFillOpacity));
        }
    }

    private PolygonOptions getPolygonOptions() {
        PolygonOptions options = new PolygonOptions();
        options.addAll(createRectangle());
        options.strokeColor(combineOpacity(this.mStrokeColor, (double) this.mStrokeOpacity));
        options.fillColor(combineOpacity(this.mFillColor, (double) this.mFillOpacity));
        options.strokeWidth(this.mLineWidth * this.mScale);
        return options;
    }

    private List<LatLng> createRectangle() {
        ArrayList<LatLng> list = new ArrayList<>();
        ArrayList<MapPoint> arrayList = this.mMapPoints;
        if (arrayList != null && !arrayList.isEmpty()) {
            Iterator<MapPoint> it = this.mMapPoints.iterator();
            while (it.hasNext()) {
                list.add(it.next().getLatLng());
            }
        }
        return list;
    }
}
