package io.dcloud.js.map.amap.adapter;

import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Polyline;
import com.amap.api.maps.model.PolylineOptions;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class MapPolylineProxy {
    private String mJsId;
    private int mLineWidth = 5;
    private ArrayList<MapPoint> mMapPoints;
    Polyline mMapPolylineImpl = null;
    private int mStrokeColor = -16777216;
    private float mStrokeOpacity = 1.0f;

    public MapPolylineProxy(ArrayList<MapPoint> pMapPoints) {
        this.mMapPoints = pMapPoints;
    }

    public Polyline getPolyline() {
        return this.mMapPolylineImpl;
    }

    public void initMapPolyline(DHMapView mapView) {
        this.mMapPolylineImpl = mapView.getMap().addPolyline(getNewGraphic());
    }

    private List<LatLng> createRectangle() {
        ArrayList<LatLng> list = new ArrayList<>();
        ArrayList<MapPoint> arrayList = this.mMapPoints;
        if (arrayList != null && !arrayList.isEmpty()) {
            Iterator<MapPoint> it = this.mMapPoints.iterator();
            while (it.hasNext()) {
                list.add(it.next().getLatLng());
            }
        }
        return list;
    }

    public void setPath(ArrayList<MapPoint> pMapPoints) {
        this.mMapPoints = pMapPoints;
        Polyline polyline = this.mMapPolylineImpl;
        if (polyline != null) {
            polyline.setPoints(createRectangle());
        }
    }

    public int getStrokeColor() {
        return this.mStrokeColor;
    }

    private int combineOpacity(int color, double opacity) {
        return (((int) (255.0d * opacity)) << 24) + color;
    }

    public void setStrokeColor(int pStrokeColor) {
        int i = -2013265920 | pStrokeColor;
        this.mStrokeColor = i;
        Polyline polyline = this.mMapPolylineImpl;
        if (polyline != null) {
            polyline.setColor(combineOpacity(i, (double) this.mStrokeOpacity));
        }
    }

    public float getStrokeOpacity() {
        return this.mStrokeOpacity;
    }

    public void setStrokeOpacity(float pStrokeOpacity) {
        this.mStrokeOpacity = pStrokeOpacity;
        Polyline polyline = this.mMapPolylineImpl;
        if (polyline != null) {
            polyline.setColor(combineOpacity(this.mStrokeColor, (double) pStrokeOpacity));
        }
    }

    public float getLineWidth() {
        return (float) this.mLineWidth;
    }

    public void setLineWidth(int pLineWidth) {
        this.mLineWidth = pLineWidth;
        Polyline polyline = this.mMapPolylineImpl;
        if (polyline != null) {
            polyline.setWidth((float) pLineWidth);
        }
    }

    private PolylineOptions getNewGraphic() {
        PolylineOptions options = new PolylineOptions();
        options.width((float) this.mLineWidth);
        float f = this.mStrokeOpacity;
        if (f != 1.0f) {
            options.color(combineOpacity(this.mStrokeColor, (double) f));
        } else {
            options.color(this.mStrokeColor);
        }
        options.addAll(createRectangle());
        return options;
    }
}
