package io.dcloud.js.map.amap.adapter;

import android.graphics.Color;
import android.graphics.Paint;
import com.amap.api.maps.MapView;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.route.BusPath;
import com.amap.api.services.route.DrivePath;
import com.amap.api.services.route.WalkPath;
import com.tencent.smtt.sdk.TbsListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.js.map.amap.overlay.BusRouteOverlay;
import io.dcloud.js.map.amap.overlay.DrivingRouteOverlay;
import io.dcloud.js.map.amap.overlay.WalkRouteOverlay;

public class MapRoute {
    MapPoint mEnd;
    DHMapView mMapview;
    private Paint mPaint;
    private Object mRoute;
    MapPoint mStart;
    IWebview mWebview;
    private Object overlay;

    public MapRoute() {
        initPaint();
    }

    public void setRoute(MapPoint pStart, MapPoint pEnd) {
        this.mStart = pStart;
        this.mEnd = pEnd;
    }

    public void initMapRoute(IWebview pWebview, DHMapView mapview) {
        this.mWebview = pWebview;
        this.mMapview = mapview;
        Object obj = this.mRoute;
        if (obj instanceof WalkPath) {
            WalkRouteOverlay walkRouteOverlay = new WalkRouteOverlay(pWebview.getContext(), this.mMapview.getMap(), (WalkPath) obj, this.mStart.getLatLngPoint(), this.mEnd.getLatLngPoint());
            this.overlay = walkRouteOverlay;
            walkRouteOverlay.zoomToSpan();
            walkRouteOverlay.addToMap();
        } else if (obj instanceof DrivePath) {
            DrivingRouteOverlay drivingRouteOverlay = new DrivingRouteOverlay(pWebview.getContext(), this.mMapview.getMap(), (DrivePath) obj, this.mStart.getLatLngPoint(), this.mEnd.getLatLngPoint(), null);
            this.overlay = drivingRouteOverlay;
            drivingRouteOverlay.zoomToSpan();
            drivingRouteOverlay.addToMap();
        } else if (obj instanceof BusPath) {
            BusRouteOverlay busRouteOverlay = new BusRouteOverlay(pWebview.getContext(), this.mMapview.getMap(), (BusPath) obj, this.mStart.getLatLngPoint(), this.mEnd.getLatLngPoint());
            this.overlay = busRouteOverlay;
            busRouteOverlay.zoomToSpan();
            busRouteOverlay.addToMap();
        }
    }

    public void removeFromMap() {
        Object obj = this.mRoute;
        if (obj instanceof WalkPath) {
            ((WalkRouteOverlay) this.overlay).removeFromMap();
        } else if (obj instanceof DrivePath) {
            ((DrivingRouteOverlay) this.overlay).removeFromMap();
        } else if (obj instanceof BusPath) {
            ((BusRouteOverlay) this.overlay).removeFromMap();
        }
    }

    public void setRoute(Object pRoute) {
        this.mRoute = pRoute;
    }

    public Object getRoute() {
        return this.mRoute;
    }

    protected class MapLine {
        public PolylineOptions options;

        public MapLine(MapView mapview, MapPoint pStartPos, MapPoint pEndPos) {
            PolylineOptions polylineOptions = new PolylineOptions();
            this.options = polylineOptions;
            polylineOptions.add(pStartPos.getLatLng(), pEndPos.getLatLng());
            this.options.color(-65536);
            this.options.width(10.0f);
        }
    }

    private void initPaint() {
        Paint paint = new Paint();
        this.mPaint = paint;
        paint.setStyle(Paint.Style.STROKE);
        this.mPaint.setColor(Color.rgb(54, 114, (int) TbsListener.ErrorCode.HOST_CONTEXT_IS_NULL));
        this.mPaint.setAlpha(180);
        this.mPaint.setStrokeWidth(5.5f);
        this.mPaint.setStrokeJoin(Paint.Join.ROUND);
        this.mPaint.setStrokeCap(Paint.Cap.ROUND);
        this.mPaint.setAntiAlias(true);
    }
}
