package io.dcloud.js.map.amap.adapter;

import android.os.Handler;
import android.os.Message;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.core.PoiItem;
import com.amap.api.services.district.DistrictSearchQuery;
import com.amap.api.services.geocoder.GeocodeAddress;
import com.amap.api.services.geocoder.GeocodeQuery;
import com.amap.api.services.geocoder.GeocodeResult;
import com.amap.api.services.geocoder.GeocodeSearch;
import com.amap.api.services.geocoder.RegeocodeQuery;
import com.amap.api.services.geocoder.RegeocodeResult;
import com.amap.api.services.poisearch.PoiResult;
import com.amap.api.services.poisearch.PoiSearch;
import com.amap.api.services.route.BusPath;
import com.amap.api.services.route.BusRouteResult;
import com.amap.api.services.route.DrivePath;
import com.amap.api.services.route.DriveRouteResult;
import com.amap.api.services.route.DriveStep;
import com.amap.api.services.route.RideRouteResult;
import com.amap.api.services.route.RouteSearch;
import com.amap.api.services.route.WalkPath;
import com.amap.api.services.route.WalkRouteResult;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.js.map.amap.JsMapManager;
import io.dcloud.js.map.amap.JsMapRoute;
import io.dcloud.js.map.amap.MapJsUtil;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.json.JSONArray;

public class MapSearch {
    private static final int BUS_MODE_SEARCH = 0;
    private static final int DRIVING_MODE_SEARCH = 1;
    private static final int POISEARCH_TYPE = 0;
    private static final int ROUTESEARCH_TYPE = 1;
    private static final int SEARCH_ACTION = 10000;
    private static final int WALK_MODE_SEARCH = 2;
    private int busMode = 0;
    private int drivingMode = 0;
    private ArrayList<AMapSearchResultData> mCallResultDatas;
    public String mCallbackId;
    private Handler mHandler = new Handler() {
        /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass1 */

        public void handleMessage(Message msg) {
            super.handleMessage(msg);
            if (msg.what == 10000) {
                AMapSearchResultData data = (AMapSearchResultData) msg.obj;
                if ((data.pStart instanceof LatLonPoint) && (data.pEnd instanceof LatLonPoint)) {
                    int i = data.type;
                    if (i == 0) {
                        MapSearch.this.transitSearch(data.pStart, data.pEnd, data.endCity);
                    } else if (i == 1) {
                        MapSearch.this.drivingSearch(data.pStart, data.startCity, data.pEnd, data.endCity);
                    } else if (i == 2) {
                        MapSearch.this.walkingSearch(data.pStart, data.startCity, data.pEnd, data.endCity);
                    }
                }
            }
        }
    };
    private IWebview mIWebview;
    private int mIndex = 0;
    DHMapView mMapView = null;
    private int mPageCapacity;
    PoiSearch.OnPoiSearchListener mPoiSearchListener = new PoiSearch.OnPoiSearchListener() {
        /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass7 */

        @Override // com.amap.api.services.poisearch.PoiSearch.OnPoiSearchListener
        public void onPoiSearched(PoiResult poiResult, int code) {
            ArrayList<PoiItem> pArray;
            if (code == 1000) {
                code = 0;
            }
            StringBuffer js = new StringBuffer();
            MapSearch.this.create_js_SearchPoiResult_Obj("spr", js);
            MapJsUtil.assignJsVar(js, "spr", "__state__", (double) code);
            MapJsUtil.assignJsVar(js, "spr", "__type__", 0.0d);
            if (code == 0) {
                int currentNumber = 0;
                int pageNumber = 0;
                int pageIndex = 0;
                if (poiResult != null) {
                    currentNumber = poiResult.getPois().size();
                    pageNumber = poiResult.getPageCount();
                    pageIndex = poiResult.getQuery().getPageNum();
                    pArray = poiResult.getPois();
                } else {
                    pArray = new ArrayList<>();
                }
                MapJsUtil.assignJsVar(js, "spr", "currentNumber", (double) currentNumber);
                MapJsUtil.assignJsVar(js, "spr", "pageNumber", (double) pageNumber);
                MapJsUtil.assignJsVar(js, "spr", "pageIndex", (double) pageIndex);
                MapJsUtil.assignJsVar(js, "spr", "poiList", MapSearch.this.toPositionArray(pArray));
                MapSearch.this.onSearchComplete(0, MapJsUtil.wrapJsEvalString(js.toString(), "spr"));
            } else if (code == 27 || code == 1804) {
                MapJsUtil.assignJsVar(js, "spr", "errorMsg", DOMException.MSG_NETWORK_ERROR);
                MapSearch.this.onSearchComplete(0, MapJsUtil.wrapJsEvalString(js.toString(), "spr"));
            } else if (code == 32 || code == 1001) {
                MapJsUtil.assignJsVar(js, "spr", "errorMsg", "签名错误");
                MapSearch.this.onSearchComplete(0, MapJsUtil.wrapJsEvalString(js.toString(), "spr"));
            } else {
                MapJsUtil.assignJsVar(js, "spr", "errorMsg", DOMException.MSG_UNKNOWN_ERROR);
                MapSearch.this.onSearchComplete(0, MapJsUtil.wrapJsEvalString(js.toString(), "spr"));
            }
        }

        @Override // com.amap.api.services.poisearch.PoiSearch.OnPoiSearchListener
        public void onPoiItemSearched(PoiItem poiItem, int i) {
        }
    };
    RouteSearch.OnRouteSearchListener mRouteSearchListener = new RouteSearch.OnRouteSearchListener() {
        /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass6 */

        @Override // com.amap.api.services.route.RouteSearch.OnRouteSearchListener
        public void onWalkRouteSearched(WalkRouteResult walkRouteResult, int iError) {
            if (iError == 1000) {
                iError = 0;
            }
            if (iError == 0) {
                if (walkRouteResult == null || walkRouteResult.getPaths() == null || walkRouteResult.getPaths().size() <= 0) {
                    MapSearch.this.route_error_callback_js(-1, "对不起，没有搜索到相关数据！");
                    return;
                }
                List<WalkPath> list = walkRouteResult.getPaths();
                MapPoint startp = MapSearch.this.getMapPoint(walkRouteResult.getStartPos());
                MapPoint endp = MapSearch.this.getMapPoint(walkRouteResult.getTargetPos());
                route_callback_js(startp, endp, list.size(), iError, MapSearch.this.toWalkRouteArray(list, startp, endp));
            } else if (iError == 27 || iError == 1804) {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_NETWORK_ERROR);
            } else if (iError == 32 || iError == 1001) {
                MapSearch.this.route_error_callback_js(iError, "签名错误");
            } else {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_UNKNOWN_ERROR);
            }
        }

        @Override // com.amap.api.services.route.RouteSearch.OnRouteSearchListener
        public void onRideRouteSearched(RideRouteResult rideRouteResult, int i) {
        }

        @Override // com.amap.api.services.route.RouteSearch.OnRouteSearchListener
        public void onDriveRouteSearched(DriveRouteResult driveRouteResult, int iError) {
            if (iError == 1000) {
                iError = 0;
            }
            if (iError == 0) {
                if (driveRouteResult == null || driveRouteResult.getPaths() == null || driveRouteResult.getPaths().size() <= 0) {
                    MapSearch.this.route_error_callback_js(-1, "对不起，没有搜索到相关数据！");
                    return;
                }
                List<DrivePath> list = driveRouteResult.getPaths();
                MapPoint startp = MapSearch.this.getMapPoint(driveRouteResult.getStartPos());
                MapPoint endp = MapSearch.this.getMapPoint(driveRouteResult.getTargetPos());
                route_callback_js(startp, endp, list.size(), iError, MapSearch.this.toDriveRouteArray(list, startp, endp));
            } else if (iError == 27 || iError == 1804) {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_NETWORK_ERROR);
            } else if (iError == 32 || iError == 1001) {
                MapSearch.this.route_error_callback_js(iError, "签名错误");
            } else {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_UNKNOWN_ERROR);
            }
        }

        @Override // com.amap.api.services.route.RouteSearch.OnRouteSearchListener
        public void onBusRouteSearched(BusRouteResult busRouteResult, int iError) {
            if (iError == 1000) {
                iError = 0;
            }
            if (iError == 0) {
                if (busRouteResult == null || busRouteResult.getPaths() == null || busRouteResult.getPaths().size() <= 0) {
                    MapSearch.this.route_error_callback_js(-1, "对不起，没有搜索到相关数据！");
                    return;
                }
                List<BusPath> list = busRouteResult.getPaths();
                MapPoint startp = MapSearch.this.getMapPoint(busRouteResult.getStartPos());
                MapPoint endp = MapSearch.this.getMapPoint(busRouteResult.getTargetPos());
                route_callback_js(startp, endp, list.size(), iError, MapSearch.this.toBusRouteArray(list, startp, endp));
            } else if (iError == 27 || iError == 1804) {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_NETWORK_ERROR);
            } else if (iError == 32 || iError == 1001) {
                MapSearch.this.route_error_callback_js(iError, "签名错误");
            } else {
                MapSearch.this.route_error_callback_js(iError, DOMException.MSG_UNKNOWN_ERROR);
            }
        }

        private void route_callback_js(MapPoint sPoint, MapPoint ePoint, int routeNumber, int state, JSONArray routeList) {
            StringBuffer js = new StringBuffer();
            MapSearch.this.create_js_SearchRouteResult_Obj("srr", js);
            MapJsUtil.assignJsVar(js, "srr", "__state__", (double) state);
            MapJsUtil.assignJsVar(js, "srr", "__type__", 1.0d);
            MapJsUtil.assignJsVar(js, "srr", "startPosition", MapJsUtil.wrapJsEvalString(MapSearch.this.create_js_Position_Obj(sPoint, "startPosition"), "startPosition"), false);
            MapJsUtil.assignJsVar(js, "srr", "endPosition", MapJsUtil.wrapJsEvalString(MapSearch.this.create_js_Position_Obj(ePoint, "endPosition"), "endPosition"), false);
            MapJsUtil.assignJsVar(js, "srr", "routeNumber", (double) routeNumber);
            MapJsUtil.assignJsVar(js, "srr", "routeList", routeList);
            MapSearch.this.onSearchComplete(1, MapJsUtil.wrapJsEvalString(js.toString(), "srr"));
        }
    };
    private RouteSearch mSearchHandler;
    private int walkMode = 0;

    public MapSearch(IWebview pIWebview) {
        try {
            this.mIWebview = pIWebview;
            RouteSearch routeSearch = new RouteSearch(pIWebview.getActivity());
            this.mSearchHandler = routeSearch;
            routeSearch.setRouteSearchListener(this.mRouteSearchListener);
        } catch (Exception e) {
        }
    }

    public int getPageCapacity() {
        return this.mPageCapacity;
    }

    public void setPageCapacity(String pageCapacity) {
        this.mPageCapacity = PdrUtil.parseInt(pageCapacity, 10);
    }

    public void setTransitPolicy(int pTransitPolicy) {
        this.busMode = pTransitPolicy;
    }

    public void setDrivingPolicy(int pDrivingPolicy) {
        this.drivingMode = pDrivingPolicy;
    }

    public void setWalkPolicy(int walkPolicy) {
        this.walkMode = walkPolicy;
    }

    public void poiSearchInCity(String pCity, String pKeyCode, String index) {
        PoiSearch.Query query = new PoiSearch.Query(pKeyCode, "", pCity);
        int parseInt = PdrUtil.parseInt(index, 0);
        this.mIndex = parseInt;
        query.setPageNum(parseInt + 1);
        query.setPageSize(this.mPageCapacity);
        try {
            PoiSearch poiSearch = new PoiSearch(this.mIWebview.getContext(), query);
            poiSearch.setOnPoiSearchListener(this.mPoiSearchListener);
            poiSearch.searchPOIAsyn();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void poiSearchNearBy(final String pKeyCode, final MapPoint pCenter, String pRadius, final String index) {
        final int _radius = PdrUtil.parseInt(pRadius, 0);
        getCityKey(new RegeocodeQuery(pCenter.getLatLngPoint(), (float) _radius, GeocodeSearch.AMAP), new ICallBack() {
            /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass2 */

            @Override // io.dcloud.common.DHInterface.ICallBack
            public Object onCallBack(int pType, Object pArgs) {
                if (pArgs == null) {
                    return null;
                }
                try {
                    PoiSearch.Query query = new PoiSearch.Query(pKeyCode, "", (String) pArgs);
                    query.setPageSize(MapSearch.this.mPageCapacity);
                    MapSearch.this.mIndex = PdrUtil.parseInt(index, 0);
                    query.setPageNum(MapSearch.this.mIndex + 1);
                    PoiSearch poiSearch = new PoiSearch(MapSearch.this.mIWebview.getContext(), query);
                    poiSearch.setBound(new PoiSearch.SearchBound(pCenter.getLatLngPoint(), _radius));
                    poiSearch.setOnPoiSearchListener(MapSearch.this.mPoiSearchListener);
                    poiSearch.searchPOIAsyn();
                    return null;
                } catch (Exception e) {
                    e.printStackTrace();
                    return null;
                }
            }
        });
    }

    public void poiSearchInbounds(final String pKeyCode, final MapPoint ptLB, final MapPoint ptRT, final String index) {
        getCityKey(new RegeocodeQuery(ptLB.getLatLngPoint(), 200.0f, GeocodeSearch.AMAP), new ICallBack() {
            /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass3 */

            @Override // io.dcloud.common.DHInterface.ICallBack
            public Object onCallBack(int pType, Object pArgs) {
                if (pArgs == null) {
                    return null;
                }
                try {
                    PoiSearch.Query query = new PoiSearch.Query(pKeyCode, "", (String) pArgs);
                    query.setPageSize(MapSearch.this.mPageCapacity);
                    MapSearch.this.mIndex = PdrUtil.parseInt(index, 0);
                    query.setPageNum(MapSearch.this.mIndex + 1);
                    PoiSearch poiSearch = new PoiSearch(MapSearch.this.mIWebview.getContext(), query);
                    poiSearch.setBound(new PoiSearch.SearchBound(ptLB.getLatLngPoint(), ptRT.getLatLngPoint()));
                    poiSearch.setOnPoiSearchListener(MapSearch.this.mPoiSearchListener);
                    poiSearch.searchPOIAsyn();
                    return null;
                } catch (Exception e) {
                    e.printStackTrace();
                    return null;
                }
            }
        });
    }

    public boolean setTransitPolicy(String pPolicy) {
        if ("TRANSIT_FEE_FIRST".equals(pPolicy)) {
            this.busMode = 1;
            return true;
        } else if ("TRANSIT_TIME_FIRST".equals(pPolicy)) {
            this.busMode = 0;
            return true;
        } else if ("TRANSIT_TRANSFER_FIRST".equals(pPolicy)) {
            this.busMode = 2;
            return true;
        } else if (!"TRANSIT_WALK_FIRST".equals(pPolicy)) {
            return false;
        } else {
            this.busMode = 3;
            return true;
        }
    }

    public boolean setDrivingPolicy(String pPolicy) {
        if ("DRIVING_DIS_FIRST".equals(pPolicy)) {
            this.drivingMode = 2;
            return true;
        } else if ("DRIVING_FEE_FIRST".equals(pPolicy)) {
            this.drivingMode = 1;
            return true;
        } else if (!"DRIVING_NO_EXPRESSWAY".equals(pPolicy)) {
            return false;
        } else {
            this.drivingMode = 6;
            return true;
        }
    }

    public void transitSearch(Object pStart, Object pEnd, String city) {
        AMapSearchResultData data = new AMapSearchResultData(0, pStart, null, pEnd, city);
        LatLonPoint lpS = getLatLonPoint(pStart, city, data, 1);
        LatLonPoint lpE = getLatLonPoint(pEnd, city, data, 2);
        if (lpS != null && lpE != null) {
            this.mSearchHandler.calculateBusRouteAsyn(new RouteSearch.BusRouteQuery(new RouteSearch.FromAndTo(lpS, lpE), this.busMode, city, 0));
        }
    }

    public void drivingSearch(Object pStart, String startCity, Object pEnd, String endCity) {
        AMapSearchResultData data = new AMapSearchResultData(1, pStart, startCity, pEnd, endCity);
        LatLonPoint lpS = getLatLonPoint(pStart, startCity, data, 1);
        LatLonPoint lpE = getLatLonPoint(pEnd, endCity, data, 2);
        if (lpS != null && lpE != null) {
            this.mSearchHandler.calculateDriveRouteAsyn(new RouteSearch.DriveRouteQuery(new RouteSearch.FromAndTo(lpS, lpE), this.drivingMode, null, null, ""));
        }
    }

    public void walkingSearch(Object pStart, String startCity, Object pEnd, String endCity) {
        AMapSearchResultData data = new AMapSearchResultData(2, pStart, startCity, pEnd, endCity);
        LatLonPoint lpS = getLatLonPoint(pStart, startCity, data, 1);
        LatLonPoint lpE = getLatLonPoint(pEnd, endCity, data, 2);
        if (lpS != null && lpE != null) {
            this.mSearchHandler.calculateWalkRouteAsyn(new RouteSearch.WalkRouteQuery(new RouteSearch.FromAndTo(lpS, lpE), this.walkMode));
        }
    }

    private LatLonPoint getLatLonPoint(Object lonPoint, String city, AMapSearchResultData data, int pointType) {
        if (lonPoint instanceof LatLonPoint) {
            return (LatLonPoint) lonPoint;
        }
        if (lonPoint instanceof MapPoint) {
            if (pointType == 1) {
                data.pStart = ((MapPoint) lonPoint).getLatLngPoint();
            } else {
                data.pEnd = ((MapPoint) lonPoint).getLatLngPoint();
            }
            return ((MapPoint) lonPoint).getLatLngPoint();
        }
        getGeocodeLatLon(new GeocodeQuery((String) lonPoint, city), data, pointType);
        return null;
    }

    private void getGeocodeLatLon(GeocodeQuery query, final AMapSearchResultData data, final int pointType) {
        try {
            GeocodeSearch search = new GeocodeSearch(this.mIWebview.getContext());
            search.getFromLocationNameAsyn(query);
            search.setOnGeocodeSearchListener(new GeocodeSearch.OnGeocodeSearchListener() {
                /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass4 */

                @Override // com.amap.api.services.geocoder.GeocodeSearch.OnGeocodeSearchListener
                public void onRegeocodeSearched(RegeocodeResult regeocodeResult, int i) {
                }

                @Override // com.amap.api.services.geocoder.GeocodeSearch.OnGeocodeSearchListener
                public void onGeocodeSearched(GeocodeResult geocodeResult, int i) {
                    if (i == 1000) {
                        List<GeocodeAddress> List = geocodeResult.getGeocodeAddressList();
                        if (List != null) {
                            GeocodeAddress address = List.get(0);
                            if (pointType == 1) {
                                data.pStart = address.getLatLonPoint();
                            } else {
                                data.pEnd = address.getLatLonPoint();
                            }
                            Message message = new Message();
                            message.what = 10000;
                            message.obj = data;
                            MapSearch.this.mHandler.sendMessage(message);
                        }
                    } else {
                        MapSearch mapSearch = MapSearch.this;
                        mapSearch.route_error_callback_js(-1, DOMException.MSG_PARAMETER_ERROR + "(原错误号" + i + ", 相关SDK官网查询具体错误原因)");
                    }
                    Logger.e("shutao", "onGeocodeSearched" + geocodeResult.getGeocodeAddressList().size() + "   code=" + i);
                }
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void getCityKey(RegeocodeQuery regeocodeQuery, final ICallBack callBack) {
        try {
            GeocodeSearch search = new GeocodeSearch(this.mIWebview.getContext());
            search.setOnGeocodeSearchListener(new GeocodeSearch.OnGeocodeSearchListener() {
                /* class io.dcloud.js.map.amap.adapter.MapSearch.AnonymousClass5 */

                @Override // com.amap.api.services.geocoder.GeocodeSearch.OnGeocodeSearchListener
                public void onRegeocodeSearched(RegeocodeResult regeocodeResult, int i) {
                    if (regeocodeResult == null || regeocodeResult.getRegeocodeAddress() == null) {
                        callBack.onCallBack(-1, null);
                    } else {
                        callBack.onCallBack(1, regeocodeResult.getRegeocodeAddress().getCity());
                    }
                }

                @Override // com.amap.api.services.geocoder.GeocodeSearch.OnGeocodeSearchListener
                public void onGeocodeSearched(GeocodeResult geocodeResult, int i) {
                }
            });
            search.getFromLocationAsyn(regeocodeQuery);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onSearchComplete(int searchType, String pScript) {
        if (searchType == 0) {
            MapJsUtil.execCallback(this.mIWebview, this.mCallbackId, pScript);
        } else if (searchType == 1) {
            MapJsUtil.execCallback(this.mIWebview, this.mCallbackId, pScript);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private StringBuffer create_js_SearchPoiResult_Obj(String pName, StringBuffer pRet) {
        MapJsUtil.create_Js_Var(pRet, pName, "plus.maps.__SearchPoiResult__", null);
        return pRet;
    }

    private String create_js_Position_Obj(PoiItem poi) {
        StringBuffer sb = new StringBuffer();
        sb.append(create_js_Point_Obj(getMapPoint(poi.getLatLonPoint()), "p"));
        MapJsUtil.create_Js_Var(sb, "pos", "plus.maps.Position", "p");
        MapJsUtil.assignJsVar(sb, "pos", "address", PdrUtil.makeQueryStringAllRegExp(poi.getSnippet()));
        MapJsUtil.assignJsVar(sb, "pos", DistrictSearchQuery.KEYWORDS_CITY, PdrUtil.makeQueryStringAllRegExp(poi.getCityName()));
        MapJsUtil.assignJsVar(sb, "pos", "name", PdrUtil.makeQueryStringAllRegExp(poi.getTitle()));
        MapJsUtil.assignJsVar(sb, "pos", "phone", poi.getTel());
        MapJsUtil.assignJsVar(sb, "pos", "postcode", poi.getPostcode());
        return MapJsUtil.wrapJsEvalString(sb.toString(), "pos");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String create_js_Position_Obj(MapPoint pt, String posName) {
        StringBuffer sb = new StringBuffer();
        sb.append(create_js_Point_Obj(pt, "p"));
        MapJsUtil.create_Js_Var(sb, posName, "plus.maps.Position", "p");
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private JSONArray toPositionArray(ArrayList<PoiItem> list) {
        JSONArray arr = new JSONArray();
        Iterator<PoiItem> it = list.iterator();
        while (it.hasNext()) {
            arr.put(create_js_Position_Obj(it.next()));
        }
        return arr;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private StringBuffer create_js_SearchRouteResult_Obj(String pName, StringBuffer pRet) {
        MapJsUtil.create_Js_Var(pRet, pName, "plus.maps.__SearchRouteResult__", null);
        return pRet;
    }

    private String create_js_Point_Obj(MapPoint pPoint, String pName) {
        StringBuffer sb = new StringBuffer();
        MapJsUtil.create_Js_Var(sb, pName, "plus.maps.Point", ((float) pPoint.getLongitude()) + "," + ((float) pPoint.getLatitude()));
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private JSONArray toWalkRouteArray(List<WalkPath> list, MapPoint startp, MapPoint endp) {
        JSONArray arr = new JSONArray();
        for (WalkPath walkPath : list) {
            arr.put(create_jsWalkRouteObject(walkPath, startp, endp));
        }
        return arr;
    }

    private String create_jsWalkRouteObject(WalkPath walkPath, MapPoint startp, MapPoint endp) {
        StringBuffer sb = new StringBuffer();
        sb.append(create_js_Point_Obj(startp, "sp"));
        sb.append(create_js_Point_Obj(endp, "ep"));
        MapJsUtil.create_Js_Var(sb, "route", "plus.maps.Route", "sp" + "," + "ep" + ",false");
        MapJsUtil.assignJsVar(sb, "route", "pointCount", (double) walkPath.getSteps().get(0).getPolyline().size());
        MapJsUtil.assignJsVar(sb, "route", "distance", (double) walkPath.getSteps().get(0).getDistance());
        MapJsUtil.assignJsVar(sb, "route", "routeTip", walkPath.getSteps().get(0).getInstruction());
        String uuid = "Route_" + walkPath.hashCode();
        MapJsUtil.assignJsVar(sb, "route", "_UUID_", uuid);
        JsMapRoute routeNativeObj = new JsMapRoute(this.mIWebview);
        routeNativeObj.setRoute(walkPath);
        routeNativeObj.setPoint(startp, endp);
        JsMapManager.getJsMapManager().putJsObject(uuid, routeNativeObj);
        return MapJsUtil.wrapJsEvalString(sb.toString(), "route");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private JSONArray toDriveRouteArray(List<DrivePath> list, MapPoint startp, MapPoint endp) {
        JSONArray arr = new JSONArray();
        for (DrivePath dp : list) {
            arr.put(create_jsDriveRouteObject(dp, startp, endp));
        }
        return arr;
    }

    private String create_jsDriveRouteObject(DrivePath dp, MapPoint startp, MapPoint endp) {
        StringBuffer sb = new StringBuffer();
        sb.append(create_js_Point_Obj(startp, "sp"));
        sb.append(create_js_Point_Obj(endp, "ep"));
        MapJsUtil.create_Js_Var(sb, "route", "plus.maps.Route", "sp" + "," + "ep" + ",false");
        MapJsUtil.assignJsVar(sb, "route", "pointCount", (double) dp.getSteps().get(0).getPolyline().size());
        MapJsUtil.assignJsVar(sb, "route", "distance", (double) dp.getSteps().get(0).getDistance());
        MapJsUtil.assignJsVar(sb, "route", "routeTip", dp.getSteps().get(0).getInstruction());
        String uuid = "Route_" + dp.hashCode();
        MapJsUtil.assignJsVar(sb, "route", "_UUID_", uuid);
        JsMapRoute routeNativeObj = new JsMapRoute(this.mIWebview);
        routeNativeObj.setRoute(dp);
        routeNativeObj.setPoint(startp, endp);
        JsMapManager.getJsMapManager().putJsObject(uuid, routeNativeObj);
        JSONArray ptsArr = new JSONArray();
        for (DriveStep ds : dp.getSteps()) {
            for (LatLonPoint p : ds.getPolyline()) {
                ptsArr.put(create_js_Point_Obj(getMapPoint(p), null));
            }
        }
        MapJsUtil.assignJsVar(sb, "route", "pointList", ptsArr);
        return MapJsUtil.wrapJsEvalString(sb.toString(), "route");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private JSONArray toBusRouteArray(List<BusPath> list, MapPoint startp, MapPoint endp) {
        JSONArray arr = new JSONArray();
        for (BusPath bh : list) {
            arr.put(create_jsBusRouteObject(bh, startp, endp));
        }
        return arr;
    }

    private String create_jsBusRouteObject(BusPath path, MapPoint startp, MapPoint endp) {
        StringBuffer sb = new StringBuffer();
        sb.append(create_js_Point_Obj(startp, "sp"));
        sb.append(create_js_Point_Obj(endp, "ep"));
        MapJsUtil.create_Js_Var(sb, "route", "plus.maps.Route", "sp" + "," + "ep" + ",false");
        MapJsUtil.assignJsVar(sb, "route", "distance", (double) path.getDistance());
        MapJsUtil.assignJsVar(sb, "route", "routeTip", "");
        String uuid = "Route_" + path.hashCode();
        MapJsUtil.assignJsVar(sb, "route", "_UUID_", uuid);
        JsMapRoute routeNativeObj = new JsMapRoute(this.mIWebview);
        routeNativeObj.setRoute(path);
        routeNativeObj.setPoint(startp, endp);
        JsMapManager.getJsMapManager().putJsObject(uuid, routeNativeObj);
        return MapJsUtil.wrapJsEvalString(sb.toString(), "route");
    }

    public void setMapView(DHMapView pMapView) {
        this.mMapView = pMapView;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void route_error_callback_js(int state, String msg) {
        StringBuffer js = new StringBuffer();
        create_js_SearchRouteResult_Obj("srr", js);
        MapJsUtil.assignJsVar(js, "srr", "__state__", (double) state);
        MapJsUtil.assignJsVar(js, "srr", "__type__", 1.0d);
        onSearchComplete(1, MapJsUtil.wrapJsEvalString(js.toString(), "srr"));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private MapPoint getMapPoint(LatLonPoint point) {
        return new MapPoint(point.getLatitude() + "", point.getLongitude() + "");
    }
}
