package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import android.graphics.Color;
import com.amap.api.maps.AMap;
import com.amap.api.maps.CameraUpdateFactory;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.Polyline;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.busline.BusLineItem;
import com.amap.api.services.busline.BusStationItem;
import com.amap.api.services.core.LatLonPoint;
import io.dcloud.js.map.amap.adapter.AMapR;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

public class BusLineOverlay {
    private BitmapDescriptor busBit;
    private BitmapDescriptor endBit;
    private AMap mAMap;
    private BusLineItem mBusLineItem;
    private Polyline mBusLinePolyline;
    private ArrayList<Marker> mBusStationMarks = new ArrayList<>();
    private List<BusStationItem> mBusStations;
    private Context mContext;
    private BitmapDescriptor startBit;

    public BusLineOverlay(Context context, AMap amap, BusLineItem busLineItem) {
        this.mContext = context;
        this.mBusLineItem = busLineItem;
        this.mAMap = amap;
        this.mBusStations = busLineItem.getBusStations();
    }

    public void addToMap() {
        try {
            this.mBusLinePolyline = this.mAMap.addPolyline(new PolylineOptions().addAll(AMapServicesUtil.convertArrList(this.mBusLineItem.getDirectionsCoordinates())).color(getBusColor()).width(getBuslineWidth()));
            if (this.mBusStations.size() >= 1) {
                for (int i = 1; i < this.mBusStations.size() - 1; i++) {
                    this.mBusStationMarks.add(this.mAMap.addMarker(getMarkerOptions(i)));
                }
                this.mBusStationMarks.add(this.mAMap.addMarker(getMarkerOptions(0)));
                this.mBusStationMarks.add(this.mAMap.addMarker(getMarkerOptions(this.mBusStations.size() - 1)));
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    public void removeFromMap() {
        Polyline polyline = this.mBusLinePolyline;
        if (polyline != null) {
            polyline.remove();
        }
        try {
            Iterator<Marker> it = this.mBusStationMarks.iterator();
            while (it.hasNext()) {
                it.next().remove();
            }
            destroyBit();
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void destroyBit() {
        BitmapDescriptor bitmapDescriptor = this.startBit;
        if (bitmapDescriptor != null) {
            bitmapDescriptor.recycle();
            this.startBit = null;
        }
        BitmapDescriptor bitmapDescriptor2 = this.endBit;
        if (bitmapDescriptor2 != null) {
            bitmapDescriptor2.recycle();
            this.endBit = null;
        }
        BitmapDescriptor bitmapDescriptor3 = this.busBit;
        if (bitmapDescriptor3 != null) {
            bitmapDescriptor3.recycle();
            this.busBit = null;
        }
    }

    public void zoomToSpan() {
        if (this.mAMap != null) {
            try {
                List<LatLonPoint> coordin = this.mBusLineItem.getDirectionsCoordinates();
                if (coordin != null && coordin.size() > 0) {
                    this.mAMap.moveCamera(CameraUpdateFactory.newLatLngBounds(getLatLngBounds(coordin), 5));
                }
            } catch (Throwable e) {
                e.printStackTrace();
            }
        }
    }

    private LatLngBounds getLatLngBounds(List<LatLonPoint> coordin) {
        LatLngBounds.Builder b = LatLngBounds.builder();
        for (int i = 0; i < coordin.size(); i++) {
            b.include(new LatLng(coordin.get(i).getLatitude(), coordin.get(i).getLongitude()));
        }
        return b.build();
    }

    private MarkerOptions getMarkerOptions(int index) {
        MarkerOptions options = new MarkerOptions().position(new LatLng(this.mBusStations.get(index).getLatLonPoint().getLatitude(), this.mBusStations.get(index).getLatLonPoint().getLongitude())).title(getTitle(index)).snippet(getSnippet(index));
        if (index == 0) {
            options.icon(getStartBitmapDescriptor());
        } else if (index == this.mBusStations.size() - 1) {
            options.icon(getEndBitmapDescriptor());
        } else {
            options.anchor(0.5f, 0.5f);
            options.icon(getBusBitmapDescriptor());
        }
        return options;
    }

    /* access modifiers changed from: protected */
    public BitmapDescriptor getStartBitmapDescriptor() {
        BitmapDescriptor fromResource = BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_START);
        this.startBit = fromResource;
        return fromResource;
    }

    /* access modifiers changed from: protected */
    public BitmapDescriptor getEndBitmapDescriptor() {
        BitmapDescriptor fromResource = BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_END);
        this.endBit = fromResource;
        return fromResource;
    }

    /* access modifiers changed from: protected */
    public BitmapDescriptor getBusBitmapDescriptor() {
        BitmapDescriptor fromResource = BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_BUS);
        this.busBit = fromResource;
        return fromResource;
    }

    /* access modifiers changed from: protected */
    public String getTitle(int index) {
        return this.mBusStations.get(index).getBusStationName();
    }

    /* access modifiers changed from: protected */
    public String getSnippet(int index) {
        return "";
    }

    public int getBusStationIndex(Marker marker) {
        for (int i = 0; i < this.mBusStationMarks.size(); i++) {
            if (this.mBusStationMarks.get(i).equals(marker)) {
                return i;
            }
        }
        return -1;
    }

    public BusStationItem getBusStationItem(int index) {
        if (index < 0 || index >= this.mBusStations.size()) {
            return null;
        }
        return this.mBusStations.get(index);
    }

    /* access modifiers changed from: protected */
    public int getBusColor() {
        return Color.parseColor("#537edc");
    }

    /* access modifiers changed from: protected */
    public float getBuslineWidth() {
        return 18.0f;
    }
}
