package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.BusPath;
import com.amap.api.services.route.BusStep;
import com.amap.api.services.route.Doorway;
import com.amap.api.services.route.RailwayStationItem;
import com.amap.api.services.route.RouteBusLineItem;
import com.amap.api.services.route.RouteRailwayItem;
import com.amap.api.services.route.TaxiItem;
import com.amap.api.services.route.WalkStep;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.js.map.amap.util.AMapUtil;
import io.dcloud.js.map.amap.util.ChString;
import java.util.ArrayList;
import java.util.List;

public class BusRouteOverlay extends RouteOverlay {
    private BusPath busPath;
    private LatLng latLng;

    public BusRouteOverlay(Context context, AMap amap, BusPath path, LatLonPoint start, LatLonPoint end) {
        super(context);
        this.busPath = path;
        this.startPoint = AMapUtil.convertToLatLng(start);
        this.endPoint = AMapUtil.convertToLatLng(end);
        this.mAMap = amap;
    }

    public void addToMap() {
        try {
            List<BusStep> busSteps = this.busPath.getSteps();
            for (int i = 0; i < busSteps.size(); i++) {
                BusStep busStep = busSteps.get(i);
                if (i < busSteps.size() - 1) {
                    BusStep busStep1 = busSteps.get(i + 1);
                    if (!(busStep.getWalk() == null || busStep.getBusLine() == null)) {
                        checkWalkToBusline(busStep);
                    }
                    if (!(busStep.getBusLine() == null || busStep1.getWalk() == null || busStep1.getWalk().getSteps().size() <= 0)) {
                        checkBusLineToNextWalk(busStep, busStep1);
                    }
                    if (!(busStep.getBusLine() == null || busStep1.getWalk() != null || busStep1.getBusLine() == null)) {
                        checkBusEndToNextBusStart(busStep, busStep1);
                    }
                    if (!(busStep.getBusLine() == null || busStep1.getWalk() != null || busStep1.getBusLine() == null)) {
                        checkBusToNextBusNoWalk(busStep, busStep1);
                    }
                    if (!(busStep.getBusLine() == null || busStep1.getRailway() == null)) {
                        checkBusLineToNextRailway(busStep, busStep1);
                    }
                    if (!(busStep1.getWalk() == null || busStep1.getWalk().getSteps().size() <= 0 || busStep.getRailway() == null)) {
                        checkRailwayToNextWalk(busStep, busStep1);
                    }
                    if (!(busStep1.getRailway() == null || busStep.getRailway() == null)) {
                        checkRailwayToNextRailway(busStep, busStep1);
                    }
                    if (!(busStep.getRailway() == null || busStep1.getTaxi() == null)) {
                        checkRailwayToNextTaxi(busStep, busStep1);
                    }
                }
                if (busStep.getWalk() != null && busStep.getWalk().getSteps().size() > 0) {
                    addWalkSteps(busStep);
                } else if (busStep.getBusLine() == null && busStep.getRailway() == null && busStep.getTaxi() == null) {
                    addWalkPolyline(this.latLng, this.endPoint);
                }
                if (busStep.getBusLine() != null) {
                    RouteBusLineItem routeBusLineItem = busStep.getBusLine();
                    addBusLineSteps(routeBusLineItem);
                    addBusStationMarkers(routeBusLineItem);
                    if (i == busSteps.size() - 1) {
                        addWalkPolyline(AMapUtil.convertToLatLng(getLastBuslinePoint(busStep)), this.endPoint);
                    }
                }
                if (busStep.getRailway() != null) {
                    addRailwayStep(busStep.getRailway());
                    addRailwayMarkers(busStep.getRailway());
                    if (i == busSteps.size() - 1) {
                        addWalkPolyline(AMapUtil.convertToLatLng(busStep.getRailway().getArrivalstop().getLocation()), this.endPoint);
                    }
                }
                if (busStep.getTaxi() != null) {
                    addTaxiStep(busStep.getTaxi());
                    addTaxiMarkers(busStep.getTaxi());
                }
            }
            addStartAndEndMarker();
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void checkRailwayToNextTaxi(BusStep busStep, BusStep busStep1) {
        LatLonPoint railwayLastPoint = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint taxiFirstPoint = busStep1.getTaxi().getOrigin();
        if (!railwayLastPoint.equals(taxiFirstPoint)) {
            addWalkPolyLineByLatLonPoints(railwayLastPoint, taxiFirstPoint);
        }
    }

    private void checkRailwayToNextRailway(BusStep busStep, BusStep busStep1) {
        LatLonPoint railwayLastPoint = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint railwayFirstPoint = busStep1.getRailway().getDeparturestop().getLocation();
        if (!railwayLastPoint.equals(railwayFirstPoint)) {
            addWalkPolyLineByLatLonPoints(railwayLastPoint, railwayFirstPoint);
        }
    }

    private void checkBusLineToNextRailway(BusStep busStep, BusStep busStep1) {
        LatLonPoint busLastPoint = getLastBuslinePoint(busStep);
        LatLonPoint railwayFirstPoint = busStep1.getRailway().getDeparturestop().getLocation();
        if (!busLastPoint.equals(railwayFirstPoint)) {
            addWalkPolyLineByLatLonPoints(busLastPoint, railwayFirstPoint);
        }
    }

    private void checkRailwayToNextWalk(BusStep busStep, BusStep busStep1) {
        LatLonPoint railwayLastPoint = busStep.getRailway().getArrivalstop().getLocation();
        LatLonPoint walkFirstPoint = getFirstWalkPoint(busStep1);
        if (!railwayLastPoint.equals(walkFirstPoint)) {
            addWalkPolyLineByLatLonPoints(railwayLastPoint, walkFirstPoint);
        }
    }

    private void addRailwayStep(RouteRailwayItem railway) {
        List<LatLng> railwaylistpoint = new ArrayList<>();
        List<RailwayStationItem> railwayStationItems = new ArrayList<>();
        railwayStationItems.add(railway.getDeparturestop());
        railwayStationItems.addAll(railway.getViastops());
        railwayStationItems.add(railway.getArrivalstop());
        for (int i = 0; i < railwayStationItems.size(); i++) {
            railwaylistpoint.add(AMapUtil.convertToLatLng(railwayStationItems.get(i).getLocation()));
        }
        addRailwayPolyline(railwaylistpoint);
    }

    private void addTaxiStep(TaxiItem taxi) {
        addPolyLine(new PolylineOptions().width(getRouteWidth()).color(getBusColor()).add(AMapUtil.convertToLatLng(taxi.getOrigin())).add(AMapUtil.convertToLatLng(taxi.getDestination())));
    }

    private void addWalkSteps(BusStep busStep) {
        List<WalkStep> walkSteps = busStep.getWalk().getSteps();
        for (int j = 0; j < walkSteps.size(); j++) {
            WalkStep walkStep = walkSteps.get(j);
            if (j == 0) {
                addWalkStationMarkers(AMapUtil.convertToLatLng(walkStep.getPolyline().get(0)), walkStep.getRoad(), getWalkSnippet(walkSteps));
            }
            List<LatLng> listWalkPolyline = AMapUtil.convertArrList(walkStep.getPolyline());
            this.latLng = listWalkPolyline.get(listWalkPolyline.size() - 1);
            addWalkPolyline(listWalkPolyline);
            if (j < walkSteps.size() - 1) {
                LatLng lastLatLng = listWalkPolyline.get(listWalkPolyline.size() - 1);
                LatLng firstlatLatLng = AMapUtil.convertToLatLng(walkSteps.get(j + 1).getPolyline().get(0));
                if (!lastLatLng.equals(firstlatLatLng)) {
                    addWalkPolyline(lastLatLng, firstlatLatLng);
                }
            }
        }
    }

    private void addBusLineSteps(RouteBusLineItem routeBusLineItem) {
        addBusLineSteps(routeBusLineItem.getPolyline());
    }

    private void addBusLineSteps(List<LatLonPoint> listPoints) {
        if (listPoints.size() >= 1) {
            addPolyLine(new PolylineOptions().width(getRouteWidth()).color(getBusColor()).addAll(AMapUtil.convertArrList(listPoints)));
        }
    }

    private void addWalkStationMarkers(LatLng latLng2, String title, String snippet) {
        addStationMarker(new MarkerOptions().position(latLng2).title(title).snippet(snippet).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getWalkBitmapDescriptor()));
    }

    private void addBusStationMarkers(RouteBusLineItem routeBusLineItem) {
        LatLng position = AMapUtil.convertToLatLng(routeBusLineItem.getDepartureBusStation().getLatLonPoint());
        String title = routeBusLineItem.getBusLineName();
        addStationMarker(new MarkerOptions().position(position).title(title).snippet(getBusSnippet(routeBusLineItem)).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
    }

    private void addTaxiMarkers(TaxiItem taxiItem) {
        LatLng position = AMapUtil.convertToLatLng(taxiItem.getOrigin());
        addStationMarker(new MarkerOptions().position(position).title(taxiItem.getmSname() + "打车").snippet("到终点").anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getDriveBitmapDescriptor()));
    }

    private void addRailwayMarkers(RouteRailwayItem railway) {
        String Departuretitle = railway.getDeparturestop().getName() + ChString.GetOn;
        addStationMarker(new MarkerOptions().position(AMapUtil.convertToLatLng(railway.getDeparturestop().getLocation())).title(Departuretitle).snippet(railway.getName()).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
        String Arrivaltitle = railway.getArrivalstop().getName() + ChString.GetOff;
        addStationMarker(new MarkerOptions().position(AMapUtil.convertToLatLng(railway.getArrivalstop().getLocation())).title(Arrivaltitle).snippet(railway.getName()).anchor(0.5f, 0.5f).visible(this.nodeIconVisible).icon(getBusBitmapDescriptor()));
    }

    private void checkBusToNextBusNoWalk(BusStep busStep, BusStep busStep1) {
        LatLng endbusLatLng = AMapUtil.convertToLatLng(getLastBuslinePoint(busStep));
        LatLng startbusLatLng = AMapUtil.convertToLatLng(getFirstBuslinePoint(busStep1));
        if (startbusLatLng.latitude - endbusLatLng.latitude > 1.0E-4d || startbusLatLng.longitude - endbusLatLng.longitude > 1.0E-4d) {
            drawLineArrow(endbusLatLng, startbusLatLng);
        }
    }

    private void checkBusEndToNextBusStart(BusStep busStep, BusStep busStep1) {
        LatLng endbusLatLng = AMapUtil.convertToLatLng(getLastBuslinePoint(busStep));
        LatLng startbusLatLng = AMapUtil.convertToLatLng(getFirstBuslinePoint(busStep1));
        if (!endbusLatLng.equals(startbusLatLng)) {
            drawLineArrow(endbusLatLng, startbusLatLng);
        }
    }

    private void checkBusLineToNextWalk(BusStep busStep, BusStep busStep1) {
        LatLonPoint busLastPoint = getLastBuslinePoint(busStep);
        LatLonPoint walkFirstPoint = getFirstWalkPoint(busStep1);
        if (!busLastPoint.equals(walkFirstPoint)) {
            addWalkPolyLineByLatLonPoints(busLastPoint, walkFirstPoint);
        }
    }

    private void checkWalkToBusline(BusStep busStep) {
        LatLonPoint walkLastPoint = getLastWalkPoint(busStep);
        LatLonPoint buslineFirstPoint = getFirstBuslinePoint(busStep);
        if (!walkLastPoint.equals(buslineFirstPoint)) {
            addWalkPolyLineByLatLonPoints(walkLastPoint, buslineFirstPoint);
        }
    }

    private LatLonPoint getFirstWalkPoint(BusStep busStep1) {
        return busStep1.getWalk().getSteps().get(0).getPolyline().get(0);
    }

    private void addWalkPolyLineByLatLonPoints(LatLonPoint pointFrom, LatLonPoint pointTo) {
        addWalkPolyline(AMapUtil.convertToLatLng(pointFrom), AMapUtil.convertToLatLng(pointTo));
    }

    private void addWalkPolyline(LatLng latLngFrom, LatLng latLngTo) {
        addPolyLine(new PolylineOptions().add(latLngFrom, latLngTo).width(getRouteWidth()).color(getWalkColor()).setDottedLine(true));
    }

    private void addWalkPolyline(List<LatLng> listWalkPolyline) {
        addPolyLine(new PolylineOptions().addAll(listWalkPolyline).color(getWalkColor()).width(getRouteWidth()).setDottedLine(true));
    }

    private void addRailwayPolyline(List<LatLng> listPolyline) {
        addPolyLine(new PolylineOptions().addAll(listPolyline).color(getDriveColor()).width(getRouteWidth()));
    }

    private String getWalkSnippet(List<WalkStep> walkSteps) {
        float disNum = 0.0f;
        for (WalkStep step : walkSteps) {
            disNum += step.getDistance();
        }
        return ChString.ByFoot + disNum + ChString.Meter;
    }

    public void drawLineArrow(LatLng latLngFrom, LatLng latLngTo) {
        addPolyLine(new PolylineOptions().add(latLngFrom, latLngTo).width(3.0f).color(getBusColor()).width(getRouteWidth()));
    }

    private String getBusSnippet(RouteBusLineItem routeBusLineItem) {
        return Operators.BRACKET_START_STR + routeBusLineItem.getDepartureBusStation().getBusStationName() + "-->" + routeBusLineItem.getArrivalBusStation().getBusStationName() + ") 经过" + (routeBusLineItem.getPassStationNum() + 1) + ChString.Zhan;
    }

    private LatLonPoint getLastWalkPoint(BusStep busStep) {
        List<WalkStep> walkSteps = busStep.getWalk().getSteps();
        List<LatLonPoint> lonPoints = walkSteps.get(walkSteps.size() - 1).getPolyline();
        return lonPoints.get(lonPoints.size() - 1);
    }

    private LatLonPoint getExitPoint(BusStep busStep) {
        Doorway doorway = busStep.getExit();
        if (doorway == null) {
            return null;
        }
        return doorway.getLatLonPoint();
    }

    private LatLonPoint getLastBuslinePoint(BusStep busStep) {
        List<LatLonPoint> lonPoints = busStep.getBusLine().getPolyline();
        return lonPoints.get(lonPoints.size() - 1);
    }

    private LatLonPoint getEntrancePoint(BusStep busStep) {
        Doorway doorway = busStep.getEntrance();
        if (doorway == null) {
            return null;
        }
        return doorway.getLatLonPoint();
    }

    private LatLonPoint getFirstBuslinePoint(BusStep busStep) {
        return busStep.getBusLine().getPolyline().get(0);
    }
}
