package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import android.graphics.Color;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.DrivePath;
import com.amap.api.services.route.DriveStep;
import com.amap.api.services.route.TMC;
import io.dcloud.js.map.amap.adapter.AMapR;
import io.dcloud.js.map.amap.util.AMapUtil;
import java.util.ArrayList;
import java.util.List;

public class DrivingRouteOverlay extends RouteOverlay {
    private DrivePath drivePath;
    private boolean isColorfulline = true;
    private Context mContext;
    private List<LatLng> mLatLngsOfPath;
    private PolylineOptions mPolylineOptions;
    private PolylineOptions mPolylineOptionscolor;
    private float mWidth = 25.0f;
    private List<LatLonPoint> throughPointList;
    private List<Marker> throughPointMarkerList = new ArrayList();
    private boolean throughPointMarkerVisible = true;
    private List<TMC> tmcs;

    public void setIsColorfulline(boolean iscolorfulline) {
        this.isColorfulline = iscolorfulline;
    }

    public DrivingRouteOverlay(Context context, AMap amap, DrivePath path, LatLonPoint start, LatLonPoint end, List<LatLonPoint> throughPointList2) {
        super(context);
        this.mContext = context;
        this.mAMap = amap;
        this.drivePath = path;
        this.startPoint = AMapUtil.convertToLatLng(start);
        this.endPoint = AMapUtil.convertToLatLng(end);
        this.throughPointList = throughPointList2;
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public float getRouteWidth() {
        return this.mWidth;
    }

    public void setRouteWidth(float mWidth2) {
        this.mWidth = mWidth2;
    }

    public void addToMap() {
        initPolylineOptions();
        try {
            if (!(this.mAMap == null || this.mWidth == 0.0f)) {
                if (this.drivePath != null) {
                    this.mLatLngsOfPath = new ArrayList();
                    this.tmcs = new ArrayList();
                    List<DriveStep> drivePaths = this.drivePath.getSteps();
                    this.mPolylineOptions.add(this.startPoint);
                    for (DriveStep step : drivePaths) {
                        List<LatLonPoint> latlonPoints = step.getPolyline();
                        this.tmcs.addAll(step.getTMCs());
                        addDrivingStationMarkers(step, convertToLatLng(latlonPoints.get(0)));
                        for (LatLonPoint latlonpoint : latlonPoints) {
                            this.mPolylineOptions.add(convertToLatLng(latlonpoint));
                            this.mLatLngsOfPath.add(convertToLatLng(latlonpoint));
                        }
                    }
                    this.mPolylineOptions.add(this.endPoint);
                    if (this.startMarker != null) {
                        this.startMarker.remove();
                        this.startMarker = null;
                    }
                    if (this.endMarker != null) {
                        this.endMarker.remove();
                        this.endMarker = null;
                    }
                    addStartAndEndMarker();
                    addThroughPointMarker();
                    if (!this.isColorfulline || this.tmcs.size() <= 0) {
                        showPolyline();
                        return;
                    }
                    colorWayUpdate(this.tmcs);
                    showcolorPolyline();
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void initPolylineOptions() {
        this.mPolylineOptions = null;
        PolylineOptions polylineOptions = new PolylineOptions();
        this.mPolylineOptions = polylineOptions;
        polylineOptions.color(getDriveColor()).width(getRouteWidth());
    }

    private void showPolyline() {
        addPolyLine(this.mPolylineOptions);
    }

    private void showcolorPolyline() {
        addPolyLine(this.mPolylineOptionscolor);
    }

    private void colorWayUpdate(List<TMC> tmcSection) {
        if (!(this.mAMap == null || tmcSection == null || tmcSection.size() <= 0)) {
            this.mPolylineOptionscolor = null;
            PolylineOptions polylineOptions = new PolylineOptions();
            this.mPolylineOptionscolor = polylineOptions;
            polylineOptions.width(getRouteWidth());
            List<Integer> colorList = new ArrayList<>();
            this.mPolylineOptionscolor.add(this.startPoint);
            this.mPolylineOptionscolor.add(AMapUtil.convertToLatLng(tmcSection.get(0).getPolyline().get(0)));
            colorList.add(Integer.valueOf(getDriveColor()));
            for (int i = 0; i < tmcSection.size(); i++) {
                TMC segmentTrafficStatus = tmcSection.get(i);
                int color = getcolor(segmentTrafficStatus.getStatus());
                List<LatLonPoint> mployline = segmentTrafficStatus.getPolyline();
                for (int j = 1; j < mployline.size(); j++) {
                    this.mPolylineOptionscolor.add(AMapUtil.convertToLatLng(mployline.get(j)));
                    colorList.add(Integer.valueOf(color));
                }
            }
            this.mPolylineOptionscolor.add(this.endPoint);
            colorList.add(Integer.valueOf(getDriveColor()));
            this.mPolylineOptionscolor.colorValues(colorList);
        }
    }

    private int getcolor(String status) {
        if (status.equals("畅通")) {
            return -16711936;
        }
        if (status.equals("缓行")) {
            return -256;
        }
        if (status.equals("拥堵")) {
            return -65536;
        }
        if (status.equals("严重拥堵")) {
            return Color.parseColor("#990033");
        }
        return Color.parseColor("#537edc");
    }

    public LatLng convertToLatLng(LatLonPoint point) {
        return new LatLng(point.getLatitude(), point.getLongitude());
    }

    private void addDrivingStationMarkers(DriveStep driveStep, LatLng latLng) {
        MarkerOptions position = new MarkerOptions().position(latLng);
        addStationMarker(position.title("方向:" + driveStep.getAction() + "\n道路:" + driveStep.getRoad()).snippet(driveStep.getInstruction()).visible(this.nodeIconVisible).anchor(0.5f, 0.5f).icon(getDriveBitmapDescriptor()));
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public LatLngBounds getLatLngBounds() {
        LatLngBounds.Builder b = LatLngBounds.builder();
        b.include(new LatLng(this.startPoint.latitude, this.startPoint.longitude));
        b.include(new LatLng(this.endPoint.latitude, this.endPoint.longitude));
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                b.include(new LatLng(this.throughPointList.get(i).getLatitude(), this.throughPointList.get(i).getLongitude()));
            }
        }
        return b.build();
    }

    public void setThroughPointIconVisibility(boolean visible) {
        try {
            this.throughPointMarkerVisible = visible;
            if (this.throughPointMarkerList != null && this.throughPointMarkerList.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).setVisible(visible);
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void addThroughPointMarker() {
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                LatLonPoint latLonPoint = this.throughPointList.get(i);
                if (latLonPoint != null) {
                    this.throughPointMarkerList.add(this.mAMap.addMarker(new MarkerOptions().position(new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude())).visible(this.throughPointMarkerVisible).icon(getThroughPointBitDes()).title("途经点")));
                }
            }
        }
    }

    private BitmapDescriptor getThroughPointBitDes() {
        return BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_THROUGH);
    }

    public static int calculateDistance(LatLng start, LatLng end) {
        return calculateDistance(start.longitude, start.latitude, end.longitude, end.latitude);
    }

    public static int calculateDistance(double x1, double y1, double x2, double y2) {
        double x12 = x1 * 0.01745329251994329d;
        double y12 = y1 * 0.01745329251994329d;
        double x22 = x2 * 0.01745329251994329d;
        double y22 = 0.01745329251994329d * y2;
        double sinx1 = Math.sin(x12);
        double siny1 = Math.sin(y12);
        double cosx1 = Math.cos(x12);
        double cosy1 = Math.cos(y12);
        double sinx2 = Math.sin(x22);
        double siny2 = Math.sin(y22);
        double cosx2 = Math.cos(x22);
        double cosy2 = Math.cos(y22);
        double[] v1 = {(cosy1 * cosx1) - (cosy2 * cosx2), (cosy1 * sinx1) - (cosy2 * sinx2), siny1 - siny2};
        return (int) (Math.asin(Math.sqrt(((v1[0] * v1[0]) + (v1[1] * v1[1])) + (v1[2] * v1[2])) / 2.0d) * 1.27420015798544E7d);
    }

    public static LatLng getPointForDis(LatLng sPt, LatLng ePt, double dis) {
        double preResult = dis / ((double) calculateDistance(sPt, ePt));
        return new LatLng(((ePt.latitude - sPt.latitude) * preResult) + sPt.latitude, ((ePt.longitude - sPt.longitude) * preResult) + sPt.longitude);
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public void removeFromMap() {
        try {
            super.removeFromMap();
            if (this.throughPointMarkerList != null && this.throughPointMarkerList.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).remove();
                }
                this.throughPointMarkerList.clear();
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }
}
