package io.dcloud.js.map.amap.overlay;

import android.content.Context;
import android.graphics.Color;
import com.amap.api.maps.AMap;
import com.amap.api.maps.model.BitmapDescriptor;
import com.amap.api.maps.model.BitmapDescriptorFactory;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.LatLngBounds;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.amap.api.maps.model.PolylineOptions;
import com.amap.api.services.core.LatLonPoint;
import com.amap.api.services.route.TMC;
import com.amap.api.services.route.TruckPath;
import com.amap.api.services.route.TruckStep;
import io.dcloud.js.map.amap.adapter.AMapR;
import io.dcloud.js.map.amap.util.AMapUtil;
import java.util.ArrayList;
import java.util.List;

public class TruckRouteColorfulOverLay extends RouteOverlay {
    private boolean isColorfulline = true;
    private Context mContext;
    private List<LatLng> mLatLngsOfPath;
    private PolylineOptions mPolylineOptions;
    private float mWidth = 17.0f;
    private List<LatLonPoint> throughPointList;
    private List<Marker> throughPointMarkerList = new ArrayList();
    private boolean throughPointMarkerVisible = true;
    private List<TMC> tmcs;
    private TruckPath truckPath;

    public void setIsColorfulline(boolean iscolorfulline) {
        this.isColorfulline = iscolorfulline;
    }

    public TruckRouteColorfulOverLay(Context context, AMap amap, TruckPath path, LatLonPoint start, LatLonPoint end, List<LatLonPoint> throughPointList2) {
        super(context);
        this.mContext = context;
        this.mAMap = amap;
        this.truckPath = path;
        this.startPoint = AMapUtil.convertToLatLng(start);
        this.endPoint = AMapUtil.convertToLatLng(end);
        this.throughPointList = throughPointList2;
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public float getRouteWidth() {
        return this.mWidth;
    }

    public void setRouteWidth(float mWidth2) {
        this.mWidth = mWidth2;
    }

    public void addToMap() {
        initPolylineOptions();
        try {
            if (this.mAMap != null && this.mWidth != 0.0f) {
                if (this.truckPath != null) {
                    this.mLatLngsOfPath = new ArrayList();
                    this.tmcs = new ArrayList();
                    List<TruckStep> steps = this.truckPath.getSteps();
                    this.mPolylineOptions.add(this.startPoint);
                    for (TruckStep step : steps) {
                        List<LatLonPoint> latlonPoints = step.getPolyline();
                        this.tmcs.addAll(step.getTMCs());
                        for (LatLonPoint latlonpoint : latlonPoints) {
                            this.mPolylineOptions.add(convertToLatLng(latlonpoint));
                            this.mLatLngsOfPath.add(convertToLatLng(latlonpoint));
                        }
                    }
                    this.mPolylineOptions.add(this.endPoint);
                    if (this.startMarker != null) {
                        this.startMarker.remove();
                        this.startMarker = null;
                    }
                    if (this.endMarker != null) {
                        this.endMarker.remove();
                        this.endMarker = null;
                    }
                    addStartAndEndMarker();
                    addThroughPointMarker();
                    if (!this.isColorfulline || this.tmcs.size() <= 0) {
                        showPolyline();
                    } else {
                        colorWayUpdate(this.tmcs);
                    }
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void initPolylineOptions() {
        this.mPolylineOptions = null;
        PolylineOptions polylineOptions = new PolylineOptions();
        this.mPolylineOptions = polylineOptions;
        polylineOptions.color(getDriveColor()).width(getRouteWidth());
    }

    private void showPolyline() {
        addPolyLine(this.mPolylineOptions);
    }

    private void colorWayUpdate(List<TMC> tmcSection) {
        List<LatLng> list;
        LatLng endLatLng;
        if (this.mAMap != null && (list = this.mLatLngsOfPath) != null && list.size() > 0 && tmcSection != null && tmcSection.size() > 0) {
            int j = 0;
            LatLng startLatLng = this.mLatLngsOfPath.get(0);
            double segmentTotalDistance = 0.0d;
            List<LatLng> tempList = new ArrayList<>();
            addPolyLine(new PolylineOptions().add(this.startPoint, startLatLng).setDottedLine(true));
            PolylineOptions polylineOptions = new PolylineOptions();
            List<LatLng> list2 = this.mLatLngsOfPath;
            addPolyLine(polylineOptions.add(list2.get(list2.size() - 1), this.endPoint).setDottedLine(true));
            int i = 0;
            while (i < this.mLatLngsOfPath.size() && j < tmcSection.size()) {
                TMC segmentTrafficStatus = tmcSection.get(j);
                LatLng endLatLng2 = this.mLatLngsOfPath.get(i);
                double distanceBetweenTwoPosition = (double) calculateDistance(startLatLng, endLatLng2);
                segmentTotalDistance += distanceBetweenTwoPosition;
                if (segmentTotalDistance > ((double) (segmentTrafficStatus.getDistance() + 1))) {
                    endLatLng = endLatLng2;
                    LatLng middleLatLng = getPointForDis(startLatLng, endLatLng, distanceBetweenTwoPosition - (segmentTotalDistance - ((double) segmentTrafficStatus.getDistance())));
                    tempList.add(middleLatLng);
                    startLatLng = middleLatLng;
                    i--;
                } else {
                    endLatLng = endLatLng2;
                    tempList.add(endLatLng);
                    startLatLng = endLatLng;
                }
                if (segmentTotalDistance >= ((double) segmentTrafficStatus.getDistance()) || i == this.mLatLngsOfPath.size() - 1) {
                    if (j == tmcSection.size() - 1 && i < this.mLatLngsOfPath.size() - 1) {
                        while (true) {
                            i++;
                            if (i >= this.mLatLngsOfPath.size()) {
                                break;
                            }
                            tempList.add(this.mLatLngsOfPath.get(i));
                        }
                    }
                    j++;
                    if (segmentTrafficStatus.getStatus().equals("畅通")) {
                        addPolyLine(new PolylineOptions().addAll(tempList).width(this.mWidth).color(-16711936));
                    } else if (segmentTrafficStatus.getStatus().equals("缓行")) {
                        addPolyLine(new PolylineOptions().addAll(tempList).width(this.mWidth).color(-256));
                    } else if (segmentTrafficStatus.getStatus().equals("拥堵")) {
                        addPolyLine(new PolylineOptions().addAll(tempList).width(this.mWidth).color(-65536));
                    } else if (segmentTrafficStatus.getStatus().equals("严重拥堵")) {
                        addPolyLine(new PolylineOptions().addAll(tempList).width(this.mWidth).color(Color.parseColor("#990033")));
                    } else {
                        addPolyLine(new PolylineOptions().addAll(tempList).width(this.mWidth).color(Color.parseColor("#537edc")));
                    }
                    tempList.clear();
                    tempList.add(startLatLng);
                    segmentTotalDistance = 0.0d;
                }
                if (i == this.mLatLngsOfPath.size() - 1) {
                    addPolyLine(new PolylineOptions().add(endLatLng, this.endPoint).setDottedLine(true));
                }
                i++;
            }
        }
    }

    public LatLng convertToLatLng(LatLonPoint point) {
        return new LatLng(point.getLatitude(), point.getLongitude());
    }

    private void addLimitMarker(TruckStep step, LatLng latLng) {
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public LatLngBounds getLatLngBounds() {
        LatLngBounds.Builder b = LatLngBounds.builder();
        b.include(new LatLng(this.startPoint.latitude, this.startPoint.longitude));
        b.include(new LatLng(this.endPoint.latitude, this.endPoint.longitude));
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                b.include(new LatLng(this.throughPointList.get(i).getLatitude(), this.throughPointList.get(i).getLongitude()));
            }
        }
        return b.build();
    }

    public void setThroughPointIconVisibility(boolean visible) {
        try {
            this.throughPointMarkerVisible = visible;
            if (this.throughPointMarkerList != null && this.throughPointMarkerList.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).setVisible(visible);
                }
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }

    private void addThroughPointMarker() {
        List<LatLonPoint> list = this.throughPointList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < this.throughPointList.size(); i++) {
                LatLonPoint latLonPoint = this.throughPointList.get(i);
                if (latLonPoint != null) {
                    this.throughPointMarkerList.add(this.mAMap.addMarker(new MarkerOptions().position(new LatLng(latLonPoint.getLatitude(), latLonPoint.getLongitude())).visible(this.throughPointMarkerVisible).icon(getThroughPointBitDes()).title("途经点")));
                }
            }
        }
    }

    private BitmapDescriptor getThroughPointBitDes() {
        return BitmapDescriptorFactory.fromResource(AMapR.AMAP_DRAWABLE_AMAP_THROUGH);
    }

    public static int calculateDistance(LatLng start, LatLng end) {
        return calculateDistance(start.longitude, start.latitude, end.longitude, end.latitude);
    }

    public static int calculateDistance(double x1, double y1, double x2, double y2) {
        double x12 = x1 * 0.01745329251994329d;
        double y12 = y1 * 0.01745329251994329d;
        double x22 = x2 * 0.01745329251994329d;
        double y22 = 0.01745329251994329d * y2;
        double sinx1 = Math.sin(x12);
        double siny1 = Math.sin(y12);
        double cosx1 = Math.cos(x12);
        double cosy1 = Math.cos(y12);
        double sinx2 = Math.sin(x22);
        double siny2 = Math.sin(y22);
        double cosx2 = Math.cos(x22);
        double cosy2 = Math.cos(y22);
        double[] v1 = {(cosy1 * cosx1) - (cosy2 * cosx2), (cosy1 * sinx1) - (cosy2 * sinx2), siny1 - siny2};
        return (int) (Math.asin(Math.sqrt(((v1[0] * v1[0]) + (v1[1] * v1[1])) + (v1[2] * v1[2])) / 2.0d) * 1.27420015798544E7d);
    }

    public static LatLng getPointForDis(LatLng sPt, LatLng ePt, double dis) {
        double preResult = dis / ((double) calculateDistance(sPt, ePt));
        return new LatLng(((ePt.latitude - sPt.latitude) * preResult) + sPt.latitude, ((ePt.longitude - sPt.longitude) * preResult) + sPt.longitude);
    }

    @Override // io.dcloud.js.map.amap.overlay.RouteOverlay
    public void removeFromMap() {
        try {
            super.removeFromMap();
            if (this.throughPointMarkerList != null && this.throughPointMarkerList.size() > 0) {
                for (int i = 0; i < this.throughPointMarkerList.size(); i++) {
                    this.throughPointMarkerList.get(i).remove();
                }
                this.throughPointMarkerList.clear();
            }
        } catch (Throwable e) {
            e.printStackTrace();
        }
    }
}
