package io.dcloud.media.live.push;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Rect;
import android.hardware.Camera;
import android.os.Handler;
import android.os.Looper;
import android.view.MotionEvent;
import android.view.OrientationEventListener;
import android.view.View;
import android.widget.AbsoluteLayout;
import android.widget.LinearLayout;
import com.autonavi.amap.mapcore.AMapEngineUtils;
import com.autonavi.amap.mapcore.tools.GlMapUtil;
import com.github.faucamp.simplertmp.RtmpHandler;
import com.seu.magicfilter.utils.MagicFilterType;
import com.tencent.liteav.audio.TXEAudioDef;
import com.tencent.rtmp.TXLiveConstants;
import com.uc.crashsdk.export.LogType;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.IFrameView;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.ui.AdaUniWebView;
import io.dcloud.common.adapter.util.ViewRect;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.livepusher.R;
import io.dcloud.media.live.LivePusherStateListener;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.SocketException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.regex.Pattern;
import net.ossrs.yasea.SrsCameraView;
import net.ossrs.yasea.SrsEncodeHandler;
import net.ossrs.yasea.SrsPublisher;
import net.ossrs.yasea.SrsRecordHandler;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class LivePusher extends AdaFrameItem implements RtmpHandler.RtmpListener, SrsEncodeHandler.SrsEncodeListener, SrsRecordHandler.SrsRecordListener {
    protected static final String EVENT_RESULT_TEMPLATE = "{code:'%d',message:'%s'}";
    protected static String EVENT_TEMPLATE = "window.__Media_Live__Push__.execCallback_LivePush('%s', %s,'%s');";
    private AbsoluteLayout.LayoutParams _lp = null;
    private JSONArray arr;
    String aspect = "3:4";
    int bBeauty = 0;
    boolean bOpenCamera = true;
    boolean bSilence = false;
    int bWhiteness = 0;
    boolean bautoFocus = true;
    private int cacheCameraHeight;
    private int cacheCameraWidth;
    LinearLayout cameraContainerView;
    private SrsCameraView cameraView;
    private int curBitrate = 200;
    private double curFps = 30.0d;
    private String curPusherID = null;
    private long curTotalSize = 0;
    private int defaultHeight = GlMapUtil.DEVICE_DISPLAY_DPI_XHIGH;
    private int defaultWidth = 640;
    private HashMap<String, HashMap<String, IWebview>> eventCallBacks;
    private IWebview initWebview;
    private boolean isFromCreate = false;
    public boolean isInited = false;
    private boolean isRegisterResize = false;
    private LivePusherStateListener listener;
    SrsPublisher mPublisher;
    private LinearLayout mainView;
    String mode = "HD";
    private OrientationEventListener moel;
    private boolean onCloseing = false;
    private boolean onStoped = false;
    private JSONObject options = null;
    private int oritation = 0;
    private String position = "static";
    int pusherHeight = 0;
    int pusherWidth = 0;
    private String rtmpULR = null;
    Pattern rtmpUrlPattern = Pattern.compile("^rtmp://([^/:]+)(:(\\d+))*/([^/]+)(/(.*))*$");
    private String startCallbackID = null;
    private boolean startPreview = false;
    private IWebview startWebview = null;
    private boolean stopPreview = false;
    EScreenOrientation styOrientation = EScreenOrientation.VERTIAL;
    private String userId;
    private String uuid;

    /* access modifiers changed from: private */
    public enum EScreenOrientation {
        VERTIAL,
        HORIZONTAL
    }

    public String getUserId() {
        return this.userId;
    }

    public void setUserId(String userId2) {
        this.userId = userId2;
    }

    @Override // net.ossrs.yasea.SrsEncodeHandler.SrsEncodeListener
    public void onNetworkWeak() {
    }

    @Override // net.ossrs.yasea.SrsEncodeHandler.SrsEncodeListener
    public void onNetworkResume() {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1102, "onNetworkResume"));
    }

    @Override // net.ossrs.yasea.SrsEncodeHandler.SrsEncodeListener
    public void onEncodeIllegalArgumentException(IllegalArgumentException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, Integer.valueOf((int) TXLiveConstants.PUSH_WARNING_VIDEO_ENCODE_FAIL), e.getMessage()));
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordPause() {
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordResume() {
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordStarted(String msg) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1004, msg));
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordFinished(String msg) {
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordIllegalArgumentException(IllegalArgumentException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1303, e.getMessage()));
    }

    @Override // net.ossrs.yasea.SrsRecordHandler.SrsRecordListener
    public void onRecordIOException(IOException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3005, e.getMessage()));
    }

    public LivePusher(IWebview pWebview, JSONArray style) {
        super(pWebview.getContext());
        setUserId(style.optString(1));
        this.uuid = style.optString(0);
        this.arr = style.optJSONArray(2);
        JSONObject optJSONObject = style.optJSONObject(3);
        this.options = optJSONObject;
        this.position = JSONUtil.getString(optJSONObject, "position");
        this.mainView = new LinearLayout(pWebview.getContext()) {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass1 */
            Paint paint = new Paint();

            /* access modifiers changed from: protected */
            public void onDraw(Canvas canvas) {
                super.onDraw(canvas);
            }
        };
        SrsCameraView srsCameraView = new SrsCameraView(pWebview.getContext(), null);
        this.cameraView = srsCameraView;
        srsCameraView.setCameraId(0);
        setMainView(this.mainView);
        this.eventCallBacks = new HashMap<>();
        this.cameraContainerView = new LinearLayout(getContext());
    }

    public void initLivePusher(IWebview pWebViewImpl, JSONArray array) {
        int cameraWidth;
        int cameraHeight;
        this.initWebview = pWebViewImpl;
        try {
            if (this.arr == null || this.arr.length() <= 0) {
                this.isFromCreate = true;
                JSONArray jSONArray = new JSONArray();
                this.arr = jSONArray;
                jSONArray.put(0, JSONUtil.getString(this.options, "left"));
                this.arr.put(1, JSONUtil.getString(this.options, "top"));
                this.arr.put(2, JSONUtil.getString(this.options, "width"));
                this.arr.put(3, JSONUtil.getString(this.options, "height"));
            }
            if (this.options != null) {
                setOptions(null, this.options);
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
        Rect dvc = getRect(pWebViewImpl, this.arr);
        if (this.cacheCameraWidth < 99 || this.cacheCameraHeight < 99) {
            if (dvc.width() % 2 == 0) {
                cameraWidth = dvc.width();
            } else {
                cameraWidth = dvc.width() - 1;
            }
            if (dvc.height() % 2 == 0) {
                cameraHeight = dvc.height();
            } else {
                cameraHeight = dvc.height() - 1;
            }
            this.cacheCameraWidth = cameraWidth;
            this.cacheCameraHeight = cameraHeight;
        }
        if (dvc.width() != 0 && dvc.height() != 0) {
            this.mainView.removeView(this.cameraContainerView);
            this.mainView.addView(this.cameraContainerView, new LinearLayout.LayoutParams(dvc.width(), dvc.height()));
            this._lp = (AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, dvc.width(), dvc.height());
            SrsCameraView srsCameraView = this.cameraView;
            if (srsCameraView == null) {
                SrsCameraView srsCameraView2 = new SrsCameraView(pWebViewImpl.getContext(), null);
                this.cameraView = srsCameraView2;
                if (srsCameraView2.getParent() == null) {
                    this.cameraContainerView.addView(this.cameraView, this._lp);
                }
                SrsPublisher srsPublisher = new SrsPublisher(this.cameraView);
                this.mPublisher = srsPublisher;
                srsPublisher.setEncodeHandler(new SrsEncodeHandler(this));
                this.mPublisher.setRtmpHandler(new RtmpHandler(this));
                this.mPublisher.setRecordHandler(new SrsRecordHandler(this));
            } else if (this.mPublisher == null) {
                if (srsCameraView.getParent() == null) {
                    this.cameraContainerView.addView(this.cameraView, this._lp);
                }
                SrsPublisher srsPublisher2 = new SrsPublisher(this.cameraView);
                this.mPublisher = srsPublisher2;
                srsPublisher2.setEncodeHandler(new SrsEncodeHandler(this));
                this.mPublisher.setRtmpHandler(new RtmpHandler(this));
                this.mPublisher.setRecordHandler(new SrsRecordHandler(this));
            }
            if (this.styOrientation == EScreenOrientation.HORIZONTAL) {
                this.mPublisher.setPreviewResolution(this._lp.width, this._lp.height);
                this.mPublisher.setOutputResolution(this.cacheCameraWidth, this.cacheCameraHeight);
                this.mPublisher.setVideoHDMode();
            } else {
                this.mPublisher.setPreviewResolution(this.cacheCameraWidth, this.cacheCameraHeight);
                int pHeight = this.mPublisher.getPreviewWidth();
                int pWidth = this.mPublisher.getPreviewHeight();
                this.cameraContainerView.removeView(this.cameraView);
                float heightRadioNeed = ((float) this._lp.height) / ((float) pHeight);
                float widthRadioNeed = ((float) this._lp.width) / ((float) pWidth);
                float needScaleRadio = heightRadioNeed > widthRadioNeed ? heightRadioNeed : widthRadioNeed;
                AbsoluteLayout.LayoutParams layoutParams = (AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, (int) (((float) pWidth) * needScaleRadio), (int) (((float) pHeight) * needScaleRadio));
                this._lp = layoutParams;
                this.cameraContainerView.addView(this.cameraView, layoutParams);
                this.mPublisher.setOutputResolution(this.cacheCameraWidth, this.cacheCameraHeight);
                this.mPublisher.setVideoHDMode();
            }
            this.mPublisher.startCamera();
            this.mPublisher.resumeRecord();
            if (this.bautoFocus) {
                this.cameraView.setOnTouchListener(new View.OnTouchListener() {
                    /* class io.dcloud.media.live.push.LivePusher.AnonymousClass2 */

                    public boolean onTouch(View v, MotionEvent event) {
                        LivePusher.focusOnTouch(LivePusher.this.cameraView);
                        return false;
                    }
                });
            }
            this.isInited = true;
            if (!this.isFromCreate) {
                pWebViewImpl.addFrameItem(this, this._lp);
            }
        }
    }

    public void preview(IWebview pwebview) {
        if (!this.isInited) {
            initLivePusher(pwebview, null);
        }
        this.startPreview = true;
        if (this.bOpenCamera) {
            this.cameraView.setBackgroundColor(0);
            this.mPublisher.startCamera();
        }
    }

    private Rect getRect(IWebview pWebViewImpl, JSONArray arr2) {
        ViewRect webParentViewRect = ((AdaFrameItem) pWebViewImpl.obtainFrameView()).obtainFrameOptions();
        float s = pWebViewImpl.getScale();
        Rect dvc = new Rect();
        int _w = PdrUtil.convertToScreenInt(JSONUtil.getString(arr2, 2), webParentViewRect.width, webParentViewRect.width, s);
        int _h = PdrUtil.convertToScreenInt(JSONUtil.getString(arr2, 3), webParentViewRect.height, webParentViewRect.height, s);
        dvc.left = PdrUtil.convertToScreenInt(JSONUtil.getString(arr2, 0), webParentViewRect.width, 0, s);
        dvc.top = PdrUtil.convertToScreenInt(JSONUtil.getString(arr2, 1), webParentViewRect.height, 0, s);
        dvc.right = dvc.left + _w;
        dvc.bottom = dvc.top + _h;
        this.pusherHeight = _h;
        this.pusherWidth = _w;
        updateViewRect((AdaFrameItem) pWebViewImpl.obtainFrameView(), new int[]{dvc.left, dvc.top, dvc.width(), dvc.height()}, new int[]{webParentViewRect.width, webParentViewRect.height});
        return dvc;
    }

    public void appendLivePusher(String positions, IFrameView frameView) {
        if (!(obtainMainView() == null || obtainMainView().getParent() == null)) {
            removeFromFrame();
        }
        IWebview obtainWebView = frameView.obtainWebView();
        this.initWebview = obtainWebView;
        Rect dvc = getRect(obtainWebView, this.arr);
        AbsoluteLayout.LayoutParams layoutParams = (AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, dvc.width(), dvc.height());
        this._lp = layoutParams;
        if (!this.isFromCreate) {
            this.initWebview.addFrameItem(this, layoutParams);
        } else if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.position)) {
            this.initWebview.obtainFrameView().addFrameItem(this, this._lp);
        } else {
            this.initWebview.addFrameItem(this, this._lp);
        }
    }

    public void removeFromFrame() {
        if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.position)) {
            this.initWebview.obtainFrameView().removeFrameItem(this);
        } else {
            this.initWebview.removeFrameItem(this);
        }
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onResize() {
        if (!this.isRegisterResize) {
            super.onResize();
            Rect dvc = getRect(this.initWebview, this.arr);
            this.mainView.setLayoutParams((AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, dvc.width(), dvc.height()));
            setOrientation();
        }
    }

    public void resize(IWebview pWebview, JSONArray objarray) {
        Rect dvc = getRect(pWebview, objarray.optJSONArray(1));
        this.mainView.setLayoutParams((AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, dvc.width(), dvc.height()));
        this.isRegisterResize = true;
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x003b  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x006b  */
    private void setResolution(String resolution) {
        char c;
        int hashCode = resolution.hashCode();
        if (hashCode != 2300) {
            if (hashCode != 2641) {
                if (hashCode == 69570 && resolution.equals("FHD")) {
                    c = 0;
                    if (c != 0) {
                        changeMode(LogType.UNEXP_ANR, TXEAudioDef.TXE_OPUS_SAMPLE_NUM, 720);
                        return;
                    } else if (c != 1) {
                        if (c != 2) {
                            changeMode(LogType.UNEXP_ANR, TXEAudioDef.TXE_OPUS_SAMPLE_NUM, 720);
                            return;
                        } else {
                            changeMode(640, GlMapUtil.DEVICE_DISPLAY_DPI_XHIGH, 368);
                            return;
                        }
                    } else if (this.aspect.equals("3:4")) {
                        this.cacheCameraWidth = GlMapUtil.DEVICE_DISPLAY_DPI_XHIGH;
                        this.cacheCameraHeight = 640;
                        return;
                    } else if (this.aspect.equals("9:16")) {
                        this.cacheCameraWidth = GlMapUtil.DEVICE_DISPLAY_DPI_XHIGH;
                        this.cacheCameraHeight = 720;
                        return;
                    } else {
                        return;
                    }
                }
            } else if (resolution.equals("SD")) {
                c = 2;
                if (c != 0) {
                }
            }
        } else if (resolution.equals("HD")) {
            c = 1;
            if (c != 0) {
            }
        }
        c = 65535;
        if (c != 0) {
        }
    }

    private void changeMode(int height16, int height4, int width) {
        if (this.aspect.equals("3:4")) {
            this.cacheCameraHeight = height4;
            this.cacheCameraWidth = width;
        } else if (this.aspect.equals("9:16")) {
            this.cacheCameraHeight = height16;
            this.cacheCameraWidth = width;
        }
    }

    public void setOptions(IWebview pwebview, JSONObject jsonObject) {
        this.options = JSONUtil.combinJSONObject(this.options, jsonObject);
        if (jsonObject.has("top") || jsonObject.has("left") || jsonObject.has("width") || jsonObject.has("height") || jsonObject.has("position")) {
            String mPosition = JSONUtil.getString(jsonObject, "position");
            try {
                this.arr.put(0, JSONUtil.getString(jsonObject, "left"));
                this.arr.put(1, JSONUtil.getString(jsonObject, "top"));
                this.arr.put(2, JSONUtil.getString(jsonObject, "width"));
                this.arr.put(3, JSONUtil.getString(jsonObject, "height"));
            } catch (JSONException e) {
            }
            Rect dvc = getRect(this.initWebview, this.arr);
            this._lp = (AbsoluteLayout.LayoutParams) AdaFrameItem.LayoutParamsUtil.createLayoutParams(dvc.left, dvc.top, dvc.width(), dvc.height());
            if (jsonObject.has("position")) {
                if (mPosition.equals(this.position)) {
                    obtainMainView().setLayoutParams(this._lp);
                } else if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.position)) {
                    this.initWebview.obtainFrameView().removeFrameItem(this);
                    this.initWebview.addFrameItem(this, this._lp);
                } else if ("static".equals(this.position)) {
                    this.initWebview.removeFrameItem(this);
                    this.initWebview.obtainFrameView().addFrameItem(this, this._lp);
                }
                this.position = mPosition;
            } else {
                obtainMainView().setLayoutParams(this._lp);
            }
        }
        JSONObject jSONObject = this.options;
        if (jSONObject != null) {
            this.rtmpULR = jSONObject.optString("url");
            this.bSilence = this.options.optBoolean("mute", false);
            boolean optBoolean = this.options.optBoolean("enable-camera", true);
            this.bOpenCamera = optBoolean;
            SrsCameraView srsCameraView = this.cameraView;
            if (srsCameraView != null) {
                if (!optBoolean) {
                    srsCameraView.setBackgroundColor(-16777216);
                } else {
                    srsCameraView.setBackgroundColor(0);
                }
            }
            this.bautoFocus = this.options.optBoolean("auto-focus", true);
            String orientation = this.options.optString("orientation");
            if (orientation == null || !orientation.equalsIgnoreCase("HORIZONTAL")) {
                this.styOrientation = EScreenOrientation.VERTIAL;
            } else {
                this.styOrientation = EScreenOrientation.HORIZONTAL;
            }
            this.bBeauty = this.options.optInt("beauty", 0);
            this.bWhiteness = this.options.optInt("whiteness", 0);
            if (this.mPublisher != null) {
                new Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                    /* class io.dcloud.media.live.push.LivePusher.AnonymousClass3 */

                    public void run() {
                        if (LivePusher.this.bWhiteness < 1 && LivePusher.this.bBeauty < 1) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.NONE);
                        }
                        if (LivePusher.this.bWhiteness > 0) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.WHITECAT, LivePusher.this.bWhiteness);
                        }
                        if (LivePusher.this.bBeauty > 0) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.BEAUTY);
                        }
                    }
                }, 1000);
            }
            String optString = this.options.optString("aspect", "3:4");
            this.aspect = optString;
            if (optString.equals("16:9")) {
                this.aspect = "9:16";
            } else {
                this.aspect = "3:4";
            }
            String upperCase = this.options.optString("mode", "FUD").toUpperCase();
            this.mode = upperCase;
            setResolution(upperCase);
        }
    }

    public void addEventListener(IWebview pwebview, JSONArray array) {
        array.optString(1);
        String event = array.optString(2);
        String callBackId = array.optString(3);
        HashMap<String, IWebview> callbacks = this.eventCallBacks.get(event);
        if (callbacks == null) {
            callbacks = new HashMap<>();
        }
        callbacks.put(callBackId, pwebview);
        this.eventCallBacks.put(event, callbacks);
    }

    public static void focusOnTouch(SrsCameraView cameraView2) {
        if (cameraView2 != null && cameraView2.getCamera() != null) {
            Camera.Parameters parameters = cameraView2.getCamera().getParameters();
            if (!parameters.getFocusMode().equals("auto") && parameters.getSupportedFocusModes() != null && parameters.getSupportedFocusModes().contains("auto")) {
                parameters.setFocusMode("auto");
                cameraView2.getCamera().setParameters(parameters);
            }
            cameraView2.getCamera().cancelAutoFocus();
            cameraView2.getCamera().autoFocus(new Camera.AutoFocusCallback() {
                /* class io.dcloud.media.live.push.LivePusher.AnonymousClass4 */

                public void onAutoFocus(boolean success, Camera camera) {
                    Camera.Parameters parameters = camera.getParameters();
                    camera.cancelAutoFocus();
                    if (parameters.getFocusMode() != "continuous-picture" && parameters.getSupportedFocusModes() != null && parameters.getSupportedFocusModes().contains("continuous-picture")) {
                        parameters.setFocusMode("continuous-picture");
                        camera.setParameters(parameters);
                    }
                }
            });
        }
    }

    public void start(IWebview pWebView, JSONArray array) {
        this.startCallbackID = array.optString(1);
        this.startWebview = pWebView;
        SrsPublisher srsPublisher = this.mPublisher;
        if (srsPublisher != null) {
            boolean z = this.bOpenCamera;
            if (!z) {
                srsPublisher.setSendAudioOnly(z);
            } else {
                boolean z2 = this.bSilence;
                if (z2) {
                    srsPublisher.setSendVideoOnly(z2);
                }
            }
            if (this.rtmpUrlPattern.matcher(this.rtmpULR).matches()) {
                if (this.bOpenCamera) {
                    this.cameraView.setBackgroundColor(0);
                    this.mPublisher.startPublish(this.rtmpULR);
                    this.mPublisher.startCamera();
                } else {
                    this.cameraView.setBackgroundColor(-16777216);
                    this.mPublisher.stopCamera();
                    this.mPublisher.startAudio();
                    this.mPublisher.startPublish(this.rtmpULR);
                }
                new Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                    /* class io.dcloud.media.live.push.LivePusher.AnonymousClass5 */

                    public void run() {
                        if (LivePusher.this.bWhiteness < 1 && LivePusher.this.bBeauty < 1) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.NONE);
                        }
                        if (LivePusher.this.bWhiteness > 0) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.WHITECAT, LivePusher.this.bWhiteness);
                        }
                        if (LivePusher.this.bBeauty > 0) {
                            LivePusher.this.mPublisher.switchCameraFilter(MagicFilterType.BEAUTY);
                        }
                    }
                }, 1000);
                return;
            }
            if (!this.startPreview) {
                this.mPublisher.stopCamera();
                this.cameraView.setBackgroundColor(-16777216);
            }
            try {
                JSUtil.execCallback(pWebView, this.startCallbackID, new JSONObject("{code:1,message:'rtmp url invalable'}"), JSUtil.ERROR, false);
            } catch (Exception e) {
            }
        }
    }

    private void setOrientation() {
        int rotation = this.initWebview.getActivity().getWindowManager().getDefaultDisplay().getRotation();
        if (rotation == 0) {
            this.cameraView.getCamera().setDisplayOrientation(0);
        } else if (rotation == 1) {
            this.cameraView.getCamera().setDisplayOrientation(270);
        } else if (rotation == 2) {
            this.cameraView.getCamera().setDisplayOrientation(180);
        } else if (rotation == 3) {
            this.cameraView.getCamera().setDisplayOrientation(90);
        }
    }

    public void resume(IWebview pWebView, JSONArray array) {
        SrsPublisher srsPublisher = this.mPublisher;
        if (srsPublisher != null) {
            try {
                srsPublisher.resumePublish();
            } catch (Exception e) {
            }
        }
    }

    public void pause(IWebview pWebView, JSONArray array) {
        SrsPublisher srsPublisher = this.mPublisher;
        if (srsPublisher != null) {
            srsPublisher.pausePublish();
        }
    }

    public void stop(IWebview pWebView, JSONObject array) {
        if (array != null) {
            this.stopPreview = array.optBoolean("preview", false);
        }
        SrsPublisher srsPublisher = this.mPublisher;
        if (srsPublisher != null) {
            srsPublisher.stopPublish();
            this.onStoped = true;
        }
    }

    public void destory(String pusherID) {
        this.curPusherID = pusherID;
        this.mPublisher.stopPublish();
        try {
            this.listener.onRtmpStopped(this.curPusherID);
        } catch (Exception e) {
        }
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void dispose() {
        super.dispose();
        stop(null, null);
        SrsPublisher srsPublisher = this.mPublisher;
        if (srsPublisher != null) {
            srsPublisher.stopPublish();
        }
        destory(this.uuid);
        OrientationEventListener orientationEventListener = this.moel;
        if (orientationEventListener != null) {
            orientationEventListener.disable();
        }
    }

    public void setStatusListener(LivePusherStateListener statelistener) {
        this.listener = statelistener;
    }

    public void switchCamera(IWebview pWebView, JSONArray array) {
        SrsPublisher srsPublisher = this.mPublisher;
        srsPublisher.switchCameraFace((srsPublisher.getCameraId() + 1) % Camera.getNumberOfCameras());
    }

    public void snapshot(final IWebview pWebView, JSONArray array) {
        final String callBackID = array.optString(1);
        final String filepath = pWebView.obtainFrameView().obtainApp().obtainAppDocPath().concat(getImageFileName());
        File parentFile = new File(filepath).getParentFile();
        if (!parentFile.exists()) {
            parentFile.mkdirs();
        }
        this.cameraView.getCamera().takePicture(new Camera.ShutterCallback() {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass6 */

            public void onShutter() {
            }
        }, new Camera.PictureCallback() {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass7 */

            public void onPictureTaken(byte[] data, Camera camera) {
            }
        }, new Camera.PictureCallback() {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass8 */

            public void onPictureTaken(byte[] data, Camera camera) {
                int errorCode = 1;
                String errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_media_livepusher_error_screen_capture);
                if (data != null) {
                    Bitmap bitmap = BitmapFactory.decodeByteArray(data, 0, data.length);
                    if (bitmap != null) {
                        LivePusher.this.saveImg(bitmap, filepath, pWebView, callBackID);
                        LivePusher.this.mPublisher.startCamera();
                        return;
                    }
                    errorCode = 2;
                    errorMessage = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_media_livepusher_error_screen_data_convert_fail);
                }
                Deprecated_JSUtil.execCallback(pWebView, callBackID, StringUtil.format("{code:\"%\",message:\"\"}", Integer.valueOf(errorCode), errorMessage), JSUtil.ERROR, false, false);
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void saveImg(final Bitmap bitmap, final String filepath, final IWebview pWebView, final String callBackID) {
        new Thread(new Runnable() {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass9 */

            public void run() {
                Bitmap finalBitmap = LivePusher.this.rotateBitmap(bitmap);
                Deprecated_JSUtil.execCallback(pWebView, callBackID, StringUtil.format("{width:\"%d\",height:\"%d\",tempImagePath:\"%s\"}", Integer.valueOf(finalBitmap.getWidth()), Integer.valueOf(finalBitmap.getHeight()), LivePusher.saveBitmap(finalBitmap, filepath)), JSUtil.OK, true, false);
                bitmap.recycle();
                finalBitmap.recycle();
            }
        }).start();
    }

    public Bitmap rotateBitmap(Bitmap bitmap) {
        if (this.cameraView.getCameraId() == 0) {
            this.oritation += AMapEngineUtils.MIN_LONGITUDE_DEGREE;
        }
        if (this.oritation == 0 || bitmap == null) {
            return bitmap;
        }
        Matrix matrix = new Matrix();
        matrix.setRotate((float) this.oritation, (float) (bitmap.getWidth() / 2), (float) (bitmap.getHeight() / 2));
        Bitmap bmp = Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, true);
        if (bitmap != null) {
            bitmap.recycle();
        }
        return bmp;
    }

    private static String getImageFileName() {
        return new SimpleDateFormat("/yyyy-MM-dd-HH-mm-ss-SSS").format(new Date()).concat(".jpg");
    }

    /* access modifiers changed from: private */
    public static String saveBitmap(Bitmap mBitmap, String savePath) {
        try {
            File filePic = new File(savePath);
            if (!filePic.exists()) {
                filePic.getParentFile().mkdirs();
                filePic.createNewFile();
            }
            FileOutputStream fos = new FileOutputStream(filePic);
            mBitmap.compress(Bitmap.CompressFormat.JPEG, 100, fos);
            fos.flush();
            fos.close();
            return filePic.getAbsolutePath();
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpConnecting(String msg) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1001, msg));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpConnected(String msg) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1002, msg));
        String str = this.startCallbackID;
        if (str != null) {
            JSUtil.execCallback(this.startWebview, str, "", JSUtil.OK, false);
            this.startCallbackID = null;
            this.startWebview = null;
        }
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpVideoStreaming() {
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpAudioStreaming() {
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpStopped() {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 1001, "onRtmpStopped"));
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            /* class io.dcloud.media.live.push.LivePusher.AnonymousClass10 */

            public void run() {
                if (LivePusher.this.onStoped) {
                    try {
                        if (!LivePusher.this.stopPreview) {
                            LivePusher.this.cameraView.setBackgroundColor(-16777216);
                        }
                        LivePusher.this.onStoped = false;
                    } catch (Exception e) {
                    }
                }
                try {
                    LivePusher.this.listener.onRtmpStopped(LivePusher.this.curPusherID);
                    LivePusher.this.cameraView.setBackgroundColor(-16777216);
                } catch (Exception e2) {
                }
            }
        });
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpDisconnected() {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3004, "RtmpDisconnected"));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpVideoFpsChanged(double fps) {
        this.curFps = fps;
        statusEventListener("netstatus", StringUtil.format("{fps:%.0f,bitrate:%d,totalsize:%d}", Double.valueOf(fps), Integer.valueOf(this.curBitrate), Long.valueOf(this.curTotalSize)));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpVideoBitrateChanged(double bitrate) {
        this.curBitrate = (int) bitrate;
        statusEventListener("netstatus", StringUtil.format("{fps:%.0f,bitrate:%d,totalsize:%d}", Double.valueOf(this.curFps), Integer.valueOf(this.curBitrate), Long.valueOf(this.curTotalSize)));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpAudioBitrateChanged(double bitrate) {
        this.curBitrate = (int) bitrate;
        statusEventListener("netstatus", StringUtil.format("{fps:%.0f,bitrate:%d,totalsize:%d}", Double.valueOf(this.curFps), Integer.valueOf(this.curBitrate), Long.valueOf(this.curTotalSize)));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpSocketException(SocketException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3002, e.toString()));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpIOException(IOException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3003, e.toString()));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpIllegalArgumentException(IllegalArgumentException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3004, e.toString()));
    }

    @Override // com.github.faucamp.simplertmp.RtmpHandler.RtmpListener
    public void onRtmpIllegalStateException(IllegalStateException e) {
        statusEventListener("statechange", StringUtil.format(EVENT_RESULT_TEMPLATE, 3005, e.toString()));
    }

    private void statusEventListener(String event, String message) {
        if (this.eventCallBacks.containsKey(event)) {
            HashMap<String, IWebview> callBacks = this.eventCallBacks.get(event);
            for (String key : callBacks.keySet()) {
                if (callBacks.get(key) instanceof AdaUniWebView) {
                    EVENT_TEMPLATE = "plus.__Media_Live__Push__.execCallback_LivePush('%s', %s,'%s');";
                } else {
                    EVENT_TEMPLATE = "window.__Media_Live__Push__.execCallback_LivePush('%s', %s,'%s');";
                }
                callBacks.get(key).executeScript(StringUtil.format(EVENT_TEMPLATE, event, message, key));
            }
        }
    }
}
