package io.dcloud.media.video;

import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IFrameView;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaFrameItem;
import io.dcloud.common.adapter.util.ViewRect;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.media.video.ijkplayer.VideoPlayerView;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DHVideoFrameItem extends AdaFrameItem implements ISysEventListener {
    private ViewGroup.LayoutParams _vlps;
    private boolean isRegisterResize = false;
    private IWebview mAppendWebview = null;
    private IWebview mContenterView = null;
    private IWebview mIWebview;
    private String mId;
    private VideoPlayerView mPlayerView;
    public String position = "static";
    private JSONArray rect = null;
    private long resumeTime = 0;
    private JSONObject styles = null;
    private String userId;

    public void removeFrameItem() {
        if (this.position.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
            this.mContenterView.obtainFrameView().removeFrameItem(this);
        } else {
            this.mContenterView.removeFrameItem(this);
        }
    }

    protected DHVideoFrameItem(Context pContext, String id, IWebview pWebview, JSONArray rectJa, JSONObject style, String userId2) {
        super(pContext);
        this.mIWebview = pWebview;
        this.mContenterView = pWebview;
        this.mId = id;
        this.userId = userId2;
        this.rect = rectJa;
        this.styles = style;
        IApp app = pWebview.obtainFrameView().obtainApp();
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onPause);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onResume);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onStop);
        app.registerSysEventListener(this, ISysEventListener.SysEventType.onKeyUp);
        VideoPlayerView videoPlayerView = new VideoPlayerView(this.mIWebview.getActivity(), pWebview, this.styles);
        this.mPlayerView = videoPlayerView;
        setMainView(videoPlayerView);
        initFrame(this.rect);
        this.position = this.styles.optString("position");
    }

    private void initFrame(JSONArray rect2) {
        ViewRect webParentViewRect = ((AdaFrameItem) this.mContenterView.obtainFrameView()).obtainFrameOptions();
        float scale = this.mContenterView.getScale();
        int _w = PdrUtil.convertToScreenInt(JSONUtil.getString(rect2, 2), webParentViewRect.width, webParentViewRect.width, scale, true);
        int _h = PdrUtil.convertToScreenInt(JSONUtil.getString(rect2, 3), webParentViewRect.height, webParentViewRect.height, scale, true);
        int _l = PdrUtil.convertToScreenInt(JSONUtil.getString(rect2, 0), webParentViewRect.width, 0, scale, true);
        int _t = PdrUtil.convertToScreenInt(JSONUtil.getString(rect2, 1), webParentViewRect.height, 0, scale, true);
        updateViewRect((AdaFrameItem) this.mContenterView.obtainFrameView(), new int[]{_l, _t, _w, _h}, new int[]{webParentViewRect.width, webParentViewRect.height});
        this._vlps = AdaFrameItem.LayoutParamsUtil.createLayoutParams(_l, _t, _w, _h);
        this.mPlayerView.setRect(new int[]{_l, _t, _w + _l, _h + _t});
    }

    public String getUserId() {
        return this.userId;
    }

    public String getmId() {
        return this.mId;
    }

    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void dispose() {
        super.dispose();
        release();
        VideoPlayerMgr.getInstance().rmovePlayer(this.mId);
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        VideoPlayerView videoPlayerView;
        if (pEventType == ISysEventListener.SysEventType.onPause) {
            if (System.currentTimeMillis() - this.resumeTime > 100) {
                pause();
                this.resumeTime = 0;
            }
            return true;
        } else if (pEventType == ISysEventListener.SysEventType.onResume) {
            if (this.resumeTime > 0) {
                resume();
            }
            this.resumeTime = System.currentTimeMillis();
            return true;
        } else if (pEventType == ISysEventListener.SysEventType.onStop) {
            release();
            return true;
        } else if (pEventType != ISysEventListener.SysEventType.onKeyUp || ((Integer) ((Object[]) pArgs)[0]).intValue() != 4 || !isFullScreen() || (videoPlayerView = this.mPlayerView) == null) {
            return false;
        } else {
            return videoPlayerView.onBackPressed();
        }
    }

    public void play() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.play();
        }
    }

    public void pause() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.pause();
        }
    }

    public void resume() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.resume();
        }
    }

    public void seek(String position2) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.seek(position2);
        }
    }

    public void sendDanmu(JSONObject danmu) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.sendDanmu(danmu);
        }
    }

    public void sendPlayBackRate(String rate) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.playbackRate(rate);
        }
    }

    public void playbackRate(String rate) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.playbackRate(rate);
        }
    }

    public void requestFullScreen(String direction) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.requestFullScreen(direction);
        }
    }

    public void exitFullScreen() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.exitFullScreen();
        }
    }

    public void setOptions(JSONObject options) {
        if (this.mPlayerView != null) {
            this.styles = JSONUtil.combinJSONObject(this.styles, options);
            if (this.mPlayerView.isFullScreen()) {
                try {
                    JSONObject fullscreenStyle = new JSONObject(this.styles.toString());
                    fullscreenStyle.remove("top");
                    fullscreenStyle.remove("left");
                    fullscreenStyle.remove("width");
                    fullscreenStyle.remove("height");
                    fullscreenStyle.remove("position");
                    this.mPlayerView.setOptions(fullscreenStyle);
                } catch (JSONException e) {
                }
            } else {
                if (options.has("top") || options.has("left") || options.has("width") || options.has("height") || options.has("position")) {
                    try {
                        this.rect.put(0, JSONUtil.getString(options, "left"));
                        this.rect.put(1, JSONUtil.getString(options, "top"));
                        this.rect.put(2, JSONUtil.getString(options, "width"));
                        this.rect.put(3, JSONUtil.getString(options, "height"));
                    } catch (JSONException e2) {
                    }
                    String mPosition = JSONUtil.getString(options, "position");
                    initFrame(this.rect);
                    if (options.has("position")) {
                        if (mPosition.equals(this.position)) {
                            obtainMainView().setLayoutParams(this._vlps);
                        } else if (AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE.equals(this.position)) {
                            this.mContenterView.obtainFrameView().removeFrameItem(this);
                            this.mContenterView.addFrameItem(this, this._vlps);
                        } else if ("static".equals(this.position)) {
                            this.mContenterView.removeFrameItem(this);
                            this.mContenterView.obtainFrameView().addFrameItem(this, this._vlps);
                        }
                        this.position = mPosition;
                    } else {
                        obtainMainView().setLayoutParams(this._vlps);
                    }
                }
                this.mPlayerView.setOptions(this.styles);
            }
        }
    }

    public void addEventListener(String event, String callbackId, String webId) {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.addEventListener(event, callbackId, webId);
        }
    }

    public void release() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.release();
            this.mPlayerView = null;
        }
    }

    public boolean isFullScreen() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            return videoPlayerView.isFullScreen();
        }
        return false;
    }

    public void stop() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.stop();
        }
    }

    public void close() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.close();
        }
    }

    public void hidden() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.setVisibility(4);
        }
    }

    public void show() {
        VideoPlayerView videoPlayerView = this.mPlayerView;
        if (videoPlayerView != null) {
            videoPlayerView.setVisibility(0);
        }
    }

    public void appendToFrame(IFrameView mFrameView) {
        View mainView = obtainMainView();
        if (!(mainView == null || mainView.getParent() == null)) {
            removeFrameItem();
        }
        this.mContenterView = mFrameView.obtainWebView();
        initFrame(this.rect);
        if (this.position.equals("static")) {
            this.mContenterView.addFrameItem(this, this._vlps);
        } else if (this.position.equals(AbsoluteConst.JSON_VALUE_POSITION_ABSOLUTE)) {
            this.mContenterView.obtainFrameView().addFrameItem(this, this._vlps);
        } else {
            this.mContenterView.addFrameItem(this, this._vlps);
        }
    }

    /* access modifiers changed from: protected */
    @Override // io.dcloud.common.adapter.ui.AdaFrameItem
    public void onResize() {
        if (!this.isRegisterResize) {
            super.onResize();
            initFrame(this.rect);
            obtainMainView().setLayoutParams(this._vlps);
        }
    }

    public void resize(JSONArray pJsArgs) {
        initFrame(pJsArgs);
        obtainMainView().setLayoutParams(this._vlps);
        this.isRegisterResize = true;
    }
}
