package io.dcloud.media.video.ijkplayer;

import android.app.Activity;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.FrameLayout;
import com.bumptech.glide.Glide;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.IVideoPlayer;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.media.video.VideoPlayerMgr;
import io.dcloud.media.video.ijkplayer.media.IjkPlayerView;
import io.dcloud.media.video.ijkplayer.option.EnumPlayStrategy;
import java.util.HashMap;
import org.json.JSONObject;
import tv.danmaku.ijk.media.player.IMediaPlayer;

public class VideoPlayerView extends FrameLayout implements IVideoPlayer {
    public JSONObject fullScreenOptions = null;
    private boolean isAutoPlay = false;
    private boolean isLoopPlay = false;
    private HashMap<String, HashMap<String, String>> mCallbacks;
    private String mHeaderInfo;
    private IWebview mIWebview;
    private JSONObject mOptions;
    private IjkPlayerView mPlayerView;
    private String mPosterUrl;
    private String mUrl;
    private int[] rect;
    public boolean videoHandleTouch = false;

    public void setFullScreenOptions(JSONObject fullScreenOptions2) {
        this.fullScreenOptions = fullScreenOptions2;
    }

    public VideoPlayerView(Activity context, IWebview webview, JSONObject style) {
        super(context);
        this.mIWebview = webview;
        IjkPlayerView ijkPlayerView = new IjkPlayerView(context, null, this);
        this.mPlayerView = ijkPlayerView;
        addView(ijkPlayerView, new FrameLayout.LayoutParams(-1, -1));
        this.mCallbacks = new HashMap<>();
        this.mPlayerView.init().setPlayerRootView(this);
        this.mPlayerView.setOnInfoListener(new IMediaPlayer.OnInfoListener() {
            /* class io.dcloud.media.video.ijkplayer.VideoPlayerView.AnonymousClass1 */

            @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnInfoListener
            public boolean onInfo(IMediaPlayer iMediaPlayer, int status, int extra) {
                if (VideoPlayerView.this.mIWebview.obtainApp() == null) {
                    return false;
                }
                if (status == 336) {
                    VideoPlayerView.this.statusChanged("ended", "");
                    if (VideoPlayerView.this.isLoopPlay) {
                        int seek = VideoPlayerView.this.mOptions.optInt("initial-time");
                        if (seek > 0) {
                            VideoPlayerView.this.mPlayerView.seekTo(seek * 1000);
                        }
                        VideoPlayerView.this.play();
                    }
                } else if (status == 334) {
                    VideoPlayerView.this.statusChanged(Constants.Value.PLAY, "");
                } else if (status == 335) {
                    VideoPlayerView.this.statusChanged("pause", "");
                } else if (status == 331) {
                    VideoPlayerView.this.statusChanged("error", "");
                } else if (status == 332 || status == 701) {
                    VideoPlayerView.this.statusChanged(IApp.ConfigProperty.CONFIG_WAITING, "");
                } else if (status == 337) {
                    VideoPlayerView videoPlayerView = VideoPlayerView.this;
                    Object[] objArr = new Object[1];
                    objArr[0] = Integer.valueOf(videoPlayerView.mPlayerView != null ? VideoPlayerView.this.mPlayerView.getCurPosition() : 0);
                    videoPlayerView.statusChanged("seekcomplete", StringUtil.format("{'position':%d}", objArr));
                }
                return false;
            }
        });
        this.mPlayerView.setOnPlayerChangedListener(new OnPlayerChangedListener() {
            /* class io.dcloud.media.video.ijkplayer.VideoPlayerView.AnonymousClass2 */

            @Override // io.dcloud.media.video.ijkplayer.OnPlayerChangedListener
            public void onChanged(String type, String msg) {
                VideoPlayerView.this.statusChanged(type, msg);
            }
        });
        initOptionsPlayerView(this.mPlayerView, style);
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public boolean isVideoHandleTouch() {
        return this.videoHandleTouch;
    }

    public void initOptionsPlayerView(IjkPlayerView playerView, JSONObject options) {
        Uri fileUri;
        this.mOptions = options;
        String url = options.optString("src");
        if (!TextUtils.isEmpty(url)) {
            if (!PdrUtil.isNetPath(url)) {
                url = this.mIWebview.obtainApp().convert2AbsFullPath(this.mIWebview.obtainFullUrl(), url);
                if (url.startsWith("/android_asset")) {
                    url = url.replace("/android_asset", "");
                } else if (url.startsWith("android_asset")) {
                    url = url.replace("android_asset", "");
                }
                if (!PdrUtil.isDeviceRootDir(url) && !TextUtils.isEmpty(url)) {
                    url = this.mIWebview.obtainApp().convert2AbsFullPath(this.mIWebview.obtainFullUrl(), this.mIWebview.obtainApp().checkPrivateDirAndCopy2Temp(url));
                }
                if (!FileUtil.checkPrivatePath(getContext(), url) && (fileUri = FileUtil.getVideoFileUri(getContext(), url)) != null) {
                    url = fileUri.toString();
                }
            }
            this.isAutoPlay = this.mOptions.optBoolean(Constants.Name.AUTOPLAY, this.isAutoPlay);
            this.isLoopPlay = this.mOptions.optBoolean("loop", this.isLoopPlay);
            setPoster(this.mOptions.optString("poster"));
            if (!this.mOptions.isNull("muted")) {
                playerView.setMutePlayer(this.mOptions.optBoolean("muted", false));
            }
            boolean gestureSwitch = false;
            if (this.mOptions.optBoolean("page-gesture", false) || this.mOptions.optBoolean("vslide-gesture", false)) {
                gestureSwitch = true;
                this.videoHandleTouch = true;
            }
            playerView.setPageGesture(gestureSwitch);
            playerView.setIsFullScreenPageGesture(this.mOptions.optBoolean("vslide-gesture-in-fullscreen", true));
            playerView.setIsShowScreenLockButton(this.mOptions.optBoolean("show-screen-lock-button", false));
            playerView.setProgressVisibility(this.mOptions.optBoolean("show-progress", true));
            playerView.setFullscreenBntVisibility(this.mOptions.optBoolean("show-fullscreen-btn", true));
            playerView.setPlayBntVisibility(this.mOptions.optBoolean("show-play-btn", true));
            playerView.setIsEnableProgressGesture(this.mOptions.optBoolean("enable-progress-gesture", true));
            playerView.setmIsDoubleTapEnable(this.mOptions.optBoolean("enable-play-gesture", false));
            playerView.setLoadingVisibility(this.mOptions.optBoolean(Constants.Name.SHOW_LOADING, true));
            playerView.setDirection(this.mOptions.optInt("direction", -90));
            playerView.setmDanmuList(this.mOptions.optString("danmu-list"));
            if (this.mOptions.has("objectFit")) {
                playerView.setScaleType(this.mOptions.optString("objectFit", "contain"));
            } else if (this.mOptions.has("object-fit")) {
                playerView.setScaleType(this.mOptions.optString("object-fit", "contain"));
            }
            playerView.isMuteBtnShow(this.mOptions.optBoolean("show-mute-btn", false));
            if (this.mOptions.has("codec")) {
                playerView.isUseMediaCodec(this.mOptions.optString("codec").equals("hardware"));
            }
            if (this.mOptions.has("advanced")) {
                playerView.setCustomAdvanced(this.mOptions.optString("advanced"));
            }
            if (this.mOptions.has("httpCache")) {
                playerView.setViewHttpCacheOpen(this.mOptions.optBoolean("httpCache", false));
            }
            if (this.mOptions.has("playStrategy")) {
                int flowStrategyFlag = this.mOptions.optInt("playStrategy", EnumPlayStrategy.DEFAULT.getFlagVal());
                EnumPlayStrategy enumPlayStrategy = EnumPlayStrategy.PLAY_SMOOTH;
                if (flowStrategyFlag == EnumPlayStrategy.PLAY_SMOOTH.getFlagVal()) {
                    enumPlayStrategy = EnumPlayStrategy.PLAY_SMOOTH;
                } else if (flowStrategyFlag == EnumPlayStrategy.START_QUICK.getFlagVal()) {
                    enumPlayStrategy = EnumPlayStrategy.START_QUICK;
                } else if (flowStrategyFlag == EnumPlayStrategy.M3U8_SMOOTH.getFlagVal()) {
                    enumPlayStrategy = EnumPlayStrategy.M3U8_SMOOTH;
                } else if (flowStrategyFlag == EnumPlayStrategy.DEFAULT.getFlagVal()) {
                    enumPlayStrategy = EnumPlayStrategy.DEFAULT;
                }
                playerView.setFlowStrategy(enumPlayStrategy);
            }
            String headerInfo = options.optString("header");
            if (TextUtils.isEmpty(this.mUrl)) {
                this.mPlayerView.setVideoPath(url, headerInfo);
                resetSeek(playerView);
            } else if (!this.mUrl.equalsIgnoreCase(url) || !this.mHeaderInfo.equalsIgnoreCase(headerInfo)) {
                this.mPlayerView.switchVideoPath(url, headerInfo);
                resetSeek(playerView);
                IjkPlayerView ijkPlayerView = this.mPlayerView;
                ijkPlayerView.setMutePlayer(ijkPlayerView.isMutePlayer());
            }
            playerView.setCenterPlayBntVisibility(this.mOptions.optBoolean("show-center-play-btn", true));
            playerView.setControls(this.mOptions.optBoolean("controls", true));
            playerView.setDuration(this.mOptions.optInt("duration", -1) * 1000);
            if (options.has("title")) {
                playerView.setTitle(options.optString("title"));
            }
            this.mUrl = url;
            this.mHeaderInfo = headerInfo;
        }
    }

    public int getDirection() {
        JSONObject jSONObject = this.mOptions;
        if (jSONObject == null || !jSONObject.has("direction")) {
            return Integer.MIN_VALUE;
        }
        try {
            return Integer.parseInt(this.mOptions.optString("direction"));
        } catch (Exception e) {
            return Integer.MIN_VALUE;
        }
    }

    private void resetSeek(IjkPlayerView playerView) {
        playerView.seekTo(this.mOptions.optInt("initial-time") * 1000);
        this.mPlayerView.clearDanma();
        playerView.enableDanmaku(this.mOptions.optBoolean("enable-danmu", false));
        playerView.enableDanmuBtn(this.mOptions.optBoolean("danmu-btn", false));
        if (this.isAutoPlay) {
            play();
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void play() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.start();
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void pause() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.pause();
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void resume() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.onResume();
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void stop() {
        statusChanged(IApp.ConfigProperty.CONFIG_WAITING, "");
        if (this.mPlayerView != null && !TextUtils.isEmpty(this.mUrl)) {
            this.mPlayerView.clearDanma();
            this.mPlayerView.switchVideoPath(this.mUrl, this.mHeaderInfo);
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void close() {
        statusChanged(IApp.ConfigProperty.CONFIG_WAITING, "");
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.stop();
            this.mPlayerView.onDestroy();
            this.mPlayerView = null;
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void seek(String position) {
        int msec = Integer.parseInt(position);
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.seekTo(msec * 1000);
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void sendDanmu(JSONObject danmu) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.sendDanmaku(danmu, true);
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void playbackRate(String rate) {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.playbackRate(rate);
        }
    }

    public boolean onBackPressed() {
        return this.mPlayerView.onBackPressed();
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void requestFullScreen(String direction) {
        int orientation = Integer.parseInt(direction);
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.fullScreen(orientation);
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void exitFullScreen() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.exitFullScreen();
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void setOptions(JSONObject options) {
        if (options != null) {
            this.mPlayerView.hiddenLoaded(true);
            initOptionsPlayerView(this.mPlayerView, options);
        }
    }

    private void setPoster(String url) {
        if (!TextUtils.isEmpty(url)) {
            if (TextUtils.isEmpty(this.mPosterUrl) || !this.mPosterUrl.equalsIgnoreCase(url)) {
                Glide.with(this).load(url).into(this.mPlayerView.mPlayerThumb);
            }
            this.mPosterUrl = url;
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void addEventListener(String event, String jsCallback, String webId) {
        HashMap<String, String> callBacks = this.mCallbacks.get(event);
        if (callBacks == null) {
            callBacks = new HashMap<>();
        }
        callBacks.put(jsCallback, webId);
        this.mCallbacks.put(event, callBacks);
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public boolean isFullScreen() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            return ijkPlayerView.isFullscreen();
        }
        return false;
    }

    public boolean isPlaying() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            return ijkPlayerView.isPlaying();
        }
        return false;
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public void release() {
        IjkPlayerView ijkPlayerView = this.mPlayerView;
        if (ijkPlayerView != null) {
            ijkPlayerView.onDestroy();
            this.mPlayerView = null;
        }
    }

    @Override // io.dcloud.common.DHInterface.IVideoPlayer
    public boolean isPointInRect(float x, float y) {
        int[] iArr = this.rect;
        if (iArr == null || x <= ((float) iArr[0]) || x >= ((float) iArr[2]) || y <= ((float) iArr[1]) || y >= ((float) iArr[3])) {
            return false;
        }
        return true;
    }

    public void setRect(int[] rect2) {
        this.rect = rect2;
    }

    public void statusChanged(String type, String msg) {
        IWebview eventWebview;
        if (this.mCallbacks.containsKey(type)) {
            HashMap<String, String> callbacks = this.mCallbacks.get(type);
            for (String key : callbacks.keySet()) {
                if (PdrUtil.isEmpty(callbacks.get(key))) {
                    eventWebview = this.mIWebview;
                } else {
                    eventWebview = VideoPlayerMgr.getInstance().findWebview(this.mIWebview, callbacks.get(key));
                }
                Deprecated_JSUtil.execCallback(eventWebview, key, msg, JSUtil.OK, !TextUtils.isEmpty(msg), true);
            }
        }
    }
}
