package io.dcloud.media.video.ijkplayer.media;

import android.animation.ValueAnimator;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.media.AudioManager;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.MediaController;
import com.alipay.sdk.m.l.b;
import com.amap.api.maps.utils.SpatialRelationUtil;
import dc.squareup.HttpConstants;
import dc.squareup.okhttp3.internal.http.BridgeInterceptor;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.media.video.ijkplayer.media.IRenderView;
import io.dcloud.media.video.ijkplayer.option.EnumPlayStrategy;
import io.dcloud.media.video.ijkplayer.utils.VideoCacheUtil;
import java.io.File;
import java.io.IOException;
import java.net.CookieHandler;
import java.net.URI;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import tv.danmaku.ijk.media.player.AndroidMediaPlayer;
import tv.danmaku.ijk.media.player.IMediaPlayer;
import tv.danmaku.ijk.media.player.IjkMediaPlayer;
import tv.danmaku.ijk.media.player.TextureMediaPlayer;
import tv.danmaku.ijk.media.player.misc.ITrackInfo;

public class IjkVideoView extends FrameLayout implements MediaController.MediaPlayerControl {
    public static final int RENDER_NONE = 0;
    public static final int RENDER_SURFACE_VIEW = 1;
    public static final int RENDER_TEXTURE_VIEW = 2;
    private static final int[] s_allAspectRatio = {0, 1, 2, 4, 5};
    private String TAG = "TTAG";
    private IMediaPlayer.OnBufferingUpdateListener bufferingUpdateListener;
    private ImageView coverImage;
    private JSONArray customAdvanceJSON = new JSONArray();
    private String customUA = "";
    private EnumPlayStrategy enumPlayStrategy = EnumPlayStrategy.DEFAULT;
    private AssetsDataSourceProvider fd;
    private boolean isHttpCacheOpen = false;
    private boolean isMediaReady = true;
    private boolean isSetSeekTo = false;
    private boolean isStoped = false;
    private Context mAppContext;
    private IMediaPlayer.OnBufferingUpdateListener mBufferingUpdateListener = new IMediaPlayer.OnBufferingUpdateListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass7 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnBufferingUpdateListener
        public void onBufferingUpdate(IMediaPlayer mp, int percent) {
            IjkVideoView.this.mCurrentBufferPercentage = percent;
            if (IjkVideoView.this.bufferingUpdateListener != null) {
                IjkVideoView.this.bufferingUpdateListener.onBufferingUpdate(mp, percent);
            }
        }
    };
    private boolean mCanPause = true;
    private boolean mCanSeekBack = true;
    private boolean mCanSeekForward = true;
    private IMediaPlayer.OnCompletionListener mCompletionListener = new IMediaPlayer.OnCompletionListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass4 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnCompletionListener
        public void onCompletion(IMediaPlayer mp) {
            Log.w(IjkVideoView.this.TAG, "OnCompletionListener:");
            IjkVideoView.this.mCurrentState = 336;
            IjkVideoView.this.mTargetState = 336;
            IjkVideoView.this._notifyMediaStatus();
            if (IjkVideoView.this.mMediaController != null) {
                IjkVideoView.this.mMediaController.hide();
            }
            if (IjkVideoView.this.mOnCompletionListener != null) {
                IjkVideoView.this.mOnCompletionListener.onCompletion(IjkVideoView.this.mMediaPlayer);
            }
        }
    };
    private int mCurrentAspectRatio = s_allAspectRatio[0];
    private int mCurrentBufferPercentage;
    private int mCurrentState = 330;
    private boolean mEnableBackgroundPlay = false;
    private IMediaPlayer.OnErrorListener mErrorListener = new IMediaPlayer.OnErrorListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass6 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnErrorListener
        public boolean onError(IMediaPlayer mp, int framework_err, int impl_err) {
            Log.d("TTAG", "Error: " + framework_err + "," + impl_err);
            IjkVideoView.this.mCurrentState = 331;
            IjkVideoView.this.mTargetState = 331;
            IjkVideoView.this._notifyMediaStatus();
            if (IjkVideoView.this.mMediaController != null) {
                IjkVideoView.this.mMediaController.hide();
            }
            return (IjkVideoView.this.mOnErrorListener == null || IjkVideoView.this.mOnErrorListener.onError(IjkVideoView.this.mMediaPlayer, framework_err, impl_err)) ? true : true;
        }
    };
    private Map<String, String> mHeaders;
    private IMediaPlayer.OnInfoListener mInfoListener = new IMediaPlayer.OnInfoListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass5 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnInfoListener
        public boolean onInfo(IMediaPlayer mp, int arg1, int arg2) {
            if (IjkVideoView.this.mOnInfoListener != null) {
                IjkVideoView.this.mOnInfoListener.onInfo(mp, arg1, arg2);
            }
            if (arg1 == 3) {
                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_VIDEO_RENDERING_START:");
                return true;
            } else if (arg1 == 901) {
                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_UNSUPPORTED_SUBTITLE:");
                return true;
            } else if (arg1 == 902) {
                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_SUBTITLE_TIMED_OUT:");
                return true;
            } else if (arg1 == 10001) {
                IjkVideoView.this.mVideoRotationDegree = arg2;
                String str = IjkVideoView.this.TAG;
                Log.d(str, "MEDIA_INFO_VIDEO_ROTATION_CHANGED: " + arg2);
                if (IjkVideoView.this.mRenderView == null) {
                    return true;
                }
                IjkVideoView.this.mRenderView.setVideoRotation(arg2);
                return true;
            } else if (arg1 != 10002) {
                switch (arg1) {
                    case 700:
                        Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_VIDEO_TRACK_LAGGING:");
                        return true;
                    case 701:
                        Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_BUFFERING_START:");
                        return true;
                    case 702:
                        Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_BUFFERING_END:");
                        return true;
                    case 703:
                        String str2 = IjkVideoView.this.TAG;
                        Log.d(str2, "MEDIA_INFO_NETWORK_BANDWIDTH: " + arg2);
                        return true;
                    default:
                        switch (arg1) {
                            case 800:
                                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_BAD_INTERLEAVING:");
                                return true;
                            case 801:
                                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_NOT_SEEKABLE:");
                                return true;
                            case 802:
                                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_METADATA_UPDATE:");
                                return true;
                            default:
                                return true;
                        }
                }
            } else {
                Log.d(IjkVideoView.this.TAG, "MEDIA_INFO_AUDIO_RENDERING_START:");
                return true;
            }
        }
    };
    private boolean mIsMediaCodecHandleResolutionChange = false;
    private boolean mIsNormalScreen = true;
    private boolean mIsUsingMediaCodec = false;
    private boolean mIsUsingMediaCodecAutoRotate = false;
    private boolean mIsUsingMediaDataSource;
    private boolean mIsUsingOpenSLES = false;
    private IMediaController mMediaController;
    private IMediaPlayer mMediaPlayer = null;
    private IMediaPlayer.OnCompletionListener mOnCompletionListener;
    private IMediaPlayer.OnErrorListener mOnErrorListener;
    private IMediaPlayer.OnInfoListener mOnInfoListener;
    private IMediaPlayer.OnPreparedListener mOnPreparedListener;
    private Matrix mOriginalMatrix;
    private String mPixelFormat = "";
    private long mPrepareEndTime = 0;
    private long mPrepareStartTime = 0;
    IMediaPlayer.OnPreparedListener mPreparedListener = new IMediaPlayer.OnPreparedListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass3 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnPreparedListener
        public void onPrepared(IMediaPlayer mp) {
            IjkVideoView.this.mPrepareEndTime = System.currentTimeMillis();
            IjkVideoView.this.mCurrentState = 333;
            IjkVideoView.this._notifyMediaStatus();
            if (IjkVideoView.this.mOnPreparedListener != null) {
                IjkVideoView.this.mOnPreparedListener.onPrepared(IjkVideoView.this.mMediaPlayer);
            }
            if (IjkVideoView.this.mMediaController != null) {
                IjkVideoView.this.mMediaController.setEnabled(true);
            }
            IjkVideoView.this.mVideoWidth = mp.getVideoWidth();
            IjkVideoView.this.mVideoHeight = mp.getVideoHeight();
            int seekToPosition = IjkVideoView.this.mSeekWhenPrepared;
            if (seekToPosition != 0) {
                IjkVideoView.this.seekTo(seekToPosition);
            }
            if (IjkVideoView.this.mVideoWidth == 0 || IjkVideoView.this.mVideoHeight == 0) {
                if (IjkVideoView.this.mTargetState == 334) {
                    IjkVideoView.this.start();
                }
            } else if (IjkVideoView.this.mRenderView != null) {
                IjkVideoView.this.mRenderView.setVideoSize(IjkVideoView.this.mVideoWidth, IjkVideoView.this.mVideoHeight);
                IjkVideoView.this.mRenderView.setVideoSampleAspectRatio(IjkVideoView.this.mVideoSarNum, IjkVideoView.this.mVideoSarDen);
                if (IjkVideoView.this.mRenderView.shouldWaitForResize() && (IjkVideoView.this.mSurfaceWidth != IjkVideoView.this.mVideoWidth || IjkVideoView.this.mSurfaceHeight != IjkVideoView.this.mVideoHeight)) {
                    return;
                }
                if (IjkVideoView.this.mTargetState == 334) {
                    IjkVideoView.this.start();
                    if (IjkVideoView.this.mMediaController != null) {
                        IjkVideoView.this.mMediaController.show();
                    }
                } else if (IjkVideoView.this.isPlaying()) {
                } else {
                    if ((seekToPosition != 0 || IjkVideoView.this.getCurrentPosition() > 0) && IjkVideoView.this.mMediaController != null) {
                        IjkVideoView.this.mMediaController.show(0);
                    }
                }
            }
        }
    };
    private IRenderView mRenderView;
    IRenderView.IRenderCallback mSHCallback = new IRenderView.IRenderCallback() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass9 */

        @Override // io.dcloud.media.video.ijkplayer.media.IRenderView.IRenderCallback
        public void onSurfaceChanged(IRenderView.ISurfaceHolder holder, int format, int w, int h) {
            if (holder.getRenderView() != IjkVideoView.this.mRenderView) {
                Log.e(IjkVideoView.this.TAG, "onSurfaceChanged: unmatched render callback\n");
                return;
            }
            IjkVideoView.this.mSurfaceWidth = w;
            IjkVideoView.this.mSurfaceHeight = h;
            boolean hasValidSize = true;
            boolean isValidState = IjkVideoView.this.mTargetState == 334;
            if (IjkVideoView.this.mRenderView.shouldWaitForResize() && !(IjkVideoView.this.mVideoWidth == w && IjkVideoView.this.mVideoHeight == h)) {
                hasValidSize = false;
            }
            if (IjkVideoView.this.mMediaPlayer != null && isValidState && hasValidSize) {
                if (IjkVideoView.this.mSeekWhenPrepared != 0) {
                    IjkVideoView ijkVideoView = IjkVideoView.this;
                    ijkVideoView.seekTo(ijkVideoView.mSeekWhenPrepared);
                }
                IjkVideoView.this.start();
            }
        }

        @Override // io.dcloud.media.video.ijkplayer.media.IRenderView.IRenderCallback
        public void onSurfaceCreated(IRenderView.ISurfaceHolder holder, int width, int height) {
            if (holder.getRenderView() != IjkVideoView.this.mRenderView) {
                Log.e(IjkVideoView.this.TAG, "onSurfaceCreated: unmatched render callback\n");
                return;
            }
            IjkVideoView.this.mSurfaceHolder = holder;
            if (IjkVideoView.this.mMediaPlayer != null) {
                IjkVideoView ijkVideoView = IjkVideoView.this;
                ijkVideoView.bindSurfaceHolder(ijkVideoView.mMediaPlayer, holder);
                return;
            }
            IjkVideoView.this.openVideo();
        }

        @Override // io.dcloud.media.video.ijkplayer.media.IRenderView.IRenderCallback
        public void onSurfaceDestroyed(IRenderView.ISurfaceHolder holder) {
            if (holder.getRenderView() != IjkVideoView.this.mRenderView) {
                Log.e(IjkVideoView.this.TAG, "onSurfaceDestroyed: unmatched render callback\n");
                return;
            }
            IjkVideoView.this.mSurfaceHolder = null;
            IjkVideoView.this.releaseWithoutStop();
        }
    };
    private Matrix mSaveMatrix;
    private int mScreenOrHeight;
    private int mScreenOrWidth;
    private IMediaPlayer.OnSeekCompleteListener mSeekCompleteListener = new IMediaPlayer.OnSeekCompleteListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass8 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnSeekCompleteListener
        public void onSeekComplete(IMediaPlayer mp) {
            IjkVideoView.this.mSeekEndTime = System.currentTimeMillis();
            IjkVideoView.this.mOnInfoListener.onInfo(mp, 337, -1);
        }
    };
    private long mSeekEndTime = 0;
    private long mSeekStartTime = 0;
    private int mSeekWhenPrepared;
    IMediaPlayer.OnVideoSizeChangedListener mSizeChangedListener = new IMediaPlayer.OnVideoSizeChangedListener() {
        /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass2 */

        @Override // tv.danmaku.ijk.media.player.IMediaPlayer.OnVideoSizeChangedListener
        public void onVideoSizeChanged(IMediaPlayer mp, int width, int height, int sarNum, int sarDen) {
            IjkVideoView.this.mVideoWidth = mp.getVideoWidth();
            IjkVideoView.this.mVideoHeight = mp.getVideoHeight();
            IjkVideoView.this.mVideoSarNum = mp.getVideoSarNum();
            IjkVideoView.this.mVideoSarDen = mp.getVideoSarDen();
            if (IjkVideoView.this.mVideoWidth != 0 && IjkVideoView.this.mVideoHeight != 0) {
                if (IjkVideoView.this.mRenderView != null) {
                    IjkVideoView.this.mRenderView.setVideoSize(IjkVideoView.this.mVideoWidth, IjkVideoView.this.mVideoHeight);
                    IjkVideoView.this.mRenderView.setVideoSampleAspectRatio(IjkVideoView.this.mVideoSarNum, IjkVideoView.this.mVideoSarDen);
                }
                IjkVideoView.this.requestLayout();
            }
        }
    };
    private int mSurfaceHeight;
    private IRenderView.ISurfaceHolder mSurfaceHolder = null;
    private int mSurfaceWidth;
    private int mTargetState = 330;
    private Uri mUri;
    private int mVideoHeight;
    private int mVideoRotationDegree;
    private int mVideoSarDen;
    private int mVideoSarNum;
    private float mVideoScale = 1.0f;
    private int mVideoTargetRotationDegree;
    private int mVideoWidth;
    private float volume = 0.0f;

    public int getCurrentState() {
        return this.mCurrentState;
    }

    public IjkVideoView(Context context) {
        super(context);
        initVideoView(context);
    }

    public IjkVideoView(Context context, AttributeSet attrs) {
        super(context, attrs);
        initVideoView(context);
    }

    public IjkVideoView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        initVideoView(context);
    }

    public IjkVideoView(Context context, AttributeSet attrs, int defStyleAttr, int defStyleRes) {
        super(context, attrs, defStyleAttr, defStyleRes);
        initVideoView(context);
    }

    private void initVideoView(Context context) {
        this.mAppContext = context.getApplicationContext();
        initBackground();
        initRenders();
        this.mVideoWidth = 0;
        this.mVideoHeight = 0;
        setFocusable(true);
        setFocusableInTouchMode(true);
        requestFocus();
        this.mCurrentState = 330;
        this.mTargetState = 330;
        _notifyMediaStatus();
        ImageView imageView = new ImageView(getContext());
        this.coverImage = imageView;
        imageView.setScaleType(ImageView.ScaleType.FIT_CENTER);
        this.coverImage.setBackgroundColor(-16777216);
        this.coverImage.setVisibility(8);
        addView(this.coverImage, new ViewGroup.LayoutParams(-1, -1));
    }

    public void setmIsUsingMediaCodec(boolean mIsUsingMediaCodec2) {
        this.mIsUsingMediaCodec = mIsUsingMediaCodec2;
    }

    public void setIsHttpCacheOpen(boolean httpCacheOpen) {
        this.isHttpCacheOpen = httpCacheOpen;
    }

    public void setFlowStrategy(EnumPlayStrategy intFlowStrategy) {
        this.enumPlayStrategy = intFlowStrategy;
    }

    public void setRenderView(IRenderView renderView) {
        int i;
        int i2;
        if (this.mRenderView != null) {
            IMediaPlayer iMediaPlayer = this.mMediaPlayer;
            if (iMediaPlayer != null) {
                iMediaPlayer.setDisplay(null);
            }
            View renderUIView = this.mRenderView.getView();
            this.mRenderView.removeRenderCallback(this.mSHCallback);
            this.mRenderView = null;
            removeView(renderUIView);
        }
        if (renderView != null) {
            this.mRenderView = renderView;
            renderView.setAspectRatio(this.mCurrentAspectRatio);
            int i3 = this.mVideoWidth;
            if (i3 > 0 && (i2 = this.mVideoHeight) > 0) {
                renderView.setVideoSize(i3, i2);
            }
            int i4 = this.mVideoSarNum;
            if (i4 > 0 && (i = this.mVideoSarDen) > 0) {
                renderView.setVideoSampleAspectRatio(i4, i);
            }
            View renderUIView2 = this.mRenderView.getView();
            renderUIView2.setLayoutParams(new FrameLayout.LayoutParams(-1, -2, 17));
            addView(renderUIView2);
            this.mRenderView.addRenderCallback(this.mSHCallback);
            this.mRenderView.setVideoRotation(this.mVideoRotationDegree);
        }
    }

    public void setVideoRotation(int degree) {
        int i = this.mVideoRotationDegree + degree;
        this.mVideoTargetRotationDegree = i;
        this.mRenderView.setVideoRotation(i);
    }

    public Matrix getVideoTransform() {
        if (this.mOriginalMatrix == null) {
            this.mOriginalMatrix = this.mRenderView.getTransform();
        }
        return this.mRenderView.getTransform();
    }

    public void setVideoTransform(Matrix transform) {
        this.mRenderView.setTransform(transform);
    }

    public boolean adjustVideoView(float scale) {
        float f = this.mVideoScale * scale;
        this.mVideoScale = f;
        int degree = (this.mVideoTargetRotationDegree + SpatialRelationUtil.A_CIRCLE_DEGREE) % SpatialRelationUtil.A_CIRCLE_DEGREE;
        if (f == 1.0f && degree == 0) {
            return false;
        }
        if (degree > 315 || degree <= 45) {
            this.mVideoRotationDegree = 0;
        } else if (degree > 45 && degree <= 135) {
            this.mVideoRotationDegree = 90;
        } else if (degree > 135 && degree <= 225) {
            this.mVideoRotationDegree = 180;
        } else if (degree <= 225 || degree > 315) {
            this.mVideoRotationDegree = 0;
        } else {
            this.mVideoRotationDegree = 270;
        }
        int i = this.mVideoRotationDegree;
        final int deltaDegree = i - this.mVideoTargetRotationDegree;
        this.mVideoTargetRotationDegree = i;
        final Matrix matrix = getVideoTransform();
        if (this.mScreenOrWidth == 0 || this.mScreenOrHeight == 0) {
            this.mScreenOrWidth = this.mRenderView.getView().getWidth();
            this.mScreenOrHeight = this.mRenderView.getView().getHeight();
        }
        if (!this.mIsNormalScreen) {
            float f2 = this.mVideoScale;
            matrix.preScale(f2, f2);
            float f3 = this.mVideoScale;
            matrix.postTranslate((((float) this.mScreenOrWidth) * (1.0f - f3)) / 2.0f, (((float) this.mScreenOrHeight) * (1.0f - f3)) / 2.0f);
            this.mRenderView.setTransform(matrix);
            this.mIsNormalScreen = true;
        } else {
            float[] points = new float[2];
            matrix.mapPoints(points);
            float f4 = this.mVideoScale;
            final float deltaX = ((((float) this.mScreenOrWidth) * (1.0f - f4)) / 2.0f) - points[0];
            final float deltaY = ((((float) this.mScreenOrHeight) * (1.0f - f4)) / 2.0f) - points[1];
            if (this.mSaveMatrix == null) {
                this.mSaveMatrix = new Matrix();
            }
            ValueAnimator animator = ValueAnimator.ofFloat(0.0f, 1.0f).setDuration(300L);
            animator.addUpdateListener(new ValueAnimator.AnimatorUpdateListener() {
                /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass1 */

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    float percent = ((Float) valueAnimator.getAnimatedValue()).floatValue();
                    IjkVideoView.this.mSaveMatrix.set(matrix);
                    IjkVideoView.this.mSaveMatrix.postTranslate(deltaX * percent, deltaY * percent);
                    IjkVideoView.this.mRenderView.setTransform(IjkVideoView.this.mSaveMatrix);
                    IjkVideoView.this.mRenderView.setVideoRotation((int) (((float) IjkVideoView.this.mVideoRotationDegree) - (((float) deltaDegree) * (1.0f - percent))));
                }
            });
            animator.start();
        }
        return true;
    }

    public void resetVideoView(boolean isForever) {
        this.mIsNormalScreen = isForever;
        this.mVideoRotationDegree = 0;
        if (isForever) {
            this.mVideoTargetRotationDegree = 0;
            this.mVideoScale = 1.0f;
        }
        this.mRenderView.setTransform(this.mOriginalMatrix);
        this.mRenderView.setVideoRotation(this.mVideoRotationDegree);
    }

    public void setRender(int render) {
        if (render == 0) {
            setRenderView(null);
        } else if (render == 1) {
            setRenderView(new SurfaceRenderView(getContext()));
        } else if (render != 2) {
            Log.e(this.TAG, String.format(Locale.US, "invalid render %d\n", Integer.valueOf(render)));
        } else {
            TextureRenderView renderView = new TextureRenderView(getContext());
            if (this.mMediaPlayer != null) {
                renderView.getSurfaceHolder().bindToMediaPlayer(this.mMediaPlayer);
                renderView.setVideoSize(this.mMediaPlayer.getVideoWidth(), this.mMediaPlayer.getVideoHeight());
                renderView.setVideoSampleAspectRatio(this.mMediaPlayer.getVideoSarNum(), this.mMediaPlayer.getVideoSarDen());
                renderView.setAspectRatio(this.mCurrentAspectRatio);
            }
            setRenderView(renderView);
        }
    }

    public void setCustomAdvanced(String customAdvanced) {
        if (!TextUtils.isEmpty(customAdvanced)) {
            try {
                this.customAdvanceJSON = new JSONArray(customAdvanced);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
    }

    public void setVideoURI(Uri uri, String headerInfo) {
        this.customUA = "";
        new HashMap();
        Map<String, List<String>> headers = new HashMap<>();
        Map<String, String> newHeader = new HashMap<>();
        try {
            Map<String, List<String>> localCookies = CookieHandler.getDefault().get(URI.create(uri.toString()), headers);
            if (localCookies != null) {
                for (Map.Entry<String, List<String>> perEntry : localCookies.entrySet()) {
                    String mapKey = perEntry.getKey();
                    List<String> mapVal = perEntry.getValue();
                    if (mapKey.equalsIgnoreCase(IWebview.COOKIE) || mapKey.equalsIgnoreCase("Cookie2")) {
                        newHeader.put(mapKey, BridgeInterceptor.buildCookieHeader(mapVal));
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            newHeader = new HashMap<>();
        }
        try {
            JSONObject headerJSON = new JSONObject(headerInfo);
            Iterator<String> iteratorKey = headerJSON.keys();
            while (iteratorKey.hasNext()) {
                String perKey = iteratorKey.next();
                String perVal = headerJSON.optString(perKey);
                if (!TextUtils.isEmpty(perKey)) {
                    if (IWebview.USER_AGENT.equalsIgnoreCase(perKey)) {
                        this.customUA = perVal;
                    } else {
                        newHeader.put(perKey, perVal);
                    }
                }
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
        setVideoURI(uri, newHeader);
    }

    public void setVideoFileDescriptor(AssetsDataSourceProvider fd2) {
        this.fd = fd2;
        this.mSeekWhenPrepared = 0;
        this.isSetSeekTo = false;
        openVideo();
        requestLayout();
        invalidate();
    }

    private void setVideoURI(Uri uri, Map<String, String> headers) {
        this.mUri = uri;
        this.mHeaders = headers;
        this.mSeekWhenPrepared = 0;
        this.isSetSeekTo = false;
        openVideo();
        requestLayout();
        invalidate();
    }

    public Uri getUri() {
        return this.mUri;
    }

    public void setSpeed(float speed) {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer instanceof IjkMediaPlayer) {
            ((IjkMediaPlayer) iMediaPlayer).setSpeed(speed);
        } else if (iMediaPlayer instanceof TextureMediaPlayer) {
            IjkMediaPlayer innerMedia = (IjkMediaPlayer) ((TextureMediaPlayer) iMediaPlayer).getInternalMediaPlayer();
            if (innerMedia instanceof IjkMediaPlayer) {
                innerMedia.setSpeed(speed);
            }
        }
    }

    public Bitmap getScreenshot() {
        IRenderView iRenderView = this.mRenderView;
        if (iRenderView != null) {
            return iRenderView.getVideoScreenshot();
        }
        return null;
    }

    public void stopPlayback() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer != null) {
            iMediaPlayer.stop();
            this.mMediaPlayer.release();
            this.mMediaPlayer = null;
            this.mCurrentState = 330;
            this.mTargetState = 330;
            _notifyMediaStatus();
            ((AudioManager) this.mAppContext.getSystemService("audio")).abandonAudioFocus(null);
            this.isStoped = true;
            showCoverImage();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void openVideo() {
        if ((this.mUri != null || this.fd != null) && this.mSurfaceHolder != null) {
            release(false);
            try {
                this.mMediaPlayer = createPlayer(2);
                if (!this.isMediaReady) {
                    setvolume(this.volume);
                    this.isMediaReady = true;
                }
                getContext();
                this.mMediaPlayer.setOnPreparedListener(this.mPreparedListener);
                this.mMediaPlayer.setOnVideoSizeChangedListener(this.mSizeChangedListener);
                this.mMediaPlayer.setOnCompletionListener(this.mCompletionListener);
                this.mMediaPlayer.setOnErrorListener(this.mErrorListener);
                this.mMediaPlayer.setOnInfoListener(this.mInfoListener);
                this.mMediaPlayer.setOnBufferingUpdateListener(this.mBufferingUpdateListener);
                this.mMediaPlayer.setOnSeekCompleteListener(this.mSeekCompleteListener);
                this.mCurrentBufferPercentage = 0;
                if (this.mUri != null) {
                    String scheme = this.mUri.getScheme();
                    if (Build.VERSION.SDK_INT >= 23 && this.mIsUsingMediaDataSource && (TextUtils.isEmpty(scheme) || scheme.equalsIgnoreCase("file"))) {
                        this.mMediaPlayer.setDataSource(new FileMediaDataSource(new File(this.mUri.toString())));
                    } else if (Build.VERSION.SDK_INT >= 14) {
                        this.mMediaPlayer.setDataSource(this.mAppContext, this.mUri, this.mHeaders);
                    } else {
                        this.mMediaPlayer.setDataSource(this.mUri.toString());
                    }
                } else if (this.fd != null) {
                    this.mMediaPlayer.setDataSource(this.fd);
                }
                bindSurfaceHolder(this.mMediaPlayer, this.mSurfaceHolder);
                this.mMediaPlayer.setAudioStreamType(3);
                this.mMediaPlayer.setScreenOnWhilePlaying(true);
                this.mPrepareStartTime = System.currentTimeMillis();
                this.mMediaPlayer.prepareAsync();
                this.mCurrentState = 332;
                attachMediaController();
            } catch (IOException e) {
                this.mCurrentState = 331;
                this.mTargetState = 331;
                this.mErrorListener.onError(this.mMediaPlayer, 1, 0);
            } catch (IllegalArgumentException e2) {
                this.mCurrentState = 331;
                this.mTargetState = 331;
                this.mErrorListener.onError(this.mMediaPlayer, 1, 0);
            } catch (Throwable th) {
                _notifyMediaStatus();
                throw th;
            }
            _notifyMediaStatus();
        } else if (this.mUri == null && this.fd == null) {
            this.mCurrentState = 331;
            this.mTargetState = 331;
            this.mErrorListener.onError(this.mMediaPlayer, 1, 0);
        }
    }

    public void setMediaController(IMediaController controller) {
        IMediaController iMediaController = this.mMediaController;
        if (iMediaController != null) {
            iMediaController.hide();
        }
        this.mMediaController = controller;
        attachMediaController();
    }

    private void attachMediaController() {
        IMediaController iMediaController;
        if (this.mMediaPlayer != null && (iMediaController = this.mMediaController) != null) {
            iMediaController.setMediaPlayer(this);
            this.mMediaController.setAnchorView(getParent() instanceof View ? (View) getParent() : this);
            this.mMediaController.setEnabled(isInPlaybackState());
        }
    }

    public IMediaPlayer getMediaPlayer() {
        return this.mMediaPlayer;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void _notifyMediaStatus() {
        IMediaPlayer.OnInfoListener onInfoListener = this.mOnInfoListener;
        if (onInfoListener != null) {
            onInfoListener.onInfo(this.mMediaPlayer, this.mCurrentState, -1);
        }
    }

    private void showCoverImage() {
        if (this.mRenderView != null) {
            if (this.mCurrentAspectRatio == 1) {
                this.coverImage.setScaleType(ImageView.ScaleType.CENTER_CROP);
            } else {
                this.coverImage.setScaleType(ImageView.ScaleType.FIT_CENTER);
            }
            Bitmap videoShot = this.mRenderView.getVideoScreenshot();
            int i = this.mVideoRotationDegree;
            if (i > 0) {
                videoShot = adjustPhotoRotation(videoShot, i);
            }
            if (videoShot != null) {
                this.coverImage.setImageBitmap(videoShot);
            } else {
                this.coverImage.setBackgroundColor(-16777216);
            }
            this.coverImage.bringToFront();
            this.coverImage.setVisibility(0);
        }
    }

    private Bitmap adjustPhotoRotation(Bitmap bm, int orientationDegree) {
        if (bm == null) {
            return null;
        }
        Matrix m = new Matrix();
        m.setRotate((float) orientationDegree, ((float) bm.getWidth()) / 2.0f, ((float) bm.getHeight()) / 2.0f);
        try {
            return Bitmap.createBitmap(bm, 0, 0, bm.getWidth(), bm.getHeight(), m, true);
        } catch (OutOfMemoryError e) {
            return null;
        }
    }

    public void setOnBufferingUpdateListener(IMediaPlayer.OnBufferingUpdateListener bufferingUpdateListener2) {
        this.bufferingUpdateListener = bufferingUpdateListener2;
    }

    public void setOnPreparedListener(IMediaPlayer.OnPreparedListener l) {
        this.mOnPreparedListener = l;
    }

    public void setOnCompletionListener(IMediaPlayer.OnCompletionListener l) {
        this.mOnCompletionListener = l;
    }

    public void setOnErrorListener(IMediaPlayer.OnErrorListener l) {
        this.mOnErrorListener = l;
    }

    public void setOnInfoListener(IMediaPlayer.OnInfoListener l) {
        this.mOnInfoListener = l;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void bindSurfaceHolder(IMediaPlayer mp, IRenderView.ISurfaceHolder holder) {
        if (mp != null) {
            if (holder == null) {
                mp.setDisplay(null);
            } else {
                holder.bindToMediaPlayer(mp);
            }
        }
    }

    public void releaseWithoutStop() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer != null) {
            iMediaPlayer.setDisplay(null);
        }
    }

    public void release(boolean cleartargetstate) {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer != null) {
            iMediaPlayer.reset();
            this.mMediaPlayer.release();
            this.mMediaPlayer = null;
            this.mCurrentState = 330;
            _notifyMediaStatus();
            if (cleartargetstate) {
                this.mTargetState = 330;
            }
            ((AudioManager) this.mAppContext.getSystemService("audio")).abandonAudioFocus(null);
        }
    }

    public void releaseOnWorkerThread(boolean cleartargetstate) {
        if (this.mMediaPlayer != null) {
            ThreadPool.self().addThreadTask(new Runnable() {
                /* class io.dcloud.media.video.ijkplayer.media.IjkVideoView.AnonymousClass10 */

                public void run() {
                    IjkVideoView.this.mMediaPlayer.reset();
                    IjkVideoView.this.mMediaPlayer.release();
                    IjkVideoView.this.mMediaPlayer = null;
                }
            });
            this.mCurrentState = 330;
            _notifyMediaStatus();
            if (cleartargetstate) {
                this.mTargetState = 330;
            }
            ((AudioManager) this.mAppContext.getSystemService("audio")).abandonAudioFocus(null);
        }
    }

    public void destroy() {
        releaseOnWorkerThread(true);
    }

    public boolean onTouchEvent(MotionEvent ev) {
        if (!isInPlaybackState() || this.mMediaController == null) {
            return false;
        }
        toggleMediaControlsVisibility();
        return false;
    }

    public boolean onTrackballEvent(MotionEvent ev) {
        if (!isInPlaybackState() || this.mMediaController == null) {
            return false;
        }
        toggleMediaControlsVisibility();
        return false;
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
        boolean isKeyCodeSupported = (keyCode == 4 || keyCode == 24 || keyCode == 25 || keyCode == 164 || keyCode == 82 || keyCode == 5 || keyCode == 6) ? false : true;
        if (isInPlaybackState() && isKeyCodeSupported && this.mMediaController != null) {
            if (keyCode == 79 || keyCode == 85) {
                if (this.mMediaPlayer.isPlaying()) {
                    pause();
                    this.mMediaController.show();
                } else {
                    start();
                    this.mMediaController.hide();
                }
                return true;
            } else if (keyCode == 126) {
                if (!this.mMediaPlayer.isPlaying()) {
                    start();
                    this.mMediaController.hide();
                }
                return true;
            } else if (keyCode == 86 || keyCode == 127) {
                if (this.mMediaPlayer.isPlaying()) {
                    pause();
                    this.mMediaController.show();
                }
                return true;
            } else {
                toggleMediaControlsVisibility();
            }
        }
        return super.onKeyDown(keyCode, event);
    }

    private void toggleMediaControlsVisibility() {
        if (this.mMediaController.isShowing()) {
            this.mMediaController.hide();
        } else {
            this.mMediaController.show();
        }
    }

    public void start() {
        Log.e("TTAG", "start " + isInPlaybackState());
        ((AudioManager) this.mAppContext.getSystemService("audio")).requestAudioFocus(null, 3, 4);
        if (this.isStoped && this.mMediaPlayer == null && this.mCurrentState == 330) {
            this.isStoped = false;
            setRender(2);
            openVideo();
            requestLayout();
            invalidate();
        }
        if (isInPlaybackState()) {
            this.mMediaPlayer.start();
            this.mCurrentState = 334;
            _notifyMediaStatus();
            this.isSetSeekTo = false;
        }
        this.mTargetState = 334;
        if (this.mCurrentState == 331) {
            this.mTargetState = 331;
            this.mErrorListener.onError(this.mMediaPlayer, 1, 0);
        }
        this.coverImage.setVisibility(8);
    }

    public void pause() {
        if (isInPlaybackState() && this.mMediaPlayer.isPlaying()) {
            this.mMediaPlayer.pause();
            this.mCurrentState = 335;
            _notifyMediaStatus();
        }
        this.mTargetState = 335;
        showCoverImage();
    }

    public void suspend() {
        release(false);
    }

    public void resume() {
        openVideo();
    }

    public void reload() {
        this.mCurrentState = 334;
        this.mTargetState = 334;
    }

    public int getDuration() {
        if (isInPlaybackState()) {
            return (int) this.mMediaPlayer.getDuration();
        }
        return -1;
    }

    public void setvolume(float volume2) {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer != null) {
            iMediaPlayer.setVolume(volume2, volume2);
            return;
        }
        this.isMediaReady = false;
        this.volume = volume2;
    }

    public int getInterruptPosition() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer != null) {
            return (int) iMediaPlayer.getCurrentPosition();
        }
        return 0;
    }

    public int getCurrentPosition() {
        if (!isInPlaybackState()) {
            return 0;
        }
        if (this.mCurrentState != 336 || this.isSetSeekTo) {
            return (int) this.mMediaPlayer.getCurrentPosition();
        }
        return (int) this.mMediaPlayer.getDuration();
    }

    public void seekTo(int msec) {
        if (isInPlaybackState()) {
            this.mSeekStartTime = System.currentTimeMillis();
            this.mMediaPlayer.seekTo((long) msec);
            this.mSeekWhenPrepared = 0;
            if (isPlaying()) {
                this.isSetSeekTo = false;
            } else {
                this.isSetSeekTo = true;
            }
        } else {
            this.mSeekWhenPrepared = msec;
            this.isSetSeekTo = false;
        }
    }

    public boolean isPlaying() {
        return isInPlaybackState() && this.mMediaPlayer.isPlaying();
    }

    public int getBufferPercentage() {
        if (this.mMediaPlayer != null) {
            return this.mCurrentBufferPercentage;
        }
        return 0;
    }

    private boolean isInPlaybackState() {
        int i;
        return (this.mMediaPlayer == null || (i = this.mCurrentState) == 331 || i == 330 || i == 332) ? false : true;
    }

    public boolean canPause() {
        return this.mCanPause;
    }

    public boolean canSeekBackward() {
        return this.mCanSeekBack;
    }

    public boolean canSeekForward() {
        return this.mCanSeekForward;
    }

    public int getAudioSessionId() {
        return 0;
    }

    public void setAspectRatio(int aspectRatio) {
        this.mCurrentAspectRatio = aspectRatio;
        IRenderView iRenderView = this.mRenderView;
        if (iRenderView != null) {
            iRenderView.setAspectRatio(aspectRatio);
        }
    }

    private void initRenders() {
        setRender(2);
    }

    /* access modifiers changed from: package-private */
    public int getVideoWidth() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer == null) {
            return 0;
        }
        return iMediaPlayer.getVideoWidth();
    }

    /* access modifiers changed from: package-private */
    public int getVideoHeight() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer == null) {
            return 0;
        }
        return iMediaPlayer.getVideoHeight();
    }

    public IMediaPlayer createPlayer(int playerType) {
        int paramVal;
        int i;
        if (playerType == 1) {
            return new AndroidMediaPlayer();
        }
        IjkMediaPlayer ijkMediaPlayer = null;
        if (!(this.mUri == null && this.fd == null)) {
            ijkMediaPlayer = new IjkMediaPlayer();
            if (TextUtils.isEmpty(this.customUA)) {
                ijkMediaPlayer.setOption(1, b.b, HttpConstants.getDefaultUA());
            } else {
                ijkMediaPlayer.setOption(1, b.b, this.customUA);
            }
            if (this.mIsUsingMediaCodec) {
                ijkMediaPlayer.setOption(4, "mediacodec", 1);
                if (this.mIsUsingMediaCodecAutoRotate) {
                    ijkMediaPlayer.setOption(4, "mediacodec-auto-rotate", 1);
                } else {
                    ijkMediaPlayer.setOption(4, "mediacodec-auto-rotate", 0);
                }
                if (this.mIsMediaCodecHandleResolutionChange) {
                    ijkMediaPlayer.setOption(4, "mediacodec-handle-resolution-change", 1);
                } else {
                    ijkMediaPlayer.setOption(4, "mediacodec-handle-resolution-change", 0);
                }
            } else {
                ijkMediaPlayer.setOption(4, "mediacodec", 0);
            }
            if (this.mIsUsingOpenSLES) {
                ijkMediaPlayer.setOption(4, "opensles", 1);
            } else {
                ijkMediaPlayer.setOption(4, "opensles", 0);
            }
            if (TextUtils.isEmpty(this.mPixelFormat)) {
                ijkMediaPlayer.setOption(4, "overlay-format", 842225234);
            } else {
                ijkMediaPlayer.setOption(4, "overlay-format", this.mPixelFormat);
            }
            ijkMediaPlayer.setOption(4, "start-on-prepared", 0);
            ijkMediaPlayer.setOption(1, "http-detect-range-support", 0);
            if (this.enumPlayStrategy == EnumPlayStrategy.PLAY_SMOOTH) {
                ijkMediaPlayer.setOption(4, "infbuf", 1);
                ijkMediaPlayer.setOption(4, "max-fps", 25);
                ijkMediaPlayer.setOption(4, "opensles", 1);
                ijkMediaPlayer.setOption(4, "mediacodec-mpeg4", 1);
                ijkMediaPlayer.setOption(4, "mediacodec-hevc", 1);
            } else if (this.enumPlayStrategy == EnumPlayStrategy.M3U8_SMOOTH) {
                ijkMediaPlayer.setOption(4, "infbuf", 1);
                ijkMediaPlayer.setOption(4, "max-fps", 25);
            } else {
                EnumPlayStrategy enumPlayStrategy2 = EnumPlayStrategy.START_QUICK;
            }
            ijkMediaPlayer.setOption(2, "skip_loop_filter", 0);
            ijkMediaPlayer.setOption(4, "framedrop", 1);
            ijkMediaPlayer.setOption(4, "soundtouch", 1);
            ijkMediaPlayer.setOption(1, "dns_cache_clear", 1);
            Uri uri = this.mUri;
            if (uri == null || (!uri.toString().startsWith("rtmp://") && !this.mUri.toString().startsWith("rtsp://"))) {
                Uri uri2 = this.mUri;
                if (uri2 != null && (uri2.toString().startsWith(DeviceInfo.HTTP_PROTOCOL) || this.mUri.toString().startsWith(DeviceInfo.HTTPS_PROTOCOL))) {
                    if (this.mUri.toString().endsWith(".m3u8") || this.mUri.toString().endsWith(".M3U8")) {
                        this.isHttpCacheOpen = false;
                    } else {
                        ijkMediaPlayer.setOption(4, "enable-accurate-seek", 1);
                    }
                    if (this.isHttpCacheOpen) {
                        VideoCacheUtil.cleanCacheIfNesscessary(this.mAppContext);
                        Uri cacheHttpUriWrap = VideoCacheUtil.cacheHttpUriWrap(this.mUri);
                        this.mUri = cacheHttpUriWrap;
                        String cacheFilePath = VideoCacheUtil.getCacheFilePath(this.mAppContext, cacheHttpUriWrap);
                        String cacheMapFilePath = VideoCacheUtil.getCacheMapFilePath(this.mAppContext, this.mUri);
                        if (!TextUtils.isEmpty(cacheFilePath) && !TextUtils.isEmpty(cacheMapFilePath)) {
                            ijkMediaPlayer.setOption(1, "cache_file_path", cacheFilePath);
                            ijkMediaPlayer.setOption(1, "cache_map_path", cacheMapFilePath);
                            ijkMediaPlayer.setOption(1, "auto_save_map", 1);
                            ijkMediaPlayer.setOption(1, "parse_cache_map", 1);
                        }
                    }
                }
            } else {
                if (this.mUri.toString().startsWith("rtsp://")) {
                    i = 1;
                    ijkMediaPlayer.setOption(1, "rtsp_transport", "tcp");
                } else {
                    i = 1;
                }
                ijkMediaPlayer.setOption(i, "flush_packets", 1);
                ijkMediaPlayer.setOption(4, "packet-buffering", 0);
                ijkMediaPlayer.setOption(4, "framedrop", 1);
            }
            for (int i2 = 0; i2 < this.customAdvanceJSON.length(); i2++) {
                try {
                    JSONObject perJsonObject = this.customAdvanceJSON.getJSONObject(i2);
                    if (perJsonObject != null) {
                        String keyParam = perJsonObject.getString("key");
                        String valString = perJsonObject.optString("value");
                        String typeParam = perJsonObject.getString("type");
                        if ("format".equalsIgnoreCase(typeParam)) {
                            paramVal = 1;
                        } else if ("codec".equalsIgnoreCase(typeParam)) {
                            paramVal = 2;
                        } else if ("sws".equalsIgnoreCase(typeParam)) {
                            paramVal = 3;
                        } else if ("player".equalsIgnoreCase(typeParam)) {
                            paramVal = 4;
                        } else {
                            paramVal = -10086;
                        }
                        if (paramVal != -10086) {
                            if (isNumeric(valString)) {
                                ijkMediaPlayer.setOption(paramVal, keyParam, (long) Integer.parseInt(valString));
                            } else {
                                ijkMediaPlayer.setOption(paramVal, keyParam, valString);
                            }
                        }
                    }
                } catch (Exception e) {
                }
            }
        }
        if (this.mIsUsingMediaCodec) {
            return new TextureMediaPlayer(ijkMediaPlayer);
        }
        return ijkMediaPlayer;
    }

    public static boolean isNumeric(String str) {
        for (int i = 0; i < str.length(); i++) {
            System.out.println(str.charAt(i));
            if (!Character.isDigit(str.charAt(i))) {
                return false;
            }
        }
        return true;
    }

    private void initBackground() {
    }

    public boolean isBackgroundPlayEnabled() {
        return this.mEnableBackgroundPlay;
    }

    public void enterBackground() {
    }

    public void stopBackgroundPlay() {
    }

    private String buildTimeMilli(long duration) {
        long total_seconds = duration / 1000;
        long hours = total_seconds / 3600;
        long minutes = (total_seconds % 3600) / 60;
        long seconds = total_seconds % 60;
        if (duration <= 0) {
            return "--:--";
        }
        if (hours >= 100) {
            return String.format(Locale.US, "%d:%02d:%02d", Long.valueOf(hours), Long.valueOf(minutes), Long.valueOf(seconds));
        } else if (hours > 0) {
            return String.format(Locale.US, "%02d:%02d:%02d", Long.valueOf(hours), Long.valueOf(minutes), Long.valueOf(seconds));
        } else {
            return String.format(Locale.US, "%02d:%02d", Long.valueOf(minutes), Long.valueOf(seconds));
        }
    }

    public ITrackInfo[] getTrackInfo() {
        IMediaPlayer iMediaPlayer = this.mMediaPlayer;
        if (iMediaPlayer == null) {
            return null;
        }
        return iMediaPlayer.getTrackInfo();
    }

    public void selectTrack(int stream) {
        MediaPlayerCompat.selectTrack(this.mMediaPlayer, stream);
    }

    public void deselectTrack(int stream) {
        MediaPlayerCompat.deselectTrack(this.mMediaPlayer, stream);
    }

    public int getSelectedTrack(int trackType) {
        return MediaPlayerCompat.getSelectedTrack(this.mMediaPlayer, trackType);
    }
}
