package io.dcloud.media.video.ijkplayer.utils;

import android.content.Context;
import android.net.Uri;
import com.facebook.common.statfs.StatFsHelper;
import java.io.File;

public class VideoCacheUtil {
    private static final int CACHE_FOLDER_MAX_LIMIT = 104857600;
    private static final String VIDEO_CACHE_FOLDER_NAME = "videoPlayer_CacheFiles";

    public static Uri cacheHttpUriWrap(Uri uri) {
        return Uri.parse("ijkio:cache:ffio:" + uri.toString());
    }

    public static String getCacheFilePath(Context appContext, Uri uri) {
        if (appContext == null || uri == null) {
            return null;
        }
        File cacheRootFile = getCacheRootFile(appContext);
        return cacheRootFile.getPath() + File.separator + (String.valueOf(uri.hashCode()) + ".videoCache");
    }

    public static String getCacheMapFilePath(Context appContext, Uri uri) {
        if (appContext == null || uri == null) {
            return null;
        }
        File cacheRootFile = getCacheRootFile(appContext);
        return cacheRootFile.getPath() + File.separator + (String.valueOf(uri.hashCode()) + ".videoCacheMap");
    }

    public static void cleanCacheIfNesscessary(Context appContext) {
        File cacheRootFile = getCacheRootFile(appContext);
        if (cacheRootFile.canRead()) {
            File[] cacheFiles = cacheRootFile.listFiles();
            long totalCacheSize = 0;
            boolean needCleanCache = false;
            int length = cacheFiles.length;
            int i = 0;
            while (true) {
                if (i >= length) {
                    break;
                }
                File cacheFile = cacheFiles[i];
                if (cacheFile.isFile()) {
                    totalCacheSize += cacheFile.length();
                }
                if (totalCacheSize >= StatFsHelper.DEFAULT_DISK_RED_LEVEL_IN_BYTES) {
                    needCleanCache = true;
                    break;
                }
                i++;
            }
            if (needCleanCache) {
                for (File perFileItem : cacheFiles) {
                    perFileItem.delete();
                }
            }
        }
    }

    private static File getCacheRootFile(Context appContext) {
        File cacheRootFile = new File(appContext.getCacheDir().toString() + File.separator + VIDEO_CACHE_FOLDER_NAME);
        if (!cacheRootFile.exists()) {
            cacheRootFile.mkdir();
        }
        return cacheRootFile;
    }
}
