package io.dcloud.media.weex.weex_video.ijkplayer.danmaku;

import android.text.TextUtils;
import com.alipay.sdk.m.s.a;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.lang.reflect.Array;
import java.util.Locale;
import master.flame.danmaku.danmaku.model.AlphaValue;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.Duration;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.android.DanmakuFactory;
import master.flame.danmaku.danmaku.model.android.Danmakus;
import master.flame.danmaku.danmaku.parser.BaseDanmakuParser;
import master.flame.danmaku.danmaku.parser.android.AndroidFileSource;
import master.flame.danmaku.danmaku.util.DanmakuUtils;
import org.json.JSONArray;
import org.json.JSONException;
import org.xml.sax.Attributes;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.helpers.XMLReaderFactory;

public class BiliDanmukuParser extends BaseDanmakuParser {
    private float mDispScaleX;
    private float mDispScaleY;

    static {
        System.setProperty("org.xml.sax.driver", "org.xmlpull.v1.sax2.Driver");
    }

    @Override // master.flame.danmaku.danmaku.parser.BaseDanmakuParser
    public Danmakus parse() {
        if (this.mDataSource == null) {
            return null;
        }
        AndroidFileSource source = (AndroidFileSource) this.mDataSource;
        try {
            XMLReader xmlReader = XMLReaderFactory.createXMLReader();
            XmlContentHandler contentHandler = new XmlContentHandler();
            xmlReader.setContentHandler(contentHandler);
            xmlReader.parse(new InputSource(source.data()));
            return contentHandler.getResult();
        } catch (SAXException e) {
            e.printStackTrace();
            return null;
        } catch (IOException e2) {
            e2.printStackTrace();
            return null;
        }
    }

    public class XmlContentHandler extends DefaultHandler {
        private static final String TRUE_STRING = "true";
        public boolean completed = false;
        public int index = 0;
        public BaseDanmaku item = null;
        public Danmakus result = null;

        public XmlContentHandler() {
        }

        public Danmakus getResult() {
            return this.result;
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void startDocument() throws SAXException {
            this.result = new Danmakus();
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void endDocument() throws SAXException {
            this.completed = true;
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void startElement(String uri, String localName, String qName, Attributes attributes) throws SAXException {
            if ((localName.length() != 0 ? localName : qName).toLowerCase(Locale.getDefault()).trim().equals("d")) {
                String[] values = attributes.getValue("p").split(",");
                if (values.length > 0) {
                    long time = (long) (Float.parseFloat(values[0]) * 1000.0f);
                    int type = Integer.parseInt(values[1]);
                    float textSize = Float.parseFloat(values[2]);
                    int color = (int) ((-16777216 | Long.parseLong(values[3])) & -1);
                    BaseDanmaku createDanmaku = BiliDanmukuParser.this.mContext.mDanmakuFactory.createDanmaku(type, BiliDanmukuParser.this.mContext);
                    this.item = createDanmaku;
                    if (createDanmaku != null) {
                        createDanmaku.setTime(time);
                        this.item.textSize = (BiliDanmukuParser.this.mDispDensity - 0.6f) * textSize;
                        this.item.textColor = color;
                        BaseDanmaku baseDanmaku = this.item;
                        int i = -16777216;
                        if (color <= -16777216) {
                            i = -1;
                        }
                        baseDanmaku.textShadowColor = i;
                    }
                }
            }
        }

        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void endElement(String uri, String localName, String qName) throws SAXException {
            BaseDanmaku baseDanmaku = this.item;
            if (baseDanmaku != null) {
                if (baseDanmaku.duration != null) {
                    if ((localName.length() != 0 ? localName : qName).equalsIgnoreCase("d")) {
                        this.item.setTimer(BiliDanmukuParser.this.mTimer);
                        this.result.addItem(this.item);
                    }
                }
                this.item = null;
            }
        }

        /* JADX INFO: Multiple debug info for r14v3 float: [D('alphaArr' java.lang.String[]), D('beginX' float)] */
        @Override // org.xml.sax.helpers.DefaultHandler, org.xml.sax.ContentHandler
        public void characters(char[] ch, int start, int length) {
            int endAlpha;
            float rotateZ;
            long translationStartDelay;
            long translationDuration;
            BaseDanmaku baseDanmaku = this.item;
            if (baseDanmaku != null) {
                DanmakuUtils.fillText(baseDanmaku, decodeXmlString(new String(ch, start, length)));
                BaseDanmaku baseDanmaku2 = this.item;
                int i = this.index;
                this.index = i + 1;
                baseDanmaku2.index = i;
                String text = String.valueOf(this.item.text).trim();
                if (this.item.getType() == 7 && text.startsWith(Operators.ARRAY_START_STR)) {
                    if (text.endsWith(Operators.ARRAY_END_STR)) {
                        String[] textArr = null;
                        try {
                            JSONArray jsonArray = new JSONArray(text);
                            textArr = new String[jsonArray.length()];
                            for (int i2 = 0; i2 < textArr.length; i2++) {
                                textArr[i2] = jsonArray.getString(i2);
                            }
                        } catch (JSONException e) {
                            e.printStackTrace();
                        }
                        if (textArr != null) {
                            if (textArr.length >= 5) {
                                this.item.text = textArr[4];
                                float beginX = Float.parseFloat(textArr[0]);
                                float beginY = Float.parseFloat(textArr[1]);
                                float endX = beginX;
                                float endY = beginY;
                                String[] alphaArr = textArr[2].split("-");
                                int beginAlpha = (int) (((float) AlphaValue.MAX) * Float.parseFloat(alphaArr[0]));
                                if (alphaArr.length > 1) {
                                    endAlpha = (int) (((float) AlphaValue.MAX) * Float.parseFloat(alphaArr[1]));
                                } else {
                                    endAlpha = beginAlpha;
                                }
                                long alphaDuraion = (long) (Float.parseFloat(textArr[3]) * 1000.0f);
                                long translationDuration2 = alphaDuraion;
                                float rotateY = 0.0f;
                                if (textArr.length >= 7) {
                                    float rotateZ2 = Float.parseFloat(textArr[5]);
                                    rotateY = Float.parseFloat(textArr[6]);
                                    rotateZ = rotateZ2;
                                } else {
                                    rotateZ = 0.0f;
                                }
                                if (textArr.length >= 11) {
                                    endX = Float.parseFloat(textArr[7]);
                                    endY = Float.parseFloat(textArr[8]);
                                    if (!"".equals(textArr[9])) {
                                        translationDuration2 = (long) Integer.parseInt(textArr[9]);
                                    }
                                    if (!"".equals(textArr[10])) {
                                        translationStartDelay = (long) Float.parseFloat(textArr[10]);
                                        translationDuration = translationDuration2;
                                    } else {
                                        translationDuration = translationDuration2;
                                        translationStartDelay = 0;
                                    }
                                } else {
                                    translationDuration = translationDuration2;
                                    translationStartDelay = 0;
                                }
                                float beginX2 = beginX;
                                if (BiliDanmukuParser.this.isPercentageNumber(beginX2)) {
                                    beginX2 *= 682.0f;
                                }
                                if (BiliDanmukuParser.this.isPercentageNumber(beginY)) {
                                    beginY *= 438.0f;
                                }
                                if (BiliDanmukuParser.this.isPercentageNumber(endX)) {
                                    endX *= 682.0f;
                                }
                                if (BiliDanmukuParser.this.isPercentageNumber(endY)) {
                                    endY *= 438.0f;
                                }
                                this.item.duration = new Duration(alphaDuraion);
                                this.item.rotationZ = rotateZ;
                                this.item.rotationY = rotateY;
                                BiliDanmukuParser.this.mContext.mDanmakuFactory.fillTranslationData(this.item, beginX2, beginY, endX, endY, translationDuration, translationStartDelay, BiliDanmukuParser.this.mDispScaleX, BiliDanmukuParser.this.mDispScaleY);
                                BiliDanmukuParser.this.mContext.mDanmakuFactory.fillAlphaData(this.item, beginAlpha, endAlpha, alphaDuraion);
                                if (textArr.length >= 12 && !TextUtils.isEmpty(textArr[11]) && "true".equals(textArr[11])) {
                                    this.item.textShadowColor = 0;
                                }
                                int length2 = textArr.length;
                                int length3 = textArr.length;
                                if (textArr.length < 15) {
                                    return;
                                }
                                if (!"".equals(textArr[14])) {
                                    String[] pointStrArray = textArr[14].substring(1).split("L");
                                    if (pointStrArray != null && pointStrArray.length > 0) {
                                        int length4 = pointStrArray.length;
                                        int[] iArr = new int[2];
                                        iArr[1] = 2;
                                        iArr[0] = length4;
                                        float[][] points = (float[][]) Array.newInstance(float.class, iArr);
                                        int i3 = 0;
                                        while (i3 < pointStrArray.length) {
                                            String[] pointArray = pointStrArray[i3].split(",");
                                            points[i3][0] = Float.parseFloat(pointArray[0]);
                                            points[i3][1] = Float.parseFloat(pointArray[1]);
                                            i3++;
                                            pointStrArray = pointStrArray;
                                        }
                                        DanmakuFactory danmakuFactory = BiliDanmukuParser.this.mContext.mDanmakuFactory;
                                        DanmakuFactory.fillLinePathData(this.item, points, BiliDanmukuParser.this.mDispScaleX, BiliDanmukuParser.this.mDispScaleY);
                                        return;
                                    }
                                    return;
                                }
                                return;
                            }
                        }
                        this.item = null;
                    }
                }
            }
        }

        private String decodeXmlString(String title) {
            if (title.contains("&amp;")) {
                title = title.replace("&amp;", a.n);
            }
            if (title.contains("&quot;")) {
                title = title.replace("&quot;", "\"");
            }
            if (title.contains("&gt;")) {
                title = title.replace("&gt;", Operators.G);
            }
            if (title.contains("&lt;")) {
                return title.replace("&lt;", Operators.L);
            }
            return title;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isPercentageNumber(float number) {
        return number >= 0.0f && number <= 1.0f;
    }

    @Override // master.flame.danmaku.danmaku.parser.BaseDanmakuParser
    public BaseDanmakuParser setDisplayer(IDisplayer disp) {
        super.setDisplayer(disp);
        this.mDispScaleX = ((float) this.mDispWidth) / 682.0f;
        this.mDispScaleY = ((float) this.mDispHeight) / 438.0f;
        return this;
    }
}
