package io.dcloud.media.weex.weex_video.ijkplayer.media;

import android.view.View;
import java.lang.ref.WeakReference;

public final class MeasureHelper {
    private int mCurrentAspectRatio = 0;
    private int mMeasuredHeight;
    private int mMeasuredWidth;
    private int mVideoHeight;
    private int mVideoRotationDegree;
    private int mVideoSarDen;
    private int mVideoSarNum;
    private int mVideoWidth;
    private WeakReference<View> mWeakView;

    public MeasureHelper(View view) {
        this.mWeakView = new WeakReference<>(view);
    }

    public View getView() {
        WeakReference<View> weakReference = this.mWeakView;
        if (weakReference == null) {
            return null;
        }
        return weakReference.get();
    }

    public void setVideoSize(int videoWidth, int videoHeight) {
        this.mVideoWidth = videoWidth;
        this.mVideoHeight = videoHeight;
    }

    public void setVideoSampleAspectRatio(int videoSarNum, int videoSarDen) {
        this.mVideoSarNum = videoSarNum;
        this.mVideoSarDen = videoSarDen;
    }

    public void setVideoRotation(int videoRotationDegree) {
        this.mVideoRotationDegree = videoRotationDegree;
    }

    public void doMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        int heightMeasureSpec2;
        int widthMeasureSpec2;
        float displayAspectRatio;
        int i;
        int i2 = this.mVideoRotationDegree;
        if (i2 == 90 || i2 == 270) {
            widthMeasureSpec2 = heightMeasureSpec;
            heightMeasureSpec2 = widthMeasureSpec;
        } else {
            widthMeasureSpec2 = widthMeasureSpec;
            heightMeasureSpec2 = heightMeasureSpec;
        }
        int width = View.getDefaultSize(this.mVideoWidth, widthMeasureSpec2);
        int height = View.getDefaultSize(this.mVideoHeight, heightMeasureSpec2);
        if (this.mCurrentAspectRatio == 3) {
            width = widthMeasureSpec2;
            height = heightMeasureSpec2;
        } else if (this.mVideoWidth > 0 && this.mVideoHeight > 0) {
            int widthSpecMode = View.MeasureSpec.getMode(widthMeasureSpec2);
            int widthSpecSize = View.MeasureSpec.getSize(widthMeasureSpec2);
            int heightSpecMode = View.MeasureSpec.getMode(heightMeasureSpec2);
            int heightSpecSize = View.MeasureSpec.getSize(heightMeasureSpec2);
            if (widthSpecMode == Integer.MIN_VALUE || heightSpecMode == Integer.MIN_VALUE) {
                float specAspectRatio = ((float) widthSpecSize) / ((float) heightSpecSize);
                int i3 = this.mCurrentAspectRatio;
                if (i3 == 4) {
                    int i4 = this.mVideoRotationDegree;
                    displayAspectRatio = (i4 == 90 || i4 == 270) ? 1.0f / 1.7777778f : 1.7777778f;
                } else if (i3 != 5) {
                    displayAspectRatio = ((float) this.mVideoWidth) / ((float) this.mVideoHeight);
                    int i5 = this.mVideoSarNum;
                    if (i5 > 0 && (i = this.mVideoSarDen) > 0) {
                        displayAspectRatio = (((float) i5) * displayAspectRatio) / ((float) i);
                    }
                } else {
                    int i6 = this.mVideoRotationDegree;
                    displayAspectRatio = (i6 == 90 || i6 == 270) ? 1.0f / 1.3333334f : 1.3333334f;
                }
                boolean shouldBeWider = displayAspectRatio > specAspectRatio;
                int i7 = this.mCurrentAspectRatio;
                if (i7 != 0) {
                    if (i7 != 1) {
                        if (!(i7 == 4 || i7 == 5)) {
                            if (shouldBeWider) {
                                width = Math.min(this.mVideoWidth, widthSpecSize);
                                height = (int) (((float) width) / displayAspectRatio);
                            } else {
                                int height2 = Math.min(this.mVideoHeight, heightSpecSize);
                                width = (int) (((float) height2) * displayAspectRatio);
                                height = height2;
                            }
                        }
                    } else if (shouldBeWider) {
                        width = (int) (((float) heightSpecSize) * displayAspectRatio);
                        height = heightSpecSize;
                    } else {
                        width = widthSpecSize;
                        height = (int) (((float) width) / displayAspectRatio);
                    }
                }
                if (shouldBeWider) {
                    width = widthSpecSize;
                    height = (int) (((float) width) / displayAspectRatio);
                } else {
                    width = (int) (((float) heightSpecSize) * displayAspectRatio);
                    height = heightSpecSize;
                }
            } else if (widthSpecMode == 1073741824 && heightSpecMode == 1073741824) {
                width = widthSpecSize;
                height = heightSpecSize;
                int i8 = this.mVideoWidth;
                int i9 = i8 * height;
                int i10 = this.mVideoHeight;
                if (i9 < width * i10) {
                    width = (i8 * height) / i10;
                } else if (i8 * height > width * i10) {
                    height = (i10 * width) / i8;
                }
            } else if (widthSpecMode == 1073741824) {
                width = widthSpecSize;
                height = (this.mVideoHeight * width) / this.mVideoWidth;
                if (heightSpecMode == Integer.MIN_VALUE && height > heightSpecSize) {
                    height = heightSpecSize;
                }
            } else if (heightSpecMode == 1073741824) {
                height = heightSpecSize;
                width = (this.mVideoWidth * height) / this.mVideoHeight;
                if (widthSpecMode == Integer.MIN_VALUE && width > widthSpecSize) {
                    width = widthSpecSize;
                }
            } else {
                width = this.mVideoWidth;
                int height3 = this.mVideoHeight;
                if (heightSpecMode != Integer.MIN_VALUE || height3 <= heightSpecSize) {
                    height = height3;
                } else {
                    height = heightSpecSize;
                    width = (this.mVideoWidth * heightSpecSize) / this.mVideoHeight;
                }
                if (widthSpecMode == Integer.MIN_VALUE && width > widthSpecSize) {
                    width = widthSpecSize;
                    height = (this.mVideoHeight * width) / this.mVideoWidth;
                }
            }
        }
        this.mMeasuredWidth = width;
        this.mMeasuredHeight = height;
    }

    public int getMeasuredWidth() {
        return this.mMeasuredWidth;
    }

    public int getMeasuredHeight() {
        return this.mMeasuredHeight;
    }

    public void setAspectRatio(int aspectRatio) {
        this.mCurrentAspectRatio = aspectRatio;
    }
}
