package io.dcloud.share.mm;

import android.app.Activity;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.ColorDrawable;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.Display;
import androidx.core.content.FileProvider;
import com.dcloud.android.widget.toast.ToastCompat;
import com.meizu.cloud.pushsdk.constants.PushConstants;
import com.nostra13.dcloudimageloader.core.DisplayImageOptions;
import com.nostra13.dcloudimageloader.core.ImageLoaderL;
import com.nostra13.dcloudimageloader.core.assist.ImageScaleType;
import com.tencent.mm.opensdk.channel.MMessageActV2;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram;
import com.tencent.mm.opensdk.modelbiz.WXOpenCustomerServiceChat;
import com.tencent.mm.opensdk.modelmsg.SendMessageToWX;
import com.tencent.mm.opensdk.modelmsg.WXImageObject;
import com.tencent.mm.opensdk.modelmsg.WXMediaMessage;
import com.tencent.mm.opensdk.modelmsg.WXMiniProgramObject;
import com.tencent.mm.opensdk.modelmsg.WXMusicObject;
import com.tencent.mm.opensdk.modelmsg.WXMusicVideoObject;
import com.tencent.mm.opensdk.modelmsg.WXTextObject;
import com.tencent.mm.opensdk.modelmsg.WXVideoObject;
import com.tencent.mm.opensdk.modelmsg.WXWebpageObject;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.RInformation;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.share.weixin.R;
import io.dcloud.share.IFShareApi;
import io.dcloud.share.IWeiXinFShareApi;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class WeiXinApiManager implements IWeiXinFShareApi {
    private static String APPID = null;
    public static final String AUTHORIZE_TEMPLATE = "{authenticated:%s,accessToken:'%s'}";
    private static final int ERROR_IMAGE_LIMIT = -102;
    private static final int ERROR_IMAGE_ONT_FOUND = -103;
    private static final int ERROR_NOTYPE = -100;
    private static final int ERROR_NOT_COMPLETE = -101;
    private static final int ERROR_NOT_SUPPORT_VERSION_CODE = -104;
    private static final String ERROR_NOT_SUPPORT_VERSION_MSG = "the current wechat client version does not support this function";
    public static final String KEY_APPID = "appid";
    private static final String TAG = "WeiXinApiManager";
    public static final int THUMB_SIZE = 150;
    private static final String WEIXIN_DES = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_desc);
    public static final String WEIXIN_ID = "weixin";
    private IWXAPI api;
    FeatureMessageDispatcher.MessageListener sSendCallbackMessageListener = new FeatureMessageDispatcher.MessageListener() {
        /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass1 */

        @Override // io.dcloud.common.DHInterface.FeatureMessageDispatcher.MessageListener
        public void onReceiver(Object msg) {
            if (msg instanceof BaseResp) {
                WeiXinApiManager.this.executeSendCallbackMsg((BaseResp) msg);
                FeatureMessageDispatcher.unregisterListener(WeiXinApiManager.this.sSendCallbackMessageListener);
            }
        }
    };
    Object[] sendCallbackMsg = null;

    @Override // io.dcloud.share.IFShareApi
    public void initConfig() {
        initData();
    }

    public void initData() {
        APPID = AndroidResources.getMetaValue("WX_APPID");
    }

    private boolean hasFullConfigData() {
        return !TextUtils.isEmpty(APPID);
    }

    private boolean hasGeneralError(IWebview pWebViewImpl, String pCallbackId) {
        if (!hasFullConfigData()) {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT)), JSUtil.ERROR, true, false);
            return true;
        } else if (PlatformUtil.isAppInstalled(pWebViewImpl.getContext(), "com.tencent.mm")) {
            return false;
        } else {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED)), JSUtil.ERROR, true, false);
            return true;
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public String getId() {
        return WEIXIN_ID;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void registerSendCallbackMsg(Object[] args) {
        this.sendCallbackMsg = args;
    }

    /* access modifiers changed from: package-private */
    public void executeSendCallbackMsg(BaseResp resp) {
        Object[] objArr = this.sendCallbackMsg;
        if (objArr != null) {
            IWebview pWebViewImpl = (IWebview) objArr[0];
            String pCallbackId = (String) objArr[1];
            if (resp == null) {
                return;
            }
            if (resp instanceof WXLaunchMiniProgram.Resp) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, ((WXLaunchMiniProgram.Resp) resp).extMsg, JSUtil.OK, false, false);
            } else {
                onSendCallBack(pWebViewImpl, pCallbackId, resp.errCode);
            }
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void send(final IWebview pWebViewImpl, final String pCallbackId, final String pShareMsg) {
        if (!hasGeneralError(pWebViewImpl, pCallbackId)) {
            new Thread() {
                /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2 */

                /* JADX WARNING: Removed duplicated region for block: B:166:0x037e  */
                /* JADX WARNING: Removed duplicated region for block: B:168:0x0393  */
                public void run() {
                    int mRunningMode;
                    char c;
                    String AbsFullPathThumb;
                    String AbsFullPath;
                    String pThumbImg;
                    String pImg;
                    SendMessageToWX.Req req;
                    boolean isContinue;
                    boolean isContinue2;
                    Exception e;
                    String pThumbImg2;
                    try {
                        JSONObject _msg = new JSONObject(pShareMsg);
                        String type = _msg.optString("type");
                        String _content = _msg.optString("content");
                        String _title = _msg.optString("title");
                        String href = _msg.optString("href");
                        String media = _msg.optString("media");
                        JSONArray _thumbs = _msg.optJSONArray("thumbs");
                        JSONArray _pictures = _msg.optJSONArray("pictures");
                        JSONObject extraInfo = JSONUtil.getJSONObject(_msg, PushConstants.EXTRA);
                        SendMessageToWX.Req req2 = new SendMessageToWX.Req();
                        req2.scene = 0;
                        if (extraInfo != null && !extraInfo.isNull("scene")) {
                            String senceValue = JSONUtil.getString(extraInfo, "scene");
                            if ("WXSceneSession".equals(senceValue)) {
                                req2.scene = 0;
                            } else if ("WXSceneFavorite".equals(senceValue)) {
                                req2.scene = 2;
                            } else {
                                if (!"WXSceneTimeline".equals(senceValue)) {
                                    if ("WXSenceTimeline".equals(senceValue)) {
                                    }
                                }
                                req2.scene = 1;
                            }
                        }
                        String pImg2 = null;
                        String pThumbImg3 = null;
                        String AbsFullPath2 = null;
                        String AbsFullPathThumb2 = null;
                        int mRunningMode2 = 0;
                        try {
                            String str = null;
                            if (!TextUtils.isEmpty(type)) {
                                try {
                                    if (type.equals("text")) {
                                        try {
                                            isContinue = WeiXinApiManager.this.reqTextMsg(req2, _content, _title);
                                            req = req2;
                                            c = 1;
                                        } catch (Exception e2) {
                                            e = e2;
                                            isContinue2 = false;
                                            req = req2;
                                            c = 1;
                                            e.printStackTrace();
                                            pImg = pImg2;
                                            pThumbImg = pThumbImg3;
                                            AbsFullPath = AbsFullPath2;
                                            AbsFullPathThumb = AbsFullPathThumb2;
                                            isContinue = isContinue2;
                                            mRunningMode = mRunningMode2;
                                            if (isContinue) {
                                            }
                                        }
                                    } else if (type.equals("image")) {
                                        if (_pictures != null) {
                                            try {
                                                if (_pictures.length() != 0) {
                                                    c = 1;
                                                    isContinue2 = false;
                                                    try {
                                                        isContinue = WeiXinApiManager.this.reqImageMsg(pWebViewImpl, req2, _pictures, _thumbs, _title, pCallbackId);
                                                        req = req2;
                                                    } catch (Exception e3) {
                                                        e = e3;
                                                        req = req2;
                                                        e.printStackTrace();
                                                        pImg = pImg2;
                                                        pThumbImg = pThumbImg3;
                                                        AbsFullPath = AbsFullPath2;
                                                        AbsFullPathThumb = AbsFullPathThumb2;
                                                        isContinue = isContinue2;
                                                        mRunningMode = mRunningMode2;
                                                        if (isContinue) {
                                                        }
                                                    }
                                                }
                                            } catch (Exception e4) {
                                                e = e4;
                                                isContinue2 = false;
                                                c = 1;
                                                req = req2;
                                                e.printStackTrace();
                                                pImg = pImg2;
                                                pThumbImg = pThumbImg3;
                                                AbsFullPath = AbsFullPath2;
                                                AbsFullPathThumb = AbsFullPathThumb2;
                                                isContinue = isContinue2;
                                                mRunningMode = mRunningMode2;
                                                if (isContinue) {
                                                }
                                            }
                                        }
                                        WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -101);
                                        return;
                                    } else {
                                        isContinue2 = false;
                                        c = 1;
                                        try {
                                            if (type.equals("music")) {
                                                try {
                                                    if (PdrUtil.isEmpty(media)) {
                                                        WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -101);
                                                        return;
                                                    }
                                                    WeiXinApiManager weiXinApiManager = WeiXinApiManager.this;
                                                    IWebview iWebview = pWebViewImpl;
                                                    if (_thumbs != null) {
                                                        str = _thumbs.optString(0, null);
                                                    }
                                                    try {
                                                        isContinue = weiXinApiManager.reqMusicMsg(iWebview, req2, href, media, str, _content, _title);
                                                        req = req2;
                                                    } catch (Exception e5) {
                                                        e = e5;
                                                        req = req2;
                                                        e.printStackTrace();
                                                        pImg = pImg2;
                                                        pThumbImg = pThumbImg3;
                                                        AbsFullPath = AbsFullPath2;
                                                        AbsFullPathThumb = AbsFullPathThumb2;
                                                        isContinue = isContinue2;
                                                        mRunningMode = mRunningMode2;
                                                        if (isContinue) {
                                                        }
                                                    }
                                                } catch (Exception e6) {
                                                    e = e6;
                                                    req = req2;
                                                    e.printStackTrace();
                                                    pImg = pImg2;
                                                    pThumbImg = pThumbImg3;
                                                    AbsFullPath = AbsFullPath2;
                                                    AbsFullPathThumb = AbsFullPathThumb2;
                                                    isContinue = isContinue2;
                                                    mRunningMode = mRunningMode2;
                                                    if (isContinue) {
                                                    }
                                                }
                                            } else {
                                                try {
                                                    if (type.equals("video")) {
                                                        if (PdrUtil.isEmpty(media)) {
                                                            WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -101);
                                                            return;
                                                        }
                                                        try {
                                                            isContinue = WeiXinApiManager.this.reqVideoMsg(pWebViewImpl, req2, media, _thumbs != null ? _thumbs.optString(0, null) : null, _content, _title);
                                                            req = req2;
                                                        } catch (Exception e7) {
                                                            e = e7;
                                                            req = req2;
                                                            e.printStackTrace();
                                                            pImg = pImg2;
                                                            pThumbImg = pThumbImg3;
                                                            AbsFullPath = AbsFullPath2;
                                                            AbsFullPathThumb = AbsFullPathThumb2;
                                                            isContinue = isContinue2;
                                                            mRunningMode = mRunningMode2;
                                                            if (isContinue) {
                                                            }
                                                        }
                                                    } else if (type.equals("web")) {
                                                        if (PdrUtil.isEmpty(href)) {
                                                            WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -101);
                                                            return;
                                                        } else {
                                                            isContinue = WeiXinApiManager.this.reqWebPageMsg(pWebViewImpl, req2, href, _thumbs != null ? _thumbs.optString(0, null) : null, _content, _title);
                                                            req = req2;
                                                        }
                                                    } else if (type.equals("miniProgram")) {
                                                        JSONObject miniProgram = _msg.optJSONObject("miniProgram");
                                                        if (miniProgram == null) {
                                                            WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -101);
                                                            return;
                                                        }
                                                        WeiXinApiManager weiXinApiManager2 = WeiXinApiManager.this;
                                                        IWebview iWebview2 = pWebViewImpl;
                                                        if (_thumbs != null) {
                                                            str = _thumbs.optString(0, null);
                                                        }
                                                        isContinue = weiXinApiManager2.reqMiniMsg(iWebview2, req2, str, _content, _title, miniProgram);
                                                        req = req2;
                                                    } else if (type.equals("musicVideo")) {
                                                        isContinue = false;
                                                        req = req2;
                                                    } else {
                                                        WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -100);
                                                        return;
                                                    }
                                                } catch (Exception e8) {
                                                    e = e8;
                                                    req = req2;
                                                    e.printStackTrace();
                                                    pImg = pImg2;
                                                    pThumbImg = pThumbImg3;
                                                    AbsFullPath = AbsFullPath2;
                                                    AbsFullPathThumb = AbsFullPathThumb2;
                                                    isContinue = isContinue2;
                                                    mRunningMode = mRunningMode2;
                                                    if (isContinue) {
                                                    }
                                                }
                                            }
                                        } catch (Exception e9) {
                                            e = e9;
                                            req = req2;
                                            e.printStackTrace();
                                            pImg = pImg2;
                                            pThumbImg = pThumbImg3;
                                            AbsFullPath = AbsFullPath2;
                                            AbsFullPathThumb = AbsFullPathThumb2;
                                            isContinue = isContinue2;
                                            mRunningMode = mRunningMode2;
                                            if (isContinue) {
                                            }
                                        }
                                    }
                                } catch (Exception e10) {
                                    e = e10;
                                    isContinue2 = false;
                                    c = 1;
                                    req = req2;
                                    e.printStackTrace();
                                    pImg = pImg2;
                                    pThumbImg = pThumbImg3;
                                    AbsFullPath = AbsFullPath2;
                                    AbsFullPathThumb = AbsFullPathThumb2;
                                    isContinue = isContinue2;
                                    mRunningMode = mRunningMode2;
                                    if (isContinue) {
                                    }
                                }
                            } else {
                                isContinue2 = false;
                                c = 1;
                                try {
                                    if (!PdrUtil.isEmpty(href)) {
                                        isContinue = WeiXinApiManager.this.reqWebPageMsg(pWebViewImpl, req2, href, _thumbs != null ? _thumbs.optString(0, null) : null, _content, _title);
                                        req = req2;
                                    } else if (_pictures == null || _pictures.length() <= 0) {
                                        req = req2;
                                        try {
                                            isContinue = WeiXinApiManager.this.reqTextMsg(req, _content, _title);
                                        } catch (Exception e11) {
                                            e = e11;
                                            e.printStackTrace();
                                            pImg = pImg2;
                                            pThumbImg = pThumbImg3;
                                            AbsFullPath = AbsFullPath2;
                                            AbsFullPathThumb = AbsFullPathThumb2;
                                            isContinue = isContinue2;
                                            mRunningMode = mRunningMode2;
                                            if (isContinue) {
                                            }
                                        }
                                    } else {
                                        String pImg3 = _pictures.optString(0);
                                        if (_thumbs != null) {
                                            try {
                                                if (!_thumbs.isNull(0)) {
                                                    pThumbImg2 = _thumbs.optString(0);
                                                    AbsFullPath2 = pWebViewImpl.obtainFrameView().obtainApp().convert2AbsFullPath(pWebViewImpl.obtainFullUrl(), pImg3);
                                                    AbsFullPathThumb2 = pWebViewImpl.obtainFrameView().obtainApp().convert2AbsFullPath(pWebViewImpl.obtainFullUrl(), pThumbImg2);
                                                    mRunningMode2 = pWebViewImpl.obtainFrameView().obtainApp().obtainRunningAppMode();
                                                    try {
                                                        isContinue = WeiXinApiManager.this.reqImageMsg(pWebViewImpl, req2, _pictures, _thumbs, _title, pCallbackId);
                                                        pThumbImg3 = pThumbImg2;
                                                        req = req2;
                                                        pImg2 = pImg3;
                                                    } catch (Exception e12) {
                                                        e = e12;
                                                        pThumbImg3 = pThumbImg2;
                                                        req = req2;
                                                        pImg2 = pImg3;
                                                        e.printStackTrace();
                                                        pImg = pImg2;
                                                        pThumbImg = pThumbImg3;
                                                        AbsFullPath = AbsFullPath2;
                                                        AbsFullPathThumb = AbsFullPathThumb2;
                                                        isContinue = isContinue2;
                                                        mRunningMode = mRunningMode2;
                                                        if (isContinue) {
                                                        }
                                                    }
                                                }
                                            } catch (Exception e13) {
                                                e = e13;
                                                pImg2 = pImg3;
                                                req = req2;
                                                e.printStackTrace();
                                                pImg = pImg2;
                                                pThumbImg = pThumbImg3;
                                                AbsFullPath = AbsFullPath2;
                                                AbsFullPathThumb = AbsFullPathThumb2;
                                                isContinue = isContinue2;
                                                mRunningMode = mRunningMode2;
                                                if (isContinue) {
                                                }
                                            }
                                        }
                                        pThumbImg2 = pImg3;
                                        try {
                                            AbsFullPath2 = pWebViewImpl.obtainFrameView().obtainApp().convert2AbsFullPath(pWebViewImpl.obtainFullUrl(), pImg3);
                                            AbsFullPathThumb2 = pWebViewImpl.obtainFrameView().obtainApp().convert2AbsFullPath(pWebViewImpl.obtainFullUrl(), pThumbImg2);
                                            mRunningMode2 = pWebViewImpl.obtainFrameView().obtainApp().obtainRunningAppMode();
                                            isContinue = WeiXinApiManager.this.reqImageMsg(pWebViewImpl, req2, _pictures, _thumbs, _title, pCallbackId);
                                            pThumbImg3 = pThumbImg2;
                                            req = req2;
                                            pImg2 = pImg3;
                                        } catch (Exception e14) {
                                            e = e14;
                                            pThumbImg3 = pThumbImg2;
                                            req = req2;
                                            pImg2 = pImg3;
                                            e.printStackTrace();
                                            pImg = pImg2;
                                            pThumbImg = pThumbImg3;
                                            AbsFullPath = AbsFullPath2;
                                            AbsFullPathThumb = AbsFullPathThumb2;
                                            isContinue = isContinue2;
                                            mRunningMode = mRunningMode2;
                                            if (isContinue) {
                                            }
                                        }
                                    }
                                } catch (Exception e15) {
                                    e = e15;
                                    req = req2;
                                    e.printStackTrace();
                                    pImg = pImg2;
                                    pThumbImg = pThumbImg3;
                                    AbsFullPath = AbsFullPath2;
                                    AbsFullPathThumb = AbsFullPathThumb2;
                                    isContinue = isContinue2;
                                    mRunningMode = mRunningMode2;
                                    if (isContinue) {
                                    }
                                }
                            }
                            pImg = pImg2;
                            pThumbImg = pThumbImg3;
                            AbsFullPath = AbsFullPath2;
                            AbsFullPathThumb = AbsFullPathThumb2;
                            mRunningMode = mRunningMode2;
                        } catch (Exception e16) {
                            e = e16;
                            isContinue2 = false;
                            req = req2;
                            c = 1;
                            e.printStackTrace();
                            pImg = pImg2;
                            pThumbImg = pThumbImg3;
                            AbsFullPath = AbsFullPath2;
                            AbsFullPathThumb = AbsFullPathThumb2;
                            isContinue = isContinue2;
                            mRunningMode = mRunningMode2;
                            if (isContinue) {
                            }
                        }
                        if (isContinue) {
                            pWebViewImpl.obtainWindowView().postDelayed(new Runnable() {
                                /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2.AnonymousClass1 */

                                public void run() {
                                    WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, 0);
                                }
                            }, 500);
                        } else if ((pWebViewImpl.getActivity() instanceof IActivityHandler) && ((IActivityHandler) pWebViewImpl.getActivity()).isMultiProcessMode()) {
                            WeiXinApiManager.this.startWeiXinMediator(pWebViewImpl, pCallbackId, req, pImg, pThumbImg, AbsFullPath, AbsFullPathThumb, mRunningMode);
                        } else if (!WeiXinApiManager.this.api.sendReq(req) || !WeiXinApiManager.this.hasWXEntryActivity(pWebViewImpl.getContext())) {
                            pWebViewImpl.obtainWindowView().postDelayed(new Runnable() {
                                /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass2.AnonymousClass2 */

                                public void run() {
                                    WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -3);
                                }
                            }, 500);
                        } else {
                            FeatureMessageDispatcher.registerListener(WeiXinApiManager.this.sSendCallbackMessageListener);
                            WeiXinApiManager weiXinApiManager3 = WeiXinApiManager.this;
                            Object[] objArr = new Object[2];
                            objArr[0] = pWebViewImpl;
                            objArr[c] = pCallbackId;
                            weiXinApiManager3.registerSendCallbackMsg(objArr);
                        }
                    } catch (Exception e17) {
                        e17.printStackTrace();
                    }
                }
            }.start();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startWeiXinMediator(final IWebview pWebViewImpl, final String pCallbackId, SendMessageToWX.Req req, String pImg, String pThumbImg, String absFullPath, String AbsFullPathThumb, int mRunningMode) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WeiXinMediator.class.getName());
        Bundle bundle = new Bundle();
        req.toBundle(bundle);
        bundle.putString("pImg", pImg);
        bundle.putString("pThumbImg", pThumbImg);
        bundle.putString("absFullPath", absFullPath);
        bundle.putString("AbsFullPathThumb", AbsFullPathThumb);
        bundle.putInt("mRunningMode", mRunningMode);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.setClassName(pWebViewImpl.getActivity(), WXShareProcessMeadiatorActivity.class.getName());
        intent.putExtra("transaction", req.transaction);
        pWebViewImpl.getActivity().startActivityForResult(intent, 1000);
        pWebViewImpl.getActivity().overridePendingTransition(0, 0);
        pWebViewImpl.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass3 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Object[] _args = (Object[]) pArgs;
                int requestCode = ((Integer) _args[0]).intValue();
                ((Integer) _args[1]).intValue();
                Intent data = (Intent) _args[2];
                if (pEventType == ISysEventListener.SysEventType.onActivityResult && requestCode == 1000) {
                    Bundle bundle = data.getBundleExtra("result");
                    if (bundle == null) {
                        WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, -3);
                    } else {
                        String s = bundle.getString("style");
                        if ("BaseResp".equals(s)) {
                            SendMessageToWX.Resp resp = new SendMessageToWX.Resp();
                            resp.fromBundle(bundle);
                            WeiXinApiManager.this.onSendCallBack(pWebViewImpl, pCallbackId, resp.errCode);
                        } else {
                            "BaseReq".equals(s);
                        }
                    }
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    private void startWXMiniProgramMediator(final IWebview webview, final String callbackId, String id, String path, int type) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WeiXinMediator.class.getName());
        Bundle bundle = new Bundle();
        bundle.putString("userName", id);
        bundle.putString("path", path);
        bundle.putInt("miniprogramType", type);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.setClassName(webview.getActivity(), WXShareProcessMeadiatorActivity.class.getName());
        intent.putExtra(WeiXinMediator.WX_MINI_PROGRAM_KEY, true);
        intent.putExtra(ProcessMediator.PROCESS_ACTIVITY_SOURCE, webview.getActivity().getClass().getName());
        webview.getActivity().startActivityForResult(intent, 1000);
        webview.getActivity().overridePendingTransition(0, 0);
        webview.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.mm.WeiXinApiManager.AnonymousClass4 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Object[] _args = (Object[]) pArgs;
                int requestCode = ((Integer) _args[0]).intValue();
                Intent data = (Intent) _args[2];
                if (pEventType == ISysEventListener.SysEventType.onActivityResult && requestCode == 1000) {
                    Bundle bundle = data.getBundleExtra("result");
                    if (bundle == null) {
                        WeiXinApiManager.this.onSendCallBack(webview, callbackId, -3);
                    } else {
                        String s = bundle.getString("style");
                        if ("BaseResp".equals(s)) {
                            WXLaunchMiniProgram.Resp resp = new WXLaunchMiniProgram.Resp();
                            resp.fromBundle(bundle);
                            Deprecated_JSUtil.execCallback(webview, callbackId, resp.extMsg, JSUtil.OK, false, false);
                        } else {
                            "BaseReq".equals(s);
                        }
                    }
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    public void send(Activity activity, String msg) {
        try {
            JSONObject msgJs = new JSONObject(msg);
            String content = msgJs.getString("content");
            String href = msgJs.getString("href");
            String thumbs = msgJs.optString("thumbs");
            int flag = msgJs.getInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            WXWebpageObject webpage = new WXWebpageObject();
            webpage.webpageUrl = href;
            WXMediaMessage wxmsg = new WXMediaMessage(webpage);
            wxmsg.description = content;
            wxmsg.title = content;
            Bitmap thumb = null;
            if (!TextUtils.isEmpty(thumbs) && new File(thumbs).exists()) {
                thumb = BitmapFactory.decodeFile(thumbs);
            }
            if (thumb == null) {
                thumb = BitmapFactory.decodeResource(activity.getResources(), RInformation.DRAWABLE_ICON);
            }
            wxmsg.setThumbImage(thumb);
            SendMessageToWX.Req req = new SendMessageToWX.Req();
            req.transaction = String.valueOf(System.currentTimeMillis());
            req.message = wxmsg;
            req.scene = flag;
            this.api.sendReq(req);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void sendImage(Activity activity, String msg) {
        try {
            JSONObject msgJs = new JSONObject(msg);
            String image = msgJs.optString("image");
            String thumbs = msgJs.optString("thumbs");
            String textToImage = msgJs.optString("textToImage");
            int flag = msgJs.optInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            Bitmap imageBitmap = null;
            if (!TextUtils.isEmpty(image) && new File(image).exists()) {
                imageBitmap = BitmapFactory.decodeFile(image);
            }
            if (imageBitmap == null && !TextUtils.isEmpty(textToImage)) {
                imageBitmap = StringUtil.textToBitmap(activity, textToImage);
            }
            if (imageBitmap != null) {
                WXImageObject imageObject = new WXImageObject(imageBitmap);
                WXMediaMessage wxmsg = new WXMediaMessage(imageObject);
                wxmsg.mediaObject = imageObject;
                Bitmap thumb = null;
                if (!TextUtils.isEmpty(thumbs) && new File(thumbs).exists()) {
                    thumb = BitmapFactory.decodeFile(thumbs);
                }
                if (thumb == null) {
                    thumb = BitmapFactory.decodeResource(activity.getResources(), RInformation.DRAWABLE_ICON);
                }
                wxmsg.setThumbImage(thumb);
                SendMessageToWX.Req req = new SendMessageToWX.Req();
                req.transaction = String.valueOf(System.currentTimeMillis());
                req.message = wxmsg;
                req.scene = flag;
                this.api.sendReq(req);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void sendText(Activity activity, String msg) {
        try {
            JSONObject msgJs = new JSONObject(msg);
            String text = msgJs.optString("text");
            int flag = msgJs.optInt("flag");
            initData();
            if (this.api == null) {
                this.api = WXAPIFactory.createWXAPI(activity.getApplicationContext(), APPID, true);
            }
            this.api.registerApp(APPID);
            if (!this.api.isWXAppInstalled()) {
                ToastCompat.makeText(activity.getApplicationContext(), (CharSequence) DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_client_not_installed), 0).show();
                return;
            }
            WXTextObject textObject = new WXTextObject();
            textObject.text = text;
            WXMediaMessage wxmsg = new WXMediaMessage(textObject);
            wxmsg.mediaObject = textObject;
            wxmsg.description = text;
            SendMessageToWX.Req req = new SendMessageToWX.Req();
            req.transaction = String.valueOf(System.currentTimeMillis());
            req.message = wxmsg;
            req.scene = flag;
            this.api.sendReq(req);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onSendCallBack(IWebview pWebViewImpl, String pCallbackId, int code) {
        boolean suc = false;
        String errorMsg = "send";
        if (code == -5) {
            errorMsg = "Unsupport error";
        } else if (code == -4) {
            errorMsg = "Authentication failed";
        } else if (code == -3) {
            errorMsg = "Unable to send";
        } else if (code == -2) {
            errorMsg = "User canceled";
        } else if (code == -1) {
            errorMsg = "General errors";
        } else if (code != 0) {
            switch (code) {
                case -103:
                    errorMsg = "Picture not found";
                    break;
                case -102:
                    errorMsg = "Picture maximum 512KB";
                    break;
                case -101:
                    errorMsg = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_param_not_complete);
                    break;
                case -100:
                    errorMsg = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_param_type_error);
                    break;
            }
        } else {
            suc = true;
        }
        if (suc) {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, "", JSUtil.OK, false, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -100, DOMException.toString(code, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_name), errorMsg, IFShareApi.mLink)), JSUtil.ERROR, true, false);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqTextMsg(SendMessageToWX.Req req, String pText, String pTitle) {
        WXTextObject textObj = new WXTextObject();
        textObj.text = pText;
        WXMediaMessage msg = new WXMediaMessage();
        msg.mediaObject = textObj;
        if (!PdrUtil.isEmpty(pTitle)) {
            msg.title = pTitle;
        } else if (req.scene == 1 && !TextUtils.isEmpty(pText)) {
            msg.title = pText;
        }
        msg.description = pText;
        req.transaction = buildTransaction("text");
        req.message = msg;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqImageMsg(IWebview pWebViewImpl, SendMessageToWX.Req req, JSONArray pImgs, JSONArray pThumbImgs, String pTitle, String callbackId) {
        String clssName;
        WXMediaMessage msg = new WXMediaMessage();
        if (pImgs.length() > 1) {
        }
        if (0 == 0) {
            String pImg = pImgs.optString(0);
            String pThumbImg = (pThumbImgs == null || pThumbImgs.isNull(0)) ? pImg : pThumbImgs.optString(0);
            if (PdrUtil.isNetPath(pImg)) {
                WXImageObject imgObj = new WXImageObject();
                try {
                    imgObj.imageData = bmpToByteArray(BitmapFactory.decodeStream(new URL(pImg).openStream()), true);
                } catch (MalformedURLException e) {
                    e.printStackTrace();
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
                msg.mediaObject = imgObj;
                msg.thumbData = buildThumbData(pWebViewImpl, PdrUtil.isEmpty(pThumbImg) ? pImg : pThumbImg);
            } else {
                String AbsFullPath = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), pImg);
                WXImageObject imgObj2 = new WXImageObject();
                File imgFile = new File(AbsFullPath);
                InputStream stream = null;
                Context context = pWebViewImpl.getContext();
                try {
                    if (imgFile.exists()) {
                        if (Build.VERSION.SDK_INT < 29) {
                            imgObj2.imagePath = imgFile.getPath();
                        } else if (FileUtil.checkPrivatePath(context, AbsFullPath)) {
                            String pat = context.getExternalCacheDir().getPath() + "/share/" + AbsFullPath.substring(AbsFullPath.lastIndexOf("/"));
                            DHFile.copyFile(AbsFullPath, pat);
                            Uri uri = FileProvider.getUriForFile(context, context.getPackageName() + ".dc.fileprovider", new File(pat));
                            context.grantUriPermission("com.tencent.mm", uri, 1);
                            imgObj2.imagePath = uri.toString();
                        } else if (FileUtil.isFilePathForPublic(context, AbsFullPath)) {
                            Uri uri2 = FileUtil.getImageFileUri(context, AbsFullPath);
                            if (uri2 != null) {
                                imgObj2.imagePath = uri2.toString();
                            } else {
                                stream = FileUtil.getImageFileStream(context, imgFile);
                            }
                        }
                        if (stream != null) {
                            if (stream.available() < 524288) {
                                imgObj2.imageData = IOUtil.getBytes(stream);
                                stream.close();
                            } else {
                                stream.close();
                                onSendCallBack(pWebViewImpl, callbackId, -102);
                                return false;
                            }
                        }
                        msg.mediaObject = imgObj2;
                        msg.thumbData = buildThumbData(pWebViewImpl, pThumbImg);
                    } else {
                        onSendCallBack(pWebViewImpl, callbackId, -103);
                        return false;
                    }
                } catch (Exception e3) {
                }
            }
            if (!PdrUtil.isEmpty(pTitle)) {
                msg.title = pTitle;
            }
            req.transaction = buildTransaction("img");
            req.message = msg;
            return true;
        }
        int i = req.scene;
        if (i == 0) {
            clssName = "com.tencent.mm.ui.chatting.ChattingUI";
        } else if (i == 1) {
            clssName = "com.tencent.mm.ui.tools.ShareToTimeLineUI";
        } else if (i != 2) {
            clssName = "com.tencent.mm.ui.tools.ShareToTimeLineUI";
        } else {
            clssName = "com.tencent.mm.plugin.favorite.ui.FavoriteIndexUI";
        }
        ArrayList<Uri> localArrayList = new ArrayList<>();
        for (int i2 = 0; i2 < pImgs.length(); i2++) {
            String pic = pImgs.optString(i2);
            if (PdrUtil.isNetPath(pic)) {
                try {
                    String t_path = pWebViewImpl.obtainApp().obtainAppTempPath() + System.currentTimeMillis() + ".png";
                    PdrUtil.saveBitmapToFile(BitmapFactory.decodeStream(new URL(pic).openStream()), t_path);
                    localArrayList.add(Uri.fromFile(new File(t_path)));
                } catch (MalformedURLException e4) {
                    e4.printStackTrace();
                } catch (IOException e5) {
                    e5.printStackTrace();
                }
            } else {
                localArrayList.add(FileUtil.getImageFileUri(pWebViewImpl.getContext(), pWebViewImpl.obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), pic)));
            }
        }
        sedMultiplePic(pWebViewImpl.getActivity(), localArrayList, clssName);
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqWebPageMsg(IWebview pWebViewImpl, SendMessageToWX.Req req, String webPage, String pThumbImg, String pText, String pTitle) {
        WXWebpageObject webpage = new WXWebpageObject();
        webpage.webpageUrl = webPage;
        WXMediaMessage msg = new WXMediaMessage(webpage);
        if (!PdrUtil.isEmpty(pTitle)) {
            msg.title = pTitle;
        } else if (req.scene == 1 && !TextUtils.isEmpty(pText)) {
            msg.title = pText;
        }
        msg.description = pText;
        if (!PdrUtil.isEmpty(pThumbImg)) {
            msg.thumbData = buildThumbData(pWebViewImpl, pThumbImg);
        }
        req.transaction = buildTransaction("webpage");
        req.message = msg;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqMusicMsg(IWebview pWebViewImpl, SendMessageToWX.Req req, String href, String musicUrl, String pThumbImg, String pText, String pTitle) {
        WXMusicObject music = new WXMusicObject();
        if (PdrUtil.isEmpty(href)) {
            music.musicUrl = musicUrl;
        } else {
            music.musicUrl = href;
            music.musicDataUrl = musicUrl;
        }
        WXMediaMessage msg = new WXMediaMessage();
        msg.mediaObject = music;
        if (!PdrUtil.isEmpty(pTitle)) {
            msg.title = pTitle;
        } else if (req.scene == 1 && !TextUtils.isEmpty(pText)) {
            msg.title = pText;
        }
        if (!PdrUtil.isEmpty(pThumbImg)) {
            msg.thumbData = buildThumbData(pWebViewImpl, pThumbImg);
        }
        msg.description = pText;
        req.transaction = buildTransaction("music");
        req.message = msg;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqVideoMsg(IWebview pWebViewImpl, SendMessageToWX.Req req, String videoUrl, String pThumbImg, String pText, String pTitle) {
        WXVideoObject video = new WXVideoObject();
        video.videoUrl = videoUrl;
        WXMediaMessage msg = new WXMediaMessage();
        msg.mediaObject = video;
        if (!PdrUtil.isEmpty(pTitle)) {
            msg.title = pTitle;
        } else if (req.scene == 1 && !TextUtils.isEmpty(pText)) {
            msg.title = pText;
        }
        if (!PdrUtil.isEmpty(pThumbImg)) {
            msg.thumbData = buildThumbData(pWebViewImpl, pThumbImg);
        }
        msg.description = pText;
        req.transaction = buildTransaction("video");
        req.message = msg;
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean reqMiniMsg(IWebview pWebViewImpl, SendMessageToWX.Req req, String pThumbImg, String pText, String pTitle, JSONObject miniProgram) {
        WXMiniProgramObject miniProgramObj = new WXMiniProgramObject();
        miniProgramObj.webpageUrl = miniProgram.optString("webUrl");
        miniProgramObj.miniprogramType = miniProgram.optInt("type");
        miniProgramObj.userName = miniProgram.optString("id");
        miniProgramObj.path = miniProgram.optString("path");
        WXMediaMessage msg = new WXMediaMessage(miniProgramObj);
        if (!PdrUtil.isEmpty(pTitle)) {
            msg.title = pTitle;
        } else if (req.scene == 1 && !TextUtils.isEmpty(pText)) {
            msg.title = pText;
        }
        req.scene = 0;
        if (!PdrUtil.isEmpty(pThumbImg)) {
            msg.thumbData = getMiniThumbaData(pWebViewImpl, pThumbImg);
        }
        msg.description = pText;
        req.transaction = buildTransaction("webpage");
        req.message = msg;
        return true;
    }

    private boolean reqMusicVideo(IWebview pWebViewImpl, SendMessageToWX.Req req, String href, String musicUrl, String songLyric, String pThumbImg, String hdAlbumThumb, String pTitle, String pDescription) {
        WXMusicVideoObject musicVideo = new WXMusicVideoObject();
        musicVideo.musicUrl = href;
        musicVideo.musicDataUrl = musicUrl;
        if (!TextUtils.isEmpty(songLyric)) {
            musicVideo.songLyric = songLyric;
        }
        if (!TextUtils.isEmpty(hdAlbumThumb)) {
            musicVideo.hdAlbumThumbFilePath = hdAlbumThumb;
        }
        musicVideo.singerName = "xxx";
        musicVideo.albumName = "album_xxx";
        musicVideo.musicGenre = "流行歌曲";
        musicVideo.issueDate = 1610713585;
        musicVideo.identification = "sample_identification";
        musicVideo.duration = 120000;
        WXMediaMessage msg = new WXMediaMessage();
        msg.mediaObject = musicVideo;
        msg.title = pTitle;
        msg.description = pDescription;
        msg.messageExt = "额外信息";
        msg.thumbData = buildThumbData(pWebViewImpl, pThumbImg);
        req.transaction = buildTransaction("musicVideo");
        req.message = msg;
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0037, code lost:
        if (r2 != null) goto L_0x0039;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x004a, code lost:
        if (0 == 0) goto L_0x0084;
     */
    private byte[] getMiniThumbaData(IWebview pWebViewImpl, String thumeImgPath) {
        Bitmap bitmap = null;
        InputStream is = null;
        String AbsFullPath = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), thumeImgPath);
        boolean isCompress = false;
        try {
            boolean z = false;
            if (PdrUtil.isNetPath(thumeImgPath)) {
                try {
                    is = new URL(thumeImgPath).openStream();
                    if (is.available() > 131072) {
                        z = true;
                    }
                    isCompress = z;
                    if (is != null) {
                        bitmap = BitmapFactory.decodeStream(is);
                    }
                } catch (MalformedURLException e) {
                    e.printStackTrace();
                } catch (IOException e2) {
                    e2.printStackTrace();
                    if (0 != 0) {
                        is.close();
                    }
                } catch (Throwable th) {
                    if (0 != 0) {
                        is.close();
                    }
                    throw th;
                }
            } else {
                InputStream stream = new FileInputStream(AbsFullPath);
                if (stream.available() > 131072) {
                    z = true;
                }
                isCompress = z;
                bitmap = BitmapFactory.decodeStream(stream);
                stream.close();
            }
        } catch (Exception e3) {
            e3.printStackTrace();
            Logger.e("buildThumbData Exception=" + e3);
        }
        if (bitmap == null) {
            bitmap = BitmapFactory.decodeResource(pWebViewImpl.getActivity().getResources(), RInformation.DRAWABLE_ICON);
        }
        if (bitmap != null && isCompress) {
            bitmap = cpBitmap(bitmap);
        }
        return bmpToByteArray(bitmap, true);
    }

    /* JADX INFO: Multiple debug info for r3v2 int: [D('imgStream' java.io.InputStream), D('imageWidth' int)] */
    public Bitmap scaleLoadPic(IWebview pWebViewImpl, String path) throws IOException {
        BitmapFactory.Options opts = new BitmapFactory.Options();
        opts.inJustDecodeBounds = true;
        if (FileUtil.checkPrivatePath(pWebViewImpl.getContext(), path)) {
            BitmapFactory.decodeFile(path, opts);
        } else {
            InputStream imgStream = FileUtil.getImageFileStream(pWebViewImpl.getContext(), new File(path));
            if (imgStream != null) {
                BitmapFactory.decodeStream(imgStream, null, opts);
                imgStream.close();
            }
        }
        int imageWidth = opts.outWidth;
        int imageHeigth = opts.outHeight;
        Display dp = pWebViewImpl.getActivity().getWindowManager().getDefaultDisplay();
        int scale = 1;
        int scaleWidth = imageWidth / dp.getWidth();
        int scaleHeight = imageHeigth / dp.getHeight();
        if (scaleWidth >= scaleHeight && scaleWidth >= 1) {
            scale = scaleWidth;
        } else if (scaleWidth < scaleHeight && scaleHeight >= 1) {
            scale = scaleHeight;
        }
        opts.inSampleSize = scale;
        opts.inJustDecodeBounds = false;
        if (path.startsWith("content://")) {
            Uri contentUri = Uri.parse(path);
            Cursor cursor = pWebViewImpl.getContext().getContentResolver().query(contentUri, null, null, null, null);
            if (cursor == null) {
                return null;
            }
            InputStream inputStream = null;
            try {
                inputStream = pWebViewImpl.getContext().getContentResolver().openInputStream(contentUri);
            } catch (FileNotFoundException e) {
                e.printStackTrace();
            }
            cursor.moveToFirst();
            Bitmap bm = BitmapFactory.decodeStream(inputStream, null, opts);
            cursor.close();
            return bm;
        } else if (FileUtil.checkPrivatePath(pWebViewImpl.getContext(), path)) {
            return BitmapFactory.decodeFile(path, opts);
        } else {
            InputStream imgStream2 = FileUtil.getImageFileStream(pWebViewImpl.getContext(), new File(path));
            Bitmap bm2 = BitmapFactory.decodeStream(imgStream2, null, opts);
            imgStream2.close();
            return bm2;
        }
    }

    private String buildTransaction(String type) {
        if (type == null) {
            return String.valueOf(System.currentTimeMillis());
        }
        return type + System.currentTimeMillis();
    }

    private static Bitmap cpBitmap(Bitmap orgBitmap) {
        if (PdrUtil.isEmpty(orgBitmap)) {
            return null;
        }
        while (orgBitmap.getHeight() * orgBitmap.getRowBytes() >= 32768) {
            Bitmap tmp = Bitmap.createScaledBitmap(orgBitmap, (orgBitmap.getWidth() * 2) / 3, (orgBitmap.getHeight() * 2) / 3, true);
            orgBitmap.recycle();
            orgBitmap = tmp;
        }
        return orgBitmap;
    }

    private byte[] buildThumbData(IWebview pWebViewImpl, String thumeImgPath) {
        Bitmap bitmap = null;
        String AbsFullPath = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), thumeImgPath);
        try {
            if (PdrUtil.isNetPath(thumeImgPath)) {
                bitmap = ImageLoaderL.getInstance().loadImageSync(thumeImgPath, new DisplayImageOptions.Builder().cacheOnDisc(false).cacheInMemory(false).imageScaleType(ImageScaleType.NONE).bitmapConfig(Bitmap.Config.RGB_565).showImageOnLoading(new ColorDrawable(0)).build());
            } else {
                bitmap = scaleLoadPic(pWebViewImpl, AbsFullPath);
            }
        } catch (Exception e) {
            Logger.e("buildThumbData Exception=" + e);
        }
        if (bitmap == null) {
            bitmap = BitmapFactory.decodeResource(pWebViewImpl.getActivity().getResources(), RInformation.DRAWABLE_ICON);
        }
        if (bitmap != null) {
            bitmap = cpBitmap(bitmap);
        }
        return bmpToByteArray(bitmap, true);
    }

    private void sedMultiplePic(Activity act, ArrayList<Uri> localArrayList, String activityClassName) {
        Intent intent = new Intent();
        intent.setComponent(new ComponentName("com.tencent.mm", activityClassName));
        intent.setAction("android.intent.action.SEND_MULTIPLE");
        intent.setType("image/*");
        intent.putParcelableArrayListExtra("android.intent.extra.STREAM", localArrayList);
        act.startActivity(intent);
    }

    public static byte[] bmpToByteArray(Bitmap bmp, boolean needRecycle) {
        ByteArrayOutputStream output = new ByteArrayOutputStream();
        bmp.compress(Bitmap.CompressFormat.JPEG, 80, output);
        if (needRecycle) {
            bmp.recycle();
        }
        byte[] result = output.toByteArray();
        try {
            output.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return result;
    }

    @Override // io.dcloud.share.IFShareApi
    public void forbid(IWebview pWebViewImpl) {
        if (this.api == null) {
            this.api = WXAPIFactory.createWXAPI(pWebViewImpl.getActivity().getApplicationContext(), APPID, true);
        }
        this.api.unregisterApp();
    }

    @Override // io.dcloud.share.IFShareApi
    public void authorize(IWebview pWebViewImpl, String pCallbackId, String options) {
        JSONObject jsonOptions = JSONUtil.createJSONObject(options);
        if (jsonOptions != null) {
            APPID = jsonOptions.optString("appid", APPID);
            Logger.e(TAG, "authorize: appId" + APPID);
        }
        if (!hasGeneralError(pWebViewImpl, pCallbackId)) {
            boolean ret = register(pWebViewImpl);
            if (ret) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format("{authenticated:%s,accessToken:'%s'}", Boolean.valueOf(ret), ""), JSUtil.OK, true, false);
                return;
            }
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, DOMException.toJSON(-100, DOMException.toString(-4, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_plugin_name), DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_wechat_error_auth_fail), IFShareApi.mLink)), JSUtil.ERROR, true, false);
        }
    }

    private boolean register(IWebview pWebViewImpl) {
        if (this.api == null) {
            this.api = WXAPIFactory.createWXAPI(pWebViewImpl.getActivity().getApplicationContext(), APPID, true);
        }
        if (!PdrUtil.isEmpty(APPID)) {
            return this.api.registerApp(APPID);
        }
        return false;
    }

    @Override // io.dcloud.share.IFShareApi
    public String getJsonObject(IWebview pWebViewImpl) {
        try {
            JSONObject _weiXinObj = new JSONObject();
            _weiXinObj.put("id", WEIXIN_ID);
            _weiXinObj.put("description", WEIXIN_DES);
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_AUTHENTICATED, register(pWebViewImpl));
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_ACCESSTOKEN, "");
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_NATIVECLIENT, this.api.isWXAppInstalled());
            return _weiXinObj.toString();
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean hasWXEntryActivity(Context context) {
        try {
            Class.forName(context.getPackageName() + MMessageActV2.DEFAULT_ENTRY_CLASS_NAME);
            return true;
        } catch (ClassNotFoundException e) {
            return false;
        }
    }

    @Override // io.dcloud.share.IWeiXinFShareApi
    public void launchMiniProgram(IWebview webview, String pOptions, String callbackId) {
        Exception e;
        try {
            if (!hasGeneralError(webview, callbackId)) {
                try {
                    JSONObject optionsJson = new JSONObject(pOptions);
                    String id = optionsJson.optString("id");
                    String path = optionsJson.optString("path");
                    int type = optionsJson.optInt("type", 0);
                    if (PdrUtil.isEmpty(id)) {
                        Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                    } else if (!(webview.getActivity() instanceof IActivityHandler) || !((IActivityHandler) webview.getActivity()).isMultiProcessMode()) {
                        WXLaunchMiniProgram.Req req = new WXLaunchMiniProgram.Req();
                        req.userName = id;
                        req.path = path;
                        req.miniprogramType = type;
                        if (!this.api.sendReq(req)) {
                            Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                        } else if (hasWXEntryActivity(webview.getContext())) {
                            FeatureMessageDispatcher.registerListener(this.sSendCallbackMessageListener);
                            registerSendCallbackMsg(new Object[]{webview, callbackId});
                        }
                    } else {
                        startWXMiniProgramMediator(webview, callbackId, id, path, type);
                    }
                } catch (Exception e2) {
                    e = e2;
                    Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
                }
            }
        } catch (Exception e3) {
            e = e3;
            Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
        }
    }

    @Override // io.dcloud.share.IWeiXinFShareApi
    public void openCustomerServiceChat(IWebview webview, String pOptions, String callbackId) {
        Exception e;
        try {
            if (hasGeneralError(webview, callbackId)) {
                return;
            }
            if (this.api.getWXAppSupportAPI() >= 671090490) {
                try {
                    JSONObject opJson = new JSONObject(pOptions);
                    String url = opJson.getString("url");
                    String corpId = opJson.getString("corpid");
                    if (PdrUtil.isEmpty(url) || PdrUtil.isEmpty(corpId)) {
                        Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                    } else {
                        WXOpenCustomerServiceChat.Req req = new WXOpenCustomerServiceChat.Req();
                        req.corpId = corpId;
                        req.url = url;
                        if (this.api.sendReq(req)) {
                            Deprecated_JSUtil.execCallback(webview, callbackId, "", JSUtil.OK, false, false);
                        } else {
                            Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -1, DOMException.MSG_PARAMETER_ERROR), JSUtil.ERROR, true, false);
                        }
                    }
                } catch (Exception e2) {
                    e = e2;
                    Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
                }
            } else {
                Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -104, ERROR_NOT_SUPPORT_VERSION_MSG), JSUtil.ERROR, true, false);
            }
        } catch (Exception e3) {
            e = e3;
            Deprecated_JSUtil.execCallback(webview, callbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -99, DOMException.MSG_UNKNOWN_ERROR + e.getMessage()), JSUtil.ERROR, true, false);
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void dispose() {
        IWXAPI iwxapi = this.api;
        if (iwxapi != null) {
            iwxapi.unregisterApp();
            this.api.detach();
        }
        this.api = null;
    }
}
