package io.dcloud.share.sina;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.webkit.URLUtil;
import androidx.core.content.FileProvider;
import com.sina.weibo.sdk.api.ImageObject;
import com.sina.weibo.sdk.api.MultiImageObject;
import com.sina.weibo.sdk.api.TextObject;
import com.sina.weibo.sdk.api.VideoSourceObject;
import com.sina.weibo.sdk.api.WeiboMultiMessage;
import com.sina.weibo.sdk.auth.AuthInfo;
import com.sina.weibo.sdk.auth.Oauth2AccessToken;
import com.sina.weibo.sdk.auth.WbAuthListener;
import com.sina.weibo.sdk.common.UiError;
import com.sina.weibo.sdk.openapi.IWBAPI;
import com.sina.weibo.sdk.openapi.WBAPIFactory;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ISysEventDispatch;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.NetTool;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.share_sina.R;
import io.dcloud.share.IFShareApi;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.util.ArrayList;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import tv.cjump.jni.DeviceUtils;

public class SinaWeiboApiManager implements IFShareApi {
    private static String APP_KEY = null;
    public static final String KEY_APPKEY = "appkey";
    public static final String KEY_REDIRECT_URI = "redirect_uri";
    private static final String PACKAGENAME = "com.sina.weibo";
    private static String REDIRECT_URL = null;
    private static String SCOPE = "email,direct_messages_read,direct_messages_write,friendships_groups_read,friendships_groups_write,statuses_to_me_read,follow_app_official_microblog";
    public static final String SHARE_AUTHOR_ERROR = "64002";
    public static final String SHARE_CANEL_ERROR = "64001";
    public static final String SHARE_CONTENT_ERROR = "64003";
    private static final String SINAWEIBO_DES = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_plugin_des);
    public static final String SINAWEIBO_ID = "sinaweibo";
    private static final String URL_REVOKE_OAUTH = "https://api.weibo.com/oauth2/revokeoauth2";
    private String SEND_CALLBACKID = null;
    private Oauth2AccessToken mAccessToken;
    Activity mActivity;
    private String mInterface = "auto";
    private JSONObject mSinaWeibo;
    private IWBAPI mWBAPI;
    String tAuthorizeCallbackId = null;

    private void initJsonObject(Context context) throws JSONException {
        String token = "";
        Oauth2AccessToken oauth2AccessToken = this.mAccessToken;
        if (oauth2AccessToken != null) {
            token = oauth2AccessToken.getAccessToken();
        }
        JSONObject jSONObject = new JSONObject();
        this.mSinaWeibo = jSONObject;
        jSONObject.put("id", SINAWEIBO_ID);
        this.mSinaWeibo.put("description", SINAWEIBO_DES);
        this.mSinaWeibo.put(AbsoluteConst.JSON_SHARE_AUTHENTICATED, !PdrUtil.isEmpty(token));
        this.mSinaWeibo.put(AbsoluteConst.JSON_SHARE_ACCESSTOKEN, token);
        this.mSinaWeibo.put(AbsoluteConst.JSON_SHARE_NATIVECLIENT, PlatformUtil.hasAppInstalled(context, "com.sina.weibo"));
        this.mActivity = (Activity) context;
    }

    @Override // io.dcloud.share.IFShareApi
    public void initConfig() {
        initData();
    }

    public void initData() {
        if (!TextUtils.isEmpty(AndroidResources.getMetaValue("SINA_APPKEY"))) {
            APP_KEY = AndroidResources.getMetaValue("SINA_APPKEY").substring(1);
        }
        REDIRECT_URL = AndroidResources.getMetaValue("SINA_REDIRECT_URI");
    }

    @Override // io.dcloud.share.IFShareApi
    public String getJsonObject(IWebview pWebViewImpl) {
        try {
            initJsonObject(pWebViewImpl.getActivity());
            return this.mSinaWeibo.toString();
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public String getId() {
        return SINAWEIBO_ID;
    }

    public void OnSendEnd(IWebview pWebViewImpl, boolean suc, int errorCode, String msg) {
        String str = this.SEND_CALLBACKID;
        if (str != null) {
            if (suc) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, str, "", 1, false, false);
            } else {
                Deprecated_JSUtil.execCallback(pWebViewImpl, this.SEND_CALLBACKID, StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf(errorCode), msg), JSUtil.ERROR, true, false);
            }
            this.SEND_CALLBACKID = null;
        }
    }

    private void initWBAPI(Activity activity) {
        IWBAPI createWBAPI = WBAPIFactory.createWBAPI(activity);
        this.mWBAPI = createWBAPI;
        createWBAPI.registerApp(activity, new AuthInfo(activity, APP_KEY, REDIRECT_URL, SCOPE));
    }

    public void send(final Activity activity, final String pShareMsg) {
        initConfig();
        Oauth2AccessToken oauth2AccessToken = this.mAccessToken;
        if (oauth2AccessToken == null || !oauth2AccessToken.isSessionValid()) {
            final Runnable runnable = new Runnable() {
                /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass1 */

                public void run() {
                    SinaWeiboApiManager.this.send(activity, pShareMsg);
                }
            };
            authorize(activity, new WbAuthListener() {
                /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass2 */

                @Override // com.sina.weibo.sdk.auth.WbAuthListener
                public void onComplete(Oauth2AccessToken oauth2AccessToken) {
                    SinaWeiboApiManager.this.mAccessToken = oauth2AccessToken;
                    runnable.run();
                }

                @Override // com.sina.weibo.sdk.auth.WbAuthListener
                public void onError(UiError uiError) {
                }

                @Override // com.sina.weibo.sdk.auth.WbAuthListener
                public void onCancel() {
                }
            });
            return;
        }
        initWBAPI(activity);
        try {
            JSONObject _msg = new JSONObject(pShareMsg);
            this.mInterface = _msg.optString("interface");
            JSONArray _pictures = _msg.optJSONArray("pictures");
            String _content = _msg.optString("content");
            if (!URLUtil.isNetworkUrl(JSONUtil.getString(_pictures, 0)) && !TextUtils.isEmpty(_content)) {
                this.mWBAPI.shareMessage(activity, getWeiboMultiMessage(pShareMsg), false);
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void send(final IWebview pWebViewImpl, String pCallbackId, String pShareMsg) {
        if (Build.CPU_ABI.equalsIgnoreCase(DeviceUtils.ABI_X86)) {
            OnSendEnd(pWebViewImpl, false, -3, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_x86_not_support));
            return;
        }
        this.SEND_CALLBACKID = pCallbackId;
        Oauth2AccessToken oauth2AccessToken = this.mAccessToken;
        if (oauth2AccessToken == null || !oauth2AccessToken.isSessionValid()) {
            OnSendEnd(pWebViewImpl, false, -10, DOMException.MSG_AUTHORIZE_FAILED);
            return;
        }
        final IApp app = pWebViewImpl.obtainApp();
        initWBAPI(pWebViewImpl.getActivity());
        pWebViewImpl.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass3 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Logger.e("ian", "onExecute");
                if (!PdrUtil.isEmpty(pArgs)) {
                    JSONObject myjson = JSONUtil.createJSONObject((String) pArgs);
                    Logger.e("ian", myjson.toString());
                    if (PdrUtil.isEquals("0", myjson.optString("_weibo_resp_errcode"))) {
                        SinaWeiboApiManager.this.OnSendEnd(pWebViewImpl, true, -1, null);
                    } else if (PdrUtil.isEquals("1", myjson.optString("_weibo_resp_errcode"))) {
                        SinaWeiboApiManager.this.OnSendEnd(pWebViewImpl, false, -2, DOMException.MSG_USER_CANCEL);
                    } else {
                        String msg = myjson.optString("_weibo_resp_errstr");
                        SinaWeiboApiManager.this.OnSendEnd(pWebViewImpl, true, Integer.valueOf(myjson.optString("_weibo_resp_errcode")).intValue(), msg);
                    }
                }
                IApp iApp = app;
                if (iApp != null) {
                    iApp.unregisterSysEventListener(this, ISysEventListener.SysEventType.onNewIntent);
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onNewIntent);
        try {
            JSONObject _msg = new JSONObject(pShareMsg);
            this.mInterface = _msg.optString("interface");
            String type = _msg.optString("type");
            JSONArray _pictures = _msg.optJSONArray("pictures");
            String _content = _msg.optString("content");
            if (URLUtil.isNetworkUrl(JSONUtil.getString(_pictures, 0))) {
                OnSendEnd(pWebViewImpl, false, 15, DOMException.MSG_SHARE_SEND_PIC_ROUTE_ERROR);
            } else if (TextUtils.isEmpty(_content)) {
                OnSendEnd(pWebViewImpl, false, 15, DOMException.MSG_SHARE_SEND_CONTENT_EMPTY_ERROR);
            } else {
                WeiboMultiMessage message = getWeiboMultiMessage(pWebViewImpl, pShareMsg, type);
                if (!this.mWBAPI.isWBAppInstalled()) {
                    if (message.imageObject != null && ((message.imageObject.imageData != null && message.imageObject.imageData.length > 128000) || (message.imageObject.thumbData != null && message.imageObject.thumbData.length > 128000))) {
                        OnSendEnd(pWebViewImpl, false, 15, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_error_web_image_morethan_128KB));
                        return;
                    } else if (!PdrUtil.isEmpty(type) && (type.equals("video") || message.multiImageObject != null)) {
                        OnSendEnd(pWebViewImpl, false, 15, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_error_web_image_multi));
                        return;
                    }
                }
                this.mWBAPI.shareMessage(pWebViewImpl.getActivity(), message, false);
            }
        } catch (JSONException e) {
            e.printStackTrace();
            OnSendEnd(pWebViewImpl, false, 15, SHARE_CONTENT_ERROR);
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void forbid(IWebview pWebViewImpl) {
        pWebViewImpl.getActivity();
        ThreadPool.self().addThreadTask(new Runnable() {
            /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass4 */

            public void run() {
                if (!PdrUtil.isEmpty(SinaWeiboApiManager.this.mAccessToken.getAccessToken())) {
                    StringBuffer buffer = new StringBuffer();
                    buffer.append("access_token=" + SinaWeiboApiManager.this.mAccessToken.getAccessToken());
                    String resultStr = new String(NetTool.httpPost(SinaWeiboApiManager.URL_REVOKE_OAUTH, buffer.toString(), null));
                    Logger.e("ian", "logout resultStr==" + resultStr);
                    SinaWeiboApiManager.this.mAccessToken = null;
                }
            }
        });
    }

    @Override // io.dcloud.share.IFShareApi
    public void authorize(final IWebview pWebViewImpl, String pCallbackId, String options) {
        if (Build.CPU_ABI.equalsIgnoreCase(DeviceUtils.ABI_X86)) {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -3, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_x86_not_support)), JSUtil.ERROR, true, false);
            return;
        }
        Oauth2AccessToken oauth2AccessToken = this.mAccessToken;
        if (oauth2AccessToken == null || !oauth2AccessToken.isSessionValid()) {
            initWBAPI(pWebViewImpl.getActivity());
            JSONObject jsonOptions = JSONUtil.createJSONObject(options);
            if (jsonOptions != null) {
                APP_KEY = jsonOptions.optString("appkey", APP_KEY);
                REDIRECT_URL = jsonOptions.optString(KEY_REDIRECT_URI, REDIRECT_URL);
            }
            if (TextUtils.isEmpty(APP_KEY) || TextUtils.isEmpty(REDIRECT_URL)) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT)), JSUtil.ERROR, true, false);
                return;
            }
            this.tAuthorizeCallbackId = pCallbackId;
            final IApp app = pWebViewImpl.obtainApp();
            app.registerSysEventListener(new ISysEventListener() {
                /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass5 */

                @Override // io.dcloud.common.DHInterface.ISysEventListener
                public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                    Object[] _args = (Object[]) pArgs;
                    int requestCode = ((Integer) _args[0]).intValue();
                    int resultCode = ((Integer) _args[1]).intValue();
                    Intent data = (Intent) _args[2];
                    app.unregisterSysEventListener(this, ISysEventListener.SysEventType.onActivityResult);
                    if (SinaWeiboApiManager.this.mWBAPI != null) {
                        SinaWeiboApiManager.this.mWBAPI.authorizeCallback(pWebViewImpl.getActivity(), requestCode, resultCode, data);
                    }
                    return false;
                }
            }, ISysEventListener.SysEventType.onActivityResult);
            this.mWBAPI.authorize(pWebViewImpl.getActivity(), new SelfWbAuthListener(pWebViewImpl));
            return;
        }
        Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, getJsonObject(pWebViewImpl), JSUtil.OK, true, false);
    }

    public void authorize(final Activity activity, WbAuthListener wbAuthListener) {
        Oauth2AccessToken oauth2AccessToken = this.mAccessToken;
        if (oauth2AccessToken == null || !oauth2AccessToken.isSessionValid()) {
            initWBAPI(activity);
            if (activity instanceof ISysEventDispatch) {
                ((ISysEventDispatch) activity).registerSysEventListener(new ISysEventListener() {
                    /* class io.dcloud.share.sina.SinaWeiboApiManager.AnonymousClass6 */

                    @Override // io.dcloud.common.DHInterface.ISysEventListener
                    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                        Object[] _args = (Object[]) pArgs;
                        int requestCode = ((Integer) _args[0]).intValue();
                        int resultCode = ((Integer) _args[1]).intValue();
                        Intent data = (Intent) _args[2];
                        ((ISysEventDispatch) activity).unRegisterSysEventListener(this, ISysEventListener.SysEventType.onActivityResult);
                        if (SinaWeiboApiManager.this.mWBAPI != null) {
                            SinaWeiboApiManager.this.mWBAPI.authorizeCallback(activity, requestCode, resultCode, data);
                        }
                        return false;
                    }
                }, ISysEventListener.SysEventType.onActivityResult);
            }
            this.mWBAPI.authorize(activity, wbAuthListener);
        }
    }

    private class SelfWbAuthListener implements WbAuthListener {
        IWebview mWebview = null;

        SelfWbAuthListener(IWebview webview) {
            this.mWebview = webview;
        }

        private void OnAuthorizeEnd(boolean suc, int errorCode, String msg) {
            if (SinaWeiboApiManager.this.tAuthorizeCallbackId != null) {
                if (suc) {
                    Deprecated_JSUtil.execCallback(this.mWebview, SinaWeiboApiManager.this.tAuthorizeCallbackId, SinaWeiboApiManager.this.getJsonObject(this.mWebview), JSUtil.OK, true, false);
                } else {
                    Deprecated_JSUtil.execCallback(this.mWebview, SinaWeiboApiManager.this.tAuthorizeCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, Integer.valueOf(errorCode), msg), JSUtil.ERROR, true, false);
                }
                SinaWeiboApiManager.this.tAuthorizeCallbackId = null;
            }
        }

        @Override // com.sina.weibo.sdk.auth.WbAuthListener
        public void onComplete(Oauth2AccessToken token) {
            SinaWeiboApiManager.this.mAccessToken = token;
            if (SinaWeiboApiManager.this.mAccessToken.isSessionValid()) {
                OnAuthorizeEnd(true, -1, null);
            }
        }

        @Override // com.sina.weibo.sdk.auth.WbAuthListener
        public void onError(UiError uiError) {
            OnAuthorizeEnd(false, -100, DOMException.toString(uiError.errorCode, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_plugin_name), uiError.errorMessage, IFShareApi.mLink));
        }

        @Override // com.sina.weibo.sdk.auth.WbAuthListener
        public void onCancel() {
            OnAuthorizeEnd(false, -2, DOMException.toString(DOMException.MSG_USER_CANCEL));
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void dispose() {
        this.mActivity = null;
    }

    public WeiboMultiMessage getWeiboMultiMessage(String message) {
        WeiboMultiMessage weiboMessage = new WeiboMultiMessage();
        try {
            weiboMessage.textObject = getTextObj(new JSONObject(message));
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return weiboMessage;
    }

    public WeiboMultiMessage getWeiboMultiMessage(IWebview pWebViewImpl, String message, String type) {
        WeiboMultiMessage weiboMessage = new WeiboMultiMessage();
        JSONObject pShareMsg = null;
        try {
            pShareMsg = new JSONObject(message);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        weiboMessage.textObject = getTextObj(pShareMsg);
        if (TextUtils.isEmpty(type) || !type.equals("text")) {
            if (!TextUtils.isEmpty(type) && type.equals("image")) {
                JSONArray _pictures = pShareMsg.optJSONArray("pictures");
                if (_pictures != null && _pictures.length() > 0) {
                    if (Build.VERSION.SDK_INT >= 24) {
                        weiboMessage.multiImageObject = getMultiImageObject(pWebViewImpl, pShareMsg);
                    } else if (_pictures.length() > 1) {
                        weiboMessage.multiImageObject = getMultiImageObject(pWebViewImpl, pShareMsg);
                    } else {
                        weiboMessage.imageObject = getImageObject(pWebViewImpl, pShareMsg);
                    }
                }
            } else if (!TextUtils.isEmpty(type) && type.equals("video")) {
                weiboMessage.videoSourceObject = getVideoObject(pWebViewImpl, pShareMsg);
            } else if (!TextUtils.isEmpty(type) && type.equals("web")) {
                weiboMessage.imageObject = getImageObject(pWebViewImpl, pShareMsg);
            } else if (!TextUtils.isEmpty(type)) {
                Deprecated_JSUtil.execCallback(pWebViewImpl, this.tAuthorizeCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -100, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_sina_type_param_error)), JSUtil.ERROR, true, false);
            } else {
                weiboMessage.imageObject = getImageObject(pWebViewImpl, pShareMsg);
            }
        }
        return weiboMessage;
    }

    private TextObject getTextObj(JSONObject pShareMsg) {
        try {
            String _content = pShareMsg.optString("content");
            String _title = pShareMsg.optString("title");
            String href = JSONUtil.getString(pShareMsg, "href");
            TextObject textObject = new TextObject();
            StringBuilder sb = new StringBuilder();
            sb.append(_content);
            sb.append(TextUtils.isEmpty(href) ? "" : href);
            textObject.text = sb.toString();
            textObject.title = _title;
            return textObject;
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    private ImageObject getImageObject(IWebview pWebViewImpl, JSONObject pShareMsg) {
        Bitmap bitmap;
        ImageObject imageObject = new ImageObject();
        try {
            JSONArray _pictures = pShareMsg.optJSONArray("pictures");
            String file = JSONUtil.getString(_pictures, 0);
            if (_pictures != null && _pictures.length() > 0 && !PdrUtil.isEmpty(_pictures.getString(0))) {
                file = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), file);
                Bitmap bitmap2 = null;
                if (file.startsWith("content://")) {
                    bitmap2 = BitmapFactory.decodeStream(pWebViewImpl.getContext().getContentResolver().openInputStream(Uri.parse(file)));
                } else if (FileUtil.checkPrivatePath(pWebViewImpl.getContext(), file)) {
                    bitmap2 = BitmapFactory.decodeFile(file);
                } else if (FileUtil.needMediaStoreOpenFile(pWebViewImpl.getContext())) {
                    bitmap2 = BitmapFactory.decodeStream(FileUtil.getFileInputStream(pWebViewImpl.getContext(), file));
                }
                if (bitmap2 != null) {
                    imageObject.setImageData(bitmap2);
                }
            }
            JSONArray thumbs = pShareMsg.optJSONArray("thumbs");
            String thumb = JSONUtil.getString(thumbs, 0);
            if (thumbs != null && thumbs.length() > 0 && !PdrUtil.isEmpty(thumbs.getString(0))) {
                String thumb2 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), thumb);
                if (file.startsWith("content://")) {
                    bitmap = BitmapFactory.decodeStream(pWebViewImpl.getContext().getContentResolver().openInputStream(Uri.parse(thumb2)));
                } else if (FileUtil.checkPrivatePath(pWebViewImpl.getContext(), file)) {
                    bitmap = BitmapFactory.decodeFile(thumb2);
                } else if (FileUtil.needMediaStoreOpenFile(pWebViewImpl.getContext())) {
                    bitmap = BitmapFactory.decodeStream(FileUtil.getFileInputStream(pWebViewImpl.getContext(), file));
                } else {
                    try {
                        bitmap = BitmapFactory.decodeFile(thumb2);
                    } catch (Exception e) {
                        bitmap = null;
                    }
                }
                if (bitmap != null) {
                    ByteArrayOutputStream baos = new ByteArrayOutputStream();
                    bitmap.compress(Bitmap.CompressFormat.PNG, 100, baos);
                    imageObject.thumbData = baos.toByteArray();
                }
            }
            return imageObject;
        } catch (Exception e2) {
            e2.printStackTrace();
            return null;
        }
    }

    private MultiImageObject getMultiImageObject(IWebview pWebViewImpl, JSONObject pShareMsg) {
        MultiImageObject multiImageObject = new MultiImageObject();
        if (pShareMsg == null) {
            return null;
        }
        try {
            ArrayList<Uri> pathList = new ArrayList<>();
            JSONArray _pictures = pShareMsg.optJSONArray("pictures");
            if (_pictures != null) {
                for (int i = 0; i < _pictures.length(); i++) {
                    String itme = _pictures.getString(i);
                    if (!PdrUtil.isEmpty(itme) && !URLUtil.isNetworkUrl(itme)) {
                        if (Build.VERSION.SDK_INT >= 24) {
                            String itme2 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), itme);
                            String name = itme2.substring(itme2.lastIndexOf("/"));
                            String pat = new File(pWebViewImpl.getContext().getExternalFilesDir(null) + "/" + name).getPath();
                            DHFile.copyFile(itme2, pat);
                            File d = new File(pat);
                            pathList.add(FileProvider.getUriForFile(pWebViewImpl.getContext(), pWebViewImpl.getContext().getPackageName() + ".fileprovider", d));
                        } else {
                            String itme3 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), itme);
                            Uri uri = FileUtil.getImageFileUri(pWebViewImpl.getContext(), itme3);
                            if (uri == null) {
                                uri = Uri.fromFile(new File(itme3));
                            }
                            pathList.add(uri);
                        }
                    }
                }
            }
            multiImageObject.imageList = pathList;
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return multiImageObject;
    }

    private VideoSourceObject getVideoObject(IWebview pWebViewImpl, JSONObject pShareMsg) {
        if (!this.mWBAPI.isWBAppSupportMultipleImage()) {
            return null;
        }
        VideoSourceObject videoSourceObject = new VideoSourceObject();
        if (pShareMsg == null) {
            return null;
        }
        try {
            String media = pShareMsg.optString("media");
            if (!TextUtils.isEmpty(media) && !URLUtil.isNetworkUrl(media)) {
                if (Build.VERSION.SDK_INT >= 24) {
                    String media2 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), media);
                    String name = media2.substring(media2.lastIndexOf("/"));
                    String pat = new File(pWebViewImpl.getContext().getExternalFilesDir(null) + "/" + name).getPath();
                    DHFile.copyFile(media2, pat);
                    File d = new File(pat);
                    videoSourceObject.videoPath = FileProvider.getUriForFile(pWebViewImpl.getContext(), pWebViewImpl.getContext().getPackageName() + ".fileprovider", d);
                } else {
                    String media3 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), media);
                    Uri uri = FileUtil.getVideoFileUri(pWebViewImpl.getContext(), media3);
                    if (uri == null) {
                        uri = Uri.fromFile(new File(media3));
                    }
                    videoSourceObject.videoPath = uri;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return videoSourceObject;
    }
}
