package io.dcloud.weex;

import android.app.Application;
import android.text.TextUtils;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.utils.WXFileUtils;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.RuningAcitvityUtil;
import io.dcloud.feature.uniapp.UniAppHookProxy;
import java.io.File;
import java.lang.reflect.Method;

public class MoudlesLoader {
    private static MoudlesLoader sLoader;
    private boolean isInitHooksClass = false;

    public static MoudlesLoader getInstance() {
        if (sLoader == null) {
            synchronized (MoudlesLoader.class) {
                if (sLoader == null) {
                    sLoader = new MoudlesLoader();
                }
            }
        }
        return sLoader;
    }

    public void onCreate(Application application) {
        JSONArray array;
        JSONObject pluginsJson = getPluginsValue(application);
        initHooksClass(application, Boolean.valueOf(application.getPackageName().equals(RuningAcitvityUtil.getAppName(application))));
        if (!(pluginsJson == null || (array = pluginsJson.getJSONArray("nativePlugins")) == null || array.size() <= 0)) {
            for (int i = 0; i < array.size(); i++) {
                initMoudle(array.getJSONObject(i), application);
            }
        }
    }

    public void onCreate(Application application, String configPath) {
        if (!(application == null || PdrUtil.isEmpty(configPath) || !DHFile.exists(configPath))) {
            JSONObject jsonObject = JSON.parseObject(new String(DHFile.readAll(new File(configPath))));
            if (!PdrUtil.isEmpty(jsonObject)) {
                JSONArray components = jsonObject.getJSONArray("components");
                if (!PdrUtil.isEmpty(components)) {
                    for (int i = 0; i < components.size(); i++) {
                        JSONObject component = components.getJSONObject(i);
                        if (component != null) {
                            registerMoudle(component.getString("name"), component.getString("class"), WXBridgeManager.COMPONENT);
                        }
                    }
                }
            }
        }
    }

    private void initMoudle(JSONObject moudleJson, Application application) {
        JSONArray moudlesJA;
        if (!(moudleJson == null || (moudlesJA = moudleJson.getJSONArray("plugins")) == null || moudlesJA == null || moudlesJA.size() <= 0)) {
            for (int i = 0; i < moudlesJA.size(); i++) {
                JSONObject item = moudlesJA.getJSONObject(i);
                if (item != null) {
                    registerMoudle(item.getString("name"), item.getString("class"), item.getString("type"));
                }
            }
        }
    }

    private void executeOnCreateProcess(JSONObject moudleJson, Application application, boolean isMainProcess) {
        try {
            Class c = Class.forName(moudleJson.getString("hooksClass"));
            Object proxy = c.newInstance();
            if (!(proxy instanceof AppHookProxy)) {
                Method m = c.getMethod("onCreate", Application.class);
                if (m != null) {
                    m.setAccessible(true);
                    m.invoke(proxy, application);
                }
            } else if (isMainProcess) {
                ((AppHookProxy) proxy).onCreate(application);
            } else if (proxy instanceof UniAppHookProxy) {
                ((UniAppHookProxy) proxy).onSubProcessCreate(application);
            }
        } catch (Exception e) {
        }
    }

    private void registerMoudle(String moduleName, String moduleClasss, String moduleType) {
        try {
            Class c = Class.forName(moduleClasss);
            if (!TextUtils.isEmpty(moduleType)) {
                if (!moduleType.equalsIgnoreCase("module")) {
                    if (moduleType.equalsIgnoreCase(WXBridgeManager.COMPONENT)) {
                        WXSDKEngine.registerComponent(moduleName, c);
                        return;
                    }
                    return;
                }
            }
            WXSDKEngine.registerModule(moduleName, c);
        } catch (Exception e) {
        }
    }

    private JSONObject getPluginsValue(Application application) {
        String plugins = WXFileUtils.loadAsset("dcloud_uniplugins.json", application);
        if (!TextUtils.isEmpty(plugins)) {
            return JSONObject.parseObject(plugins);
        }
        return null;
    }

    public void initHooksClass(Application application, Boolean isMainProcess) {
        JSONObject pluginsJson;
        JSONArray array;
        if (!this.isInitHooksClass && (pluginsJson = getPluginsValue(application)) != null && (array = pluginsJson.getJSONArray("nativePlugins")) != null && array.size() > 0) {
            this.isInitHooksClass = true;
            for (int i = 0; i < array.size(); i++) {
                executeOnCreateProcess(array.getJSONObject(i), application, isMainProcess.booleanValue());
            }
        }
    }
}
