package io.dcloud.weex;

import android.os.Handler;
import android.view.MotionEvent;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.Map;
import java.util.Set;

public class ViewHover {
    public static final String VIEW_HOVER_EVENT = "view_hover_event";
    private WXComponent component;
    private Handler handler;
    private JSONObject hoverClass;
    private int hoverStartTime;
    private int hoverStayTime;
    private boolean hoverStopPropagation;
    private boolean isHover;
    private boolean isReceiveTouch;
    private Map<String, Object> originalStyles;
    public Runnable touchEndRunnable;
    public Runnable touchStartRunnable;

    public ViewHover(WXComponent component2) {
        this(component2, null);
    }

    public ViewHover(WXComponent component2, JSONObject data) {
        this.hoverStopPropagation = false;
        this.hoverClass = null;
        this.hoverStartTime = 50;
        this.hoverStayTime = 400;
        this.isHover = false;
        this.isReceiveTouch = true;
        this.handler = new Handler();
        this.touchStartRunnable = new Runnable() {
            /* class io.dcloud.weex.ViewHover.AnonymousClass1 */

            public void run() {
                if (!ViewHover.this.isHover && ViewHover.this.component != null && ViewHover.this.component.getInstance() != null) {
                    ViewHover viewHover = ViewHover.this;
                    viewHover.originalStyles = viewHover.component.getStyles().clone();
                    ViewHover.this.component.setHoverClassStatus(true);
                }
            }
        };
        this.touchEndRunnable = new Runnable() {
            /* class io.dcloud.weex.ViewHover.AnonymousClass2 */

            public void run() {
                if (ViewHover.this.component != null && ViewHover.this.component.getInstance() != null) {
                    ViewHover.this.component.setHoverClassStatus(false);
                    ViewHover.this.isHover = false;
                }
            }
        };
        update(data);
        this.component = component2;
    }

    public void update(JSONObject data) {
        if (data != null) {
            JSONObject jSONObject = this.hoverClass;
            if (jSONObject == null) {
                this.hoverClass = data;
            } else {
                jSONObject.putAll(data);
            }
        }
    }

    public boolean isHoverStopPropagation() {
        return this.hoverStopPropagation;
    }

    public void setHoverStopPropagation(boolean hoverStopPropagation2) {
        this.hoverStopPropagation = hoverStopPropagation2;
    }

    public int getHoverStartTime() {
        return this.hoverStartTime;
    }

    public void setHoverStartTime(int hoverStartTime2) {
        this.hoverStartTime = hoverStartTime2;
    }

    public int getHoverStayTime() {
        return this.hoverStayTime;
    }

    public void setHoverStayTime(int hoverStayTime2) {
        this.hoverStayTime = hoverStayTime2;
    }

    public void handleMotionEvent(WXGestureType wxGestureType, MotionEvent motionEvent) {
        if (this.hoverClass != null && this.isReceiveTouch) {
            String obj = wxGestureType.toString();
            char c = 65535;
            switch (obj.hashCode()) {
                case -1578593149:
                    if (obj.equals(AbsoluteConst.EVENTS_WEBVIEW_ONTOUCH_START)) {
                        c = 0;
                        break;
                    }
                    break;
                case -819532484:
                    if (obj.equals("touchend")) {
                        c = 2;
                        break;
                    }
                    break;
                case 364536720:
                    if (obj.equals("touchmove")) {
                        c = 1;
                        break;
                    }
                    break;
                case 2127979129:
                    if (obj.equals("touchcancel")) {
                        c = 3;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.removeCallbacks(this.touchStartRunnable);
                this.handler.postDelayed(this.touchStartRunnable, (long) this.hoverStartTime);
            } else if (c == 2) {
                this.isHover = true;
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.postDelayed(this.touchEndRunnable, (long) this.hoverStayTime);
            } else if (c == 3) {
                this.isHover = true;
                this.handler.removeCallbacks(this.touchEndRunnable);
                this.handler.postDelayed(this.touchEndRunnable, (long) this.hoverStayTime);
            }
        }
    }

    public Map<String, Object> updateStatusAndGetUpdateStyles(boolean status) {
        Map<String, Object> resultStyles = new JSONObject();
        if (status) {
            return this.hoverClass;
        }
        if (this.originalStyles == null) {
            return resultStyles;
        }
        Set<String> keys = this.hoverClass.keySet();
        Map<String, Object> resultStyles2 = new JSONObject();
        for (String key : keys) {
            if (this.originalStyles.containsKey(key)) {
                resultStyles2.put(key, this.originalStyles.get(key));
            } else {
                resultStyles2.put(key, "");
            }
        }
        return resultStyles2;
    }

    public void setReceiveTouch(boolean receiveTouch) {
        this.isReceiveTouch = receiveTouch;
    }

    public void destroy() {
        this.component = null;
        this.originalStyles = null;
    }
}
