package master.flame.danmaku.controller;

import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import master.flame.danmaku.controller.IDrawTask;
import master.flame.danmaku.danmaku.model.AbsDisplayer;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.DanmakuTimer;
import master.flame.danmaku.danmaku.model.ICacheManager;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.IDrawingCache;
import master.flame.danmaku.danmaku.model.android.DanmakuContext;
import master.flame.danmaku.danmaku.model.android.DanmakuFactory;
import master.flame.danmaku.danmaku.model.android.Danmakus;
import master.flame.danmaku.danmaku.model.android.DrawingCache;
import master.flame.danmaku.danmaku.model.android.DrawingCachePoolManager;
import master.flame.danmaku.danmaku.model.objectpool.Pool;
import master.flame.danmaku.danmaku.model.objectpool.Pools;
import master.flame.danmaku.danmaku.renderer.IRenderer;
import master.flame.danmaku.danmaku.util.DanmakuUtils;
import master.flame.danmaku.danmaku.util.SystemClock;
import tv.cjump.jni.NativeBitmapFactory;

public class CacheManagingDrawTask extends DrawTask {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private static final int MAX_CACHE_SCREEN_SIZE = 3;
    private CacheManager mCacheManager;
    private DanmakuTimer mCacheTimer;
    private final Object mDrawingNotify = new Object();
    private int mMaxCacheSize = 2;
    private int mRemaininCacheCount;

    public CacheManagingDrawTask(DanmakuTimer timer, DanmakuContext config, IDrawTask.TaskListener taskListener, int maxCacheSize) {
        super(timer, config, taskListener);
        NativeBitmapFactory.loadLibs();
        this.mMaxCacheSize = maxCacheSize;
        if (NativeBitmapFactory.isInNativeAlloc()) {
            this.mMaxCacheSize = maxCacheSize * 2;
        }
        this.mCacheManager = new CacheManager(maxCacheSize, 3);
        this.mRenderer.setCacheManager(this.mCacheManager);
    }

    /* access modifiers changed from: protected */
    @Override // master.flame.danmaku.controller.DrawTask
    public void initTimer(DanmakuTimer timer) {
        this.mTimer = timer;
        DanmakuTimer danmakuTimer = new DanmakuTimer();
        this.mCacheTimer = danmakuTimer;
        danmakuTimer.update(timer.currMillisecond);
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void addDanmaku(BaseDanmaku danmaku) {
        super.addDanmaku(danmaku);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            cacheManager.addDanmaku(danmaku);
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void invalidateDanmaku(BaseDanmaku item, boolean remeasure) {
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager == null) {
            super.invalidateDanmaku(item, remeasure);
        } else {
            cacheManager.invalidateDanmaku(item, remeasure);
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void removeAllDanmakus(boolean isClearDanmakusOnScreen) {
        super.removeAllDanmakus(isClearDanmakusOnScreen);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            cacheManager.requestClearAll();
        }
    }

    /* access modifiers changed from: protected */
    @Override // master.flame.danmaku.controller.DrawTask
    public void onDanmakuRemoved(BaseDanmaku danmaku) {
        super.onDanmakuRemoved(danmaku);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            int i = this.mRemaininCacheCount + 1;
            this.mRemaininCacheCount = i;
            if (i > 5) {
                cacheManager.requestClearTimeout();
                this.mRemaininCacheCount = 0;
                return;
            }
            return;
        }
        IDrawingCache<?> cache = danmaku.getDrawingCache();
        if (cache != null) {
            if (cache.hasReferences()) {
                cache.decreaseReference();
            } else {
                cache.destroy();
            }
            danmaku.cache = null;
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public IRenderer.RenderingState draw(AbsDisplayer displayer) {
        IRenderer.RenderingState result = super.draw(displayer);
        synchronized (this.mDrawingNotify) {
            this.mDrawingNotify.notify();
        }
        if (!(result == null || this.mCacheManager == null || result.totalDanmakuCount - result.lastTotalDanmakuCount >= -20)) {
            this.mCacheManager.requestClearTimeout();
            this.mCacheManager.requestBuild(-this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
        }
        return result;
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void seek(long mills) {
        super.seek(mills);
        if (this.mCacheManager == null) {
            start();
        }
        this.mCacheManager.seek(mills);
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void start() {
        super.start();
        NativeBitmapFactory.loadLibs();
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager == null) {
            CacheManager cacheManager2 = new CacheManager(this.mMaxCacheSize, 3);
            this.mCacheManager = cacheManager2;
            cacheManager2.begin();
            this.mRenderer.setCacheManager(this.mCacheManager);
            return;
        }
        cacheManager.resume();
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void quit() {
        super.quit();
        reset();
        this.mRenderer.setCacheManager(null);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            cacheManager.end();
            this.mCacheManager = null;
        }
        NativeBitmapFactory.releaseLibs();
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void prepare() {
        loadDanmakus(this.mParser);
        this.mCacheManager.begin();
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void onPlayStateChanged(int state) {
        super.onPlayStateChanged(state);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            cacheManager.onPlayStateChanged(state);
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask, master.flame.danmaku.controller.DrawTask
    public void requestSync(long fromTimeMills, long toTimeMills, long offsetMills) {
        super.requestSync(fromTimeMills, toTimeMills, offsetMills);
        CacheManager cacheManager = this.mCacheManager;
        if (cacheManager != null) {
            cacheManager.seek(toTimeMills);
        }
    }

    public class CacheManager implements ICacheManager {
        public static final byte RESULT_FAILED = 1;
        public static final byte RESULT_FAILED_OVERSIZE = 2;
        public static final byte RESULT_SUCCESS = 0;
        private static final String TAG = "CacheManager";
        Pool<DrawingCache> mCachePool;
        DrawingCachePoolManager mCachePoolManager;
        Danmakus mCaches = new Danmakus();
        private boolean mEndFlag;
        private CacheHandler mHandler;
        private int mMaxSize;
        private int mRealSize;
        private int mScreenSize;
        public HandlerThread mThread;

        public CacheManager(int maxSize, int screenSize) {
            DrawingCachePoolManager drawingCachePoolManager = new DrawingCachePoolManager();
            this.mCachePoolManager = drawingCachePoolManager;
            this.mCachePool = Pools.finitePool(drawingCachePoolManager, 800);
            this.mScreenSize = 3;
            this.mEndFlag = false;
            this.mRealSize = 0;
            this.mMaxSize = maxSize;
            this.mScreenSize = screenSize;
        }

        public void seek(long mills) {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.requestCancelCaching();
                this.mHandler.removeMessages(3);
                this.mHandler.obtainMessage(5, Long.valueOf(mills)).sendToTarget();
            }
        }

        @Override // master.flame.danmaku.danmaku.model.ICacheManager
        public void addDanmaku(BaseDanmaku danmaku) {
            if (this.mHandler == null) {
                return;
            }
            if (!danmaku.isLive) {
                this.mHandler.obtainMessage(2, danmaku).sendToTarget();
            } else if (!danmaku.forceBuildCacheInSameThread) {
                this.mHandler.obtainMessage(18, danmaku).sendToTarget();
            } else if (!danmaku.isTimeOut()) {
                this.mHandler.createCache(danmaku);
            }
        }

        public void invalidateDanmaku(BaseDanmaku danmaku, boolean remeasure) {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.requestCancelCaching();
                this.mHandler.obtainMessage(17, danmaku).sendToTarget();
            }
        }

        public void begin() {
            this.mEndFlag = false;
            if (this.mThread == null) {
                HandlerThread handlerThread = new HandlerThread("DFM Cache-Building Thread");
                this.mThread = handlerThread;
                handlerThread.start();
            }
            if (this.mHandler == null) {
                this.mHandler = new CacheHandler(this.mThread.getLooper());
            }
            this.mHandler.begin();
        }

        public void end() {
            this.mEndFlag = true;
            synchronized (CacheManagingDrawTask.this.mDrawingNotify) {
                CacheManagingDrawTask.this.mDrawingNotify.notifyAll();
            }
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.pause();
                this.mHandler = null;
            }
            HandlerThread handlerThread = this.mThread;
            if (handlerThread != null) {
                try {
                    handlerThread.join();
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
                this.mThread.quit();
                this.mThread = null;
            }
        }

        public void resume() {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.resume();
            } else {
                begin();
            }
        }

        public void onPlayStateChanged(int state) {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                boolean z = true;
                if (state != 1) {
                    z = false;
                }
                cacheHandler.onPlayStateChanged(z);
            }
        }

        public float getPoolPercent() {
            int i = this.mMaxSize;
            if (i == 0) {
                return 0.0f;
            }
            return ((float) this.mRealSize) / ((float) i);
        }

        public boolean isPoolFull() {
            return this.mRealSize + 5120 >= this.mMaxSize;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void evictAll() {
            Danmakus danmakus = this.mCaches;
            if (danmakus != null) {
                IDanmakuIterator it = danmakus.iterator();
                while (it.hasNext()) {
                    entryRemoved(true, it.next(), null);
                }
                this.mCaches.clear();
            }
            this.mRealSize = 0;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void evictAllNotInScreen() {
            evictAllNotInScreen(false);
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void evictAllNotInScreen(boolean removeAllReferences) {
            Danmakus danmakus = this.mCaches;
            if (danmakus != null) {
                IDanmakuIterator it = danmakus.iterator();
                while (it.hasNext()) {
                    BaseDanmaku danmaku = it.next();
                    IDrawingCache<?> cache = danmaku.cache;
                    boolean hasReferences = cache != null && cache.hasReferences();
                    if (removeAllReferences && hasReferences) {
                        if (cache.get() != null) {
                            this.mRealSize -= cache.size();
                            cache.destroy();
                        }
                        entryRemoved(true, danmaku, null);
                        it.remove();
                    } else if (danmaku.isOutside()) {
                        entryRemoved(true, danmaku, null);
                        it.remove();
                    }
                }
            }
            this.mRealSize = 0;
        }

        /* access modifiers changed from: protected */
        public void entryRemoved(boolean evicted, BaseDanmaku oldValue, BaseDanmaku newValue) {
            IDrawingCache<?> cache = oldValue.getDrawingCache();
            if (cache != null) {
                long releasedSize = clearCache(oldValue);
                if (oldValue.isTimeOut()) {
                    CacheManagingDrawTask.this.mContext.getDisplayer().getCacheStuffer().releaseResource(oldValue);
                }
                if (releasedSize > 0) {
                    this.mRealSize = (int) (((long) this.mRealSize) - releasedSize);
                    this.mCachePool.release((DrawingCache) cache);
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private long clearCache(BaseDanmaku oldValue) {
            IDrawingCache<?> cache = oldValue.cache;
            if (cache == null) {
                return 0;
            }
            if (cache.hasReferences()) {
                cache.decreaseReference();
                oldValue.cache = null;
                return 0;
            }
            long size = (long) sizeOf(oldValue);
            cache.destroy();
            oldValue.cache = null;
            return size;
        }

        /* access modifiers changed from: protected */
        public int sizeOf(BaseDanmaku value) {
            if (value.cache == null || value.cache.hasReferences()) {
                return 0;
            }
            return value.cache.size();
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void clearCachePool() {
            while (true) {
                DrawingCache item = this.mCachePool.acquire();
                if (item != null) {
                    item.destroy();
                } else {
                    return;
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean push(BaseDanmaku item, int itemSize, boolean forcePush) {
            while (true) {
                if (this.mRealSize + itemSize <= this.mMaxSize || this.mCaches.size() <= 0) {
                    break;
                }
                BaseDanmaku oldValue = this.mCaches.first();
                if (oldValue.isTimeOut()) {
                    entryRemoved(false, oldValue, item);
                    this.mCaches.removeItem(oldValue);
                } else if (!forcePush) {
                    return false;
                }
            }
            this.mCaches.addItem(item);
            this.mRealSize += itemSize;
            return true;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private void clearTimeOutCaches() {
            clearTimeOutCaches(CacheManagingDrawTask.this.mTimer.currMillisecond);
        }

        private void clearTimeOutCaches(long time) {
            IDanmakuIterator it = this.mCaches.iterator();
            while (it.hasNext() && !this.mEndFlag) {
                BaseDanmaku val = it.next();
                if (val.isTimeOut()) {
                    synchronized (CacheManagingDrawTask.this.mDrawingNotify) {
                        try {
                            CacheManagingDrawTask.this.mDrawingNotify.wait(30);
                        } catch (InterruptedException e) {
                            e.printStackTrace();
                            return;
                        }
                    }
                    entryRemoved(false, val, null);
                    it.remove();
                } else {
                    return;
                }
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private BaseDanmaku findReuseableCache(BaseDanmaku refDanmaku, boolean strictMode, int maximumTimes) {
            IDanmakuIterator it = this.mCaches.iterator();
            int slopPixel = 0;
            if (!strictMode) {
                slopPixel = CacheManagingDrawTask.this.mDisp.getSlopPixel() * 2;
            }
            int count = 0;
            while (it.hasNext()) {
                int count2 = count + 1;
                if (count < maximumTimes) {
                    BaseDanmaku danmaku = it.next();
                    IDrawingCache<?> cache = danmaku.getDrawingCache();
                    if (!(cache == null || cache.get() == null)) {
                        if (danmaku.paintWidth == refDanmaku.paintWidth && danmaku.paintHeight == refDanmaku.paintHeight && danmaku.underlineColor == refDanmaku.underlineColor && danmaku.borderColor == refDanmaku.borderColor && danmaku.textColor == refDanmaku.textColor && danmaku.text.equals(refDanmaku.text) && danmaku.tag == refDanmaku.tag) {
                            return danmaku;
                        }
                        if (strictMode) {
                            continue;
                        } else if (danmaku.isTimeOut()) {
                            if (cache.hasReferences()) {
                                continue;
                            } else {
                                float widthGap = ((float) cache.width()) - refDanmaku.paintWidth;
                                float heightGap = ((float) cache.height()) - refDanmaku.paintHeight;
                                if (widthGap >= 0.0f && widthGap <= ((float) slopPixel) && heightGap >= 0.0f && heightGap <= ((float) slopPixel)) {
                                    return danmaku;
                                }
                            }
                        }
                    }
                    count = count2;
                }
                return null;
            }
            return null;
        }

        public class CacheHandler extends Handler {
            public static final int ADD_DANMAKKU = 2;
            public static final int BIND_CACHE = 18;
            public static final int BUILD_CACHES = 3;
            public static final int CLEAR_ALL_CACHES = 7;
            public static final int CLEAR_OUTSIDE_CACHES = 8;
            public static final int CLEAR_OUTSIDE_CACHES_AND_RESET = 9;
            public static final int CLEAR_TIMEOUT_CACHES = 4;
            public static final int DISABLE_CANCEL_FLAG = 19;
            public static final int DISPATCH_ACTIONS = 16;
            private static final int PREPARE = 1;
            public static final int QUIT = 6;
            public static final int REBUILD_CACHE = 17;
            public static final int SEEK = 5;
            private boolean mCancelFlag;
            private boolean mIsPlayerPause;
            private boolean mPause;
            private boolean mSeekedFlag;

            public CacheHandler(Looper looper) {
                super(looper);
            }

            public void requestCancelCaching() {
                this.mCancelFlag = true;
            }

            /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
            public void handleMessage(Message msg) {
                int what = msg.what;
                switch (what) {
                    case 1:
                        CacheManager.this.evictAllNotInScreen();
                        for (int i = 0; i < 300; i++) {
                            CacheManager.this.mCachePool.release(new DrawingCache());
                        }
                        break;
                    case 2:
                        addDanmakuAndBuildCache((BaseDanmaku) msg.obj);
                        return;
                    case 3:
                        removeMessages(3);
                        boolean repositioned = (CacheManagingDrawTask.this.mTaskListener != null && !CacheManagingDrawTask.this.mReadyState) || this.mSeekedFlag;
                        prepareCaches(repositioned);
                        if (repositioned) {
                            this.mSeekedFlag = false;
                        }
                        if (!(CacheManagingDrawTask.this.mTaskListener == null || CacheManagingDrawTask.this.mReadyState)) {
                            CacheManagingDrawTask.this.mTaskListener.ready();
                            CacheManagingDrawTask.this.mReadyState = true;
                            return;
                        }
                        return;
                    case 4:
                        CacheManager.this.clearTimeOutCaches();
                        return;
                    case 5:
                        Long seekMills = (Long) msg.obj;
                        if (seekMills != null) {
                            long seekCacheTime = seekMills.longValue();
                            long oldCacheTime = CacheManagingDrawTask.this.mCacheTimer.currMillisecond;
                            CacheManagingDrawTask.this.mCacheTimer.update(seekCacheTime);
                            this.mSeekedFlag = true;
                            long firstCacheTime = CacheManager.this.getFirstCacheTime();
                            if (seekCacheTime <= oldCacheTime) {
                                if (firstCacheTime - seekCacheTime <= CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) {
                                    CacheManager.this.clearTimeOutCaches();
                                    prepareCaches(true);
                                    resume();
                                    return;
                                }
                            }
                            CacheManager.this.evictAllNotInScreen();
                            prepareCaches(true);
                            resume();
                            return;
                        }
                        return;
                    case 6:
                        removeCallbacksAndMessages(null);
                        this.mPause = true;
                        CacheManager.this.evictAll();
                        CacheManager.this.clearCachePool();
                        getLooper().quit();
                        return;
                    case 7:
                        CacheManager.this.evictAll();
                        CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond - CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
                        this.mSeekedFlag = true;
                        return;
                    case 8:
                        CacheManager.this.evictAllNotInScreen(true);
                        CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond);
                        return;
                    case 9:
                        CacheManager.this.evictAllNotInScreen(true);
                        CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond);
                        CacheManagingDrawTask.this.requestClear();
                        return;
                    default:
                        switch (what) {
                            case 16:
                                break;
                            case 17:
                                BaseDanmaku cacheitem = (BaseDanmaku) msg.obj;
                                if (cacheitem != null) {
                                    IDrawingCache<?> cache = cacheitem.getDrawingCache();
                                    if (((cacheitem.requestFlags & 1) != 0) || cache == null || cache.get() == null || cache.hasReferences()) {
                                        if (cacheitem.isLive) {
                                            CacheManager.this.clearCache(cacheitem);
                                            createCache(cacheitem);
                                        } else {
                                            if (cache != null && cache.hasReferences()) {
                                                cache.destroy();
                                            }
                                            CacheManager.this.entryRemoved(true, cacheitem, null);
                                            addDanmakuAndBuildCache(cacheitem);
                                        }
                                        return;
                                    }
                                    cacheitem.cache = DanmakuUtils.buildDanmakuDrawingCache(cacheitem, CacheManagingDrawTask.this.mDisp, (DrawingCache) cacheitem.cache);
                                    CacheManager.this.push(cacheitem, 0, true);
                                    return;
                                }
                                return;
                            case 18:
                                BaseDanmaku danmaku = (BaseDanmaku) msg.obj;
                                if (!danmaku.isTimeOut()) {
                                    createCache(danmaku);
                                    if (danmaku.cache != null) {
                                        CacheManager.this.push(danmaku, danmaku.cache.size(), true);
                                        return;
                                    }
                                    return;
                                }
                                return;
                            case 19:
                                this.mCancelFlag = false;
                                return;
                            default:
                                return;
                        }
                }
                long delayed = dispatchAction();
                if (delayed <= 0) {
                    delayed = CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION / 2;
                }
                sendEmptyMessageDelayed(16, delayed);
            }

            private long dispatchAction() {
                if (CacheManagingDrawTask.this.mCacheTimer.currMillisecond <= CacheManagingDrawTask.this.mTimer.currMillisecond - CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) {
                    CacheManager.this.evictAllNotInScreen();
                    CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond);
                    sendEmptyMessage(3);
                    return 0;
                }
                float level = CacheManager.this.getPoolPercent();
                BaseDanmaku firstCache = CacheManager.this.mCaches.first();
                long gapTime = firstCache != null ? firstCache.getActualTime() - CacheManagingDrawTask.this.mTimer.currMillisecond : 0;
                long doubleScreenDuration = CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION * 2;
                if (level < 0.6f && gapTime > CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) {
                    CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond);
                    removeMessages(3);
                    sendEmptyMessage(3);
                    return 0;
                } else if (level > 0.4f && gapTime < (-doubleScreenDuration)) {
                    removeMessages(4);
                    sendEmptyMessage(4);
                    return 0;
                } else if (level >= 0.9f) {
                    return 0;
                } else {
                    long deltaTime = CacheManagingDrawTask.this.mCacheTimer.currMillisecond - CacheManagingDrawTask.this.mTimer.currMillisecond;
                    if (firstCache != null && firstCache.isTimeOut() && deltaTime < (-CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION)) {
                        CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond);
                        sendEmptyMessage(8);
                        sendEmptyMessage(3);
                        return 0;
                    } else if (deltaTime > doubleScreenDuration) {
                        return 0;
                    } else {
                        removeMessages(3);
                        sendEmptyMessage(3);
                        return 0;
                    }
                }
            }

            private void releaseDanmakuCache(BaseDanmaku item, DrawingCache cache) {
                if (cache == null) {
                    cache = (DrawingCache) item.cache;
                }
                item.cache = null;
                if (cache != null) {
                    cache.destroy();
                    CacheManager.this.mCachePool.release(cache);
                }
            }

            private void preMeasure() {
                IDanmakus danmakus = null;
                try {
                    long begin = CacheManagingDrawTask.this.mTimer.currMillisecond;
                    danmakus = CacheManagingDrawTask.this.danmakuList.subnew(begin - CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION, (CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION * 2) + begin);
                } catch (Exception e) {
                }
                if (danmakus != null && !danmakus.isEmpty()) {
                    IDanmakuIterator itr = danmakus.iterator();
                    while (itr.hasNext() && !this.mPause) {
                        BaseDanmaku item = itr.next();
                        if (!item.hasPassedFilter()) {
                            CacheManagingDrawTask.this.mContext.mDanmakuFilters.filter(item, 0, 0, null, true, CacheManagingDrawTask.this.mContext);
                        }
                        if (!item.isFiltered()) {
                            if (!item.isMeasured()) {
                                item.measure(CacheManagingDrawTask.this.mDisp, true);
                            }
                            if (!item.isPrepared()) {
                                item.prepare(CacheManagingDrawTask.this.mDisp, true);
                            }
                        }
                    }
                }
            }

            /* JADX WARNING: Code restructure failed: missing block: B:88:0x01f2, code lost:
                r0 = r21;
             */
            /* JADX WARNING: Removed duplicated region for block: B:15:0x005a  */
            /* JADX WARNING: Removed duplicated region for block: B:17:0x0066  */
            /* JADX WARNING: Removed duplicated region for block: B:91:0x01fe  */
            /* JADX WARNING: Removed duplicated region for block: B:92:0x0210  */
            private long prepareCaches(boolean repositioned) {
                long end;
                long end2;
                BaseDanmaku item;
                long consumingTime;
                long curr;
                int screenIndex;
                preMeasure();
                long curr2 = CacheManagingDrawTask.this.mCacheTimer.currMillisecond;
                long end3 = (CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION * ((long) CacheManager.this.mScreenSize)) + curr2;
                if (end3 < CacheManagingDrawTask.this.mTimer.currMillisecond) {
                    return 0;
                }
                long startTime = SystemClock.uptimeMillis();
                boolean hasException = false;
                int tryCount = 0;
                IDanmakus danmakus = null;
                do {
                    try {
                        danmakus = CacheManagingDrawTask.this.danmakuList.subnew(curr2, end3);
                    } catch (Exception e) {
                        hasException = true;
                        SystemClock.sleep(10);
                    }
                    tryCount++;
                    if (tryCount >= 3 || danmakus != null) {
                        if (danmakus != null) {
                            CacheManagingDrawTask.this.mCacheTimer.update(end3);
                            return 0;
                        }
                        BaseDanmaku first = danmakus.first();
                        BaseDanmaku last = danmakus.last();
                        if (first == null) {
                            end = end3;
                        } else if (last == null) {
                            end = end3;
                        } else {
                            long deltaTime = first.getActualTime() - CacheManagingDrawTask.this.mTimer.currMillisecond;
                            long sleepTime = 30;
                            if (deltaTime >= 0) {
                                sleepTime = 30 + ((10 * deltaTime) / CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
                            }
                            long sleepTime2 = Math.min(100L, sleepTime);
                            if (repositioned) {
                                sleepTime2 = 0;
                            }
                            IDanmakuIterator itr = danmakus.iterator();
                            long consumingTime2 = 0;
                            int orderInScreen = 0;
                            int sizeInScreen = danmakus.size();
                            BaseDanmaku item2 = null;
                            int currScreenIndex = 0;
                            while (true) {
                                if (this.mPause || this.mCancelFlag) {
                                    end2 = end3;
                                    consumingTime = consumingTime2;
                                } else if (!itr.hasNext()) {
                                    end2 = end3;
                                    consumingTime = consumingTime2;
                                    break;
                                } else {
                                    BaseDanmaku item3 = itr.next();
                                    if (last.getActualTime() < CacheManagingDrawTask.this.mTimer.currMillisecond) {
                                        end2 = end3;
                                        item = item3;
                                        break;
                                    }
                                    IDrawingCache<?> cache = item3.getDrawingCache();
                                    if ((cache == null || cache.get() == null) && (repositioned || (!item3.isTimeOut() && item3.isOutside()))) {
                                        if (!item3.hasPassedFilter()) {
                                            CacheManagingDrawTask.this.mContext.mDanmakuFilters.filter(item3, orderInScreen, sizeInScreen, null, true, CacheManagingDrawTask.this.mContext);
                                        }
                                        if (item3.priority != 0 || !item3.isFiltered()) {
                                            if (item3.getType() == 1) {
                                                curr = curr2;
                                                screenIndex = (int) ((item3.getActualTime() - curr2) / CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
                                                if (currScreenIndex == screenIndex) {
                                                    orderInScreen++;
                                                    screenIndex = currScreenIndex;
                                                } else {
                                                    orderInScreen = 0;
                                                }
                                            } else {
                                                curr = curr2;
                                                screenIndex = currScreenIndex;
                                            }
                                            if (!repositioned && !this.mIsPlayerPause) {
                                                try {
                                                    synchronized (CacheManagingDrawTask.this.mDrawingNotify) {
                                                        CacheManagingDrawTask.this.mDrawingNotify.wait(sleepTime2);
                                                    }
                                                } catch (InterruptedException e2) {
                                                    e2.printStackTrace();
                                                    end2 = end3;
                                                    item = item3;
                                                    long consumingTime3 = SystemClock.uptimeMillis() - startTime;
                                                    if (item == null) {
                                                    }
                                                    return consumingTime3;
                                                }
                                            }
                                            if (buildCache(item3, false) == 1) {
                                                break;
                                            }
                                            if (!repositioned) {
                                                consumingTime2 = SystemClock.uptimeMillis() - startTime;
                                                DanmakuFactory danmakuFactory = CacheManagingDrawTask.this.mContext.mDanmakuFactory;
                                                end2 = end3;
                                                if (consumingTime2 >= ((long) CacheManager.this.mScreenSize) * DanmakuFactory.COMMON_DANMAKU_DURATION) {
                                                    item = item3;
                                                    break;
                                                }
                                            } else {
                                                end2 = end3;
                                                consumingTime2 = consumingTime2;
                                            }
                                            currScreenIndex = screenIndex;
                                            item2 = item3;
                                            curr2 = curr;
                                            end3 = end2;
                                            danmakus = danmakus;
                                            itr = itr;
                                        }
                                    }
                                    item2 = item3;
                                    danmakus = danmakus;
                                    itr = itr;
                                    consumingTime2 = consumingTime2;
                                }
                            }
                            long consumingTime32 = SystemClock.uptimeMillis() - startTime;
                            if (item == null) {
                                CacheManagingDrawTask.this.mCacheTimer.update(item.getActualTime());
                            } else {
                                CacheManagingDrawTask.this.mCacheTimer.update(end2);
                            }
                            return consumingTime32;
                        }
                        CacheManagingDrawTask.this.mCacheTimer.update(end);
                        return 0;
                    }
                } while (hasException);
                if (danmakus != null) {
                }
            }

            public boolean createCache(BaseDanmaku item) {
                if (!item.isMeasured()) {
                    item.measure(CacheManagingDrawTask.this.mDisp, true);
                }
                DrawingCache cache = null;
                try {
                    cache = DanmakuUtils.buildDanmakuDrawingCache(item, CacheManagingDrawTask.this.mDisp, CacheManager.this.mCachePool.acquire());
                    item.cache = cache;
                    return true;
                } catch (OutOfMemoryError e) {
                    if (cache != null) {
                        CacheManager.this.mCachePool.release(cache);
                    }
                    item.cache = null;
                    return false;
                } catch (Exception e2) {
                    if (cache != null) {
                        CacheManager.this.mCachePool.release(cache);
                    }
                    item.cache = null;
                    return false;
                }
            }

            private byte buildCache(BaseDanmaku item, boolean forceInsert) {
                if (!item.isMeasured()) {
                    item.measure(CacheManagingDrawTask.this.mDisp, true);
                }
                DrawingCache cache = null;
                try {
                    BaseDanmaku danmaku = CacheManager.this.findReuseableCache(item, true, 20);
                    if (danmaku != null) {
                        cache = (DrawingCache) danmaku.cache;
                    }
                    if (cache != null) {
                        cache.increaseReference();
                        item.cache = cache;
                        CacheManagingDrawTask.this.mCacheManager.push(item, 0, forceInsert);
                        return 0;
                    }
                    BaseDanmaku danmaku2 = CacheManager.this.findReuseableCache(item, false, 50);
                    if (danmaku2 != null) {
                        cache = (DrawingCache) danmaku2.cache;
                    }
                    if (cache != null) {
                        danmaku2.cache = null;
                        item.cache = DanmakuUtils.buildDanmakuDrawingCache(item, CacheManagingDrawTask.this.mDisp, cache);
                        CacheManagingDrawTask.this.mCacheManager.push(item, 0, forceInsert);
                        return 0;
                    }
                    if (!forceInsert) {
                        if (CacheManager.this.mRealSize + DanmakuUtils.getCacheSize((int) item.paintWidth, (int) item.paintHeight) > CacheManager.this.mMaxSize) {
                            return 1;
                        }
                    }
                    DrawingCache cache2 = DanmakuUtils.buildDanmakuDrawingCache(item, CacheManagingDrawTask.this.mDisp, CacheManager.this.mCachePool.acquire());
                    item.cache = cache2;
                    boolean pushed = CacheManagingDrawTask.this.mCacheManager.push(item, CacheManager.this.sizeOf(item), forceInsert);
                    if (!pushed) {
                        releaseDanmakuCache(item, cache2);
                    }
                    if (pushed) {
                        return 0;
                    }
                    return 1;
                } catch (OutOfMemoryError e) {
                    releaseDanmakuCache(item, null);
                    return 1;
                } catch (Exception e2) {
                    releaseDanmakuCache(item, null);
                    return 1;
                }
            }

            private final void addDanmakuAndBuildCache(BaseDanmaku danmaku) {
                if (danmaku.isTimeOut()) {
                    return;
                }
                if (danmaku.getActualTime() > CacheManagingDrawTask.this.mCacheTimer.currMillisecond + CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION && !danmaku.isLive) {
                    return;
                }
                if (danmaku.priority != 0 || !danmaku.isFiltered()) {
                    IDrawingCache<?> cache = danmaku.getDrawingCache();
                    if (cache == null || cache.get() == null) {
                        buildCache(danmaku, true);
                    }
                }
            }

            public void begin() {
                sendEmptyMessage(1);
                sendEmptyMessageDelayed(4, CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
            }

            public void pause() {
                this.mPause = true;
                removeCallbacksAndMessages(null);
                sendEmptyMessage(6);
            }

            public void resume() {
                sendEmptyMessage(19);
                this.mPause = false;
                removeMessages(16);
                sendEmptyMessage(16);
                sendEmptyMessageDelayed(4, CacheManagingDrawTask.this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
            }

            public boolean isPause() {
                return this.mPause;
            }

            public void requestBuildCacheAndDraw(long correctionTime) {
                removeMessages(3);
                this.mSeekedFlag = true;
                sendEmptyMessage(19);
                CacheManagingDrawTask.this.mCacheTimer.update(CacheManagingDrawTask.this.mTimer.currMillisecond + correctionTime);
                sendEmptyMessage(3);
            }

            public void onPlayStateChanged(boolean isPlaying) {
                this.mIsPlayerPause = !isPlaying;
            }
        }

        public long getFirstCacheTime() {
            BaseDanmaku firstItem;
            Danmakus danmakus = this.mCaches;
            if (danmakus == null || danmakus.size() <= 0 || (firstItem = this.mCaches.first()) == null) {
                return 0;
            }
            return firstItem.getActualTime();
        }

        public void requestBuild(long correctionTime) {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.requestBuildCacheAndDraw(correctionTime);
            }
        }

        public void requestClearAll() {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.removeMessages(3);
                this.mHandler.removeMessages(19);
                this.mHandler.requestCancelCaching();
                this.mHandler.removeMessages(7);
                this.mHandler.sendEmptyMessage(7);
            }
        }

        public void requestClearUnused() {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.removeMessages(9);
                this.mHandler.sendEmptyMessage(9);
            }
        }

        public void requestClearTimeout() {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.removeMessages(4);
                this.mHandler.sendEmptyMessage(4);
            }
        }

        public void post(Runnable runnable) {
            CacheHandler cacheHandler = this.mHandler;
            if (cacheHandler != null) {
                cacheHandler.post(runnable);
            }
        }
    }

    @Override // master.flame.danmaku.controller.DrawTask
    public boolean onDanmakuConfigChanged(DanmakuContext config, DanmakuContext.DanmakuConfigTag tag, Object... values) {
        CacheManager cacheManager;
        CacheManager cacheManager2;
        if (!super.handleOnDanmakuConfigChanged(config, tag, values)) {
            if (DanmakuContext.DanmakuConfigTag.SCROLL_SPEED_FACTOR.equals(tag)) {
                this.mDisp.resetSlopPixel(this.mContext.scaleTextSize);
                requestClear();
            } else if (tag.isVisibilityRelatedTag()) {
                if (values != null && values.length > 0 && values[0] != null && ((!(values[0] instanceof Boolean) || ((Boolean) values[0]).booleanValue()) && (cacheManager2 = this.mCacheManager) != null)) {
                    cacheManager2.requestBuild(0);
                }
                requestClear();
            } else if (DanmakuContext.DanmakuConfigTag.TRANSPARENCY.equals(tag) || DanmakuContext.DanmakuConfigTag.SCALE_TEXTSIZE.equals(tag) || DanmakuContext.DanmakuConfigTag.DANMAKU_STYLE.equals(tag)) {
                if (DanmakuContext.DanmakuConfigTag.SCALE_TEXTSIZE.equals(tag)) {
                    this.mDisp.resetSlopPixel(this.mContext.scaleTextSize);
                }
                CacheManager cacheManager3 = this.mCacheManager;
                if (cacheManager3 != null) {
                    cacheManager3.requestClearAll();
                    this.mCacheManager.requestBuild(-this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION);
                }
            } else {
                CacheManager cacheManager4 = this.mCacheManager;
                if (cacheManager4 != null) {
                    cacheManager4.requestClearUnused();
                    this.mCacheManager.requestBuild(0);
                }
            }
        }
        if (this.mTaskListener == null || (cacheManager = this.mCacheManager) == null) {
            return true;
        }
        cacheManager.post(new Runnable() {
            /* class master.flame.danmaku.controller.CacheManagingDrawTask.AnonymousClass1 */

            public void run() {
                CacheManagingDrawTask.this.mTaskListener.onDanmakuConfigChanged();
            }
        });
        return true;
    }
}
