package master.flame.danmaku.controller;

import android.graphics.Canvas;
import master.flame.danmaku.controller.IDrawTask;
import master.flame.danmaku.danmaku.model.AbsDisplayer;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.DanmakuTimer;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.android.DanmakuContext;
import master.flame.danmaku.danmaku.model.android.Danmakus;
import master.flame.danmaku.danmaku.parser.BaseDanmakuParser;
import master.flame.danmaku.danmaku.renderer.IRenderer;
import master.flame.danmaku.danmaku.renderer.android.DanmakuRenderer;
import master.flame.danmaku.danmaku.util.SystemClock;

public class DrawTask implements IDrawTask {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    protected boolean clearRetainerFlag;
    protected IDanmakus danmakuList;
    private IDanmakus danmakus = new Danmakus(4);
    private DanmakuContext.ConfigChangedCallback mConfigChangedCallback = new DanmakuContext.ConfigChangedCallback() {
        /* class master.flame.danmaku.controller.DrawTask.AnonymousClass1 */

        @Override // master.flame.danmaku.danmaku.model.android.DanmakuContext.ConfigChangedCallback
        public boolean onDanmakuConfigChanged(DanmakuContext config, DanmakuContext.DanmakuConfigTag tag, Object... values) {
            return DrawTask.this.onDanmakuConfigChanged(config, tag, values);
        }
    };
    protected final DanmakuContext mContext;
    protected final AbsDisplayer mDisp;
    private boolean mIsHidden;
    private long mLastBeginMills;
    private BaseDanmaku mLastDanmaku;
    private long mLastEndMills;
    private Danmakus mLiveDanmakus = new Danmakus(4);
    protected BaseDanmakuParser mParser;
    protected int mPlayState;
    protected boolean mReadyState;
    final IRenderer mRenderer;
    private final IRenderer.RenderingState mRenderingState = new IRenderer.RenderingState();
    private IDanmakus mRunningDanmakus;
    private long mStartRenderTime = 0;
    IDrawTask.TaskListener mTaskListener;
    DanmakuTimer mTimer;

    public DrawTask(DanmakuTimer timer, DanmakuContext context, IDrawTask.TaskListener taskListener) {
        if (context != null) {
            this.mContext = context;
            this.mDisp = context.getDisplayer();
            this.mTaskListener = taskListener;
            DanmakuRenderer danmakuRenderer = new DanmakuRenderer(context);
            this.mRenderer = danmakuRenderer;
            danmakuRenderer.setOnDanmakuShownListener(new IRenderer.OnDanmakuShownListener() {
                /* class master.flame.danmaku.controller.DrawTask.AnonymousClass2 */

                @Override // master.flame.danmaku.danmaku.renderer.IRenderer.OnDanmakuShownListener
                public void onDanmakuShown(BaseDanmaku danmaku) {
                    if (DrawTask.this.mTaskListener != null) {
                        DrawTask.this.mTaskListener.onDanmakuShown(danmaku);
                    }
                }
            });
            this.mRenderer.setVerifierEnabled(this.mContext.isPreventOverlappingEnabled() || this.mContext.isMaxLinesLimited());
            initTimer(timer);
            Boolean enable = Boolean.valueOf(this.mContext.isDuplicateMergingEnabled());
            if (enable == null) {
                return;
            }
            if (enable.booleanValue()) {
                this.mContext.mDanmakuFilters.registerFilter(DanmakuFilters.TAG_DUPLICATE_FILTER);
            } else {
                this.mContext.mDanmakuFilters.unregisterFilter(DanmakuFilters.TAG_DUPLICATE_FILTER);
            }
        } else {
            throw new IllegalArgumentException("context is null");
        }
    }

    /* access modifiers changed from: protected */
    public void initTimer(DanmakuTimer timer) {
        this.mTimer = timer;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public synchronized void addDanmaku(BaseDanmaku item) {
        boolean added;
        if (this.danmakuList != null) {
            if (item.isLive) {
                this.mLiveDanmakus.addItem(item);
                removeUnusedLiveDanmakusIn(10);
            }
            item.index = this.danmakuList.size();
            boolean subAdded = true;
            if (this.mLastBeginMills <= item.getActualTime() && item.getActualTime() <= this.mLastEndMills) {
                synchronized (this.danmakus) {
                    subAdded = this.danmakus.addItem(item);
                }
            } else if (item.isLive) {
                subAdded = false;
            }
            synchronized (this.danmakuList) {
                added = this.danmakuList.addItem(item);
            }
            if (!subAdded) {
                this.mLastEndMills = 0;
                this.mLastBeginMills = 0;
            }
            if (added && this.mTaskListener != null) {
                this.mTaskListener.onDanmakuAdd(item);
            }
            if (this.mLastDanmaku == null || !(item == null || this.mLastDanmaku == null || item.getActualTime() <= this.mLastDanmaku.getActualTime())) {
                this.mLastDanmaku = item;
            }
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void invalidateDanmaku(BaseDanmaku item, boolean remeasure) {
        this.mContext.getDisplayer().getCacheStuffer().clearCache(item);
        item.requestFlags |= 2;
        if (remeasure) {
            item.paintWidth = -1.0f;
            item.paintHeight = -1.0f;
            item.requestFlags |= 1;
            item.measureResetFlag++;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0041, code lost:
        r1 = th;
     */
    @Override // master.flame.danmaku.controller.IDrawTask
    public synchronized void removeAllDanmakus(boolean isClearDanmakusOnScreen) {
        if (this.danmakuList != null) {
            if (!this.danmakuList.isEmpty()) {
                synchronized (this.danmakuList) {
                    if (!isClearDanmakusOnScreen) {
                        long endMills = this.mTimer.currMillisecond + this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION;
                        IDanmakus tempDanmakus = this.danmakuList.subnew((this.mTimer.currMillisecond - this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) - 100, endMills);
                        if (tempDanmakus != null) {
                            this.danmakus = tempDanmakus;
                        }
                    }
                    this.danmakuList.clear();
                }
                return;
            }
        }
        return;
        while (true) {
        }
    }

    /* access modifiers changed from: protected */
    public void onDanmakuRemoved(BaseDanmaku danmaku) {
    }

    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0032, code lost:
        r1 = th;
     */
    @Override // master.flame.danmaku.controller.IDrawTask
    public synchronized void removeAllLiveDanmakus() {
        if (this.danmakus != null) {
            if (!this.danmakus.isEmpty()) {
                synchronized (this.danmakus) {
                    IDanmakuIterator it = this.danmakus.iterator();
                    while (it.hasNext()) {
                        BaseDanmaku danmaku = it.next();
                        if (danmaku.isLive) {
                            it.remove();
                            onDanmakuRemoved(danmaku);
                        }
                    }
                }
                return;
            }
        }
        return;
        while (true) {
        }
    }

    /* access modifiers changed from: protected */
    public synchronized void removeUnusedLiveDanmakusIn(int msec) {
        BaseDanmaku danmaku;
        boolean isTimeout;
        if (this.danmakuList != null && !this.danmakuList.isEmpty()) {
            if (!this.mLiveDanmakus.isEmpty()) {
                long startTime = SystemClock.uptimeMillis();
                IDanmakuIterator it = this.mLiveDanmakus.iterator();
                while (it.hasNext() && (isTimeout = (danmaku = it.next()).isTimeOut())) {
                    it.remove();
                    this.danmakuList.removeItem(danmaku);
                    onDanmakuRemoved(danmaku);
                    if (isTimeout) {
                        if (SystemClock.uptimeMillis() - startTime > ((long) msec)) {
                            break;
                        }
                    } else {
                        break;
                    }
                }
            }
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public IDanmakus getVisibleDanmakusOnTime(long time) {
        IDanmakus subDanmakus = this.danmakuList.subnew((time - this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) - 100, this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION + time);
        IDanmakus visibleDanmakus = new Danmakus();
        if (subDanmakus != null && !subDanmakus.isEmpty()) {
            IDanmakuIterator iterator = subDanmakus.iterator();
            while (iterator.hasNext()) {
                BaseDanmaku danmaku = iterator.next();
                if (danmaku.isShown() && !danmaku.isOutside()) {
                    visibleDanmakus.addItem(danmaku);
                }
            }
        }
        return visibleDanmakus;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public synchronized IRenderer.RenderingState draw(AbsDisplayer displayer) {
        return drawDanmakus(displayer, this.mTimer);
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void reset() {
        if (this.danmakus != null) {
            this.danmakus = new Danmakus();
        }
        IRenderer iRenderer = this.mRenderer;
        if (iRenderer != null) {
            iRenderer.clear();
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void seek(long mills) {
        BaseDanmaku last;
        reset();
        this.mContext.mGlobalFlagValues.updateVisibleFlag();
        this.mContext.mGlobalFlagValues.updateFirstShownFlag();
        this.mContext.mGlobalFlagValues.updateSyncOffsetTimeFlag();
        this.mContext.mGlobalFlagValues.updatePrepareFlag();
        this.mRunningDanmakus = new Danmakus(4);
        this.mStartRenderTime = mills < 1000 ? 0 : mills;
        this.mRenderingState.reset();
        this.mRenderingState.endTime = this.mStartRenderTime;
        this.mLastEndMills = 0;
        this.mLastBeginMills = 0;
        IDanmakus iDanmakus = this.danmakuList;
        if (iDanmakus != null && (last = iDanmakus.last()) != null && !last.isTimeOut()) {
            this.mLastDanmaku = last;
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void clearDanmakusOnScreen(long currMillis) {
        reset();
        this.mContext.mGlobalFlagValues.updateVisibleFlag();
        this.mContext.mGlobalFlagValues.updateFirstShownFlag();
        this.mStartRenderTime = currMillis;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void start() {
        this.mContext.registerConfigChangedCallback(this.mConfigChangedCallback);
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void quit() {
        this.mContext.unregisterAllConfigChangedCallbacks();
        IRenderer iRenderer = this.mRenderer;
        if (iRenderer != null) {
            iRenderer.release();
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void prepare() {
        loadDanmakus(this.mParser);
        this.mLastEndMills = 0;
        this.mLastBeginMills = 0;
        IDrawTask.TaskListener taskListener = this.mTaskListener;
        if (taskListener != null) {
            taskListener.ready();
            this.mReadyState = true;
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void onPlayStateChanged(int state) {
        this.mPlayState = state;
    }

    /* access modifiers changed from: protected */
    public void loadDanmakus(BaseDanmakuParser parser) {
        IDanmakus danmakus2 = parser.setConfig(this.mContext).setDisplayer(this.mDisp).setTimer(this.mTimer).getDanmakus();
        this.danmakuList = danmakus2;
        if (danmakus2 != null && !danmakus2.isEmpty() && this.danmakuList.first().flags == null) {
            IDanmakuIterator it = this.danmakuList.iterator();
            while (it.hasNext()) {
                BaseDanmaku item = it.next();
                if (item != null) {
                    item.flags = this.mContext.mGlobalFlagValues;
                }
            }
        }
        this.mContext.mGlobalFlagValues.resetAll();
        IDanmakus iDanmakus = this.danmakuList;
        if (iDanmakus != null) {
            this.mLastDanmaku = iDanmakus.last();
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void setParser(BaseDanmakuParser parser) {
        this.mParser = parser;
        this.mReadyState = false;
    }

    /* access modifiers changed from: protected */
    public IRenderer.RenderingState drawDanmakus(AbsDisplayer disp, DanmakuTimer timer) {
        long endMills;
        long beginMills;
        IDanmakus screenDanmakus;
        if (this.clearRetainerFlag) {
            this.mRenderer.clearRetainer();
            this.clearRetainerFlag = false;
        }
        if (this.danmakuList == null) {
            return null;
        }
        DrawHelper.clearCanvas((Canvas) disp.getExtraData());
        if (this.mIsHidden) {
            return this.mRenderingState;
        }
        IRenderer.RenderingState renderingState = this.mRenderingState;
        long beginMills2 = (timer.currMillisecond - this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION) - 100;
        long endMills2 = timer.currMillisecond + this.mContext.mDanmakuFactory.MAX_DANMAKU_DURATION;
        IDanmakus screenDanmakus2 = this.danmakus;
        if (this.mLastBeginMills > beginMills2 || timer.currMillisecond > this.mLastEndMills) {
            IDanmakus screenDanmakus3 = this.danmakuList.sub(beginMills2, endMills2);
            if (screenDanmakus3 != null) {
                this.danmakus = screenDanmakus3;
            }
            this.mLastBeginMills = beginMills2;
            this.mLastEndMills = endMills2;
            beginMills = beginMills2;
            endMills = endMills2;
            screenDanmakus = screenDanmakus3;
        } else {
            beginMills = this.mLastBeginMills;
            endMills = this.mLastEndMills;
            screenDanmakus = screenDanmakus2;
        }
        IDanmakus runningDanmakus = this.mRunningDanmakus;
        beginTracing(renderingState, runningDanmakus, screenDanmakus);
        if (runningDanmakus != null && !runningDanmakus.isEmpty()) {
            this.mRenderingState.isRunningDanmakus = true;
            this.mRenderer.draw(disp, runningDanmakus, 0, this.mRenderingState);
        }
        this.mRenderingState.isRunningDanmakus = false;
        if (screenDanmakus == null || screenDanmakus.isEmpty()) {
            renderingState.nothingRendered = true;
            renderingState.beginTime = beginMills;
            renderingState.endTime = endMills;
            return renderingState;
        }
        this.mRenderer.draw(this.mDisp, screenDanmakus, this.mStartRenderTime, renderingState);
        endTracing(renderingState);
        if (renderingState.nothingRendered) {
            BaseDanmaku baseDanmaku = this.mLastDanmaku;
            if (baseDanmaku != null && baseDanmaku.isTimeOut()) {
                this.mLastDanmaku = null;
                IDrawTask.TaskListener taskListener = this.mTaskListener;
                if (taskListener != null) {
                    taskListener.onDanmakusDrawingFinished();
                }
            }
            if (renderingState.beginTime == -1) {
                renderingState.beginTime = beginMills;
            }
            if (renderingState.endTime == -1) {
                renderingState.endTime = endMills;
            }
        }
        return renderingState;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void requestClear() {
        this.mLastEndMills = 0;
        this.mLastBeginMills = 0;
        this.mIsHidden = false;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void requestClearRetainer() {
        this.clearRetainerFlag = true;
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void requestSync(long fromTimeMills, long toTimeMills, long offsetMills) {
        IDanmakus runningDanmakus = this.mRenderingState.obtainRunningDanmakus();
        this.mRunningDanmakus = runningDanmakus;
        IDanmakuIterator it = runningDanmakus.iterator();
        while (it.hasNext()) {
            BaseDanmaku danmaku = it.next();
            if (danmaku.isOutside()) {
                it.remove();
            } else {
                danmaku.setTimeOffset(danmaku.timeOffset + offsetMills);
                danmaku.isOffset = true;
            }
        }
        this.mStartRenderTime = toTimeMills;
    }

    public boolean onDanmakuConfigChanged(DanmakuContext config, DanmakuContext.DanmakuConfigTag tag, Object... values) {
        boolean handled = handleOnDanmakuConfigChanged(config, tag, values);
        IDrawTask.TaskListener taskListener = this.mTaskListener;
        if (taskListener != null) {
            taskListener.onDanmakuConfigChanged();
        }
        return handled;
    }

    /* access modifiers changed from: protected */
    public boolean handleOnDanmakuConfigChanged(DanmakuContext config, DanmakuContext.DanmakuConfigTag tag, Object[] values) {
        Boolean enable;
        if (tag == null || DanmakuContext.DanmakuConfigTag.MAXIMUM_NUMS_IN_SCREEN.equals(tag)) {
            return true;
        }
        boolean z = false;
        if (DanmakuContext.DanmakuConfigTag.DUPLICATE_MERGING_ENABLED.equals(tag)) {
            Boolean enable2 = (Boolean) values[0];
            if (enable2 == null) {
                return false;
            }
            if (enable2.booleanValue()) {
                this.mContext.mDanmakuFilters.registerFilter(DanmakuFilters.TAG_DUPLICATE_FILTER);
            } else {
                this.mContext.mDanmakuFilters.unregisterFilter(DanmakuFilters.TAG_DUPLICATE_FILTER);
            }
            return true;
        } else if (DanmakuContext.DanmakuConfigTag.SCALE_TEXTSIZE.equals(tag) || DanmakuContext.DanmakuConfigTag.SCROLL_SPEED_FACTOR.equals(tag)) {
            requestClearRetainer();
            return false;
        } else if (DanmakuContext.DanmakuConfigTag.MAXIMUN_LINES.equals(tag) || DanmakuContext.DanmakuConfigTag.OVERLAPPING_ENABLE.equals(tag)) {
            IRenderer iRenderer = this.mRenderer;
            if (iRenderer != null) {
                if (this.mContext.isPreventOverlappingEnabled() || this.mContext.isMaxLinesLimited()) {
                    z = true;
                }
                iRenderer.setVerifierEnabled(z);
            }
            return true;
        } else if (!DanmakuContext.DanmakuConfigTag.ALIGN_BOTTOM.equals(tag) || (enable = (Boolean) values[0]) == null) {
            return false;
        } else {
            IRenderer iRenderer2 = this.mRenderer;
            if (iRenderer2 != null) {
                iRenderer2.alignBottom(enable.booleanValue());
            }
            return true;
        }
    }

    @Override // master.flame.danmaku.controller.IDrawTask
    public void requestHide() {
        this.mIsHidden = true;
    }

    private void beginTracing(IRenderer.RenderingState renderingState, IDanmakus runningDanmakus, IDanmakus screenDanmakus) {
        renderingState.reset();
        renderingState.timer.update(SystemClock.uptimeMillis());
        int i = 0;
        renderingState.indexInScreen = 0;
        int size = runningDanmakus != null ? runningDanmakus.size() : 0;
        if (screenDanmakus != null) {
            i = screenDanmakus.size();
        }
        renderingState.totalSizeInScreen = size + i;
    }

    private void endTracing(IRenderer.RenderingState renderingState) {
        renderingState.nothingRendered = renderingState.totalDanmakuCount == 0;
        long j = -1;
        if (renderingState.nothingRendered) {
            renderingState.beginTime = -1;
        }
        BaseDanmaku lastDanmaku = renderingState.lastDanmaku;
        renderingState.lastDanmaku = null;
        if (lastDanmaku != null) {
            j = lastDanmaku.getActualTime();
        }
        renderingState.endTime = j;
        renderingState.consumingTime = renderingState.timer.update(SystemClock.uptimeMillis());
    }
}
