package master.flame.danmaku.danmaku.model;

public class SpecialDanmaku extends BaseDanmaku {
    public long alphaDuration;
    public int beginAlpha;
    public float beginX;
    public float beginY;
    private float[] currStateValues = new float[4];
    public int deltaAlpha;
    public float deltaX;
    public float deltaY;
    public int endAlpha;
    public float endX;
    public float endY;
    public LinePath[] linePaths;
    public float pivotX;
    public float pivotY;
    public float rotateX;
    public float rotateZ;
    public long translationDuration;
    public long translationStartDelay;

    /* access modifiers changed from: private */
    public class Point {
        float x;
        float y;

        public Point(float x2, float y2) {
            this.x = x2;
            this.y = y2;
        }

        public float getDistance(Point p) {
            float _x = Math.abs(this.x - p.x);
            float _y = Math.abs(this.y - p.y);
            return (float) Math.sqrt((double) ((_x * _x) + (_y * _y)));
        }
    }

    public class LinePath {
        public long beginTime;
        float delatX;
        float deltaY;
        public long duration;
        public long endTime;
        Point pBegin;
        Point pEnd;

        public LinePath() {
        }

        public void setPoints(Point pBegin2, Point pEnd2) {
            this.pBegin = pBegin2;
            this.pEnd = pEnd2;
            this.delatX = pEnd2.x - pBegin2.x;
            this.deltaY = pEnd2.y - pBegin2.y;
        }

        public float getDistance() {
            return this.pEnd.getDistance(this.pBegin);
        }

        public float[] getBeginPoint() {
            return new float[]{this.pBegin.x, this.pBegin.y};
        }

        public float[] getEndPoint() {
            return new float[]{this.pEnd.x, this.pEnd.y};
        }
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public void layout(IDisplayer displayer, float x, float y) {
        getRectAtTime(displayer, this.mTimer.currMillisecond);
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public float[] getRectAtTime(IDisplayer displayer, long currTime) {
        int i;
        if (!isMeasured()) {
            return null;
        }
        long deltaTime = currTime - getActualTime();
        long j = this.alphaDuration;
        if (j > 0 && (i = this.deltaAlpha) != 0) {
            if (deltaTime >= j) {
                this.alpha = this.endAlpha;
            } else {
                this.alpha = this.beginAlpha + ((int) (((float) i) * (((float) deltaTime) / ((float) j))));
            }
        }
        float currX = this.beginX;
        float currY = this.beginY;
        long dtime = deltaTime - this.translationStartDelay;
        long j2 = this.translationDuration;
        if (j2 > 0 && dtime >= 0 && dtime <= j2) {
            float tranalationProgress = ((float) dtime) / ((float) j2);
            LinePath[] linePathArr = this.linePaths;
            if (linePathArr != null) {
                LinePath currentLinePath = null;
                int length = linePathArr.length;
                int i2 = 0;
                while (true) {
                    if (i2 >= length) {
                        break;
                    }
                    LinePath line = linePathArr[i2];
                    if (dtime >= line.beginTime && dtime < line.endTime) {
                        currentLinePath = line;
                        break;
                    }
                    currX = line.pEnd.x;
                    currY = line.pEnd.y;
                    i2++;
                    length = length;
                }
                if (currentLinePath != null) {
                    float deltaX2 = currentLinePath.delatX;
                    float deltaY2 = currentLinePath.deltaY;
                    float tranalationProgress2 = ((float) (deltaTime - currentLinePath.beginTime)) / ((float) currentLinePath.duration);
                    float beginX2 = currentLinePath.pBegin.x;
                    float beginY2 = currentLinePath.pBegin.y;
                    if (deltaX2 != 0.0f) {
                        currX = beginX2 + (deltaX2 * tranalationProgress2);
                    }
                    if (deltaY2 != 0.0f) {
                        currY = beginY2 + (deltaY2 * tranalationProgress2);
                    }
                }
            } else {
                float f = this.deltaX;
                if (f != 0.0f) {
                    currX = this.beginX + (f * tranalationProgress);
                }
                float vectorX = this.deltaY;
                if (vectorX != 0.0f) {
                    currY = this.beginY + (vectorX * tranalationProgress);
                }
            }
        } else if (dtime > this.translationDuration) {
            currX = this.endX;
            currY = this.endY;
        }
        float[] fArr = this.currStateValues;
        fArr[0] = currX;
        fArr[1] = currY;
        fArr[2] = this.paintWidth + currX;
        this.currStateValues[3] = this.paintHeight + currY;
        setVisibility(!isOutside());
        return this.currStateValues;
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public float getLeft() {
        return this.currStateValues[0];
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public float getTop() {
        return this.currStateValues[1];
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public float getRight() {
        return this.currStateValues[2];
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public float getBottom() {
        return this.currStateValues[3];
    }

    @Override // master.flame.danmaku.danmaku.model.BaseDanmaku
    public int getType() {
        return 7;
    }

    public void setTranslationData(float beginX2, float beginY2, float endX2, float endY2, long translationDuration2, long translationStartDelay2) {
        this.beginX = beginX2;
        this.beginY = beginY2;
        this.endX = endX2;
        this.endY = endY2;
        this.deltaX = endX2 - beginX2;
        this.deltaY = endY2 - beginY2;
        this.translationDuration = translationDuration2;
        this.translationStartDelay = translationStartDelay2;
    }

    public void setAlphaData(int beginAlpha2, int endAlpha2, long alphaDuration2) {
        this.beginAlpha = beginAlpha2;
        this.endAlpha = endAlpha2;
        int i = endAlpha2 - beginAlpha2;
        this.deltaAlpha = i;
        this.alphaDuration = alphaDuration2;
        if (i != 0 && beginAlpha2 != AlphaValue.MAX) {
            this.alpha = beginAlpha2;
        }
    }

    public void setLinePathData(float[][] points) {
        LinePath[] linePathArr;
        if (points != null) {
            int length = points.length;
            this.beginX = points[0][0];
            this.beginY = points[0][1];
            this.endX = points[length - 1][0];
            this.endY = points[length - 1][1];
            if (points.length > 1) {
                this.linePaths = new LinePath[(points.length - 1)];
                int i = 0;
                while (true) {
                    linePathArr = this.linePaths;
                    if (i >= linePathArr.length) {
                        break;
                    }
                    linePathArr[i] = new LinePath();
                    this.linePaths[i].setPoints(new Point(points[i][0], points[i][1]), new Point(points[i + 1][0], points[i + 1][1]));
                    i++;
                }
                float totalDistance = 0.0f;
                for (LinePath line : linePathArr) {
                    totalDistance += line.getDistance();
                }
                LinePath lastLine = null;
                LinePath[] linePathArr2 = this.linePaths;
                for (LinePath line2 : linePathArr2) {
                    line2.duration = (long) ((line2.getDistance() / totalDistance) * ((float) this.translationDuration));
                    line2.beginTime = lastLine == null ? 0 : lastLine.endTime;
                    line2.endTime = line2.beginTime + line2.duration;
                    lastLine = line2;
                }
            }
        }
    }

    public void updateData(float scale) {
    }
}
