package master.flame.danmaku.danmaku.model.android;

import android.graphics.Camera;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.os.Build;
import android.text.TextPaint;
import com.tencent.smtt.sdk.TbsListener;
import java.util.HashMap;
import java.util.Map;
import master.flame.danmaku.danmaku.model.AbsDisplayer;
import master.flame.danmaku.danmaku.model.AlphaValue;
import master.flame.danmaku.danmaku.model.BaseDanmaku;

public class AndroidDisplayer extends AbsDisplayer<Canvas, Typeface> {
    private Camera camera = new Camera();
    public Canvas canvas;
    private float density = 1.0f;
    private int densityDpi = 160;
    private int height;
    private final DisplayerConfig mDisplayConfig = new DisplayerConfig();
    private boolean mIsHardwareAccelerated = true;
    private int mMaximumBitmapHeight = 2048;
    private int mMaximumBitmapWidth = 2048;
    private int mSlopPixel = 0;
    private Matrix matrix = new Matrix();
    private BaseCacheStuffer sStuffer = new SimpleTextCacheStuffer();
    private float scaledDensity = 1.0f;
    private int width;

    public static class DisplayerConfig {
        public static final int BORDER_WIDTH = 4;
        private Paint ALPHA_PAINT;
        private boolean ANTI_ALIAS = true;
        private Paint BORDER_PAINT;
        public boolean CONFIG_ANTI_ALIAS = true;
        public boolean CONFIG_HAS_PROJECTION = false;
        public boolean CONFIG_HAS_SHADOW = false;
        public boolean CONFIG_HAS_STROKE = true;
        public boolean HAS_PROJECTION = false;
        private boolean HAS_SHADOW = false;
        private boolean HAS_STROKE = true;
        public final TextPaint PAINT;
        public final TextPaint PAINT_DUPLICATE;
        private float SHADOW_RADIUS = 4.0f;
        private float STROKE_WIDTH = 3.5f;
        public int UNDERLINE_HEIGHT = 4;
        private Paint UNDERLINE_PAINT;
        private boolean isTextScaled = false;
        private boolean isTranslucent;
        private final Map<Float, Float> sCachedScaleSize = new HashMap(10);
        private float sLastScaleTextSize;
        private int sProjectionAlpha = TbsListener.ErrorCode.APK_INVALID;
        public float sProjectionOffsetX = 1.0f;
        public float sProjectionOffsetY = 1.0f;
        private float scaleTextSize = 1.0f;
        private int transparency = AlphaValue.MAX;

        public DisplayerConfig() {
            TextPaint textPaint = new TextPaint();
            this.PAINT = textPaint;
            textPaint.setStrokeWidth(this.STROKE_WIDTH);
            this.PAINT_DUPLICATE = new TextPaint(this.PAINT);
            this.ALPHA_PAINT = new Paint();
            Paint paint = new Paint();
            this.UNDERLINE_PAINT = paint;
            paint.setStrokeWidth((float) this.UNDERLINE_HEIGHT);
            this.UNDERLINE_PAINT.setStyle(Paint.Style.STROKE);
            Paint paint2 = new Paint();
            this.BORDER_PAINT = paint2;
            paint2.setStyle(Paint.Style.STROKE);
            this.BORDER_PAINT.setStrokeWidth(4.0f);
        }

        public void setTypeface(Typeface typeface) {
            this.PAINT.setTypeface(typeface);
        }

        public void setShadowRadius(float shadowRadius) {
            this.SHADOW_RADIUS = shadowRadius;
        }

        public void setStrokeWidth(float s) {
            this.PAINT.setStrokeWidth(s);
            this.STROKE_WIDTH = s;
        }

        public void setProjectionConfig(float offsetX, float offsetY, int alpha) {
            if (this.sProjectionOffsetX != offsetX || this.sProjectionOffsetY != offsetY || this.sProjectionAlpha != alpha) {
                float f = 1.0f;
                this.sProjectionOffsetX = offsetX > 1.0f ? offsetX : 1.0f;
                if (offsetY > 1.0f) {
                    f = offsetY;
                }
                this.sProjectionOffsetY = f;
                int i = 255;
                if (alpha < 0) {
                    i = 0;
                } else if (alpha <= 255) {
                    i = alpha;
                }
                this.sProjectionAlpha = i;
            }
        }

        public void setFakeBoldText(boolean fakeBoldText) {
            this.PAINT.setFakeBoldText(fakeBoldText);
        }

        public void setTransparency(int newTransparency) {
            this.isTranslucent = newTransparency != AlphaValue.MAX;
            this.transparency = newTransparency;
        }

        public void setScaleTextSizeFactor(float factor) {
            this.isTextScaled = factor != 1.0f;
            this.scaleTextSize = factor;
        }

        private void applyTextScaleConfig(BaseDanmaku danmaku, Paint paint) {
            if (this.isTextScaled) {
                Float size = this.sCachedScaleSize.get(Float.valueOf(danmaku.textSize));
                if (size == null || this.sLastScaleTextSize != this.scaleTextSize) {
                    this.sLastScaleTextSize = this.scaleTextSize;
                    size = Float.valueOf(danmaku.textSize * this.scaleTextSize);
                    this.sCachedScaleSize.put(Float.valueOf(danmaku.textSize), size);
                }
                paint.setTextSize(size.floatValue());
            }
        }

        public boolean hasStroke(BaseDanmaku danmaku) {
            return (this.HAS_STROKE || this.HAS_PROJECTION) && this.STROKE_WIDTH > 0.0f && danmaku.textShadowColor != 0;
        }

        public Paint getBorderPaint(BaseDanmaku danmaku) {
            this.BORDER_PAINT.setColor(danmaku.borderColor);
            return this.BORDER_PAINT;
        }

        public Paint getUnderlinePaint(BaseDanmaku danmaku) {
            this.UNDERLINE_PAINT.setColor(danmaku.underlineColor);
            return this.UNDERLINE_PAINT;
        }

        public TextPaint getPaint(BaseDanmaku danmaku, boolean fromWorkerThread) {
            TextPaint paint;
            if (fromWorkerThread) {
                paint = this.PAINT;
            } else {
                paint = this.PAINT_DUPLICATE;
                paint.set(this.PAINT);
            }
            paint.setTextSize(danmaku.textSize);
            applyTextScaleConfig(danmaku, paint);
            if (!this.HAS_SHADOW || this.SHADOW_RADIUS <= 0.0f || danmaku.textShadowColor == 0) {
                paint.clearShadowLayer();
            } else {
                paint.setShadowLayer(this.SHADOW_RADIUS, 0.0f, 0.0f, danmaku.textShadowColor);
            }
            paint.setAntiAlias(this.ANTI_ALIAS);
            return paint;
        }

        public void applyPaintConfig(BaseDanmaku danmaku, Paint paint, boolean stroke) {
            if (this.isTranslucent) {
                if (stroke) {
                    paint.setStyle(this.HAS_PROJECTION ? Paint.Style.FILL : Paint.Style.STROKE);
                    paint.setColor(danmaku.textShadowColor & 16777215);
                    paint.setAlpha(this.HAS_PROJECTION ? (int) (((float) this.sProjectionAlpha) * (((float) this.transparency) / ((float) AlphaValue.MAX))) : this.transparency);
                    return;
                }
                paint.setStyle(Paint.Style.FILL);
                paint.setColor(danmaku.textColor & 16777215);
                paint.setAlpha(this.transparency);
            } else if (stroke) {
                paint.setStyle(this.HAS_PROJECTION ? Paint.Style.FILL : Paint.Style.STROKE);
                paint.setColor(danmaku.textShadowColor & 16777215);
                paint.setAlpha(this.HAS_PROJECTION ? this.sProjectionAlpha : AlphaValue.MAX);
            } else {
                paint.setStyle(Paint.Style.FILL);
                paint.setColor(danmaku.textColor & 16777215);
                paint.setAlpha(AlphaValue.MAX);
            }
        }

        public void clearTextHeightCache() {
            this.sCachedScaleSize.clear();
        }

        public float getStrokeWidth() {
            if (this.HAS_SHADOW && this.HAS_STROKE) {
                return Math.max(this.SHADOW_RADIUS, this.STROKE_WIDTH);
            }
            if (this.HAS_SHADOW) {
                return this.SHADOW_RADIUS;
            }
            if (this.HAS_STROKE) {
                return this.STROKE_WIDTH;
            }
            return 0.0f;
        }

        public void definePaintParams(boolean fromWorkerThread) {
            this.HAS_STROKE = this.CONFIG_HAS_STROKE;
            this.HAS_SHADOW = this.CONFIG_HAS_SHADOW;
            this.HAS_PROJECTION = this.CONFIG_HAS_PROJECTION;
            this.ANTI_ALIAS = fromWorkerThread && this.CONFIG_ANTI_ALIAS;
        }
    }

    private static final int getMaximumBitmapWidth(Canvas c) {
        if (Build.VERSION.SDK_INT >= 14) {
            return c.getMaximumBitmapWidth();
        }
        return c.getWidth();
    }

    private static final int getMaximumBitmapHeight(Canvas c) {
        if (Build.VERSION.SDK_INT >= 14) {
            return c.getMaximumBitmapHeight();
        }
        return c.getHeight();
    }

    public void setTypeFace(Typeface font) {
        this.mDisplayConfig.setTypeface(font);
    }

    public void setShadowRadius(float s) {
        this.mDisplayConfig.setShadowRadius(s);
    }

    public void setPaintStorkeWidth(float s) {
        this.mDisplayConfig.setStrokeWidth(s);
    }

    public void setProjectionConfig(float offsetX, float offsetY, int alpha) {
        this.mDisplayConfig.setProjectionConfig(offsetX, offsetY, alpha);
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public void setFakeBoldText(boolean fakeBoldText) {
        this.mDisplayConfig.setFakeBoldText(fakeBoldText);
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public void setTransparency(int newTransparency) {
        this.mDisplayConfig.setTransparency(newTransparency);
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public void setScaleTextSizeFactor(float factor) {
        this.mDisplayConfig.setScaleTextSizeFactor(factor);
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public void setCacheStuffer(BaseCacheStuffer cacheStuffer) {
        if (cacheStuffer != this.sStuffer) {
            this.sStuffer = cacheStuffer;
        }
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public BaseCacheStuffer getCacheStuffer() {
        return this.sStuffer;
    }

    private void update(Canvas c) {
        this.canvas = c;
        if (c != null) {
            this.width = c.getWidth();
            this.height = c.getHeight();
            if (this.mIsHardwareAccelerated) {
                this.mMaximumBitmapWidth = getMaximumBitmapWidth(c);
                this.mMaximumBitmapHeight = getMaximumBitmapHeight(c);
            }
        }
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getWidth() {
        return this.width;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getHeight() {
        return this.height;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public float getDensity() {
        return this.density;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getDensityDpi() {
        return this.densityDpi;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int draw(BaseDanmaku danmaku) {
        boolean needRestore;
        Paint alphaPaint;
        float top = danmaku.getTop();
        float left = danmaku.getLeft();
        if (this.canvas == null) {
            return 0;
        }
        boolean needRestore2 = false;
        if (danmaku.getType() != 7) {
            alphaPaint = null;
            needRestore = false;
        } else if (danmaku.getAlpha() == AlphaValue.TRANSPARENT) {
            return 0;
        } else {
            if (!(danmaku.rotationZ == 0.0f && danmaku.rotationY == 0.0f)) {
                saveCanvas(danmaku, this.canvas, left, top);
                needRestore2 = true;
            }
            if (danmaku.getAlpha() != AlphaValue.MAX) {
                Paint alphaPaint2 = this.mDisplayConfig.ALPHA_PAINT;
                alphaPaint2.setAlpha(danmaku.getAlpha());
                alphaPaint = alphaPaint2;
                needRestore = needRestore2;
            } else {
                alphaPaint = null;
                needRestore = needRestore2;
            }
        }
        if (alphaPaint != null && alphaPaint.getAlpha() == AlphaValue.TRANSPARENT) {
            return 0;
        }
        int result = 1;
        if (!this.sStuffer.drawCache(danmaku, this.canvas, left, top, alphaPaint, this.mDisplayConfig.PAINT)) {
            if (alphaPaint != null) {
                this.mDisplayConfig.PAINT.setAlpha(alphaPaint.getAlpha());
            } else {
                resetPaintAlpha(this.mDisplayConfig.PAINT);
            }
            drawDanmaku(danmaku, this.canvas, left, top, false);
            result = 2;
        }
        if (needRestore) {
            restoreCanvas(this.canvas);
        }
        return result;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void recycle(BaseDanmaku danmaku) {
        BaseCacheStuffer baseCacheStuffer = this.sStuffer;
        if (baseCacheStuffer != null) {
            baseCacheStuffer.releaseResource(danmaku);
        }
    }

    private void resetPaintAlpha(Paint paint) {
        if (paint.getAlpha() != AlphaValue.MAX) {
            paint.setAlpha(AlphaValue.MAX);
        }
    }

    private void restoreCanvas(Canvas canvas2) {
        canvas2.restore();
    }

    private int saveCanvas(BaseDanmaku danmaku, Canvas canvas2, float left, float top) {
        this.camera.save();
        this.camera.rotateY(-danmaku.rotationY);
        this.camera.rotateZ(-danmaku.rotationZ);
        this.camera.getMatrix(this.matrix);
        this.matrix.preTranslate(-left, -top);
        this.matrix.postTranslate(left, top);
        this.camera.restore();
        int count = canvas2.save();
        canvas2.concat(this.matrix);
        return count;
    }

    public synchronized void drawDanmaku(BaseDanmaku danmaku, Canvas canvas2, float left, float top, boolean fromWorkerThread) {
        if (this.sStuffer != null) {
            this.sStuffer.drawDanmaku(danmaku, canvas2, left, top, fromWorkerThread, this.mDisplayConfig);
        }
    }

    private synchronized TextPaint getPaint(BaseDanmaku danmaku, boolean fromWorkerThread) {
        return this.mDisplayConfig.getPaint(danmaku, fromWorkerThread);
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void prepare(BaseDanmaku danmaku, boolean fromWorkerThread) {
        BaseCacheStuffer baseCacheStuffer = this.sStuffer;
        if (baseCacheStuffer != null) {
            baseCacheStuffer.prepare(danmaku, fromWorkerThread);
        }
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void measure(BaseDanmaku danmaku, boolean fromWorkerThread) {
        TextPaint paint = getPaint(danmaku, fromWorkerThread);
        if (this.mDisplayConfig.HAS_STROKE) {
            this.mDisplayConfig.applyPaintConfig(danmaku, paint, true);
        }
        calcPaintWH(danmaku, paint, fromWorkerThread);
        if (this.mDisplayConfig.HAS_STROKE) {
            this.mDisplayConfig.applyPaintConfig(danmaku, paint, false);
        }
    }

    private void calcPaintWH(BaseDanmaku danmaku, TextPaint paint, boolean fromWorkerThread) {
        this.sStuffer.measure(danmaku, paint, fromWorkerThread);
        setDanmakuPaintWidthAndHeight(danmaku, danmaku.paintWidth, danmaku.paintHeight);
    }

    private void setDanmakuPaintWidthAndHeight(BaseDanmaku danmaku, float w, float h) {
        float pw = ((float) (danmaku.padding * 2)) + w;
        float ph = ((float) (danmaku.padding * 2)) + h;
        if (danmaku.borderColor != 0) {
            float f = (float) 8;
            pw += f;
            ph += f;
        }
        danmaku.paintWidth = getStrokeWidth() + pw;
        danmaku.paintHeight = ph;
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public void clearTextHeightCache() {
        this.sStuffer.clearCaches();
        this.mDisplayConfig.clearTextHeightCache();
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public float getScaledDensity() {
        return this.scaledDensity;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void resetSlopPixel(float factor) {
        float slop = 25.0f * Math.max(factor, ((float) getWidth()) / 682.0f);
        this.mSlopPixel = (int) slop;
        if (factor > 1.0f) {
            this.mSlopPixel = (int) (slop * factor);
        }
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getSlopPixel() {
        return this.mSlopPixel;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void setDensities(float density2, int densityDpi2, float scaledDensity2) {
        this.density = density2;
        this.densityDpi = densityDpi2;
        this.scaledDensity = scaledDensity2;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void setSize(int width2, int height2) {
        this.width = width2;
        this.height = height2;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void setDanmakuStyle(int style, float[] values) {
        if (style != -1) {
            if (style == 0) {
                this.mDisplayConfig.CONFIG_HAS_SHADOW = false;
                this.mDisplayConfig.CONFIG_HAS_STROKE = false;
                this.mDisplayConfig.CONFIG_HAS_PROJECTION = false;
                return;
            } else if (style == 1) {
                this.mDisplayConfig.CONFIG_HAS_SHADOW = true;
                this.mDisplayConfig.CONFIG_HAS_STROKE = false;
                this.mDisplayConfig.CONFIG_HAS_PROJECTION = false;
                setShadowRadius(values[0]);
                return;
            } else if (style != 2) {
                if (style == 3) {
                    this.mDisplayConfig.CONFIG_HAS_SHADOW = false;
                    this.mDisplayConfig.CONFIG_HAS_STROKE = false;
                    this.mDisplayConfig.CONFIG_HAS_PROJECTION = true;
                    setProjectionConfig(values[0], values[1], (int) values[2]);
                    return;
                }
                return;
            }
        }
        this.mDisplayConfig.CONFIG_HAS_SHADOW = false;
        this.mDisplayConfig.CONFIG_HAS_STROKE = true;
        this.mDisplayConfig.CONFIG_HAS_PROJECTION = false;
        setPaintStorkeWidth(values[0]);
    }

    public void setExtraData(Canvas data) {
        update(data);
    }

    @Override // master.flame.danmaku.danmaku.model.AbsDisplayer
    public Canvas getExtraData() {
        return this.canvas;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public float getStrokeWidth() {
        return this.mDisplayConfig.getStrokeWidth();
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public void setHardwareAccelerated(boolean enable) {
        this.mIsHardwareAccelerated = enable;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer, master.flame.danmaku.danmaku.model.AbsDisplayer
    public boolean isHardwareAccelerated() {
        return this.mIsHardwareAccelerated;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getMaximumCacheWidth() {
        return this.mMaximumBitmapWidth;
    }

    @Override // master.flame.danmaku.danmaku.model.IDisplayer
    public int getMaximumCacheHeight() {
        return this.mMaximumBitmapHeight;
    }
}
