package master.flame.danmaku.danmaku.model.android;

import java.lang.reflect.Array;
import master.flame.danmaku.danmaku.model.AbsDisplayer;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.Duration;
import master.flame.danmaku.danmaku.model.FBDanmaku;
import master.flame.danmaku.danmaku.model.FTDanmaku;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.L2RDanmaku;
import master.flame.danmaku.danmaku.model.R2LDanmaku;
import master.flame.danmaku.danmaku.model.SpecialDanmaku;

public class DanmakuFactory {
    public static final float BILI_PLAYER_HEIGHT = 438.0f;
    public static final float BILI_PLAYER_WIDTH = 682.0f;
    public static final long COMMON_DANMAKU_DURATION = 3800;
    public static final int DANMAKU_MEDIUM_TEXTSIZE = 25;
    public static final long MAX_DANMAKU_DURATION_HIGH_DENSITY = 9000;
    public static final long MIN_DANMAKU_DURATION = 4000;
    public static final float OLD_BILI_PLAYER_HEIGHT = 385.0f;
    public static final float OLD_BILI_PLAYER_WIDTH = 539.0f;
    public int CURRENT_DISP_HEIGHT = 0;
    private float CURRENT_DISP_SIZE_FACTOR = 1.0f;
    public int CURRENT_DISP_WIDTH = 0;
    public long MAX_DANMAKU_DURATION = MIN_DANMAKU_DURATION;
    public Duration MAX_Duration_Fix_Danmaku;
    public Duration MAX_Duration_Scroll_Danmaku;
    public Duration MAX_Duration_Special_Danmaku;
    public long REAL_DANMAKU_DURATION = COMMON_DANMAKU_DURATION;
    private DanmakuContext sLastConfig;
    public IDisplayer sLastDisp;
    public IDanmakus sSpecialDanmakus = new Danmakus();

    static DanmakuFactory create() {
        return new DanmakuFactory();
    }

    protected DanmakuFactory() {
    }

    public void resetDurationsData() {
        this.sLastDisp = null;
        this.CURRENT_DISP_HEIGHT = 0;
        this.CURRENT_DISP_WIDTH = 0;
        this.sSpecialDanmakus.clear();
        this.MAX_Duration_Scroll_Danmaku = null;
        this.MAX_Duration_Fix_Danmaku = null;
        this.MAX_Duration_Special_Danmaku = null;
        this.MAX_DANMAKU_DURATION = MIN_DANMAKU_DURATION;
    }

    public void notifyDispSizeChanged(DanmakuContext context) {
        this.sLastConfig = context;
        this.sLastDisp = context.getDisplayer();
        createDanmaku(1, context);
    }

    public BaseDanmaku createDanmaku(int type) {
        return createDanmaku(type, this.sLastConfig);
    }

    public BaseDanmaku createDanmaku(int type, DanmakuContext context) {
        if (context == null) {
            return null;
        }
        this.sLastConfig = context;
        AbsDisplayer displayer = context.getDisplayer();
        this.sLastDisp = displayer;
        return createDanmaku(type, displayer.getWidth(), this.sLastDisp.getHeight(), this.CURRENT_DISP_SIZE_FACTOR, context.scrollSpeedFactor);
    }

    public BaseDanmaku createDanmaku(int type, IDisplayer disp, float viewportScale, float scrollSpeedFactor) {
        if (disp == null) {
            return null;
        }
        this.sLastDisp = disp;
        return createDanmaku(type, disp.getWidth(), disp.getHeight(), viewportScale, scrollSpeedFactor);
    }

    public BaseDanmaku createDanmaku(int type, int viewportWidth, int viewportHeight, float viewportScale, float scrollSpeedFactor) {
        return createDanmaku(type, (float) viewportWidth, (float) viewportHeight, viewportScale, scrollSpeedFactor);
    }

    public BaseDanmaku createDanmaku(int type, float viewportWidth, float viewportHeight, float viewportSizeFactor, float scrollSpeedFactor) {
        int oldDispWidth = this.CURRENT_DISP_WIDTH;
        int oldDispHeight = this.CURRENT_DISP_HEIGHT;
        boolean sizeChanged = updateViewportState(viewportWidth, viewportHeight, viewportSizeFactor);
        Duration duration = this.MAX_Duration_Scroll_Danmaku;
        if (duration == null) {
            Duration duration2 = new Duration(this.REAL_DANMAKU_DURATION);
            this.MAX_Duration_Scroll_Danmaku = duration2;
            duration2.setFactor(scrollSpeedFactor);
        } else if (sizeChanged) {
            duration.setValue(this.REAL_DANMAKU_DURATION);
        }
        if (this.MAX_Duration_Fix_Danmaku == null) {
            this.MAX_Duration_Fix_Danmaku = new Duration(COMMON_DANMAKU_DURATION);
        }
        if (sizeChanged && viewportWidth > 0.0f) {
            updateMaxDanmakuDuration();
            float scaleX = 1.0f;
            float scaleY = 1.0f;
            if (oldDispWidth > 0 && oldDispHeight > 0) {
                scaleX = viewportWidth / ((float) oldDispWidth);
                scaleY = viewportHeight / ((float) oldDispHeight);
            }
            if (viewportHeight > 0.0f) {
                updateSpecialDanmakusDate(scaleX, scaleY);
            }
        }
        if (type == 1) {
            return new R2LDanmaku(this.MAX_Duration_Scroll_Danmaku);
        }
        if (type == 4) {
            return new FBDanmaku(this.MAX_Duration_Fix_Danmaku);
        }
        if (type == 5) {
            return new FTDanmaku(this.MAX_Duration_Fix_Danmaku);
        }
        if (type == 6) {
            return new L2RDanmaku(this.MAX_Duration_Scroll_Danmaku);
        }
        if (type != 7) {
            return null;
        }
        BaseDanmaku instance = new SpecialDanmaku();
        this.sSpecialDanmakus.addItem(instance);
        return instance;
    }

    public boolean updateViewportState(float viewportWidth, float viewportHeight, float viewportSizeFactor) {
        if (this.CURRENT_DISP_WIDTH == ((int) viewportWidth) && this.CURRENT_DISP_HEIGHT == ((int) viewportHeight) && this.CURRENT_DISP_SIZE_FACTOR == viewportSizeFactor) {
            return false;
        }
        long j = (long) (((viewportSizeFactor * viewportWidth) / 682.0f) * 3800.0f);
        this.REAL_DANMAKU_DURATION = j;
        long min = Math.min((long) MAX_DANMAKU_DURATION_HIGH_DENSITY, j);
        this.REAL_DANMAKU_DURATION = min;
        this.REAL_DANMAKU_DURATION = Math.max((long) MIN_DANMAKU_DURATION, min);
        this.CURRENT_DISP_WIDTH = (int) viewportWidth;
        this.CURRENT_DISP_HEIGHT = (int) viewportHeight;
        this.CURRENT_DISP_SIZE_FACTOR = viewportSizeFactor;
        return true;
    }

    private void updateSpecialDanmakusDate(float scaleX, float scaleY) {
        IDanmakuIterator it = this.sSpecialDanmakus.iterator();
        while (it.hasNext()) {
            SpecialDanmaku speicalDanmaku = (SpecialDanmaku) it.next();
            fillTranslationData(speicalDanmaku, speicalDanmaku.beginX, speicalDanmaku.beginY, speicalDanmaku.endX, speicalDanmaku.endY, speicalDanmaku.translationDuration, speicalDanmaku.translationStartDelay, scaleX, scaleY);
            SpecialDanmaku.LinePath[] linePaths = speicalDanmaku.linePaths;
            if (linePaths != null && linePaths.length > 0) {
                int length = linePaths.length;
                int[] iArr = new int[2];
                iArr[1] = 2;
                iArr[0] = length + 1;
                float[][] points = (float[][]) Array.newInstance(float.class, iArr);
                for (int j = 0; j < length; j++) {
                    points[j] = linePaths[j].getBeginPoint();
                    points[j + 1] = linePaths[j].getEndPoint();
                }
                fillLinePathData(speicalDanmaku, points, scaleX, scaleY);
            }
        }
    }

    public void updateMaxDanmakuDuration() {
        Duration duration = this.MAX_Duration_Scroll_Danmaku;
        long maxSpecialDuration = 0;
        long maxScrollDuration = duration == null ? 0 : duration.value;
        Duration duration2 = this.MAX_Duration_Fix_Danmaku;
        long maxFixDuration = duration2 == null ? 0 : duration2.value;
        Duration duration3 = this.MAX_Duration_Special_Danmaku;
        if (duration3 != null) {
            maxSpecialDuration = duration3.value;
        }
        long max = Math.max(maxScrollDuration, maxFixDuration);
        this.MAX_DANMAKU_DURATION = max;
        long max2 = Math.max(max, maxSpecialDuration);
        this.MAX_DANMAKU_DURATION = max2;
        long max3 = Math.max((long) COMMON_DANMAKU_DURATION, max2);
        this.MAX_DANMAKU_DURATION = max3;
        this.MAX_DANMAKU_DURATION = Math.max(this.REAL_DANMAKU_DURATION, max3);
    }

    public void updateDurationFactor(float f) {
        Duration duration = this.MAX_Duration_Scroll_Danmaku;
        if (duration != null && this.MAX_Duration_Fix_Danmaku != null) {
            duration.setFactor(f);
            updateMaxDanmakuDuration();
        }
    }

    public void fillTranslationData(BaseDanmaku item, float beginX, float beginY, float endX, float endY, long translationDuration, long translationStartDelay, float scaleX, float scaleY) {
        if (item.getType() == 7) {
            ((SpecialDanmaku) item).setTranslationData(beginX * scaleX, beginY * scaleY, endX * scaleX, endY * scaleY, translationDuration, translationStartDelay);
            updateSpecicalDanmakuDuration(item);
        }
    }

    public static void fillLinePathData(BaseDanmaku item, float[][] points, float scaleX, float scaleY) {
        if (item.getType() == 7 && points.length != 0 && points[0].length == 2) {
            for (int i = 0; i < points.length; i++) {
                float[] fArr = points[i];
                fArr[0] = fArr[0] * scaleX;
                float[] fArr2 = points[i];
                fArr2[1] = fArr2[1] * scaleY;
            }
            ((SpecialDanmaku) item).setLinePathData(points);
        }
    }

    public void fillAlphaData(BaseDanmaku item, int beginAlpha, int endAlpha, long alphaDuraion) {
        if (item.getType() == 7) {
            ((SpecialDanmaku) item).setAlphaData(beginAlpha, endAlpha, alphaDuraion);
            updateSpecicalDanmakuDuration(item);
        }
    }

    private void updateSpecicalDanmakuDuration(BaseDanmaku item) {
        if (this.MAX_Duration_Special_Danmaku == null || (item.duration != null && item.duration.value > this.MAX_Duration_Special_Danmaku.value)) {
            this.MAX_Duration_Special_Danmaku = item.duration;
            updateMaxDanmakuDuration();
        }
    }
}
