package master.flame.danmaku.danmaku.model.android;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.text.TextPaint;
import java.util.HashMap;
import java.util.Map;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.android.AndroidDisplayer;

public class SimpleTextCacheStuffer extends BaseCacheStuffer {
    private static final Map<Float, Float> sTextHeightCache = new HashMap();

    /* access modifiers changed from: protected */
    public Float getCacheHeight(BaseDanmaku danmaku, Paint paint) {
        Float textSize = Float.valueOf(paint.getTextSize());
        Float textHeight = sTextHeightCache.get(textSize);
        if (textHeight != null) {
            return textHeight;
        }
        Paint.FontMetrics fontMetrics = paint.getFontMetrics();
        Float textHeight2 = Float.valueOf((fontMetrics.descent - fontMetrics.ascent) + fontMetrics.leading);
        sTextHeightCache.put(textSize, textHeight2);
        return textHeight2;
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void measure(BaseDanmaku danmaku, TextPaint paint, boolean fromWorkerThread) {
        float w;
        float w2 = 0.0f;
        Float textHeight = Float.valueOf(0.0f);
        if (danmaku.lines == null) {
            if (danmaku.text == null) {
                w = 0.0f;
            } else {
                w = paint.measureText(danmaku.text.toString());
                textHeight = getCacheHeight(danmaku, paint);
            }
            danmaku.paintWidth = w;
            danmaku.paintHeight = textHeight.floatValue();
            return;
        }
        Float textHeight2 = getCacheHeight(danmaku, paint);
        String[] strArr = danmaku.lines;
        for (String tempStr : strArr) {
            if (tempStr.length() > 0) {
                w2 = Math.max(paint.measureText(tempStr), w2);
            }
        }
        danmaku.paintWidth = w2;
        danmaku.paintHeight = ((float) danmaku.lines.length) * textHeight2.floatValue();
    }

    /* access modifiers changed from: protected */
    public void drawStroke(BaseDanmaku danmaku, String lineText, Canvas canvas, float left, float top, Paint paint) {
        if (lineText != null) {
            canvas.drawText(lineText, left, top, paint);
        } else {
            canvas.drawText(danmaku.text.toString(), left, top, paint);
        }
    }

    /* access modifiers changed from: protected */
    public void drawText(BaseDanmaku danmaku, String lineText, Canvas canvas, float left, float top, TextPaint paint, boolean fromWorkerThread) {
        if (lineText != null) {
            canvas.drawText(lineText, left, top, paint);
        } else {
            canvas.drawText(danmaku.text.toString(), left, top, paint);
        }
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void clearCaches() {
        sTextHeightCache.clear();
    }

    /* access modifiers changed from: protected */
    public void drawBackground(BaseDanmaku danmaku, Canvas canvas, float left, float top) {
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void drawDanmaku(BaseDanmaku danmaku, Canvas canvas, float left, float top, boolean fromWorkerThread, AndroidDisplayer.DisplayerConfig displayerConfig) {
        float top2;
        float left2;
        float _left;
        float strokeTop;
        float strokeLeft;
        int t;
        float strokeTop2;
        float strokeLeft2;
        boolean z;
        String[] lines;
        float strokeTop3;
        float strokeLeft3;
        float left3 = left + ((float) danmaku.padding);
        float top3 = top + ((float) danmaku.padding);
        if (danmaku.borderColor != 0) {
            left2 = left3 + 4.0f;
            top2 = top3 + 4.0f;
        } else {
            left2 = left3;
            top2 = top3;
        }
        displayerConfig.definePaintParams(fromWorkerThread);
        TextPaint paint = displayerConfig.getPaint(danmaku, fromWorkerThread);
        drawBackground(danmaku, canvas, left, top);
        boolean z2 = true;
        if (danmaku.lines != null) {
            String[] lines2 = danmaku.lines;
            if (lines2.length == 1) {
                if (displayerConfig.hasStroke(danmaku)) {
                    displayerConfig.applyPaintConfig(danmaku, paint, true);
                    float strokeTop4 = top2 - paint.ascent();
                    if (displayerConfig.HAS_PROJECTION) {
                        strokeLeft3 = left2 + displayerConfig.sProjectionOffsetX;
                        strokeTop3 = strokeTop4 + displayerConfig.sProjectionOffsetY;
                    } else {
                        strokeLeft3 = left2;
                        strokeTop3 = strokeTop4;
                    }
                    lines = lines2;
                    _left = left;
                    z = false;
                    drawStroke(danmaku, lines2[0], canvas, strokeLeft3, strokeTop3, paint);
                } else {
                    lines = lines2;
                    _left = left;
                    z = false;
                }
                displayerConfig.applyPaintConfig(danmaku, paint, z);
                char c = z ? 1 : 0;
                char c2 = z ? 1 : 0;
                char c3 = z ? 1 : 0;
                drawText(danmaku, lines[c], canvas, left2, top2 - paint.ascent(), paint, fromWorkerThread);
            } else {
                _left = left;
                float textHeight = (danmaku.paintHeight - ((float) (danmaku.padding * 2))) / ((float) lines2.length);
                int t2 = 0;
                while (t2 < lines2.length) {
                    if (lines2[t2] == null) {
                        t = t2;
                    } else if (lines2[t2].length() == 0) {
                        t = t2;
                    } else {
                        if (displayerConfig.hasStroke(danmaku)) {
                            displayerConfig.applyPaintConfig(danmaku, paint, z2);
                            float strokeTop5 = ((((float) t2) * textHeight) + top2) - paint.ascent();
                            if (displayerConfig.HAS_PROJECTION) {
                                strokeLeft2 = left2 + displayerConfig.sProjectionOffsetX;
                                strokeTop2 = strokeTop5 + displayerConfig.sProjectionOffsetY;
                            } else {
                                strokeLeft2 = left2;
                                strokeTop2 = strokeTop5;
                            }
                            drawStroke(danmaku, lines2[t2], canvas, strokeLeft2, strokeTop2, paint);
                        }
                        displayerConfig.applyPaintConfig(danmaku, paint, false);
                        t = t2;
                        drawText(danmaku, lines2[t2], canvas, left2, ((((float) t2) * textHeight) + top2) - paint.ascent(), paint, fromWorkerThread);
                    }
                    t2 = t + 1;
                    z2 = true;
                }
            }
        } else {
            _left = left;
            if (displayerConfig.hasStroke(danmaku)) {
                displayerConfig.applyPaintConfig(danmaku, paint, true);
                float strokeTop6 = top2 - paint.ascent();
                if (displayerConfig.HAS_PROJECTION) {
                    strokeLeft = left2 + displayerConfig.sProjectionOffsetX;
                    strokeTop = strokeTop6 + displayerConfig.sProjectionOffsetY;
                } else {
                    strokeLeft = left2;
                    strokeTop = strokeTop6;
                }
                drawStroke(danmaku, null, canvas, strokeLeft, strokeTop, paint);
            }
            displayerConfig.applyPaintConfig(danmaku, paint, false);
            drawText(danmaku, null, canvas, left2, top2 - paint.ascent(), paint, fromWorkerThread);
        }
        if (danmaku.underlineColor != 0) {
            Paint linePaint = displayerConfig.getUnderlinePaint(danmaku);
            float bottom = (danmaku.paintHeight + top) - ((float) displayerConfig.UNDERLINE_HEIGHT);
            canvas.drawLine(_left, bottom, _left + danmaku.paintWidth, bottom, linePaint);
        }
        if (danmaku.borderColor != 0) {
            canvas.drawRect(_left, top, _left + danmaku.paintWidth, top + danmaku.paintHeight, displayerConfig.getBorderPaint(danmaku));
        }
    }
}
