package master.flame.danmaku.danmaku.model.android;

import android.graphics.Canvas;
import android.graphics.Paint;
import android.text.TextPaint;
import android.util.SparseArray;
import android.view.View;
import com.tencent.mm.opensdk.modelmsg.WXVideoFileObject;
import java.util.ArrayList;
import java.util.List;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.android.AndroidDisplayer;
import master.flame.danmaku.danmaku.model.android.ViewCacheStuffer.ViewHolder;

public abstract class ViewCacheStuffer<VH extends ViewHolder> extends BaseCacheStuffer {
    public static final int CACHE_VIEW_TYPE = -3;
    public static final int DRAW_VIEW_TYPE = -3;
    public static final int INVALID_TYPE = -1;
    public static final int MEASURE_VIEW_TYPE = -2;
    private final int mMaximumHeightPixels = -1;
    private final int mMaximumWidthPixels = -1;
    private SparseArray<List<VH>> mViewHolderArray = new SparseArray<>();

    public abstract void onBindViewHolder(int i, VH vh, BaseDanmaku baseDanmaku, AndroidDisplayer.DisplayerConfig displayerConfig, TextPaint textPaint);

    public abstract VH onCreateViewHolder(int i);

    public static abstract class ViewHolder {
        protected final View itemView;

        public ViewHolder(View itemView2) {
            if (itemView2 != null) {
                this.itemView = itemView2;
                return;
            }
            throw new IllegalArgumentException("itemView may not be null");
        }

        public void measure(int widthMeasureSpec, int heightMeasureSpec) {
            this.itemView.measure(widthMeasureSpec, heightMeasureSpec);
        }

        public int getMeasureWidth() {
            return this.itemView.getMeasuredWidth();
        }

        public int getMeasureHeight() {
            return this.itemView.getMeasuredHeight();
        }

        public void layout(int l, int t, int r, int b) {
            this.itemView.layout(l, t, r, b);
        }

        public void draw(Canvas canvas, AndroidDisplayer.DisplayerConfig displayerConfig) {
            this.itemView.draw(canvas);
        }
    }

    public int getItemViewType(int position, BaseDanmaku danmaku) {
        return 0;
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void measure(BaseDanmaku danmaku, TextPaint paint, boolean fromWorkerThread) {
        List<VH> viewHolders;
        int viewType = getItemViewType(danmaku.index, danmaku);
        List<VH> viewHolders2 = this.mViewHolderArray.get(viewType);
        if (viewHolders2 == null) {
            List<VH> arrayList = new ArrayList<>();
            arrayList.add(onCreateViewHolder(viewType));
            arrayList.add(onCreateViewHolder(viewType));
            arrayList.add(onCreateViewHolder(viewType));
            this.mViewHolderArray.put(viewType, arrayList);
            viewHolders = arrayList;
        } else {
            viewHolders = viewHolders2;
        }
        VH viewHolder = viewHolders.get(0);
        onBindViewHolder(viewType, viewHolder, danmaku, null, paint);
        viewHolder.measure(View.MeasureSpec.makeMeasureSpec(this.mMaximumWidthPixels, Integer.MIN_VALUE), View.MeasureSpec.makeMeasureSpec(this.mMaximumHeightPixels, Integer.MIN_VALUE));
        viewHolder.layout(0, 0, viewHolder.getMeasureWidth(), viewHolder.getMeasureHeight());
        danmaku.paintWidth = (float) viewHolder.getMeasureWidth();
        danmaku.paintHeight = (float) viewHolder.getMeasureHeight();
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void clearCaches() {
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void releaseResource(BaseDanmaku danmaku) {
        super.releaseResource(danmaku);
        danmaku.tag = null;
    }

    @Override // master.flame.danmaku.danmaku.model.android.BaseCacheStuffer
    public void drawDanmaku(BaseDanmaku danmaku, Canvas canvas, float left, float top, boolean fromWorkerThread, AndroidDisplayer.DisplayerConfig displayerConfig) {
        VH viewHolder;
        boolean needRestore;
        int viewType = getItemViewType(danmaku.index, danmaku);
        List<VH> viewHolders = this.mViewHolderArray.get(viewType);
        if (viewHolders != null) {
            viewHolder = viewHolders.get(fromWorkerThread ? 1 : 2);
        } else {
            viewHolder = null;
        }
        if (viewHolder != null) {
            displayerConfig.definePaintParams(fromWorkerThread);
            TextPaint paint = displayerConfig.getPaint(danmaku, fromWorkerThread);
            displayerConfig.applyPaintConfig(danmaku, paint, false);
            onBindViewHolder(viewType, viewHolder, danmaku, displayerConfig, paint);
            viewHolder.measure(View.MeasureSpec.makeMeasureSpec(Math.round(danmaku.paintWidth), WXVideoFileObject.FILE_SIZE_LIMIT), View.MeasureSpec.makeMeasureSpec(Math.round(danmaku.paintHeight), WXVideoFileObject.FILE_SIZE_LIMIT));
            if (!fromWorkerThread) {
                canvas.save();
                canvas.translate(left, top);
                needRestore = true;
            } else {
                needRestore = false;
            }
            if (danmaku.underlineColor != 0) {
                Paint linePaint = displayerConfig.getUnderlinePaint(danmaku);
                float bottom = (top + danmaku.paintHeight) - ((float) displayerConfig.UNDERLINE_HEIGHT);
                canvas.drawLine(left, bottom, left + danmaku.paintWidth, bottom, linePaint);
            }
            if (danmaku.borderColor != 0) {
                canvas.drawRect(left, top, left + danmaku.paintWidth, top + danmaku.paintHeight, displayerConfig.getBorderPaint(danmaku));
            }
            viewHolder.layout(0, 0, (int) danmaku.paintWidth, (int) danmaku.paintHeight);
            viewHolder.draw(canvas, displayerConfig);
            if (needRestore) {
                canvas.restore();
            }
        }
    }
}
