package master.flame.danmaku.danmaku.model.objectpool;

import master.flame.danmaku.danmaku.model.objectpool.Poolable;

/* access modifiers changed from: package-private */
public class FinitePool<T extends Poolable<T>> implements Pool<T> {
    private final boolean mInfinite;
    private final int mLimit;
    private final PoolableManager<T> mManager;
    private int mPoolCount;
    private T mRoot;

    FinitePool(PoolableManager<T> manager) {
        this.mManager = manager;
        this.mLimit = 0;
        this.mInfinite = true;
    }

    FinitePool(PoolableManager<T> manager, int limit) {
        if (limit > 0) {
            this.mManager = manager;
            this.mLimit = limit;
            this.mInfinite = false;
            return;
        }
        throw new IllegalArgumentException("The pool limit must be > 0");
    }

    @Override // master.flame.danmaku.danmaku.model.objectpool.Pool
    public T acquire() {
        T element;
        if (this.mRoot != null) {
            element = this.mRoot;
            this.mRoot = (T) ((Poolable) element.getNextPoolable());
            this.mPoolCount--;
        } else {
            element = this.mManager.newInstance();
        }
        if (element != null) {
            element.setNextPoolable(null);
            element.setPooled(false);
            this.mManager.onAcquired(element);
        }
        return element;
    }

    @Override // master.flame.danmaku.danmaku.model.objectpool.Pool
    public void release(T element) {
        if (!element.isPooled()) {
            if (this.mInfinite || this.mPoolCount < this.mLimit) {
                this.mPoolCount++;
                element.setNextPoolable(this.mRoot);
                element.setPooled(true);
                this.mRoot = element;
            }
            this.mManager.onReleased(element);
            return;
        }
        System.out.print("[FinitePool] Element is already in pool: " + element);
    }
}
