package master.flame.danmaku.danmaku.renderer;

import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.DanmakuTimer;
import master.flame.danmaku.danmaku.model.ICacheManager;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.android.Danmakus;

public interface IRenderer {
    public static final int CACHE_RENDERING = 1;
    public static final int NOTHING_RENDERING = 0;
    public static final int TEXT_RENDERING = 2;

    public interface OnDanmakuShownListener {
        void onDanmakuShown(BaseDanmaku baseDanmaku);
    }

    void alignBottom(boolean z);

    void clear();

    void clearRetainer();

    void draw(IDisplayer iDisplayer, IDanmakus iDanmakus, long j, RenderingState renderingState);

    void release();

    void removeOnDanmakuShownListener();

    void setCacheManager(ICacheManager iCacheManager);

    void setOnDanmakuShownListener(OnDanmakuShownListener onDanmakuShownListener);

    void setVerifierEnabled(boolean z);

    public static class Area {
        private int mMaxHeight;
        private int mMaxWidth;
        public final float[] mRefreshRect = new float[4];

        public void setEdge(int maxWidth, int maxHeight) {
            this.mMaxWidth = maxWidth;
            this.mMaxHeight = maxHeight;
        }

        public void reset() {
            set((float) this.mMaxWidth, (float) this.mMaxHeight, 0.0f, 0.0f);
        }

        public void resizeToMax() {
            set(0.0f, 0.0f, (float) this.mMaxWidth, (float) this.mMaxHeight);
        }

        public void set(float left, float top, float right, float bottom) {
            float[] fArr = this.mRefreshRect;
            fArr[0] = left;
            fArr[1] = top;
            fArr[2] = right;
            fArr[3] = bottom;
        }
    }

    public static class RenderingState {
        public static final int UNKNOWN_TIME = -1;
        public long beginTime;
        public long cacheHitCount;
        public long cacheMissCount;
        public long consumingTime;
        public long endTime;
        public int fbDanmakuCount;
        public int ftDanmakuCount;
        public int indexInScreen;
        public boolean isRunningDanmakus;
        public int l2rDanmakuCount;
        public BaseDanmaku lastDanmaku;
        public int lastTotalDanmakuCount;
        private boolean mIsObtaining;
        public boolean nothingRendered;
        public int r2lDanmakuCount;
        private IDanmakus runningDanmakus = new Danmakus(4);
        public int specialDanmakuCount;
        public long sysTime;
        public DanmakuTimer timer = new DanmakuTimer();
        public int totalDanmakuCount;
        public int totalSizeInScreen;

        public int addTotalCount(int count) {
            int i = this.totalDanmakuCount + count;
            this.totalDanmakuCount = i;
            return i;
        }

        public int addCount(int type, int count) {
            if (type == 1) {
                int i = this.r2lDanmakuCount + count;
                this.r2lDanmakuCount = i;
                return i;
            } else if (type == 4) {
                int i2 = this.fbDanmakuCount + count;
                this.fbDanmakuCount = i2;
                return i2;
            } else if (type == 5) {
                int i3 = this.ftDanmakuCount + count;
                this.ftDanmakuCount = i3;
                return i3;
            } else if (type == 6) {
                int i4 = this.l2rDanmakuCount + count;
                this.l2rDanmakuCount = i4;
                return i4;
            } else if (type != 7) {
                return 0;
            } else {
                int i5 = this.specialDanmakuCount + count;
                this.specialDanmakuCount = i5;
                return i5;
            }
        }

        public void reset() {
            this.lastTotalDanmakuCount = this.totalDanmakuCount;
            this.totalDanmakuCount = 0;
            this.specialDanmakuCount = 0;
            this.fbDanmakuCount = 0;
            this.ftDanmakuCount = 0;
            this.l2rDanmakuCount = 0;
            this.r2lDanmakuCount = 0;
            this.consumingTime = 0;
            this.endTime = 0;
            this.beginTime = 0;
            this.sysTime = 0;
            this.nothingRendered = false;
            synchronized (this) {
                this.runningDanmakus.clear();
            }
        }

        public void set(RenderingState other) {
            if (other != null) {
                this.lastTotalDanmakuCount = other.lastTotalDanmakuCount;
                this.r2lDanmakuCount = other.r2lDanmakuCount;
                this.l2rDanmakuCount = other.l2rDanmakuCount;
                this.ftDanmakuCount = other.ftDanmakuCount;
                this.fbDanmakuCount = other.fbDanmakuCount;
                this.specialDanmakuCount = other.specialDanmakuCount;
                this.totalDanmakuCount = other.totalDanmakuCount;
                this.consumingTime = other.consumingTime;
                this.beginTime = other.beginTime;
                this.endTime = other.endTime;
                this.nothingRendered = other.nothingRendered;
                this.sysTime = other.sysTime;
                this.cacheHitCount = other.cacheHitCount;
                this.cacheMissCount = other.cacheMissCount;
            }
        }

        public void appendToRunningDanmakus(BaseDanmaku danmaku) {
            if (!this.mIsObtaining) {
                this.runningDanmakus.addItem(danmaku);
            }
        }

        public IDanmakus obtainRunningDanmakus() {
            Throwable th;
            this.mIsObtaining = true;
            synchronized (this) {
                try {
                    IDanmakus danmakus = this.runningDanmakus;
                    try {
                        this.runningDanmakus = new Danmakus(4);
                        this.mIsObtaining = false;
                        return danmakus;
                    } catch (Throwable th2) {
                        th = th2;
                        throw th;
                    }
                } catch (Throwable th3) {
                    th = th3;
                    throw th;
                }
            }
        }
    }
}
