package master.flame.danmaku.danmaku.renderer.android;

import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.DanmakuTimer;
import master.flame.danmaku.danmaku.model.ICacheManager;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.IDrawingCache;
import master.flame.danmaku.danmaku.model.android.DanmakuContext;
import master.flame.danmaku.danmaku.renderer.IRenderer;
import master.flame.danmaku.danmaku.renderer.Renderer;
import master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer;

public class DanmakuRenderer extends Renderer {
    private ICacheManager mCacheManager;
    private final DanmakuContext mContext;
    private final DanmakusRetainer mDanmakusRetainer;
    private IRenderer.OnDanmakuShownListener mOnDanmakuShownListener;
    private DanmakuTimer mStartTimer;
    private DanmakusRetainer.Verifier mVerifier;
    private final DanmakusRetainer.Verifier verifier = new DanmakusRetainer.Verifier() {
        /* class master.flame.danmaku.danmaku.renderer.android.DanmakuRenderer.AnonymousClass1 */

        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.Verifier
        public boolean skipLayout(BaseDanmaku danmaku, float fixedTop, int lines, boolean willHit) {
            if (danmaku.priority != 0 || !DanmakuRenderer.this.mContext.mDanmakuFilters.filterSecondary(danmaku, lines, 0, DanmakuRenderer.this.mStartTimer, willHit, DanmakuRenderer.this.mContext)) {
                return false;
            }
            danmaku.setVisibility(false);
            return true;
        }
    };

    public DanmakuRenderer(DanmakuContext config) {
        this.mContext = config;
        this.mDanmakusRetainer = new DanmakusRetainer(config.isAlignBottom());
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void clear() {
        clearRetainer();
        this.mContext.mDanmakuFilters.clear();
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void clearRetainer() {
        this.mDanmakusRetainer.clear();
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void release() {
        this.mDanmakusRetainer.release();
        this.mContext.mDanmakuFilters.clear();
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void setVerifierEnabled(boolean enabled) {
        this.mVerifier = enabled ? this.verifier : null;
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void draw(IDisplayer disp, IDanmakus danmakus, long startRenderTime, IRenderer.RenderingState renderingState) {
        this.mStartTimer = renderingState.timer;
        BaseDanmaku drawItem = null;
        IDanmakuIterator itr = danmakus.iterator();
        while (true) {
            if (!itr.hasNext()) {
                break;
            }
            drawItem = itr.next();
            if (drawItem.isTimeOut()) {
                disp.recycle(drawItem);
            } else if (renderingState.isRunningDanmakus || !drawItem.isOffset()) {
                if (!drawItem.hasPassedFilter()) {
                    this.mContext.mDanmakuFilters.filter(drawItem, renderingState.indexInScreen, renderingState.totalSizeInScreen, renderingState.timer, false, this.mContext);
                }
                if (drawItem.getActualTime() >= startRenderTime && (drawItem.priority != 0 || !drawItem.isFiltered())) {
                    if (drawItem.isLate()) {
                        IDrawingCache<?> cache = drawItem.getDrawingCache();
                        if (this.mCacheManager != null && (cache == null || cache.get() == null)) {
                            this.mCacheManager.addDanmaku(drawItem);
                        }
                    } else {
                        if (drawItem.getType() == 1) {
                            renderingState.indexInScreen++;
                        }
                        if (!drawItem.isMeasured()) {
                            drawItem.measure(disp, false);
                        }
                        if (!drawItem.isPrepared()) {
                            drawItem.prepare(disp, false);
                        }
                        this.mDanmakusRetainer.fix(drawItem, disp, this.mVerifier);
                        if (drawItem.isShown() && (drawItem.lines != null || drawItem.getBottom() <= ((float) disp.getHeight()))) {
                            int renderingType = drawItem.draw(disp);
                            if (renderingType == 1) {
                                renderingState.cacheHitCount++;
                            } else if (renderingType == 2) {
                                renderingState.cacheMissCount++;
                                ICacheManager iCacheManager = this.mCacheManager;
                                if (iCacheManager != null) {
                                    iCacheManager.addDanmaku(drawItem);
                                }
                            }
                            renderingState.addCount(drawItem.getType(), 1);
                            renderingState.addTotalCount(1);
                            renderingState.appendToRunningDanmakus(drawItem);
                            if (!(this.mOnDanmakuShownListener == null || drawItem.firstShownFlag == this.mContext.mGlobalFlagValues.FIRST_SHOWN_RESET_FLAG)) {
                                drawItem.firstShownFlag = this.mContext.mGlobalFlagValues.FIRST_SHOWN_RESET_FLAG;
                                this.mOnDanmakuShownListener.onDanmakuShown(drawItem);
                            }
                        }
                    }
                }
            } else {
                itr.remove();
            }
        }
        renderingState.lastDanmaku = drawItem;
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void setCacheManager(ICacheManager cacheManager) {
        this.mCacheManager = cacheManager;
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void setOnDanmakuShownListener(IRenderer.OnDanmakuShownListener onDanmakuShownListener) {
        this.mOnDanmakuShownListener = onDanmakuShownListener;
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void removeOnDanmakuShownListener() {
        this.mOnDanmakuShownListener = null;
    }

    @Override // master.flame.danmaku.danmaku.renderer.IRenderer
    public void alignBottom(boolean enable) {
        DanmakusRetainer danmakusRetainer = this.mDanmakusRetainer;
        if (danmakusRetainer != null) {
            danmakusRetainer.alignBottom(enable);
        }
    }
}
