package master.flame.danmaku.danmaku.renderer.android;

import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.android.Danmakus;
import master.flame.danmaku.danmaku.util.DanmakuUtils;

public class DanmakusRetainer {
    private IDanmakusRetainer fbdrInstance = null;
    private IDanmakusRetainer ftdrInstance = null;
    private IDanmakusRetainer lrdrInstance = null;
    private IDanmakusRetainer rldrInstance = null;

    public interface IDanmakusRetainer {
        void clear();

        void fix(BaseDanmaku baseDanmaku, IDisplayer iDisplayer, Verifier verifier);
    }

    public interface Verifier {
        boolean skipLayout(BaseDanmaku baseDanmaku, float f, int i, boolean z);
    }

    public DanmakusRetainer(boolean alignBottom) {
        alignBottom(alignBottom);
    }

    public void alignBottom(boolean alignBottom) {
        this.rldrInstance = alignBottom ? new AlignBottomRetainer() : new AlignTopRetainer();
        this.lrdrInstance = alignBottom ? new AlignBottomRetainer() : new AlignTopRetainer();
        if (this.ftdrInstance == null) {
            this.ftdrInstance = new FTDanmakusRetainer();
        }
        if (this.fbdrInstance == null) {
            this.fbdrInstance = new AlignBottomRetainer();
        }
    }

    public void fix(BaseDanmaku danmaku, IDisplayer disp, Verifier verifier) {
        int type = danmaku.getType();
        if (type == 1) {
            this.rldrInstance.fix(danmaku, disp, verifier);
        } else if (type == 4) {
            this.fbdrInstance.fix(danmaku, disp, verifier);
        } else if (type == 5) {
            this.ftdrInstance.fix(danmaku, disp, verifier);
        } else if (type == 6) {
            this.lrdrInstance.fix(danmaku, disp, verifier);
        } else if (type == 7) {
            danmaku.layout(disp, 0.0f, 0.0f);
        }
    }

    public void clear() {
        IDanmakusRetainer iDanmakusRetainer = this.rldrInstance;
        if (iDanmakusRetainer != null) {
            iDanmakusRetainer.clear();
        }
        IDanmakusRetainer iDanmakusRetainer2 = this.lrdrInstance;
        if (iDanmakusRetainer2 != null) {
            iDanmakusRetainer2.clear();
        }
        IDanmakusRetainer iDanmakusRetainer3 = this.ftdrInstance;
        if (iDanmakusRetainer3 != null) {
            iDanmakusRetainer3.clear();
        }
        IDanmakusRetainer iDanmakusRetainer4 = this.fbdrInstance;
        if (iDanmakusRetainer4 != null) {
            iDanmakusRetainer4.clear();
        }
    }

    public void release() {
        clear();
    }

    /* access modifiers changed from: private */
    public static class AlignTopRetainer implements IDanmakusRetainer {
        protected boolean mCancelFixingFlag;
        protected Danmakus mVisibleDanmakus;

        private AlignTopRetainer() {
            this.mVisibleDanmakus = new Danmakus(1);
            this.mCancelFixingFlag = false;
        }

        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.IDanmakusRetainer
        public void fix(BaseDanmaku drawItem, IDisplayer disp, Verifier verifier) {
            BaseDanmaku minRightRow;
            BaseDanmaku firstItem;
            int lines;
            boolean willHit;
            BaseDanmaku removeItem;
            boolean shown;
            float topPos;
            boolean checkEdge;
            float topPos2;
            if (!drawItem.isOutside()) {
                float topPos3 = 0.0f;
                int lines2 = 0;
                boolean shown2 = drawItem.isShown();
                boolean willHit2 = !shown2 && !this.mVisibleDanmakus.isEmpty();
                boolean isOutOfVertialEdge = false;
                BaseDanmaku removeItem2 = null;
                if (!shown2) {
                    this.mCancelFixingFlag = false;
                    IDanmakuIterator it = this.mVisibleDanmakus.iterator();
                    BaseDanmaku insertItem = null;
                    BaseDanmaku firstItem2 = null;
                    BaseDanmaku minRightRow2 = null;
                    boolean overwriteInsert = false;
                    boolean willHit3 = willHit2;
                    BaseDanmaku lastItem = null;
                    while (true) {
                        if (this.mCancelFixingFlag || !it.hasNext()) {
                            lines = lines2;
                            firstItem = firstItem2;
                            minRightRow = minRightRow2;
                        } else {
                            lines = lines2 + 1;
                            BaseDanmaku item = it.next();
                            if (item == drawItem) {
                                insertItem = item;
                                lastItem = null;
                                shown2 = true;
                                willHit3 = false;
                                firstItem = firstItem2;
                                minRightRow = minRightRow2;
                                break;
                            }
                            if (firstItem2 == null) {
                                firstItem = item;
                            } else {
                                firstItem = firstItem2;
                            }
                            if (drawItem.paintHeight + item.getTop() > ((float) disp.getHeight())) {
                                overwriteInsert = true;
                                minRightRow = minRightRow2;
                                break;
                            }
                            if (minRightRow2 == null) {
                                minRightRow = item;
                            } else if (minRightRow2.getRight() >= item.getRight()) {
                                minRightRow = item;
                            } else {
                                minRightRow = minRightRow2;
                            }
                            willHit3 = DanmakuUtils.willHitInDuration(disp, item, drawItem, drawItem.getDuration(), drawItem.getTimer().currMillisecond);
                            if (!willHit3) {
                                insertItem = item;
                                break;
                            }
                            lastItem = item;
                            lines2 = lines;
                            firstItem2 = firstItem;
                            minRightRow2 = minRightRow;
                        }
                    }
                    lines = lines2;
                    firstItem = firstItem2;
                    minRightRow = minRightRow2;
                    if (insertItem != null) {
                        if (lastItem != null) {
                            topPos2 = lastItem.getBottom();
                        } else {
                            topPos2 = insertItem.getTop();
                        }
                        if (insertItem != drawItem) {
                            checkEdge = true;
                            topPos = topPos2;
                            willHit = willHit3;
                            removeItem = insertItem;
                            shown = false;
                        } else {
                            checkEdge = true;
                            willHit = willHit3;
                            removeItem = null;
                            shown = shown2;
                            topPos = topPos2;
                        }
                    } else if (overwriteInsert && minRightRow != null) {
                        checkEdge = false;
                        topPos = minRightRow.getTop();
                        willHit = willHit3;
                        removeItem = null;
                        shown = false;
                    } else if (lastItem != null) {
                        checkEdge = true;
                        willHit = false;
                        removeItem = null;
                        shown = shown2;
                        topPos = lastItem.getBottom();
                    } else if (firstItem != null) {
                        checkEdge = true;
                        topPos = firstItem.getTop();
                        willHit = willHit3;
                        removeItem = firstItem;
                        shown = false;
                    } else {
                        checkEdge = true;
                        willHit = willHit3;
                        removeItem = null;
                        shown = shown2;
                        topPos = 0.0f;
                    }
                    if (checkEdge) {
                        isOutOfVertialEdge = isOutVerticalEdge(overwriteInsert, drawItem, disp, topPos, firstItem, lastItem);
                    }
                    if (isOutOfVertialEdge) {
                        topPos = 0.0f;
                        lines2 = 1;
                        willHit2 = true;
                    } else if (removeItem != null) {
                        lines2 = lines - 1;
                        willHit2 = willHit;
                    } else {
                        lines2 = lines;
                        willHit2 = willHit;
                    }
                    if (topPos == 0.0f) {
                        topPos3 = topPos;
                        removeItem2 = removeItem;
                        shown2 = false;
                    } else {
                        topPos3 = topPos;
                        shown2 = shown;
                        removeItem2 = removeItem;
                    }
                }
                if (verifier == null || !verifier.skipLayout(drawItem, topPos3, lines2, willHit2)) {
                    if (isOutOfVertialEdge) {
                        clear();
                    }
                    drawItem.layout(disp, drawItem.getLeft(), topPos3);
                    if (!shown2) {
                        this.mVisibleDanmakus.removeItem(removeItem2);
                        this.mVisibleDanmakus.addItem(drawItem);
                    }
                }
            }
        }

        /* access modifiers changed from: protected */
        public boolean isOutVerticalEdge(boolean overwriteInsert, BaseDanmaku drawItem, IDisplayer disp, float topPos, BaseDanmaku firstItem, BaseDanmaku lastItem) {
            if (topPos < 0.0f) {
                return true;
            }
            if ((firstItem == null || firstItem.getTop() <= 0.0f) && drawItem.paintHeight + topPos <= ((float) disp.getHeight())) {
                return false;
            }
            return true;
        }

        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.IDanmakusRetainer
        public void clear() {
            this.mCancelFixingFlag = true;
            this.mVisibleDanmakus.clear();
        }
    }

    /* access modifiers changed from: private */
    public static class FTDanmakusRetainer extends AlignTopRetainer {
        private FTDanmakusRetainer() {
            super();
        }

        /* access modifiers changed from: protected */
        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.AlignTopRetainer
        public boolean isOutVerticalEdge(boolean overwriteInsert, BaseDanmaku drawItem, IDisplayer disp, float topPos, BaseDanmaku firstItem, BaseDanmaku lastItem) {
            if (drawItem.paintHeight + topPos > ((float) disp.getHeight())) {
                return true;
            }
            return false;
        }
    }

    /* access modifiers changed from: private */
    public static class AlignBottomRetainer extends FTDanmakusRetainer {
        protected Danmakus mVisibleDanmakus;

        private AlignBottomRetainer() {
            super();
            this.mVisibleDanmakus = new Danmakus(2);
        }

        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.AlignTopRetainer, master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.IDanmakusRetainer
        public void fix(BaseDanmaku drawItem, IDisplayer disp, Verifier verifier) {
            BaseDanmaku firstItem;
            int lines;
            if (!drawItem.isOutside()) {
                boolean shown = drawItem.isShown();
                float topPos = shown ? drawItem.getTop() : -1.0f;
                int lines2 = 0;
                boolean willHit = !shown && !this.mVisibleDanmakus.isEmpty();
                boolean isOutOfVerticalEdge = false;
                if (topPos < 0.0f) {
                    topPos = ((float) disp.getHeight()) - drawItem.paintHeight;
                }
                BaseDanmaku removeItem = null;
                BaseDanmaku firstItem2 = null;
                if (!shown) {
                    this.mCancelFixingFlag = false;
                    IDanmakuIterator it = this.mVisibleDanmakus.iterator();
                    float topPos2 = topPos;
                    boolean willHit2 = willHit;
                    while (true) {
                        if (this.mCancelFixingFlag || !it.hasNext()) {
                            lines = lines2;
                            firstItem = firstItem2;
                        } else {
                            lines = lines2 + 1;
                            BaseDanmaku item = it.next();
                            if (item == drawItem) {
                                willHit2 = false;
                                removeItem = null;
                                firstItem = firstItem2;
                                break;
                            }
                            if (firstItem2 != null) {
                                firstItem = firstItem2;
                            } else if (item.getBottom() != ((float) disp.getHeight())) {
                                firstItem = item;
                                break;
                            } else {
                                firstItem = item;
                            }
                            if (topPos2 < 0.0f) {
                                removeItem = null;
                                break;
                            }
                            willHit2 = DanmakuUtils.willHitInDuration(disp, item, drawItem, drawItem.getDuration(), drawItem.getTimer().currMillisecond);
                            if (!willHit2) {
                                removeItem = item;
                                break;
                            }
                            topPos2 = item.getTop() - drawItem.paintHeight;
                            lines2 = lines;
                            firstItem2 = firstItem;
                        }
                    }
                    isOutOfVerticalEdge = isOutVerticalEdge(false, drawItem, disp, topPos2, firstItem, null);
                    if (isOutOfVerticalEdge) {
                        topPos = ((float) disp.getHeight()) - drawItem.paintHeight;
                        willHit = true;
                        lines2 = 1;
                    } else {
                        if (topPos2 >= 0.0f) {
                            willHit = false;
                        } else {
                            willHit = willHit2;
                        }
                        if (removeItem != null) {
                            lines2 = lines - 1;
                            topPos = topPos2;
                        } else {
                            topPos = topPos2;
                            lines2 = lines;
                        }
                    }
                }
                if (verifier == null || !verifier.skipLayout(drawItem, topPos, lines2, willHit)) {
                    if (isOutOfVerticalEdge) {
                        clear();
                    }
                    drawItem.layout(disp, drawItem.getLeft(), topPos);
                    if (!shown) {
                        this.mVisibleDanmakus.removeItem(removeItem);
                        this.mVisibleDanmakus.addItem(drawItem);
                    }
                }
            }
        }

        /* access modifiers changed from: protected */
        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.AlignTopRetainer, master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.FTDanmakusRetainer
        public boolean isOutVerticalEdge(boolean overwriteInsert, BaseDanmaku drawItem, IDisplayer disp, float topPos, BaseDanmaku firstItem, BaseDanmaku lastItem) {
            if (topPos < 0.0f) {
                return true;
            }
            if (firstItem == null || firstItem.getBottom() == ((float) disp.getHeight())) {
                return false;
            }
            return true;
        }

        @Override // master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.AlignTopRetainer, master.flame.danmaku.danmaku.renderer.android.DanmakusRetainer.IDanmakusRetainer
        public void clear() {
            this.mCancelFixingFlag = true;
            this.mVisibleDanmakus.clear();
        }
    }
}
