package master.flame.danmaku.ui.widget;

import android.graphics.RectF;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import master.flame.danmaku.controller.IDanmakuView;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.IDanmakuIterator;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.android.Danmakus;

public class DanmakuTouchHelper {
    private IDanmakuView danmakuView;
    private RectF mDanmakuBounds;
    private final GestureDetector.OnGestureListener mOnGestureListener = new GestureDetector.SimpleOnGestureListener() {
        /* class master.flame.danmaku.ui.widget.DanmakuTouchHelper.AnonymousClass1 */

        public boolean onDown(MotionEvent event) {
            if (DanmakuTouchHelper.this.danmakuView == null || DanmakuTouchHelper.this.danmakuView.getOnDanmakuClickListener() == null) {
                return false;
            }
            return true;
        }

        public boolean onSingleTapConfirmed(MotionEvent event) {
            IDanmakus clickDanmakus = DanmakuTouchHelper.this.touchHitDanmaku(event.getX(), event.getY());
            boolean isEventConsumed = false;
            if (clickDanmakus != null && !clickDanmakus.isEmpty()) {
                isEventConsumed = DanmakuTouchHelper.this.performDanmakuClick(clickDanmakus);
            }
            if (!isEventConsumed) {
                return DanmakuTouchHelper.this.performViewClick();
            }
            return isEventConsumed;
        }
    };
    private final GestureDetector mTouchDelegate;

    private DanmakuTouchHelper(IDanmakuView danmakuView2) {
        this.danmakuView = danmakuView2;
        this.mDanmakuBounds = new RectF();
        this.mTouchDelegate = new GestureDetector(((View) danmakuView2).getContext(), this.mOnGestureListener);
    }

    public static synchronized DanmakuTouchHelper instance(IDanmakuView danmakuView2) {
        DanmakuTouchHelper danmakuTouchHelper;
        synchronized (DanmakuTouchHelper.class) {
            danmakuTouchHelper = new DanmakuTouchHelper(danmakuView2);
        }
        return danmakuTouchHelper;
    }

    public boolean onTouchEvent(MotionEvent event) {
        return this.mTouchDelegate.onTouchEvent(event);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean performDanmakuClick(IDanmakus danmakus) {
        IDanmakuView.OnDanmakuClickListener onDanmakuClickListener = this.danmakuView.getOnDanmakuClickListener();
        if (onDanmakuClickListener != null) {
            return onDanmakuClickListener.onDanmakuClick(danmakus);
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean performViewClick() {
        IDanmakuView.OnDanmakuClickListener onDanmakuClickListener = this.danmakuView.getOnDanmakuClickListener();
        if (onDanmakuClickListener != null) {
            return onDanmakuClickListener.onViewClick(this.danmakuView);
        }
        return false;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private IDanmakus touchHitDanmaku(float x, float y) {
        IDanmakus hitDanmakus = new Danmakus();
        this.mDanmakuBounds.setEmpty();
        IDanmakus danmakus = this.danmakuView.getCurrentVisibleDanmakus();
        if (danmakus != null && !danmakus.isEmpty()) {
            IDanmakuIterator iterator = danmakus.iterator();
            while (iterator.hasNext()) {
                BaseDanmaku danmaku = iterator.next();
                if (danmaku != null) {
                    this.mDanmakuBounds.set(danmaku.getLeft(), danmaku.getTop(), danmaku.getRight(), danmaku.getBottom());
                    if (this.mDanmakuBounds.contains(x, y)) {
                        hitDanmakus.addItem(danmaku);
                    }
                }
            }
        }
        return hitDanmakus;
    }
}
