package net.ossrs.yasea;

import java.util.Arrays;

public final class SrsAllocator {
    private Allocation[] availableAllocations;
    private volatile int availableSentinel;
    private final int individualAllocationSize;

    public class Allocation {
        private byte[] data;
        private int size = 0;

        public Allocation(int size2) {
            this.data = new byte[size2];
        }

        public byte[] array() {
            return this.data;
        }

        public int size() {
            return this.size;
        }

        public void appendOffset(int offset) {
            this.size += offset;
        }

        public void clear() {
            this.size = 0;
        }

        public void put(byte b) {
            byte[] bArr = this.data;
            int i = this.size;
            this.size = i + 1;
            bArr[i] = b;
        }

        public void put(byte b, int pos) {
            int pos2 = pos + 1;
            this.data[pos] = b;
            int i = this.size;
            if (pos2 > i) {
                i = pos2;
            }
            this.size = i;
        }

        public void put(short s) {
            put((byte) s);
            put((byte) (s >>> 8));
        }

        public void put(int i) {
            put((byte) i);
            put((byte) (i >>> 8));
            put((byte) (i >>> 16));
            put((byte) (i >>> 24));
        }

        public void put(byte[] bs) {
            System.arraycopy(bs, 0, this.data, this.size, bs.length);
            this.size += bs.length;
        }
    }

    public SrsAllocator(int individualAllocationSize2) {
        this(individualAllocationSize2, 0);
    }

    public SrsAllocator(int individualAllocationSize2, int initialAllocationCount) {
        this.individualAllocationSize = individualAllocationSize2;
        this.availableSentinel = initialAllocationCount + 10;
        this.availableAllocations = new Allocation[this.availableSentinel];
        for (int i = 0; i < this.availableSentinel; i++) {
            this.availableAllocations[i] = new Allocation(individualAllocationSize2);
        }
    }

    public synchronized Allocation allocate(int size) {
        for (int i = 0; i < this.availableSentinel; i++) {
            if (this.availableAllocations[i].size() >= size) {
                Allocation ret = this.availableAllocations[i];
                this.availableAllocations[i] = null;
                return ret;
            }
        }
        return new Allocation(size > this.individualAllocationSize ? size : this.individualAllocationSize);
    }

    public synchronized void release(Allocation allocation) {
        allocation.clear();
        for (int i = 0; i < this.availableSentinel; i++) {
            if (this.availableAllocations[i].size() == 0) {
                this.availableAllocations[i] = allocation;
                return;
            }
        }
        if (this.availableSentinel + 1 > this.availableAllocations.length) {
            this.availableAllocations = (Allocation[]) Arrays.copyOf(this.availableAllocations, this.availableAllocations.length * 2);
        }
        Allocation[] allocationArr = this.availableAllocations;
        int i2 = this.availableSentinel;
        this.availableSentinel = i2 + 1;
        allocationArr[i2] = allocation;
    }
}
