package net.ossrs.yasea;

import android.app.Activity;
import android.content.Context;
import android.graphics.SurfaceTexture;
import android.hardware.Camera;
import android.opengl.GLES20;
import android.opengl.GLSurfaceView;
import android.opengl.Matrix;
import android.util.AttributeSet;
import com.amap.api.maps.utils.SpatialRelationUtil;
import com.seu.magicfilter.base.gpuimage.GPUImageFilter;
import com.seu.magicfilter.utils.DCOpenGLUtil;
import com.seu.magicfilter.utils.MagicFilterFactory;
import com.seu.magicfilter.utils.MagicFilterType;
import com.uc.crashsdk.export.LogType;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.IntBuffer;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.ConcurrentLinkedQueue;
import javax.microedition.khronos.egl.EGLConfig;
import javax.microedition.khronos.opengles.GL10;

public class SrsCameraView extends GLSurfaceView implements GLSurfaceView.Renderer {
    private CameraCallbacksHandler cameraCallbacksHandler;
    private int mCamId;
    private Camera mCamera;
    private ConcurrentLinkedQueue<IntBuffer> mGLIntBufferCache;
    private ByteBuffer mGLPreviewBuffer;
    private float mInputAspectRatio;
    private volatile boolean mIsEncoding;
    private boolean mIsTorchOn;
    private int mOESTextureId;
    private float mOutputAspectRatio;
    private PreviewCallback mPrevCb;
    private int mPreviewHeight;
    private int mPreviewOrientation;
    private int mPreviewRotation;
    private int mPreviewWidth;
    private float[] mProjectionMatrix;
    private int mSurfaceHeight;
    private float[] mSurfaceMatrix;
    private int mSurfaceWidth;
    private float[] mTransformMatrix;
    private GPUImageFilter magicFilter;
    private SurfaceTexture surfaceTexture;
    private Thread worker;
    private final Object writeLock;

    public interface CameraCallbacks {
        void onCameraParameters(Camera.Parameters parameters);
    }

    public interface PreviewCallback {
        void onGetRgbaFrame(byte[] bArr, int i, int i2);
    }

    public SrsCameraView(Context context) {
        this(context, null);
    }

    public SrsCameraView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.mOESTextureId = -1;
        this.mIsTorchOn = false;
        this.mProjectionMatrix = new float[16];
        this.mSurfaceMatrix = new float[16];
        this.mTransformMatrix = new float[16];
        this.mCamId = -1;
        this.mPreviewRotation = 90;
        this.mPreviewOrientation = 1;
        this.writeLock = new Object();
        this.mGLIntBufferCache = new ConcurrentLinkedQueue<>();
        this.cameraCallbacksHandler = new CameraCallbacksHandler();
        setEGLContextClientVersion(2);
        setRenderer(this);
        setRenderMode(0);
    }

    public void onSurfaceCreated(GL10 gl, EGLConfig config) {
        GLES20.glDisable(3024);
        GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
        GPUImageFilter gPUImageFilter = new GPUImageFilter(MagicFilterType.NONE);
        this.magicFilter = gPUImageFilter;
        gPUImageFilter.init(getContext().getApplicationContext());
        this.magicFilter.onInputSizeChanged(this.mPreviewWidth, this.mPreviewHeight);
        this.mOESTextureId = DCOpenGLUtil.getExternalOESTextureID();
        SurfaceTexture surfaceTexture2 = new SurfaceTexture(this.mOESTextureId);
        this.surfaceTexture = surfaceTexture2;
        surfaceTexture2.setOnFrameAvailableListener(new SurfaceTexture.OnFrameAvailableListener() {
            /* class net.ossrs.yasea.SrsCameraView.AnonymousClass1 */

            public void onFrameAvailable(SurfaceTexture surfaceTexture) {
                SrsCameraView.this.requestRender();
            }
        });
        Camera camera = this.mCamera;
        if (camera != null) {
            try {
                camera.setPreviewTexture(this.surfaceTexture);
            } catch (IOException ioe) {
                ioe.printStackTrace();
            }
        }
    }

    public void onSurfaceChanged(GL10 gl, int width, int height) {
        float f;
        float f2;
        GLES20.glViewport(0, 0, width, height);
        this.mSurfaceWidth = width;
        this.mSurfaceHeight = height;
        this.magicFilter.onDisplaySizeChanged(width, height);
        this.magicFilter.onInputSizeChanged(this.mPreviewWidth, this.mPreviewHeight);
        if (width > height) {
            f2 = (float) width;
            f = (float) height;
        } else {
            f2 = (float) height;
            f = (float) width;
        }
        float f3 = f2 / f;
        this.mOutputAspectRatio = f3;
        float aspectRatio = f3 / this.mInputAspectRatio;
        if (width > height) {
            Matrix.orthoM(this.mProjectionMatrix, 0, -1.0f, 1.0f, -aspectRatio, aspectRatio, -1.0f, 1.0f);
        } else {
            Matrix.orthoM(this.mProjectionMatrix, 0, -aspectRatio, aspectRatio, -1.0f, 1.0f, -1.0f, 1.0f);
        }
    }

    public void onDrawFrame(GL10 gl) {
        GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
        GLES20.glClear(LogType.UNEXP_RESTART);
        this.surfaceTexture.updateTexImage();
        this.surfaceTexture.getTransformMatrix(this.mSurfaceMatrix);
        Matrix.multiplyMM(this.mTransformMatrix, 0, this.mSurfaceMatrix, 0, this.mProjectionMatrix, 0);
        this.magicFilter.setTextureTransformMatrix(this.mTransformMatrix);
        this.magicFilter.onDrawFrame(this.mOESTextureId);
        if (this.mIsEncoding) {
            this.mGLIntBufferCache.add(this.magicFilter.getGLFboBuffer());
            synchronized (this.writeLock) {
                this.writeLock.notifyAll();
            }
        }
    }

    public void setPreviewCallback(PreviewCallback cb) {
        this.mPrevCb = cb;
    }

    public Camera getCamera() {
        return this.mCamera;
    }

    public void setPreviewCallback(Camera.PreviewCallback previewCallback) {
        this.mCamera.setPreviewCallback(previewCallback);
    }

    public int[] setPreviewResolution(int width, int height) {
        this.mCamera = openCamera();
        this.mPreviewWidth = width;
        this.mPreviewHeight = height;
        Camera camera = this.mCamera;
        Objects.requireNonNull(camera);
        Camera.Size rs = adaptPreviewResolution(new Camera.Size(camera, width, height));
        if (rs != null) {
            this.mPreviewWidth = rs.width;
            this.mPreviewHeight = rs.height;
        }
        getHolder().setFixedSize(this.mPreviewWidth, this.mPreviewHeight);
        this.mCamera.getParameters().setPreviewSize(this.mPreviewWidth, this.mPreviewHeight);
        this.mGLPreviewBuffer = ByteBuffer.allocate(this.mPreviewWidth * this.mPreviewHeight * 4);
        int i = this.mPreviewWidth;
        int i2 = this.mPreviewHeight;
        this.mInputAspectRatio = i > i2 ? ((float) i) / ((float) i2) : ((float) i2) / ((float) i);
        return new int[]{this.mPreviewWidth, this.mPreviewHeight};
    }

    public int[] setPreviewResolutionLand(int width, int height) {
        this.mCamera = openCamera();
        this.mPreviewWidth = width;
        this.mPreviewHeight = height;
        Camera camera = this.mCamera;
        Objects.requireNonNull(camera);
        Camera.Size rs = adaptPreviewResolutionLand(new Camera.Size(camera, width, height));
        if (rs != null) {
            this.mPreviewWidth = rs.width;
            this.mPreviewHeight = rs.height;
        }
        getHolder().setFixedSize(this.mPreviewWidth, this.mPreviewHeight);
        this.mCamera.getParameters().setPreviewSize(this.mPreviewWidth, this.mPreviewHeight);
        this.mCamera.getParameters().setRotation(90);
        this.mGLPreviewBuffer = ByteBuffer.allocate(this.mPreviewWidth * this.mPreviewHeight * 4);
        int i = this.mPreviewWidth;
        int i2 = this.mPreviewHeight;
        this.mInputAspectRatio = i > i2 ? ((float) i) / ((float) i2) : ((float) i2) / ((float) i);
        return new int[]{this.mPreviewWidth, this.mPreviewHeight};
    }

    public boolean setFilter(final MagicFilterType type, final int progress) {
        if (this.mCamera == null) {
            return false;
        }
        queueEvent(new Runnable() {
            /* class net.ossrs.yasea.SrsCameraView.AnonymousClass2 */

            public void run() {
                if (SrsCameraView.this.magicFilter != null) {
                    SrsCameraView.this.magicFilter.destroy();
                }
                SrsCameraView.this.magicFilter = MagicFilterFactory.initFilters(type, progress);
                if (SrsCameraView.this.magicFilter != null) {
                    SrsCameraView.this.magicFilter.init(SrsCameraView.this.getContext().getApplicationContext());
                    SrsCameraView.this.magicFilter.onInputSizeChanged(SrsCameraView.this.mPreviewWidth, SrsCameraView.this.mPreviewHeight);
                    SrsCameraView.this.magicFilter.onDisplaySizeChanged(SrsCameraView.this.mSurfaceWidth, SrsCameraView.this.mSurfaceHeight);
                }
            }
        });
        requestRender();
        return true;
    }

    private void deleteTextures() {
        if (this.mOESTextureId != -1) {
            queueEvent(new Runnable() {
                /* class net.ossrs.yasea.SrsCameraView.AnonymousClass3 */

                public void run() {
                    GLES20.glDeleteTextures(1, new int[]{SrsCameraView.this.mOESTextureId}, 0);
                    SrsCameraView.this.mOESTextureId = -1;
                }
            });
        }
    }

    public void setCameraId(int id) {
        stopTorch();
        this.mCamId = id;
        setPreviewOrientation(this.mPreviewOrientation);
    }

    /* access modifiers changed from: protected */
    public int getRotateDeg() {
        try {
            int rotate = ((Activity) getContext()).getWindowManager().getDefaultDisplay().getRotation();
            if (rotate == 0) {
                return 0;
            }
            if (rotate == 1) {
                return 90;
            }
            if (rotate == 2) {
                return 180;
            }
            if (rotate != 3) {
                return -1;
            }
            return 270;
        } catch (Exception e) {
            e.printStackTrace();
            return -1;
        }
    }

    public void setPreviewOrientation(int orientation) {
        this.mPreviewOrientation = orientation;
        Camera.CameraInfo info = new Camera.CameraInfo();
        Camera.getCameraInfo(this.mCamId, info);
        int rotateDeg = getRotateDeg();
        if (orientation == 1) {
            if (info.facing == 1) {
                int i = info.orientation % SpatialRelationUtil.A_CIRCLE_DEGREE;
                this.mPreviewRotation = i;
                this.mPreviewRotation = (360 - i) % SpatialRelationUtil.A_CIRCLE_DEGREE;
            } else {
                this.mPreviewRotation = (info.orientation + SpatialRelationUtil.A_CIRCLE_DEGREE) % SpatialRelationUtil.A_CIRCLE_DEGREE;
            }
        } else if (orientation == 2) {
            if (info.facing == 1) {
                int i2 = (info.orientation - 90) % SpatialRelationUtil.A_CIRCLE_DEGREE;
                this.mPreviewRotation = i2;
                this.mPreviewRotation = (360 - i2) % SpatialRelationUtil.A_CIRCLE_DEGREE;
            } else {
                this.mPreviewRotation = (info.orientation + 90) % SpatialRelationUtil.A_CIRCLE_DEGREE;
            }
        }
        if (rotateDeg > 0) {
            this.mPreviewRotation %= rotateDeg;
        }
    }

    public int getCameraId() {
        return this.mCamId;
    }

    public void enableEncoding() {
        Thread thread = new Thread(new Runnable() {
            /* class net.ossrs.yasea.SrsCameraView.AnonymousClass4 */

            public void run() {
                while (!Thread.interrupted()) {
                    while (!SrsCameraView.this.mGLIntBufferCache.isEmpty()) {
                        SrsCameraView.this.mGLPreviewBuffer.asIntBuffer().put(((IntBuffer) SrsCameraView.this.mGLIntBufferCache.poll()).array());
                        SrsCameraView.this.mPrevCb.onGetRgbaFrame(SrsCameraView.this.mGLPreviewBuffer.array(), SrsCameraView.this.mPreviewWidth, SrsCameraView.this.mPreviewHeight);
                    }
                    synchronized (SrsCameraView.this.writeLock) {
                        try {
                            SrsCameraView.this.writeLock.wait(500);
                        } catch (InterruptedException e) {
                            SrsCameraView.this.worker.interrupt();
                        }
                    }
                }
            }
        });
        this.worker = thread;
        thread.start();
        this.mIsEncoding = true;
    }

    public void disableEncoding() {
        this.mIsEncoding = false;
        this.mGLIntBufferCache.clear();
        this.mGLPreviewBuffer.clear();
        Thread thread = this.worker;
        if (thread != null) {
            thread.interrupt();
            try {
                this.worker.join();
            } catch (InterruptedException e) {
                e.printStackTrace();
                this.worker.interrupt();
            }
            this.worker = null;
        }
    }

    public boolean startCamera() {
        if (this.mCamera == null) {
            Camera openCamera = openCamera();
            this.mCamera = openCamera;
            if (openCamera == null) {
                return false;
            }
        }
        Camera.Parameters params = this.mCamera.getParameters();
        params.setPreviewSize(this.mPreviewWidth, this.mPreviewHeight);
        int[] range = adaptFpsRange(24, params.getSupportedPreviewFpsRange());
        params.setPreviewFpsRange(range[0], range[1]);
        params.setPreviewFormat(17);
        params.setFlashMode("off");
        params.setWhiteBalance("auto");
        params.setSceneMode("auto");
        params.setRecordingHint(true);
        List<String> supportedFocusModes = params.getSupportedFocusModes();
        if (supportedFocusModes != null && !supportedFocusModes.isEmpty()) {
            if (supportedFocusModes.contains("continuous-picture")) {
                params.setFocusMode("continuous-picture");
            } else if (supportedFocusModes.contains("auto")) {
                params.setFocusMode("auto");
                this.mCamera.autoFocus(null);
            } else {
                params.setFocusMode(supportedFocusModes.get(0));
            }
        }
        List<String> supportedFlashModes = params.getSupportedFlashModes();
        if (supportedFlashModes != null && !supportedFlashModes.isEmpty()) {
            if (!supportedFlashModes.contains("torch")) {
                params.setFlashMode(supportedFlashModes.get(0));
            } else if (this.mIsTorchOn) {
                params.setFlashMode("torch");
            }
        }
        this.cameraCallbacksHandler.onCameraParameters(params);
        this.mCamera.setParameters(params);
        this.mCamera.setDisplayOrientation(this.mPreviewRotation);
        try {
            this.mCamera.setPreviewTexture(this.surfaceTexture);
        } catch (IOException e) {
            e.printStackTrace();
        }
        this.mCamera.startPreview();
        return true;
    }

    public void stopCamera() {
        disableEncoding();
        stopTorch();
        Camera camera = this.mCamera;
        if (camera != null) {
            camera.setPreviewCallback(null);
            this.mCamera.stopPreview();
            this.mCamera.release();
            this.mCamera = null;
        }
    }

    /* access modifiers changed from: protected */
    public Camera openCamera() {
        Camera camera = null;
        if (this.mCamId < 0) {
            Camera.CameraInfo info = new Camera.CameraInfo();
            int numCameras = Camera.getNumberOfCameras();
            int frontCamId = -1;
            int backCamId = -1;
            int i = 0;
            while (true) {
                if (i >= numCameras) {
                    break;
                }
                Camera.getCameraInfo(i, info);
                if (info.facing == 0) {
                    backCamId = i;
                } else if (info.facing == 1) {
                    frontCamId = i;
                    break;
                }
                i++;
            }
            if (frontCamId != -1) {
                this.mCamId = frontCamId;
            } else if (backCamId != -1) {
                this.mCamId = backCamId;
            } else {
                this.mCamId = 0;
            }
        }
        try {
            camera = Camera.open(this.mCamId);
            camera.setErrorCallback(new Camera.ErrorCallback() {
                /* class net.ossrs.yasea.SrsCameraView.AnonymousClass5 */

                public void onError(int error, Camera camera) {
                    SrsCameraView.this.stopCamera();
                }
            });
            return camera;
        } catch (Exception e) {
            e.printStackTrace();
            return camera;
        }
    }

    private Camera.Size adaptPreviewResolution(Camera.Size resolution) {
        float diff = 100.0f;
        float xdy = ((float) resolution.width) / ((float) resolution.height);
        Camera.Size best = null;
        for (Camera.Size size : this.mCamera.getParameters().getSupportedPreviewSizes()) {
            if (size.height == resolution.width && size.width == resolution.height) {
                return size;
            }
            float tmp = Math.abs((((float) size.height) / ((float) size.width)) - xdy);
            if (tmp < diff) {
                diff = tmp;
                best = size;
            }
        }
        return best;
    }

    private Camera.Size adaptPreviewResolutionLand(Camera.Size resolution) {
        float diff = 100.0f;
        float xdy = ((float) resolution.height) / ((float) resolution.width);
        Camera.Size best = null;
        for (Camera.Size size : this.mCamera.getParameters().getSupportedPreviewSizes()) {
            if (size.height == resolution.width && size.width == resolution.height) {
                return size;
            }
            float tmp = Math.abs((((float) size.width) / ((float) size.height)) - xdy);
            if (tmp < diff) {
                diff = tmp;
                best = size;
            }
        }
        return best;
    }

    private int[] adaptFpsRange(int expectedFps, List<int[]> fpsRanges) {
        int curMeasure;
        int expectedFps2 = expectedFps * 1000;
        int[] closestRange = fpsRanges.get(0);
        int measure = Math.abs(closestRange[0] - expectedFps2) + Math.abs(closestRange[1] - expectedFps2);
        for (int[] range : fpsRanges) {
            if (range[0] <= expectedFps2 && range[1] >= expectedFps2 && (curMeasure = Math.abs(range[0] - expectedFps2) + Math.abs(range[1] - expectedFps2)) < measure) {
                closestRange = range;
                measure = curMeasure;
            }
        }
        return closestRange;
    }

    public boolean startTorch() {
        Camera.Parameters params;
        List<String> supportedFlashModes;
        Camera camera = this.mCamera;
        if (camera == null || (supportedFlashModes = (params = camera.getParameters()).getSupportedFlashModes()) == null || supportedFlashModes.isEmpty() || !supportedFlashModes.contains("torch")) {
            return false;
        }
        params.setFlashMode("torch");
        this.mCamera.setParameters(params);
        return true;
    }

    public void stopTorch() {
        Camera camera = this.mCamera;
        if (camera != null) {
            try {
                Camera.Parameters params = camera.getParameters();
                params.setFlashMode("off");
                this.mCamera.setParameters(params);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public static class CameraCallbacksHandler implements CameraCallbacks {
        @Override // net.ossrs.yasea.SrsCameraView.CameraCallbacks
        public void onCameraParameters(Camera.Parameters params) {
        }
    }

    public void setCameraCallbacksHandler(CameraCallbacksHandler cameraCallbacksHandler2) {
        this.cameraCallbacksHandler = cameraCallbacksHandler2;
    }
}
