package net.ossrs.yasea;

import android.os.Handler;
import android.os.Message;
import java.lang.ref.WeakReference;

public class SrsEncodeHandler extends Handler {
    private static final int MSG_ENCODE_ILLEGAL_ARGUMENT_EXCEPTION = 2;
    private static final int MSG_ENCODE_NETWORK_RESUME = 1;
    private static final int MSG_ENCODE_NETWORK_WEAK = 0;
    private WeakReference<SrsEncodeListener> mWeakListener;

    public interface SrsEncodeListener {
        void onEncodeIllegalArgumentException(IllegalArgumentException illegalArgumentException);

        void onNetworkResume();

        void onNetworkWeak();
    }

    public SrsEncodeHandler(SrsEncodeListener listener) {
        this.mWeakListener = new WeakReference<>(listener);
    }

    public void notifyNetworkWeak() {
        sendEmptyMessage(0);
    }

    public void notifyNetworkResume() {
        sendEmptyMessage(1);
    }

    public void notifyEncodeIllegalArgumentException(IllegalArgumentException e) {
        obtainMessage(2, e).sendToTarget();
    }

    public void handleMessage(Message msg) {
        SrsEncodeListener listener = this.mWeakListener.get();
        if (listener != null) {
            int i = msg.what;
            if (i == 0) {
                listener.onNetworkWeak();
            } else if (i == 1) {
                listener.onNetworkResume();
            } else if (i == 2) {
                listener.onEncodeIllegalArgumentException((IllegalArgumentException) msg.obj);
            }
        }
    }
}
