package net.ossrs.yasea;

import android.graphics.Rect;
import android.media.AudioRecord;
import android.media.MediaCodec;
import android.media.MediaCodecInfo;
import android.media.MediaCodecList;
import android.media.MediaCrypto;
import android.media.MediaFormat;
import android.util.Log;
import android.view.Surface;
import com.amap.api.maps.utils.SpatialRelationUtil;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.concurrent.atomic.AtomicInteger;

public class SrsEncoder {
    public static final int ABITRATE = 65536;
    public static final String ACODEC = "audio/mp4a-latm";
    public static final int ASAMPLERATE = 44100;
    private static final String TAG = "SrsEncoder";
    public static final String VCODEC = "video/avc";
    public static final int VFPS = 24;
    public static final int VGOP = 48;
    public static int aChannelConfig = 12;
    public static int vBitrate = 1228800;
    public static int vLandscapeHeight = SpatialRelationUtil.A_CIRCLE_DEGREE;
    public static int vLandscapeWidth = 640;
    public static int vOutHeight = 640;
    public static int vOutWidth = SpatialRelationUtil.A_CIRCLE_DEGREE;
    public static int vPortraitHeight = 640;
    public static int vPortraitWidth = SpatialRelationUtil.A_CIRCLE_DEGREE;
    public static int vPrevHeight = SpatialRelationUtil.A_CIRCLE_DEGREE;
    public static int vPrevWidth = 640;
    public static String x264Preset = "veryfast";
    private MediaCodec aencoder;
    private int audioFlvTrack;
    private int audioMp4Track;
    private boolean canSoftEncode = false;
    private SrsFlvMuxer flvMuxer;
    private boolean mCameraFaceFront = true;
    private SrsEncodeHandler mHandler;
    private long mPausetime;
    private long mPresentTimeUs;
    private int mVideoColorFormat;
    private SrsMp4Muxer mp4Muxer;
    private boolean networkWeakTriggered = false;
    private boolean useSoftEncoder = false;
    private MediaCodec vencoder;
    private int videoFlvTrack;
    private int videoMp4Track;
    private MediaCodecInfo vmci;

    private native byte[] ARGBToI420(int[] iArr, int i, int i2, boolean z, int i3);

    private native byte[] ARGBToI420Scaled(int[] iArr, int i, int i2, boolean z, int i3, int i4, int i5, int i6, int i7);

    private native byte[] ARGBToNV12(int[] iArr, int i, int i2, boolean z, int i3);

    private native byte[] ARGBToNV12Scaled(int[] iArr, int i, int i2, boolean z, int i3, int i4, int i5, int i6, int i7);

    private native byte[] NV21ToI420Scaled(byte[] bArr, int i, int i2, boolean z, int i3, int i4, int i5, int i6, int i7);

    private native byte[] NV21ToNV12Scaled(byte[] bArr, int i, int i2, boolean z, int i3, int i4, int i5, int i6, int i7);

    private native int RGBASoftEncode(byte[] bArr, int i, int i2, boolean z, int i3, long j);

    private native byte[] RGBAToI420(byte[] bArr, int i, int i2, boolean z, int i3);

    private native byte[] RGBAToNV12(byte[] bArr, int i, int i2, boolean z, int i3);

    private native void closeSoftEncoder();

    private native boolean openSoftEncoder();

    private native void setEncoderBitrate(int i);

    private native void setEncoderFps(int i);

    private native void setEncoderGop(int i);

    private native void setEncoderPreset(String str);

    private native void setEncoderResolution(int i, int i2);

    static {
        System.loadLibrary("yuv");
        System.loadLibrary("enc");
    }

    public SrsEncoder(SrsEncodeHandler handler) {
        this.mHandler = handler;
        this.mVideoColorFormat = chooseVideoEncoder();
    }

    public void setFlvMuxer(SrsFlvMuxer flvMuxer2) {
        this.flvMuxer = flvMuxer2;
    }

    public void setMp4Muxer(SrsMp4Muxer mp4Muxer2) {
        this.mp4Muxer = mp4Muxer2;
    }

    public boolean start() {
        if (this.flvMuxer == null || this.mp4Muxer == null) {
            return false;
        }
        this.mPresentTimeUs = System.nanoTime() / 1000;
        if (!this.useSoftEncoder && !(vOutWidth % 32 == 0 && vOutHeight % 32 == 0)) {
            this.vmci.getName().contains("MTK");
        }
        setEncoderResolution(vOutWidth, vOutHeight);
        setEncoderFps(24);
        setEncoderGop(48);
        setEncoderBitrate(vBitrate);
        setEncoderPreset(x264Preset);
        if (this.useSoftEncoder) {
            boolean openSoftEncoder = openSoftEncoder();
            this.canSoftEncode = openSoftEncoder;
            if (!openSoftEncoder) {
                return false;
            }
        }
        try {
            MediaCodec createEncoderByType = MediaCodec.createEncoderByType("audio/mp4a-latm");
            this.aencoder = createEncoderByType;
            if (createEncoderByType == null) {
                return false;
            }
            MediaFormat audioFormat = MediaFormat.createAudioFormat("audio/mp4a-latm", 44100, aChannelConfig == 12 ? 2 : 1);
            audioFormat.setInteger("bitrate", 65536);
            audioFormat.setInteger("max-input-size", 0);
            this.aencoder.configure(audioFormat, (Surface) null, (MediaCrypto) null, 1);
            this.audioFlvTrack = this.flvMuxer.addTrack(audioFormat);
            this.audioMp4Track = this.mp4Muxer.addTrack(audioFormat);
            try {
                this.vencoder = MediaCodec.createByCodecName(this.vmci.getName());
                MediaFormat videoFormat = MediaFormat.createVideoFormat("video/avc", vOutWidth, vOutHeight);
                videoFormat.setInteger("color-format", this.mVideoColorFormat);
                videoFormat.setInteger("max-input-size", 0);
                videoFormat.setInteger("bitrate", vBitrate);
                videoFormat.setInteger("frame-rate", 24);
                videoFormat.setInteger("i-frame-interval", 2);
                this.vencoder.configure(videoFormat, (Surface) null, (MediaCrypto) null, 1);
                this.videoFlvTrack = this.flvMuxer.addTrack(videoFormat);
                this.videoMp4Track = this.mp4Muxer.addTrack(videoFormat);
                this.vencoder.start();
                this.aencoder.start();
                return true;
            } catch (IOException e) {
                Log.e(TAG, "create vencoder failed.");
                e.printStackTrace();
                return false;
            }
        } catch (IOException e2) {
            Log.e(TAG, "create aencoder failed.");
            e2.printStackTrace();
            return false;
        }
    }

    public void pause() {
        this.mPausetime = System.nanoTime() / 1000;
    }

    public void resume() {
        this.mPresentTimeUs += (System.nanoTime() / 1000) - this.mPausetime;
        this.mPausetime = 0;
    }

    public void stop() {
        if (this.useSoftEncoder) {
            closeSoftEncoder();
            this.canSoftEncode = false;
        }
        if (this.aencoder != null) {
            Log.i(TAG, "stop aencoder");
            try {
                this.aencoder.stop();
            } catch (IllegalStateException e) {
                e.printStackTrace();
            }
            this.aencoder.release();
            this.aencoder = null;
        }
        if (this.vencoder != null) {
            Log.i(TAG, "stop vencoder");
            try {
                this.vencoder.stop();
            } catch (IllegalStateException e2) {
                e2.printStackTrace();
            }
            this.vencoder.release();
            this.vencoder = null;
        }
    }

    public void setCameraFrontFace() {
        this.mCameraFaceFront = true;
    }

    public void setCameraBackFace() {
        this.mCameraFaceFront = false;
    }

    public void switchToSoftEncoder() {
        this.useSoftEncoder = true;
    }

    public void switchToHardEncoder() {
        this.useSoftEncoder = false;
    }

    public boolean isSoftEncoder() {
        return this.useSoftEncoder;
    }

    public boolean canHardEncode() {
        return this.vencoder != null;
    }

    public boolean canSoftEncode() {
        return this.canSoftEncode;
    }

    public boolean isEnabled() {
        return canHardEncode() || canSoftEncode();
    }

    public void setPreviewResolution(int width, int height) {
        vPrevWidth = width;
        vPrevHeight = height;
    }

    public void setPortraitResolution(int width, int height) {
        vOutWidth = width;
        vOutHeight = height;
        vPortraitWidth = width;
        vPortraitHeight = height;
        vLandscapeWidth = height;
        vLandscapeHeight = width;
    }

    public void setLandscapeResolution(int width, int height) {
        vOutWidth = width;
        vOutHeight = height;
        vLandscapeWidth = width;
        vLandscapeHeight = height;
        vPortraitWidth = height;
        vPortraitHeight = width;
    }

    public void setVideoHDMode() {
        vBitrate = 1228800;
        x264Preset = "veryfast";
    }

    public void setVideoSmoothMode() {
        vBitrate = 512000;
        x264Preset = "superfast";
    }

    public int getPreviewWidth() {
        return vPrevWidth;
    }

    public int getPreviewHeight() {
        return vPrevHeight;
    }

    public int getOutputWidth() {
        return vOutWidth;
    }

    public int getOutputHeight() {
        return vOutHeight;
    }

    public void setScreenOrientation(int orientation) {
        if (orientation == 1) {
            vOutWidth = vPortraitWidth;
            vOutHeight = vPortraitHeight;
        } else if (orientation == 2) {
            vOutWidth = vLandscapeWidth;
            vOutHeight = vLandscapeHeight;
        }
        if (!this.useSoftEncoder && !(vOutWidth % 32 == 0 && vOutHeight % 32 == 0)) {
            this.vmci.getName().contains("MTK");
        }
        setEncoderResolution(vOutWidth, vOutHeight);
    }

    private void onProcessedYuvFrame(byte[] yuvFrame, long pts) {
        ByteBuffer[] inBuffers = this.vencoder.getInputBuffers();
        ByteBuffer[] outBuffers = this.vencoder.getOutputBuffers();
        int inBufferIndex = this.vencoder.dequeueInputBuffer(-1);
        if (inBufferIndex >= 0) {
            ByteBuffer bb = inBuffers[inBufferIndex];
            bb.clear();
            bb.put(yuvFrame, 0, yuvFrame.length);
            this.vencoder.queueInputBuffer(inBufferIndex, 0, yuvFrame.length, pts, 0);
        }
        while (true) {
            MediaCodec.BufferInfo vebi = new MediaCodec.BufferInfo();
            int outBufferIndex = this.vencoder.dequeueOutputBuffer(vebi, 0);
            if (outBufferIndex >= 0) {
                onEncodedAnnexbFrame(outBuffers[outBufferIndex], vebi);
                this.vencoder.releaseOutputBuffer(outBufferIndex, false);
            } else {
                return;
            }
        }
    }

    private void onSoftEncodedData(byte[] es, long pts, boolean isKeyFrame) {
        ByteBuffer bb = ByteBuffer.wrap(es);
        MediaCodec.BufferInfo vebi = new MediaCodec.BufferInfo();
        vebi.offset = 0;
        vebi.size = es.length;
        vebi.presentationTimeUs = pts;
        vebi.flags = isKeyFrame ? 1 : 0;
        onEncodedAnnexbFrame(bb, vebi);
    }

    private void onEncodedAnnexbFrame(ByteBuffer es, MediaCodec.BufferInfo bi) {
        this.mp4Muxer.writeSampleData(this.videoMp4Track, es.duplicate(), bi);
        this.flvMuxer.writeSampleData(this.videoFlvTrack, es, bi);
    }

    private void onEncodedAacFrame(ByteBuffer es, MediaCodec.BufferInfo bi) {
        this.mp4Muxer.writeSampleData(this.audioMp4Track, es.duplicate(), bi);
        this.flvMuxer.writeSampleData(this.audioFlvTrack, es, bi);
    }

    public void onGetPcmFrame(byte[] data, int size) {
        AtomicInteger videoFrameCacheNumber = this.flvMuxer.getVideoFrameCacheNumber();
        if (videoFrameCacheNumber != null && videoFrameCacheNumber.get() < 24) {
            MediaCodec mediaCodec = this.aencoder;
            if (mediaCodec != null) {
                ByteBuffer[] inBuffers = mediaCodec.getInputBuffers();
                ByteBuffer[] outBuffers = this.aencoder.getOutputBuffers();
                int inBufferIndex = this.aencoder.dequeueInputBuffer(-1);
                if (inBufferIndex >= 0) {
                    ByteBuffer bb = inBuffers[inBufferIndex];
                    bb.clear();
                    bb.put(data, 0, size);
                    this.aencoder.queueInputBuffer(inBufferIndex, 0, size, (System.nanoTime() / 1000) - this.mPresentTimeUs, 0);
                }
                while (true) {
                    MediaCodec.BufferInfo aebi = new MediaCodec.BufferInfo();
                    int outBufferIndex = this.aencoder.dequeueOutputBuffer(aebi, 0);
                    if (outBufferIndex >= 0) {
                        onEncodedAacFrame(outBuffers[outBufferIndex], aebi);
                        this.aencoder.releaseOutputBuffer(outBufferIndex, false);
                    } else {
                        return;
                    }
                }
            }
        }
    }

    public void onGetRgbaFrame(byte[] data, int width, int height) {
        AtomicInteger videoFrameCacheNumber = this.flvMuxer.getVideoFrameCacheNumber();
        if (videoFrameCacheNumber == null || videoFrameCacheNumber.get() >= 24) {
            this.mHandler.notifyNetworkWeak();
            this.networkWeakTriggered = true;
            return;
        }
        long pts = (System.nanoTime() / 1000) - this.mPresentTimeUs;
        if (this.useSoftEncoder) {
            swRgbaFrame(data, width, height, pts);
        } else {
            byte[] processedData = hwRgbaFrame(data, width, height);
            if (processedData != null) {
                onProcessedYuvFrame(processedData, pts);
            } else {
                this.mHandler.notifyEncodeIllegalArgumentException(new IllegalArgumentException("libyuv failure"));
            }
        }
        if (this.networkWeakTriggered) {
            this.networkWeakTriggered = false;
            this.mHandler.notifyNetworkResume();
        }
    }

    public void onGetYuvNV21Frame(byte[] data, int width, int height, Rect boundingBox) {
        AtomicInteger videoFrameCacheNumber = this.flvMuxer.getVideoFrameCacheNumber();
        if (videoFrameCacheNumber == null || videoFrameCacheNumber.get() >= 24) {
            this.mHandler.notifyNetworkWeak();
            this.networkWeakTriggered = true;
            return;
        }
        long pts = (System.nanoTime() / 1000) - this.mPresentTimeUs;
        if (!this.useSoftEncoder) {
            byte[] processedData = hwYUVNV21FrameScaled(data, width, height, boundingBox);
            if (processedData != null) {
                onProcessedYuvFrame(processedData, pts);
            } else {
                this.mHandler.notifyEncodeIllegalArgumentException(new IllegalArgumentException("libyuv failure"));
            }
            if (this.networkWeakTriggered) {
                this.networkWeakTriggered = false;
                this.mHandler.notifyNetworkResume();
                return;
            }
            return;
        }
        throw new UnsupportedOperationException("Not implemented");
    }

    public void onGetArgbFrame(int[] data, int width, int height, Rect boundingBox) {
        AtomicInteger videoFrameCacheNumber = this.flvMuxer.getVideoFrameCacheNumber();
        if (videoFrameCacheNumber == null || videoFrameCacheNumber.get() >= 24) {
            this.mHandler.notifyNetworkWeak();
            this.networkWeakTriggered = true;
            return;
        }
        long pts = (System.nanoTime() / 1000) - this.mPresentTimeUs;
        if (!this.useSoftEncoder) {
            byte[] processedData = hwArgbFrameScaled(data, width, height, boundingBox);
            if (processedData != null) {
                onProcessedYuvFrame(processedData, pts);
            } else {
                this.mHandler.notifyEncodeIllegalArgumentException(new IllegalArgumentException("libyuv failure"));
            }
            if (this.networkWeakTriggered) {
                this.networkWeakTriggered = false;
                this.mHandler.notifyNetworkResume();
                return;
            }
            return;
        }
        throw new UnsupportedOperationException("Not implemented");
    }

    public void onGetArgbFrame(int[] data, int width, int height) {
        AtomicInteger videoFrameCacheNumber = this.flvMuxer.getVideoFrameCacheNumber();
        if (videoFrameCacheNumber == null || videoFrameCacheNumber.get() >= 24) {
            this.mHandler.notifyNetworkWeak();
            this.networkWeakTriggered = true;
            return;
        }
        long pts = (System.nanoTime() / 1000) - this.mPresentTimeUs;
        if (!this.useSoftEncoder) {
            byte[] processedData = hwArgbFrame(data, width, height);
            if (processedData != null) {
                onProcessedYuvFrame(processedData, pts);
            } else {
                this.mHandler.notifyEncodeIllegalArgumentException(new IllegalArgumentException("libyuv failure"));
            }
            if (this.networkWeakTriggered) {
                this.networkWeakTriggered = false;
                this.mHandler.notifyNetworkResume();
                return;
            }
            return;
        }
        throw new UnsupportedOperationException("Not implemented");
    }

    private byte[] hwRgbaFrame(byte[] data, int width, int height) {
        int i = this.mVideoColorFormat;
        if (i == 19) {
            return RGBAToI420(data, width, height, true, 180);
        }
        if (i == 21) {
            return RGBAToNV12(data, width, height, true, 180);
        }
        throw new IllegalStateException("Unsupported color format!");
    }

    private byte[] hwYUVNV21FrameScaled(byte[] data, int width, int height, Rect boundingBox) {
        int i = this.mVideoColorFormat;
        if (i == 19) {
            return NV21ToI420Scaled(data, width, height, true, 180, boundingBox.left, boundingBox.top, boundingBox.width(), boundingBox.height());
        }
        if (i == 21) {
            return NV21ToNV12Scaled(data, width, height, true, 180, boundingBox.left, boundingBox.top, boundingBox.width(), boundingBox.height());
        }
        throw new IllegalStateException("Unsupported color format!");
    }

    private byte[] hwArgbFrameScaled(int[] data, int width, int height, Rect boundingBox) {
        int i = this.mVideoColorFormat;
        if (i == 19) {
            return ARGBToI420Scaled(data, width, height, false, 0, boundingBox.left, boundingBox.top, boundingBox.width(), boundingBox.height());
        }
        if (i == 21) {
            return ARGBToNV12Scaled(data, width, height, false, 0, boundingBox.left, boundingBox.top, boundingBox.width(), boundingBox.height());
        }
        throw new IllegalStateException("Unsupported color format!");
    }

    private byte[] hwArgbFrame(int[] data, int inputWidth, int inputHeight) {
        int i = this.mVideoColorFormat;
        if (i == 19) {
            return ARGBToI420(data, inputWidth, inputHeight, false, 0);
        }
        if (i == 21) {
            return ARGBToNV12(data, inputWidth, inputHeight, false, 0);
        }
        throw new IllegalStateException("Unsupported color format!");
    }

    private void swRgbaFrame(byte[] data, int width, int height, long pts) {
        RGBASoftEncode(data, width, height, true, 180, pts);
    }

    public AudioRecord chooseAudioRecord() {
        AudioRecord mic = new AudioRecord(7, 44100, 12, 2, getPcmBufferSize() * 4);
        if (mic.getState() != 1) {
            AudioRecord mic2 = new AudioRecord(7, 44100, 16, 2, getPcmBufferSize() * 4);
            if (mic2.getState() != 1) {
                return null;
            }
            aChannelConfig = 16;
            return mic2;
        }
        aChannelConfig = 12;
        return mic;
    }

    private int getPcmBufferSize() {
        int pcmBufSize = AudioRecord.getMinBufferSize(44100, 12, 2) + 8191;
        return pcmBufSize - (pcmBufSize % 8192);
    }

    private MediaCodecInfo chooseVideoEncoder(String name) {
        int nbCodecs = MediaCodecList.getCodecCount();
        for (int i = 0; i < nbCodecs; i++) {
            MediaCodecInfo mci = MediaCodecList.getCodecInfoAt(i);
            if (mci.isEncoder()) {
                String[] types = mci.getSupportedTypes();
                for (int j = 0; j < types.length; j++) {
                    if (types[j].equalsIgnoreCase("video/avc")) {
                        Log.i(TAG, String.format("vencoder %s types: %s", mci.getName(), types[j]));
                        if (name == null || mci.getName().contains(name)) {
                            return mci;
                        }
                    }
                }
                continue;
            }
        }
        return null;
    }

    private int chooseVideoEncoder() {
        MediaCodecInfo chooseVideoEncoder = chooseVideoEncoder(null);
        this.vmci = chooseVideoEncoder;
        int matchedColorFormat = 0;
        MediaCodecInfo.CodecCapabilities cc = chooseVideoEncoder.getCapabilitiesForType("video/avc");
        for (int i = 0; i < cc.colorFormats.length; i++) {
            int cf = cc.colorFormats[i];
            Log.i(TAG, String.format("vencoder %s supports color fomart 0x%x(%d)", this.vmci.getName(), Integer.valueOf(cf), Integer.valueOf(cf)));
            if (cf >= 19 && cf <= 21 && cf > matchedColorFormat) {
                matchedColorFormat = cf;
            }
        }
        for (int i2 = 0; i2 < cc.profileLevels.length; i2++) {
            MediaCodecInfo.CodecProfileLevel pl2 = cc.profileLevels[i2];
            Log.i(TAG, String.format("vencoder %s support profile %d, level %d", this.vmci.getName(), Integer.valueOf(pl2.profile), Integer.valueOf(pl2.level)));
        }
        Log.i(TAG, String.format("vencoder %s choose color format 0x%x(%d)", this.vmci.getName(), Integer.valueOf(matchedColorFormat), Integer.valueOf(matchedColorFormat)));
        return matchedColorFormat;
    }
}
