package net.ossrs.yasea;

import android.media.MediaCodec;
import android.media.MediaFormat;
import android.util.Log;
import com.coremedia.iso.BoxParser;
import com.coremedia.iso.IsoFile;
import com.coremedia.iso.IsoTypeWriter;
import com.coremedia.iso.boxes.AbstractMediaHeaderBox;
import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.ContainerBox;
import com.coremedia.iso.boxes.DataEntryUrlBox;
import com.coremedia.iso.boxes.DataInformationBox;
import com.coremedia.iso.boxes.DataReferenceBox;
import com.coremedia.iso.boxes.FileTypeBox;
import com.coremedia.iso.boxes.HandlerBox;
import com.coremedia.iso.boxes.MediaBox;
import com.coremedia.iso.boxes.MediaHeaderBox;
import com.coremedia.iso.boxes.MediaInformationBox;
import com.coremedia.iso.boxes.MovieBox;
import com.coremedia.iso.boxes.MovieHeaderBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SampleSizeBox;
import com.coremedia.iso.boxes.SampleTableBox;
import com.coremedia.iso.boxes.SampleToChunkBox;
import com.coremedia.iso.boxes.SoundMediaHeaderBox;
import com.coremedia.iso.boxes.StaticChunkOffsetBox;
import com.coremedia.iso.boxes.SyncSampleBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.TrackBox;
import com.coremedia.iso.boxes.TrackHeaderBox;
import com.coremedia.iso.boxes.VideoMediaHeaderBox;
import com.coremedia.iso.boxes.h264.AvcConfigurationBox;
import com.coremedia.iso.boxes.mdat.MediaDataBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.coremedia.iso.boxes.sampleentry.VisualSampleEntry;
import com.googlecode.mp4parser.boxes.mp4.ESDescriptorBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.AudioSpecificConfig;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.DecoderConfigDescriptor;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.ESDescriptor;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.SLConfigDescriptor;
import com.googlecode.mp4parser.util.Math;
import com.googlecode.mp4parser.util.Matrix;
import com.tencent.ugc.TXRecordCommon;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.ReadableByteChannel;
import java.nio.channels.WritableByteChannel;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentLinkedQueue;
import net.ossrs.yasea.SrsFlvMuxer;

public class SrsMp4Muxer {
    private static final int AUDIO_TRACK = 101;
    private static final String TAG = "SrsMp4Muxer";
    private static final int VIDEO_TRACK = 100;
    private static Map<Integer, Integer> samplingFrequencyIndexMap;
    private boolean aacSpecConfig = false;
    private MediaFormat audioFormat = null;
    private SrsRawH264Stream avc = new SrsRawH264Stream();
    private volatile boolean bPaused = false;
    private volatile boolean bRecording = false;
    private FileChannel fc = null;
    private volatile long flushBytes = 0;
    private FileOutputStream fos = null;
    private ConcurrentLinkedQueue<SrsEsFrame> frameCache = new ConcurrentLinkedQueue<>();
    private ByteBuffer h264_pps = null;
    private ByteBuffer h264_sps = null;
    private SrsRecordHandler mHandler;
    private File mRecFile;
    private InterleaveChunkMdat mdat = null;
    private volatile long mdatOffset = 0;
    private Mp4Movie mp4Movie = new Mp4Movie();
    private volatile boolean needToFindKeyFrame = true;
    private ArrayList<byte[]> ppsList = new ArrayList<>();
    private volatile long recFileSize = 0;
    private ArrayList<byte[]> spsList = new ArrayList<>();
    private HashMap<Track, long[]> track2SampleSizes = new HashMap<>();
    private MediaFormat videoFormat = null;
    private Thread worker;
    private final Object writeLock = new Object();

    static {
        HashMap hashMap = new HashMap();
        samplingFrequencyIndexMap = hashMap;
        hashMap.put(96000, 0);
        samplingFrequencyIndexMap.put(88200, 1);
        samplingFrequencyIndexMap.put(64000, 2);
        samplingFrequencyIndexMap.put(48000, 3);
        samplingFrequencyIndexMap.put(44100, 4);
        samplingFrequencyIndexMap.put(32000, 5);
        samplingFrequencyIndexMap.put(24000, 6);
        samplingFrequencyIndexMap.put(Integer.valueOf((int) SrsFlvMuxer.SrsCodecAudioSampleRate.R22050), 7);
        samplingFrequencyIndexMap.put(16000, 8);
        samplingFrequencyIndexMap.put(12000, 9);
        samplingFrequencyIndexMap.put(Integer.valueOf((int) SrsFlvMuxer.SrsCodecAudioSampleRate.R11025), 10);
        samplingFrequencyIndexMap.put(Integer.valueOf((int) TXRecordCommon.AUDIO_SAMPLERATE_8000), 11);
    }

    public SrsMp4Muxer(SrsRecordHandler handler) {
        this.mHandler = handler;
    }

    public boolean record(File outputFile) {
        if (this.videoFormat == null && this.audioFormat == null) {
            return false;
        }
        this.mRecFile = outputFile;
        createMovie(outputFile);
        this.mHandler.notifyRecordStarted(this.mRecFile.getPath());
        if (!this.spsList.isEmpty() && !this.ppsList.isEmpty()) {
            this.mp4Movie.addTrack(this.videoFormat, false);
        }
        this.mp4Movie.addTrack(this.audioFormat, true);
        Thread thread = new Thread(new Runnable() {
            /* class net.ossrs.yasea.SrsMp4Muxer.AnonymousClass1 */

            public void run() {
                SrsMp4Muxer.this.bRecording = true;
                while (SrsMp4Muxer.this.bRecording) {
                    while (!SrsMp4Muxer.this.frameCache.isEmpty()) {
                        SrsEsFrame frame = (SrsEsFrame) SrsMp4Muxer.this.frameCache.poll();
                        SrsMp4Muxer.this.writeSampleData((SrsMp4Muxer) frame.bb, (ByteBuffer) frame.bi, (MediaCodec.BufferInfo) frame.is_audio());
                    }
                    synchronized (SrsMp4Muxer.this.writeLock) {
                        try {
                            SrsMp4Muxer.this.writeLock.wait(500);
                        } catch (InterruptedException e) {
                            SrsMp4Muxer.this.worker.interrupt();
                        }
                    }
                }
            }
        });
        this.worker = thread;
        thread.start();
        return true;
    }

    public void pause() {
        if (this.bRecording) {
            this.bPaused = true;
            this.mHandler.notifyRecordPause();
        }
    }

    public void resume() {
        if (this.bRecording) {
            this.bPaused = false;
            this.needToFindKeyFrame = true;
            this.mHandler.notifyRecordResume();
        }
    }

    public void stop() {
        this.bRecording = false;
        this.bPaused = false;
        this.needToFindKeyFrame = true;
        this.aacSpecConfig = false;
        this.frameCache.clear();
        Thread thread = this.worker;
        if (thread != null) {
            try {
                thread.join();
            } catch (InterruptedException e) {
                e.printStackTrace();
                this.worker.interrupt();
            }
            this.worker = null;
            finishMovie();
            this.mHandler.notifyRecordFinished(this.mRecFile.getPath());
        }
        Log.i(TAG, "SrsMp4Muxer closed");
    }

    public int addTrack(MediaFormat format) {
        if (format.getString("mime").contentEquals("video/avc")) {
            this.videoFormat = format;
            return 100;
        }
        this.audioFormat = format;
        return 101;
    }

    public void writeSampleData(int trackIndex, ByteBuffer byteBuf, MediaCodec.BufferInfo bufferInfo) {
        if (100 == trackIndex) {
            writeVideoSample(byteBuf, bufferInfo);
        } else {
            writeAudioSample(byteBuf, bufferInfo);
        }
    }

    private class SrsAvcNaluType {
        public static final int AccessUnitDelimiter = 9;
        public static final int CodedSliceExt = 20;
        public static final int DataPartitionA = 2;
        public static final int DataPartitionB = 3;
        public static final int DataPartitionC = 4;
        public static final int EOSequence = 10;
        public static final int EOStream = 11;
        public static final int FilterData = 12;
        public static final int IDR = 5;
        public static final int LayerWithoutPartition = 19;
        public static final int NonIDR = 1;
        public static final int PPS = 8;
        public static final int PrefixNALU = 14;
        public static final int Reserved = 0;
        public static final int SEI = 6;
        public static final int SPS = 7;
        public static final int SPSExt = 13;
        public static final int SubsetSPS = 15;

        private SrsAvcNaluType() {
        }
    }

    private void writeVideoSample(ByteBuffer bb, MediaCodec.BufferInfo bi) {
        int nal_unit_type = bb.get(4) & 31;
        boolean z = true;
        if (nal_unit_type == 5 || nal_unit_type == 1) {
            if (nal_unit_type != 5) {
                z = false;
            }
            writeFrameByte(100, bb, bi, z);
            return;
        }
        while (bb.position() < bi.size) {
            SrsEsFrameBytes frame = this.avc.annexb_demux(bb, bi);
            if (this.avc.is_sps(frame)) {
                if (!frame.data.equals(this.h264_sps)) {
                    byte[] sps = new byte[frame.size];
                    frame.data.get(sps);
                    this.h264_sps = ByteBuffer.wrap(sps);
                    this.spsList.clear();
                    this.spsList.add(sps);
                }
            } else if (this.avc.is_pps(frame) && !frame.data.equals(this.h264_pps)) {
                byte[] pps = new byte[frame.size];
                frame.data.get(pps);
                this.h264_pps = ByteBuffer.wrap(pps);
                this.ppsList.clear();
                this.ppsList.add(pps);
            }
        }
    }

    private void writeAudioSample(ByteBuffer bb, MediaCodec.BufferInfo bi) {
        if (!this.aacSpecConfig) {
            this.aacSpecConfig = true;
        } else {
            writeFrameByte(101, bb, bi, false);
        }
    }

    private void writeFrameByte(int track, ByteBuffer bb, MediaCodec.BufferInfo bi, boolean isKeyFrame) {
        SrsEsFrame frame = new SrsEsFrame();
        frame.bb = bb;
        frame.bi = bi;
        frame.isKeyFrame = isKeyFrame;
        frame.track = track;
        if (this.bRecording && !this.bPaused) {
            if (!this.needToFindKeyFrame) {
                this.frameCache.add(frame);
                synchronized (this.writeLock) {
                    this.writeLock.notifyAll();
                }
            } else if (frame.isKeyFrame) {
                this.needToFindKeyFrame = false;
                this.frameCache.add(frame);
                synchronized (this.writeLock) {
                    this.writeLock.notifyAll();
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public class SrsAnnexbSearch {
        public boolean match;
        public int nb_start_code;

        private SrsAnnexbSearch() {
            this.nb_start_code = 0;
            this.match = false;
        }
    }

    /* access modifiers changed from: private */
    public class SrsEsFrameBytes {
        public ByteBuffer data;
        public int size;

        private SrsEsFrameBytes() {
        }
    }

    /* access modifiers changed from: private */
    public class SrsEsFrame {
        public ByteBuffer bb;
        public MediaCodec.BufferInfo bi;
        public boolean isKeyFrame;
        public int track;

        private SrsEsFrame() {
        }

        public boolean is_video() {
            return this.track == 100;
        }

        public boolean is_audio() {
            return this.track == 101;
        }
    }

    /* access modifiers changed from: private */
    public class SrsRawH264Stream {
        private SrsRawH264Stream() {
        }

        public boolean is_sps(SrsEsFrameBytes frame) {
            if (frame.size >= 1 && (frame.data.get(0) & 31) == 7) {
                return true;
            }
            return false;
        }

        public boolean is_pps(SrsEsFrameBytes frame) {
            if (frame.size >= 1 && (frame.data.get(0) & 31) == 8) {
                return true;
            }
            return false;
        }

        public SrsAnnexbSearch srs_avc_startswith_annexb(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            SrsAnnexbSearch as = new SrsAnnexbSearch();
            as.match = false;
            int pos = bb.position();
            while (true) {
                if (pos >= bi.size - 3 || bb.get(pos) != 0 || bb.get(pos + 1) != 0) {
                    break;
                } else if (bb.get(pos + 2) == 1) {
                    as.match = true;
                    as.nb_start_code = (pos + 3) - bb.position();
                    break;
                } else {
                    pos++;
                }
            }
            return as;
        }

        public SrsEsFrameBytes annexb_demux(ByteBuffer bb, MediaCodec.BufferInfo bi) {
            SrsEsFrameBytes tbb = new SrsEsFrameBytes();
            if (bb.position() < bi.size) {
                SrsAnnexbSearch tbbsc = srs_avc_startswith_annexb(bb, bi);
                if (!tbbsc.match || tbbsc.nb_start_code < 3) {
                    Log.e(SrsMp4Muxer.TAG, "annexb not match.");
                    SrsMp4Muxer.this.mHandler.notifyRecordIllegalArgumentException(new IllegalArgumentException(String.format("annexb not match for %dB, pos=%d", Integer.valueOf(bi.size), Integer.valueOf(bb.position()))));
                }
                bb.slice();
                for (int i = 0; i < tbbsc.nb_start_code; i++) {
                    bb.get();
                }
                tbb.data = bb.slice();
                int pos = bb.position();
                while (bb.position() < bi.size && !srs_avc_startswith_annexb(bb, bi).match) {
                    bb.get();
                }
                tbb.size = bb.position() - pos;
            }
            return tbb;
        }
    }

    /* access modifiers changed from: private */
    public class Sample {
        private long offset = 0;
        private long size = 0;

        public Sample(long offset2, long size2) {
            this.offset = offset2;
            this.size = size2;
        }

        public long getOffset() {
            return this.offset;
        }

        public long getSize() {
            return this.size;
        }
    }

    /* access modifiers changed from: private */
    public class Track {
        private Date creationTime = new Date();
        private long duration = 0;
        private boolean first;
        private String handler;
        private AbstractMediaHeaderBox headerBox = null;
        private int height;
        private boolean isAudio;
        private long lastPresentationTimeUs;
        private SampleDescriptionBox sampleDescriptionBox = null;
        private ArrayList<Long> sampleDurations;
        private ArrayList<Sample> samples = new ArrayList<>();
        private LinkedList<Integer> syncSamples = null;
        private int timeScale;
        private int trackId = 0;
        private float volume = 0.0f;
        private int width;

        public Track(int id, MediaFormat format, boolean audio) {
            ArrayList<Long> arrayList = new ArrayList<>();
            this.sampleDurations = arrayList;
            this.isAudio = false;
            this.lastPresentationTimeUs = 0;
            this.first = true;
            this.trackId = id;
            this.isAudio = audio;
            if (!audio) {
                arrayList.add(3015L);
                this.duration = 3015;
                this.width = format.getInteger("width");
                this.height = format.getInteger("height");
                this.timeScale = 90000;
                this.syncSamples = new LinkedList<>();
                this.handler = "vide";
                this.headerBox = new VideoMediaHeaderBox();
                this.sampleDescriptionBox = new SampleDescriptionBox();
                if (format.getString("mime").contentEquals("video/avc")) {
                    VisualSampleEntry visualSampleEntry = new VisualSampleEntry(VisualSampleEntry.TYPE3);
                    visualSampleEntry.setDataReferenceIndex(1);
                    visualSampleEntry.setDepth(24);
                    visualSampleEntry.setFrameCount(1);
                    visualSampleEntry.setHorizresolution(72.0d);
                    visualSampleEntry.setVertresolution(72.0d);
                    visualSampleEntry.setWidth(this.width);
                    visualSampleEntry.setHeight(this.height);
                    visualSampleEntry.setCompressorname("AVC Coding");
                    AvcConfigurationBox avcConfigurationBox = new AvcConfigurationBox();
                    avcConfigurationBox.setConfigurationVersion(1);
                    avcConfigurationBox.setAvcProfileIndication(SrsMp4Muxer.this.h264_sps.get(1));
                    avcConfigurationBox.setProfileCompatibility(0);
                    avcConfigurationBox.setAvcLevelIndication(SrsMp4Muxer.this.h264_sps.get(3));
                    avcConfigurationBox.setLengthSizeMinusOne(3);
                    avcConfigurationBox.setSequenceParameterSets(SrsMp4Muxer.this.spsList);
                    avcConfigurationBox.setPictureParameterSets(SrsMp4Muxer.this.ppsList);
                    avcConfigurationBox.setBitDepthLumaMinus8(-1);
                    avcConfigurationBox.setBitDepthChromaMinus8(-1);
                    avcConfigurationBox.setChromaFormat(-1);
                    avcConfigurationBox.setHasExts(false);
                    visualSampleEntry.addBox(avcConfigurationBox);
                    this.sampleDescriptionBox.addBox(visualSampleEntry);
                    return;
                }
                return;
            }
            arrayList.add(1024L);
            this.duration = 1024;
            this.volume = 1.0f;
            this.timeScale = format.getInteger("sample-rate");
            this.handler = "soun";
            this.headerBox = new SoundMediaHeaderBox();
            this.sampleDescriptionBox = new SampleDescriptionBox();
            AudioSampleEntry audioSampleEntry = new AudioSampleEntry(AudioSampleEntry.TYPE3);
            audioSampleEntry.setChannelCount(format.getInteger("channel-count"));
            audioSampleEntry.setSampleRate((long) format.getInteger("sample-rate"));
            audioSampleEntry.setDataReferenceIndex(1);
            audioSampleEntry.setSampleSize(16);
            ESDescriptorBox esds = new ESDescriptorBox();
            ESDescriptor descriptor = new ESDescriptor();
            descriptor.setEsId(0);
            SLConfigDescriptor slConfigDescriptor = new SLConfigDescriptor();
            slConfigDescriptor.setPredefined(2);
            descriptor.setSlConfigDescriptor(slConfigDescriptor);
            DecoderConfigDescriptor decoderConfigDescriptor = new DecoderConfigDescriptor();
            decoderConfigDescriptor.setObjectTypeIndication(64);
            decoderConfigDescriptor.setStreamType(5);
            decoderConfigDescriptor.setBufferSizeDB(1536);
            decoderConfigDescriptor.setMaxBitRate(96000);
            decoderConfigDescriptor.setAvgBitRate(96000);
            AudioSpecificConfig audioSpecificConfig = new AudioSpecificConfig();
            audioSpecificConfig.setAudioObjectType(2);
            audioSpecificConfig.setSamplingFrequencyIndex(((Integer) SrsMp4Muxer.samplingFrequencyIndexMap.get(Integer.valueOf((int) audioSampleEntry.getSampleRate()))).intValue());
            audioSpecificConfig.setChannelConfiguration(audioSampleEntry.getChannelCount());
            decoderConfigDescriptor.setAudioSpecificInfo(audioSpecificConfig);
            descriptor.setDecoderConfigDescriptor(decoderConfigDescriptor);
            ByteBuffer data = descriptor.serialize();
            esds.setEsDescriptor(descriptor);
            esds.setData(data);
            audioSampleEntry.addBox(esds);
            this.sampleDescriptionBox.addBox(audioSampleEntry);
        }

        public void addSample(long offset, MediaCodec.BufferInfo bi) {
            long delta = bi.presentationTimeUs - this.lastPresentationTimeUs;
            if (delta >= 0) {
                boolean isSyncFrame = !this.isAudio && (bi.flags & 1) != 0;
                this.samples.add(new Sample(offset, (long) bi.size));
                LinkedList<Integer> linkedList = this.syncSamples;
                if (linkedList != null && isSyncFrame) {
                    linkedList.add(Integer.valueOf(this.samples.size()));
                }
                long delta2 = ((((long) this.timeScale) * delta) + 500000) / 1000000;
                this.lastPresentationTimeUs = bi.presentationTimeUs;
                if (!this.first) {
                    ArrayList<Long> arrayList = this.sampleDurations;
                    arrayList.add(arrayList.size() - 1, Long.valueOf(delta2));
                    this.duration += delta2;
                }
                this.first = false;
            }
        }

        public void clearSample() {
            this.first = true;
            this.samples.clear();
            this.syncSamples.clear();
            this.sampleDurations.clear();
        }

        public ArrayList<Sample> getSamples() {
            return this.samples;
        }

        public long getDuration() {
            return this.duration;
        }

        public String getHandler() {
            return this.handler;
        }

        public AbstractMediaHeaderBox getMediaHeaderBox() {
            return this.headerBox;
        }

        public SampleDescriptionBox getSampleDescriptionBox() {
            return this.sampleDescriptionBox;
        }

        public long[] getSyncSamples() {
            LinkedList<Integer> linkedList = this.syncSamples;
            if (linkedList == null || linkedList.isEmpty()) {
                return null;
            }
            long[] returns = new long[this.syncSamples.size()];
            for (int i = 0; i < this.syncSamples.size(); i++) {
                returns[i] = (long) this.syncSamples.get(i).intValue();
            }
            return returns;
        }

        public int getTimeScale() {
            return this.timeScale;
        }

        public Date getCreationTime() {
            return this.creationTime;
        }

        public int getWidth() {
            return this.width;
        }

        public int getHeight() {
            return this.height;
        }

        public float getVolume() {
            return this.volume;
        }

        public ArrayList<Long> getSampleDurations() {
            return this.sampleDurations;
        }

        public boolean isAudio() {
            return this.isAudio;
        }

        public int getTrackId() {
            return this.trackId;
        }
    }

    /* access modifiers changed from: private */
    public class Mp4Movie {
        private Matrix matrix;
        private HashMap<Integer, Track> tracks;

        private Mp4Movie() {
            this.matrix = Matrix.ROTATE_0;
            this.tracks = new HashMap<>();
        }

        public Matrix getMatrix() {
            return this.matrix;
        }

        public HashMap<Integer, Track> getTracks() {
            return this.tracks;
        }

        public void addSample(int trackIndex, long offset, MediaCodec.BufferInfo bi) {
            this.tracks.get(Integer.valueOf(trackIndex)).addSample(offset, bi);
        }

        public void addTrack(MediaFormat format, boolean isAudio) {
            if (format == null) {
                return;
            }
            if (isAudio) {
                this.tracks.put(101, new Track(this.tracks.size(), format, true));
            } else {
                this.tracks.put(100, new Track(this.tracks.size(), format, false));
            }
        }

        public void removeTrack(int trackIndex) {
            this.tracks.remove(Integer.valueOf(trackIndex));
        }
    }

    /* access modifiers changed from: private */
    public class InterleaveChunkMdat implements Box {
        private long contentSize;
        private boolean first;
        private ByteBuffer header;
        private ContainerBox parent;

        private InterleaveChunkMdat() {
            this.first = true;
            this.header = ByteBuffer.allocate(16);
            this.contentSize = 1073741824;
        }

        @Override // com.coremedia.iso.boxes.Box
        public ContainerBox getParent() {
            return this.parent;
        }

        @Override // com.coremedia.iso.boxes.Box
        public void setParent(ContainerBox parent2) {
            this.parent = parent2;
        }

        public void setContentSize(long contentSize2) {
            this.contentSize = contentSize2;
        }

        public long getContentSize() {
            return this.contentSize;
        }

        @Override // com.coremedia.iso.boxes.Box
        public String getType() {
            return MediaDataBox.TYPE;
        }

        @Override // com.coremedia.iso.boxes.Box
        public long getSize() {
            return ((long) this.header.limit()) + this.contentSize;
        }

        public int getHeaderSize() {
            return this.header.limit();
        }

        private boolean isSmallBox(long contentSize2) {
            return ((long) this.header.limit()) + contentSize2 < 4294967296L;
        }

        @Override // com.coremedia.iso.boxes.Box
        public void getBox(WritableByteChannel writableByteChannel) {
            this.header.rewind();
            long size = getSize();
            if (isSmallBox(size)) {
                IsoTypeWriter.writeUInt32(this.header, size);
            } else {
                IsoTypeWriter.writeUInt32(this.header, 1);
            }
            this.header.put(IsoFile.fourCCtoBytes(MediaDataBox.TYPE));
            if (isSmallBox(size)) {
                this.header.put(new byte[8]);
            } else {
                IsoTypeWriter.writeUInt64(this.header, size);
            }
            this.header.rewind();
            try {
                writableByteChannel.write(this.header);
            } catch (IOException e) {
                SrsMp4Muxer.this.mHandler.notifyRecordIOException(e);
            }
        }

        @Override // com.coremedia.iso.boxes.Box
        public void parse(ReadableByteChannel readableByteChannel, ByteBuffer header2, long contentSize2, BoxParser boxParser) throws IOException {
        }
    }

    private void createMovie(File outputFile) {
        try {
            FileOutputStream fileOutputStream = new FileOutputStream(outputFile);
            this.fos = fileOutputStream;
            this.fc = fileOutputStream.getChannel();
            this.mdat = new InterleaveChunkMdat();
            this.mdatOffset = 0;
            FileTypeBox fileTypeBox = createFileTypeBox();
            fileTypeBox.getBox(this.fc);
            this.recFileSize += fileTypeBox.getSize();
        } catch (IOException e) {
            e.printStackTrace();
            this.mHandler.notifyRecordIOException(e);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void writeSampleData(ByteBuffer byteBuf, MediaCodec.BufferInfo bi, boolean isAudio) {
        int trackIndex = isAudio ? 101 : 100;
        if (this.mp4Movie.getTracks().containsKey(Integer.valueOf(trackIndex))) {
            try {
                if (this.mdat.first) {
                    this.mdat.setContentSize(0);
                    this.mdat.getBox(this.fc);
                    this.mdatOffset = this.recFileSize;
                    this.recFileSize += (long) this.mdat.getHeaderSize();
                    this.mdat.first = false;
                }
                this.mp4Movie.addSample(trackIndex, this.recFileSize, bi);
                byteBuf.position(bi.offset + (isAudio ? 0 : 4));
                byteBuf.limit(bi.offset + bi.size);
                if (!isAudio) {
                    ByteBuffer size = ByteBuffer.allocate(4);
                    size.position(0);
                    size.putInt(bi.size - 4);
                    size.position(0);
                    this.recFileSize += (long) this.fc.write(size);
                }
                int writeBytes = this.fc.write(byteBuf);
                this.recFileSize += (long) writeBytes;
                this.flushBytes += (long) writeBytes;
                if (this.flushBytes > 65536) {
                    this.fos.flush();
                    this.flushBytes = 0;
                }
            } catch (IOException e) {
                e.printStackTrace();
                this.mHandler.notifyRecordIOException(e);
            }
        }
    }

    private void finishMovie() {
        try {
            if (this.flushBytes > 0) {
                this.fos.flush();
                this.flushBytes = 0;
            }
            if (this.mdat.getSize() != 0) {
                long oldPosition = this.fc.position();
                this.fc.position(this.mdatOffset);
                this.mdat.setContentSize((this.recFileSize - ((long) this.mdat.getHeaderSize())) - this.mdatOffset);
                this.mdat.getBox(this.fc);
                this.fc.position(oldPosition);
                this.mdat.setContentSize(0);
                this.fos.flush();
            }
            for (Track track : this.mp4Movie.getTracks().values()) {
                List<Sample> samples = track.getSamples();
                long[] sizes = new long[samples.size()];
                for (int i = 0; i < sizes.length; i++) {
                    sizes[i] = samples.get(i).getSize();
                }
                this.track2SampleSizes.put(track, sizes);
            }
            createMovieBox(this.mp4Movie).getBox(this.fc);
            this.fos.flush();
            this.fc.close();
            this.fos.close();
            this.mp4Movie.getTracks().clear();
            this.track2SampleSizes.clear();
            this.recFileSize = 0;
            this.flushBytes = 0;
        } catch (IOException e) {
            this.mHandler.notifyRecordIOException(e);
        }
    }

    private FileTypeBox createFileTypeBox() {
        LinkedList<String> minorBrands = new LinkedList<>();
        minorBrands.add("isom");
        minorBrands.add("3gp4");
        return new FileTypeBox("isom", 0, minorBrands);
    }

    private long getTimescale(Mp4Movie mp4Movie2) {
        long timescale = 0;
        if (!mp4Movie2.getTracks().isEmpty()) {
            timescale = (long) mp4Movie2.getTracks().values().iterator().next().getTimeScale();
        }
        for (Track track : mp4Movie2.getTracks().values()) {
            timescale = Math.gcd((long) track.getTimeScale(), timescale);
        }
        return timescale;
    }

    private MovieBox createMovieBox(Mp4Movie movie) {
        MovieBox movieBox = new MovieBox();
        MovieHeaderBox mvhd = new MovieHeaderBox();
        mvhd.setCreationTime(new Date());
        mvhd.setModificationTime(new Date());
        mvhd.setMatrix(Matrix.ROTATE_0);
        long movieTimeScale = getTimescale(movie);
        long duration = 0;
        for (Track track : movie.getTracks().values()) {
            long tracksDuration = (track.getDuration() * movieTimeScale) / ((long) track.getTimeScale());
            if (tracksDuration > duration) {
                duration = tracksDuration;
            }
        }
        mvhd.setDuration(duration);
        mvhd.setTimescale(movieTimeScale);
        mvhd.setNextTrackId((long) (movie.getTracks().size() + 1));
        movieBox.addBox(mvhd);
        for (Track track2 : movie.getTracks().values()) {
            movieBox.addBox(createTrackBox(track2, movie));
        }
        return movieBox;
    }

    private TrackBox createTrackBox(Track track, Mp4Movie movie) {
        TrackBox trackBox = new TrackBox();
        TrackHeaderBox tkhd = new TrackHeaderBox();
        tkhd.setEnabled(true);
        tkhd.setInMovie(true);
        tkhd.setInPreview(true);
        if (track.isAudio()) {
            tkhd.setMatrix(Matrix.ROTATE_0);
        } else {
            tkhd.setMatrix(movie.getMatrix());
        }
        tkhd.setAlternateGroup(0);
        tkhd.setCreationTime(track.getCreationTime());
        tkhd.setModificationTime(track.getCreationTime());
        tkhd.setDuration((track.getDuration() * getTimescale(movie)) / ((long) track.getTimeScale()));
        tkhd.setHeight((double) track.getHeight());
        tkhd.setWidth((double) track.getWidth());
        tkhd.setLayer(0);
        tkhd.setModificationTime(new Date());
        tkhd.setTrackId((long) (track.getTrackId() + 1));
        tkhd.setVolume(track.getVolume());
        trackBox.addBox(tkhd);
        MediaBox mdia = new MediaBox();
        trackBox.addBox(mdia);
        MediaHeaderBox mdhd = new MediaHeaderBox();
        mdhd.setCreationTime(track.getCreationTime());
        mdhd.setModificationTime(track.getCreationTime());
        mdhd.setDuration(track.getDuration());
        mdhd.setTimescale((long) track.getTimeScale());
        mdhd.setLanguage("eng");
        mdia.addBox(mdhd);
        HandlerBox hdlr = new HandlerBox();
        hdlr.setName(track.isAudio() ? "SoundHandle" : "VideoHandle");
        hdlr.setHandlerType(track.getHandler());
        mdia.addBox(hdlr);
        MediaInformationBox minf = new MediaInformationBox();
        minf.addBox(track.getMediaHeaderBox());
        DataInformationBox dinf = new DataInformationBox();
        DataReferenceBox dref = new DataReferenceBox();
        dinf.addBox(dref);
        DataEntryUrlBox url = new DataEntryUrlBox();
        url.setFlags(1);
        dref.addBox(url);
        minf.addBox(dinf);
        minf.addBox(createStbl(track));
        mdia.addBox(minf);
        return trackBox;
    }

    private Box createStbl(Track track) {
        SampleTableBox stbl = new SampleTableBox();
        createStsd(track, stbl);
        createStts(track, stbl);
        createStss(track, stbl);
        createStsc(track, stbl);
        createStsz(track, stbl);
        createStco(track, stbl);
        return stbl;
    }

    private void createStsd(Track track, SampleTableBox stbl) {
        stbl.addBox(track.getSampleDescriptionBox());
    }

    private void createStts(Track track, SampleTableBox stbl) {
        TimeToSampleBox.Entry lastEntry = null;
        List<TimeToSampleBox.Entry> entries = new ArrayList<>();
        Iterator<Long> it = track.getSampleDurations().iterator();
        while (it.hasNext()) {
            long delta = it.next().longValue();
            if (lastEntry == null || lastEntry.getDelta() != delta) {
                lastEntry = new TimeToSampleBox.Entry(1, delta);
                entries.add(lastEntry);
            } else {
                lastEntry.setCount(lastEntry.getCount() + 1);
            }
        }
        TimeToSampleBox stts = new TimeToSampleBox();
        stts.setEntries(entries);
        stbl.addBox(stts);
    }

    private void createStss(Track track, SampleTableBox stbl) {
        long[] syncSamples = track.getSyncSamples();
        if (syncSamples != null && syncSamples.length > 0) {
            SyncSampleBox stss = new SyncSampleBox();
            stss.setSampleNumber(syncSamples);
            stbl.addBox(stss);
        }
    }

    private void createStsc(Track track, SampleTableBox stbl) {
        int samplesCount;
        SampleToChunkBox stsc = new SampleToChunkBox();
        stsc.setEntries(new LinkedList());
        int lastChunkNumber = 1;
        int lastSampleCount = 0;
        int previousWritedChunkCount = -1;
        int samplesCount2 = track.getSamples().size();
        int a = 0;
        while (a < samplesCount2) {
            Sample sample = track.getSamples().get(a);
            long lastOffset = sample.getOffset() + sample.getSize();
            lastSampleCount++;
            boolean write = false;
            if (a == samplesCount2 - 1) {
                write = true;
            } else if (lastOffset != track.getSamples().get(a + 1).getOffset()) {
                write = true;
            }
            if (write) {
                if (previousWritedChunkCount != lastSampleCount) {
                    samplesCount = samplesCount2;
                    stsc.getEntries().add(new SampleToChunkBox.Entry((long) lastChunkNumber, (long) lastSampleCount, 1));
                    previousWritedChunkCount = lastSampleCount;
                } else {
                    samplesCount = samplesCount2;
                }
                lastSampleCount = 0;
                lastChunkNumber++;
            } else {
                samplesCount = samplesCount2;
            }
            a++;
            samplesCount2 = samplesCount;
        }
        stbl.addBox(stsc);
    }

    private void createStsz(Track track, SampleTableBox stbl) {
        SampleSizeBox stsz = new SampleSizeBox();
        stsz.setSampleSizes(this.track2SampleSizes.get(track));
        stbl.addBox(stsz);
    }

    private void createStco(Track track, SampleTableBox stbl) {
        ArrayList<Long> chunksOffsets = new ArrayList<>();
        long lastOffset = -1;
        Iterator<Sample> it = track.getSamples().iterator();
        while (it.hasNext()) {
            Sample sample = it.next();
            long offset = sample.getOffset();
            if (!(lastOffset == -1 || lastOffset == offset)) {
                lastOffset = -1;
            }
            if (lastOffset == -1) {
                chunksOffsets.add(Long.valueOf(offset));
            }
            lastOffset = offset + sample.getSize();
        }
        long[] chunkOffsetsLong = new long[chunksOffsets.size()];
        for (int a = 0; a < chunksOffsets.size(); a++) {
            chunkOffsetsLong[a] = chunksOffsets.get(a).longValue();
        }
        StaticChunkOffsetBox stco = new StaticChunkOffsetBox();
        stco.setChunkOffsets(chunkOffsetsLong);
        stbl.addBox(stco);
    }
}
