package net.ossrs.yasea;

import android.hardware.Camera;
import android.media.AudioRecord;
import android.media.audiofx.AcousticEchoCanceler;
import android.media.audiofx.AutomaticGainControl;
import android.os.Process;
import com.github.faucamp.simplertmp.RtmpHandler;
import com.seu.magicfilter.utils.MagicFilterType;
import java.io.File;
import net.ossrs.yasea.SrsCameraView;

public class SrsPublisher {
    private static AcousticEchoCanceler aec;
    private static AutomaticGainControl agc;
    private static AudioRecord mic;
    private Thread aworker;
    private long lastTimeMillis;
    private SrsCameraView mCameraView;
    private SrsEncoder mEncoder;
    private SrsFlvMuxer mFlvMuxer;
    private SrsMp4Muxer mMp4Muxer;
    private byte[] mPcmBuffer = new byte[4096];
    private double mSamplingFps;
    private boolean sendAudioOnly = false;
    private boolean sendVideoOnly = false;
    private int videoFrameCount;

    public SrsPublisher(SrsCameraView view) {
        this.mCameraView = view;
        view.setPreviewCallback(new SrsCameraView.PreviewCallback() {
            /* class net.ossrs.yasea.SrsPublisher.AnonymousClass1 */

            @Override // net.ossrs.yasea.SrsCameraView.PreviewCallback
            public void onGetRgbaFrame(byte[] data, int width, int height) {
                SrsPublisher.this.calcSamplingFps();
                if (!SrsPublisher.this.sendAudioOnly) {
                    SrsPublisher.this.mEncoder.onGetRgbaFrame(data, width, height);
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void calcSamplingFps() {
        int i = this.videoFrameCount;
        if (i == 0) {
            this.lastTimeMillis = System.nanoTime() / 1000000;
            this.videoFrameCount++;
            return;
        }
        int i2 = i + 1;
        this.videoFrameCount = i2;
        if (i2 >= 48) {
            this.mSamplingFps = (((double) this.videoFrameCount) * 1000.0d) / ((double) ((System.nanoTime() / 1000000) - this.lastTimeMillis));
            this.videoFrameCount = 0;
        }
    }

    public void startCamera() {
        this.mCameraView.startCamera();
    }

    public void stopCamera() {
        this.mCameraView.stopCamera();
    }

    public void startAudio() {
        AudioRecord chooseAudioRecord = this.mEncoder.chooseAudioRecord();
        mic = chooseAudioRecord;
        if (chooseAudioRecord != null) {
            if (AcousticEchoCanceler.isAvailable()) {
                AcousticEchoCanceler create = AcousticEchoCanceler.create(mic.getAudioSessionId());
                aec = create;
                if (create != null) {
                    create.setEnabled(true);
                }
            }
            if (AutomaticGainControl.isAvailable()) {
                AutomaticGainControl create2 = AutomaticGainControl.create(mic.getAudioSessionId());
                agc = create2;
                if (create2 != null) {
                    create2.setEnabled(true);
                }
            }
            Thread thread = new Thread(new Runnable() {
                /* class net.ossrs.yasea.SrsPublisher.AnonymousClass2 */

                public void run() {
                    int size;
                    Process.setThreadPriority(-16);
                    SrsPublisher.mic.startRecording();
                    while (!Thread.interrupted()) {
                        if (SrsPublisher.this.sendVideoOnly) {
                            SrsPublisher.this.mEncoder.onGetPcmFrame(SrsPublisher.this.mPcmBuffer, SrsPublisher.this.mPcmBuffer.length);
                            try {
                                Thread.sleep(20);
                            } catch (InterruptedException e) {
                                return;
                            }
                        } else if (SrsPublisher.mic != null && (size = SrsPublisher.mic.read(SrsPublisher.this.mPcmBuffer, 0, SrsPublisher.this.mPcmBuffer.length)) > 0) {
                            SrsPublisher.this.mEncoder.onGetPcmFrame(SrsPublisher.this.mPcmBuffer, size);
                        }
                    }
                }
            });
            this.aworker = thread;
            thread.start();
        }
    }

    public void stopAudio() {
        Thread thread = this.aworker;
        if (thread != null) {
            thread.interrupt();
            try {
                this.aworker.join();
            } catch (InterruptedException e) {
                this.aworker.interrupt();
            }
            this.aworker = null;
        }
        AudioRecord audioRecord = mic;
        if (audioRecord != null) {
            audioRecord.setRecordPositionUpdateListener(null);
            mic.stop();
            mic.release();
            mic = null;
        }
        AcousticEchoCanceler acousticEchoCanceler = aec;
        if (acousticEchoCanceler != null) {
            acousticEchoCanceler.setEnabled(false);
            aec.release();
            aec = null;
        }
        AutomaticGainControl automaticGainControl = agc;
        if (automaticGainControl != null) {
            automaticGainControl.setEnabled(false);
            agc.release();
            agc = null;
        }
    }

    public void startEncode() {
        if (this.mEncoder.start()) {
            this.mCameraView.enableEncoding();
            startAudio();
        }
    }

    public void stopEncode() {
        stopAudio();
        stopCamera();
        this.mEncoder.stop();
    }

    public void pauseEncode() {
        stopAudio();
        this.mCameraView.disableEncoding();
        this.mCameraView.stopTorch();
    }

    private void resumeEncode() {
        startAudio();
        this.mCameraView.enableEncoding();
    }

    public void startPublish(String rtmpUrl) {
        SrsFlvMuxer srsFlvMuxer = this.mFlvMuxer;
        if (srsFlvMuxer != null) {
            srsFlvMuxer.start(rtmpUrl);
            this.mFlvMuxer.setVideoResolution(this.mEncoder.getOutputWidth(), this.mEncoder.getOutputHeight());
            startEncode();
        }
    }

    public void resumePublish() {
        if (this.mFlvMuxer != null) {
            this.mEncoder.resume();
            resumeEncode();
        }
    }

    public void stopPublish() {
        if (this.mFlvMuxer != null) {
            stopEncode();
            this.mFlvMuxer.stop();
        }
    }

    public void pausePublish() {
        if (this.mFlvMuxer != null) {
            this.mEncoder.pause();
            pauseEncode();
        }
    }

    public boolean startRecord(String recPath) {
        SrsMp4Muxer srsMp4Muxer = this.mMp4Muxer;
        return srsMp4Muxer != null && srsMp4Muxer.record(new File(recPath));
    }

    public void stopRecord() {
        SrsMp4Muxer srsMp4Muxer = this.mMp4Muxer;
        if (srsMp4Muxer != null) {
            srsMp4Muxer.stop();
        }
    }

    public void pauseRecord() {
        SrsMp4Muxer srsMp4Muxer = this.mMp4Muxer;
        if (srsMp4Muxer != null) {
            srsMp4Muxer.pause();
        }
    }

    public void resumeRecord() {
        SrsMp4Muxer srsMp4Muxer = this.mMp4Muxer;
        if (srsMp4Muxer != null) {
            srsMp4Muxer.resume();
        }
    }

    public boolean isAllFramesUploaded() {
        return this.mFlvMuxer.getVideoFrameCacheNumber().get() == 0;
    }

    public int getVideoFrameCacheCount() {
        SrsFlvMuxer srsFlvMuxer = this.mFlvMuxer;
        if (srsFlvMuxer != null) {
            return srsFlvMuxer.getVideoFrameCacheNumber().get();
        }
        return 0;
    }

    public void switchToSoftEncoder() {
        this.mEncoder.switchToSoftEncoder();
    }

    public void switchToHardEncoder() {
        this.mEncoder.switchToHardEncoder();
    }

    public boolean isSoftEncoder() {
        return this.mEncoder.isSoftEncoder();
    }

    public int getPreviewWidth() {
        return this.mEncoder.getPreviewWidth();
    }

    public int getPreviewHeight() {
        return this.mEncoder.getPreviewHeight();
    }

    public double getmSamplingFps() {
        return this.mSamplingFps;
    }

    public int getCameraId() {
        return this.mCameraView.getCameraId();
    }

    public Camera getCamera() {
        return this.mCameraView.getCamera();
    }

    public void setPreviewResolution(int width, int height) {
        int[] resolution = this.mCameraView.setPreviewResolution(width, height);
        this.mEncoder.setPreviewResolution(resolution[0], resolution[1]);
    }

    public void setPreviewResolutionLand(int width, int height) {
        int[] resolution = this.mCameraView.setPreviewResolutionLand(width, height);
        this.mEncoder.setPreviewResolution(resolution[0], resolution[1]);
    }

    public void setOutputResolution(int width, int height) {
        if (width <= height) {
            this.mEncoder.setPortraitResolution(width, height);
        } else {
            this.mEncoder.setLandscapeResolution(width, height);
        }
    }

    public void setScreenOrientation(int orientation) {
        this.mCameraView.setPreviewOrientation(orientation);
        this.mEncoder.setScreenOrientation(orientation);
    }

    public void setVideoHDMode() {
        this.mEncoder.setVideoHDMode();
    }

    public void setVideoSmoothMode() {
        this.mEncoder.setVideoSmoothMode();
    }

    public void setSendVideoOnly(boolean flag) {
        AudioRecord audioRecord = mic;
        if (audioRecord != null) {
            if (flag) {
                audioRecord.stop();
                this.mPcmBuffer = new byte[4096];
            } else {
                audioRecord.startRecording();
            }
        }
        this.sendVideoOnly = flag;
    }

    public void setSendAudioOnly(boolean flag) {
        this.sendAudioOnly = flag;
    }

    public boolean switchCameraFilter(MagicFilterType type, int progress) {
        return this.mCameraView.setFilter(type, progress);
    }

    public boolean switchCameraFilter(MagicFilterType type) {
        return this.mCameraView.setFilter(type, 0);
    }

    public void switchCameraFace(int id) {
        this.mCameraView.stopCamera();
        this.mCameraView.setCameraId(id);
        if (id == 0) {
            this.mEncoder.setCameraBackFace();
        } else {
            this.mEncoder.setCameraFrontFace();
        }
        SrsEncoder srsEncoder = this.mEncoder;
        if (srsEncoder != null && srsEncoder.isEnabled()) {
            this.mCameraView.enableEncoding();
        }
        this.mCameraView.startCamera();
    }

    public void setRtmpHandler(RtmpHandler handler) {
        SrsFlvMuxer srsFlvMuxer = new SrsFlvMuxer(handler);
        this.mFlvMuxer = srsFlvMuxer;
        SrsEncoder srsEncoder = this.mEncoder;
        if (srsEncoder != null) {
            srsEncoder.setFlvMuxer(srsFlvMuxer);
        }
    }

    public void setRecordHandler(SrsRecordHandler handler) {
        SrsMp4Muxer srsMp4Muxer = new SrsMp4Muxer(handler);
        this.mMp4Muxer = srsMp4Muxer;
        SrsEncoder srsEncoder = this.mEncoder;
        if (srsEncoder != null) {
            srsEncoder.setMp4Muxer(srsMp4Muxer);
        }
    }

    public void setEncodeHandler(SrsEncodeHandler handler) {
        SrsEncoder srsEncoder = new SrsEncoder(handler);
        this.mEncoder = srsEncoder;
        SrsFlvMuxer srsFlvMuxer = this.mFlvMuxer;
        if (srsFlvMuxer != null) {
            srsEncoder.setFlvMuxer(srsFlvMuxer);
        }
        SrsMp4Muxer srsMp4Muxer = this.mMp4Muxer;
        if (srsMp4Muxer != null) {
            this.mEncoder.setMp4Muxer(srsMp4Muxer);
        }
    }
}
