package net.ossrs.yasea;

import android.os.Handler;
import android.os.Message;
import java.io.IOException;
import java.lang.ref.WeakReference;

public class SrsRecordHandler extends Handler {
    private static final int MSG_RECORD_FINISHED = 3;
    private static final int MSG_RECORD_ILLEGEL_ARGUMENT_EXCEPTION = 4;
    private static final int MSG_RECORD_IO_EXCEPTION = 5;
    private static final int MSG_RECORD_PAUSE = 0;
    private static final int MSG_RECORD_RESUME = 1;
    private static final int MSG_RECORD_STARTED = 2;
    private WeakReference<SrsRecordListener> mWeakListener;

    public interface SrsRecordListener {
        void onRecordFinished(String str);

        void onRecordIOException(IOException iOException);

        void onRecordIllegalArgumentException(IllegalArgumentException illegalArgumentException);

        void onRecordPause();

        void onRecordResume();

        void onRecordStarted(String str);
    }

    public SrsRecordHandler(SrsRecordListener listener) {
        this.mWeakListener = new WeakReference<>(listener);
    }

    public void notifyRecordPause() {
        sendEmptyMessage(0);
    }

    public void notifyRecordResume() {
        sendEmptyMessage(1);
    }

    public void notifyRecordStarted(String msg) {
        obtainMessage(2, msg).sendToTarget();
    }

    public void notifyRecordFinished(String msg) {
        obtainMessage(3, msg).sendToTarget();
    }

    public void notifyRecordIllegalArgumentException(IllegalArgumentException e) {
        obtainMessage(4, e).sendToTarget();
    }

    public void notifyRecordIOException(IOException e) {
        obtainMessage(5, e).sendToTarget();
    }

    public void handleMessage(Message msg) {
        SrsRecordListener listener = this.mWeakListener.get();
        if (listener != null) {
            int i = msg.what;
            if (i == 0) {
                listener.onRecordPause();
            } else if (i == 1) {
                listener.onRecordResume();
            } else if (i == 2) {
                listener.onRecordStarted((String) msg.obj);
            } else if (i == 3) {
                listener.onRecordFinished((String) msg.obj);
            } else if (i == 4) {
                listener.onRecordIllegalArgumentException((IllegalArgumentException) msg.obj);
            } else if (i == 5) {
                listener.onRecordIOException((IOException) msg.obj);
            } else {
                throw new RuntimeException("unknown msg " + msg.what);
            }
        }
    }
}
