package tv.cjump.jni;

import android.os.Build;
import android.os.Environment;
import android.text.TextUtils;
import android.util.Log;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.lang.reflect.Field;

public class DeviceUtils {
    public static final String ABI_MIPS = "mips";
    public static final String ABI_X86 = "x86";
    private static final int EM_386 = 3;
    private static final int EM_AARCH64 = 183;
    private static final int EM_ARM = 40;
    private static final int EM_MIPS = 8;
    private static ARCH sArch = ARCH.Unknown;

    public enum ARCH {
        Unknown,
        ARM,
        X86,
        MIPS,
        ARM64
    }

    public static synchronized ARCH getMyCpuArch() {
        synchronized (DeviceUtils.class) {
            byte[] data = new byte[20];
            File libc = new File(Environment.getRootDirectory(), "lib/libc.so");
            if (libc.canRead()) {
                RandomAccessFile fp = null;
                try {
                    RandomAccessFile fp2 = new RandomAccessFile(libc, "r");
                    fp2.readFully(data);
                    int machine = (data[19] << 8) | data[18];
                    if (machine == 3) {
                        sArch = ARCH.X86;
                    } else if (machine == 8) {
                        sArch = ARCH.MIPS;
                    } else if (machine == 40) {
                        sArch = ARCH.ARM;
                    } else if (machine != 183) {
                        Log.e("NativeBitmapFactory", "libc.so is unknown arch: " + Integer.toHexString(machine));
                    } else {
                        sArch = ARCH.ARM64;
                    }
                    try {
                        fp2.close();
                    } catch (IOException e) {
                        e = e;
                    }
                } catch (FileNotFoundException e2) {
                    e2.printStackTrace();
                    if (0 != 0) {
                        try {
                            fp.close();
                        } catch (IOException e3) {
                            e = e3;
                        }
                    }
                } catch (IOException e4) {
                    e4.printStackTrace();
                    if (0 != 0) {
                        try {
                            fp.close();
                        } catch (IOException e5) {
                            e = e5;
                        }
                    }
                } catch (Throwable th) {
                    if (0 != 0) {
                        try {
                            fp.close();
                        } catch (IOException e6) {
                            e6.printStackTrace();
                        }
                    }
                    throw th;
                }
            }
            ARCH arch = sArch;
        }
        return arch;
        e.printStackTrace();
        ARCH arch2 = sArch;
        return arch2;
    }

    public static String get_CPU_ABI() {
        return Build.CPU_ABI;
    }

    public static String get_CPU_ABI2() {
        try {
            Field field = Build.class.getDeclaredField("CPU_ABI2");
            if (field == null) {
                return null;
            }
            Object fieldValue = field.get(null);
            if (!(fieldValue instanceof String)) {
                return null;
            }
            return (String) fieldValue;
        } catch (Exception e) {
            return null;
        }
    }

    public static boolean supportABI(String requestAbi) {
        String abi = get_CPU_ABI();
        if (!TextUtils.isEmpty(abi) && abi.equalsIgnoreCase(requestAbi)) {
            return true;
        }
        if (TextUtils.isEmpty(get_CPU_ABI2()) || !abi.equalsIgnoreCase(requestAbi)) {
            return false;
        }
        return true;
    }

    public static boolean supportX86() {
        return supportABI(ABI_X86);
    }

    public static boolean supportMips() {
        return supportABI(ABI_MIPS);
    }

    public static boolean isARMSimulatedByX86() {
        return !supportX86() && ARCH.X86.equals(getMyCpuArch());
    }

    public static boolean isMiBox2Device() {
        return Build.MANUFACTURER.equalsIgnoreCase("Xiaomi") && Build.PRODUCT.equalsIgnoreCase("dredd");
    }

    public static boolean isMagicBoxDevice() {
        return Build.MANUFACTURER.equalsIgnoreCase("MagicBox") && Build.PRODUCT.equalsIgnoreCase("MagicBox");
    }

    public static boolean isProblemBoxDevice() {
        return isMiBox2Device() || isMagicBoxDevice();
    }

    public static boolean isRealARMArch() {
        return (supportABI("armeabi-v7a") || supportABI("armeabi")) && ARCH.ARM.equals(getMyCpuArch());
    }

    public static boolean isRealX86Arch() {
        return supportABI(ABI_X86) || ARCH.X86.equals(getMyCpuArch());
    }
}
