package tv.danmaku.ijk.media.player.misc;

import android.text.TextUtils;
import com.taobao.weex.el.parse.Operators;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import tv.danmaku.ijk.media.player.IjkMediaMeta;

public class IjkMediaFormat implements IMediaFormat {
    public static final String CODEC_NAME_H264 = "h264";
    public static final String KEY_IJK_BIT_RATE_UI = "ijk-bit-rate-ui";
    public static final String KEY_IJK_CHANNEL_UI = "ijk-channel-ui";
    public static final String KEY_IJK_CODEC_LONG_NAME_UI = "ijk-codec-long-name-ui";
    public static final String KEY_IJK_CODEC_NAME_UI = "ijk-codec-name-ui";
    public static final String KEY_IJK_CODEC_PIXEL_FORMAT_UI = "ijk-pixel-format-ui";
    public static final String KEY_IJK_CODEC_PROFILE_LEVEL_UI = "ijk-profile-level-ui";
    public static final String KEY_IJK_FRAME_RATE_UI = "ijk-frame-rate-ui";
    public static final String KEY_IJK_RESOLUTION_UI = "ijk-resolution-ui";
    public static final String KEY_IJK_SAMPLE_RATE_UI = "ijk-sample-rate-ui";
    private static final Map<String, Formatter> sFormatterMap = new HashMap();
    public final IjkMediaMeta.IjkStreamMeta mMediaFormat;

    public IjkMediaFormat(IjkMediaMeta.IjkStreamMeta streamMeta) {
        sFormatterMap.put("ijk-codec-long-name-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass1 */

            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                return IjkMediaFormat.this.mMediaFormat.getString("codec_long_name");
            }
        });
        sFormatterMap.put("ijk-codec-name-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass2 */

            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                return IjkMediaFormat.this.mMediaFormat.getString("codec_name");
            }
        });
        sFormatterMap.put("ijk-bit-rate-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass3 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                int bitRate = mediaFormat.getInteger("bitrate");
                if (bitRate <= 0) {
                    return null;
                }
                if (bitRate < 1000) {
                    return String.format(Locale.US, "%d bit/s", Integer.valueOf(bitRate));
                }
                return String.format(Locale.US, "%d kb/s", Integer.valueOf(bitRate / 1000));
            }
        });
        sFormatterMap.put("ijk-profile-level-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass4 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                String profile;
                switch (mediaFormat.getInteger("codec_profile_id")) {
                    case 44:
                        profile = "CAVLC 4:4:4";
                        break;
                    case 66:
                        profile = "Baseline";
                        break;
                    case 77:
                        profile = "Main";
                        break;
                    case 88:
                        profile = "Extended";
                        break;
                    case 100:
                        profile = "High";
                        break;
                    case 110:
                        profile = "High 10";
                        break;
                    case 122:
                        profile = "High 4:2:2";
                        break;
                    case 144:
                        profile = "High 4:4:4";
                        break;
                    case 244:
                        profile = "High 4:4:4 Predictive";
                        break;
                    case 578:
                        profile = "Constrained Baseline";
                        break;
                    case 2158:
                        profile = "High 10 Intra";
                        break;
                    case 2170:
                        profile = "High 4:2:2 Intra";
                        break;
                    case 2292:
                        profile = "High 4:4:4 Intra";
                        break;
                    default:
                        return null;
                }
                StringBuilder sb = new StringBuilder();
                sb.append(profile);
                String codecName = mediaFormat.getString("codec_name");
                if (!TextUtils.isEmpty(codecName) && codecName.equalsIgnoreCase("h264")) {
                    int level = mediaFormat.getInteger("codec_level");
                    if (level < 10) {
                        return sb.toString();
                    }
                    sb.append(" Profile Level ");
                    sb.append((level / 10) % 10);
                    if (level % 10 != 0) {
                        sb.append(Operators.DOT_STR);
                        sb.append(level % 10);
                    }
                }
                return sb.toString();
            }
        });
        sFormatterMap.put("ijk-pixel-format-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass5 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                return mediaFormat.getString("codec_pixel_format");
            }
        });
        sFormatterMap.put("ijk-resolution-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass6 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                int width = mediaFormat.getInteger("width");
                int height = mediaFormat.getInteger("height");
                int sarNum = mediaFormat.getInteger("sar_num");
                int sarDen = mediaFormat.getInteger("sar_den");
                if (width <= 0 || height <= 0) {
                    return null;
                }
                if (sarNum <= 0 || sarDen <= 0) {
                    return String.format(Locale.US, "%d x %d", Integer.valueOf(width), Integer.valueOf(height));
                }
                return String.format(Locale.US, "%d x %d [SAR %d:%d]", Integer.valueOf(width), Integer.valueOf(height), Integer.valueOf(sarNum), Integer.valueOf(sarDen));
            }
        });
        sFormatterMap.put("ijk-frame-rate-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass7 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                int fpsNum = mediaFormat.getInteger("fps_num");
                int fpsDen = mediaFormat.getInteger("fps_den");
                if (fpsNum <= 0 || fpsDen <= 0) {
                    return null;
                }
                return String.valueOf(((float) fpsNum) / ((float) fpsDen));
            }
        });
        sFormatterMap.put("ijk-sample-rate-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass8 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                int sampleRate = mediaFormat.getInteger("sample_rate");
                if (sampleRate <= 0) {
                    return null;
                }
                return String.format(Locale.US, "%d Hz", Integer.valueOf(sampleRate));
            }
        });
        sFormatterMap.put("ijk-channel-ui", new Formatter() {
            /* class tv.danmaku.ijk.media.player.misc.IjkMediaFormat.AnonymousClass9 */

            /* access modifiers changed from: protected */
            @Override // tv.danmaku.ijk.media.player.misc.IjkMediaFormat.Formatter
            public String doFormat(IjkMediaFormat mediaFormat) {
                int channelLayout = mediaFormat.getInteger("channel_layout");
                if (channelLayout <= 0) {
                    return null;
                }
                if (((long) channelLayout) == 4) {
                    return "mono";
                }
                if (((long) channelLayout) == 3) {
                    return "stereo";
                }
                return String.format(Locale.US, "%x", Integer.valueOf(channelLayout));
            }
        });
        this.mMediaFormat = streamMeta;
    }

    @Override // tv.danmaku.ijk.media.player.misc.IMediaFormat
    public int getInteger(String name) {
        IjkMediaMeta.IjkStreamMeta ijkStreamMeta = this.mMediaFormat;
        if (ijkStreamMeta == null) {
            return 0;
        }
        return ijkStreamMeta.getInt(name);
    }

    @Override // tv.danmaku.ijk.media.player.misc.IMediaFormat
    public String getString(String name) {
        if (this.mMediaFormat == null) {
            return null;
        }
        if (sFormatterMap.containsKey(name)) {
            return sFormatterMap.get(name).format(this);
        }
        return this.mMediaFormat.getString(name);
    }

    /* access modifiers changed from: private */
    public static abstract class Formatter {
        /* access modifiers changed from: protected */
        public abstract String doFormat(IjkMediaFormat ijkMediaFormat);

        private Formatter() {
        }

        public String format(IjkMediaFormat mediaFormat) {
            String value = doFormat(mediaFormat);
            if (TextUtils.isEmpty(value)) {
                return getDefaultString();
            }
            return value;
        }

        /* access modifiers changed from: protected */
        public String getDefaultString() {
            return "N/A";
        }
    }
}
