package com.alibaba.android.bindingx.core.internal;

import com.alibaba.android.bindingx.core.LogProxy;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.component.richtext.node.RichTextNode;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.json.JSONTokener;

/* access modifiers changed from: package-private */
public class Expression {
    private JSONObject root;

    Expression(String json) {
        try {
            this.root = (JSONObject) new JSONTokener(json).nextValue();
        } catch (Throwable e) {
            LogProxy.e("[Expression] expression is illegal. \n ", e);
        }
    }

    Expression(JSONObject root2) {
        this.root = root2;
    }

    /* access modifiers changed from: package-private */
    public Object execute(Map<String, Object> scope) throws IllegalArgumentException, JSONException {
        return execute(this.root, scope);
    }

    private double toNumber(Object value) {
        if (value instanceof String) {
            return Double.parseDouble((String) value);
        }
        if (value instanceof Boolean) {
            return ((Boolean) value).booleanValue() ? 1.0d : 0.0d;
        }
        return ((Double) value).doubleValue();
    }

    private boolean toBoolean(Object value) {
        if (value instanceof String) {
            return "".equals(value);
        }
        if (value instanceof Double) {
            return ((Double) value).doubleValue() != 0.0d;
        }
        return ((Boolean) value).booleanValue();
    }

    private String toString(Object value) {
        if (value instanceof Boolean) {
            return ((Boolean) value).booleanValue() ? AbsoluteConst.TRUE : AbsoluteConst.FALSE;
        }
        if (value instanceof Double) {
            return Double.toString(((Double) value).doubleValue());
        }
        return (String) value;
    }

    private boolean equal(Object v1, Object v2) {
        if (!(v1 instanceof JSObjectInterface) || !(v2 instanceof JSObjectInterface)) {
            if ((v1 instanceof String) && (v2 instanceof String)) {
                return v1.equals(v2);
            }
            if (!(v1 instanceof Boolean) || !(v2 instanceof Boolean)) {
                if (toNumber(v1) == toNumber(v2)) {
                    return true;
                }
                return false;
            } else if (toBoolean(v1) == toBoolean(v2)) {
                return true;
            } else {
                return false;
            }
        } else if (v1 == v2) {
            return true;
        } else {
            return false;
        }
    }

    private boolean strictlyEqual(Object v1, Object v2) {
        if ((v1 instanceof JSObjectInterface) && !(v2 instanceof JSObjectInterface)) {
            return false;
        }
        if ((v1 instanceof Boolean) && !(v2 instanceof Boolean)) {
            return false;
        }
        if ((v1 instanceof Double) && !(v2 instanceof Double)) {
            return false;
        }
        if ((!(v1 instanceof String) || (v2 instanceof String)) && v1 == v2) {
            return true;
        }
        return false;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private Object execute(JSONObject node, Map<String, Object> scope) throws IllegalArgumentException, JSONException {
        char c;
        String type = node.getString("type");
        JSONArray children = node.optJSONArray(RichTextNode.CHILDREN);
        boolean z = false;
        switch (type.hashCode()) {
            case -1746151498:
                if (type.equals("CallExpression")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 33:
                if (type.equals(Operators.AND_NOT)) {
                    c = 22;
                    break;
                }
                c = 65535;
                break;
            case 37:
                if (type.equals("%")) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case 42:
                if (type.equals("*")) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 43:
                if (type.equals(Operators.PLUS)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 45:
                if (type.equals("-")) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case 47:
                if (type.equals("/")) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 60:
                if (type.equals(Operators.L)) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case 62:
                if (type.equals(Operators.G)) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case 63:
                if (type.equals(Operators.CONDITION_IF_STRING)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 1084:
                if (type.equals(Operators.NOT_EQUAL2)) {
                    c = 18;
                    break;
                }
                c = 65535;
                break;
            case 1216:
                if (type.equals(Operators.AND)) {
                    c = 20;
                    break;
                }
                c = 65535;
                break;
            case 1344:
                if (type.equals("**")) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 1921:
                if (type.equals(Operators.LE)) {
                    c = 15;
                    break;
                }
                c = 65535;
                break;
            case 1952:
                if (type.equals(Operators.EQUAL2)) {
                    c = 16;
                    break;
                }
                c = 65535;
                break;
            case 1983:
                if (type.equals(Operators.GE)) {
                    c = 14;
                    break;
                }
                c = 65535;
                break;
            case 3968:
                if (type.equals(Operators.OR)) {
                    c = 21;
                    break;
                }
                c = 65535;
                break;
            case 33665:
                if (type.equals(Operators.NOT_EQUAL)) {
                    c = 19;
                    break;
                }
                c = 65535;
                break;
            case 60573:
                if (type.equals(Operators.EQUAL)) {
                    c = 17;
                    break;
                }
                c = 65535;
                break;
            case 189157634:
                if (type.equals("NumericLiteral")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 375032009:
                if (type.equals("Identifier")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 1074430782:
                if (type.equals("StringLiteral")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 1816238983:
                if (type.equals("BooleanLiteral")) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                return node.getString("value");
            case 1:
                return Double.valueOf(node.getDouble("value"));
            case 2:
                return Boolean.valueOf(node.getBoolean("value"));
            case 3:
                return scope.get(node.getString("value"));
            case 4:
                JSFunctionInterface function = (JSFunctionInterface) execute(children.getJSONObject(0), scope);
                ArrayList<Object> arguments = new ArrayList<>();
                JSONArray jsonArguments = children.getJSONObject(1).getJSONArray(RichTextNode.CHILDREN);
                for (int i = 0; i < jsonArguments.length(); i++) {
                    arguments.add(execute(jsonArguments.getJSONObject(i), scope));
                }
                return function.execute(arguments);
            case 5:
                if (((Boolean) execute(children.getJSONObject(0), scope)).booleanValue()) {
                    return execute(children.getJSONObject(1), scope);
                }
                return execute(children.getJSONObject(2), scope);
            case 6:
                return Double.valueOf(toNumber(execute(children.getJSONObject(0), scope)) + toNumber(execute(children.getJSONObject(1), scope)));
            case 7:
                return Double.valueOf(toNumber(execute(children.getJSONObject(0), scope)) - toNumber(execute(children.getJSONObject(1), scope)));
            case '\b':
                return Double.valueOf(toNumber(execute(children.getJSONObject(0), scope)) * toNumber(execute(children.getJSONObject(1), scope)));
            case '\t':
                return Double.valueOf(toNumber(execute(children.getJSONObject(0), scope)) / toNumber(execute(children.getJSONObject(1), scope)));
            case '\n':
                return Double.valueOf(toNumber(execute(children.getJSONObject(0), scope)) % toNumber(execute(children.getJSONObject(1), scope)));
            case 11:
                return Double.valueOf(Math.pow(toNumber(execute(children.getJSONObject(0), scope)), toNumber(execute(children.getJSONObject(1), scope))));
            case '\f':
                if (toNumber(execute(children.getJSONObject(0), scope)) > toNumber(execute(children.getJSONObject(1), scope))) {
                    z = true;
                }
                return Boolean.valueOf(z);
            case '\r':
                if (toNumber(execute(children.getJSONObject(0), scope)) < toNumber(execute(children.getJSONObject(1), scope))) {
                    z = true;
                }
                return Boolean.valueOf(z);
            case 14:
                if (toNumber(execute(children.getJSONObject(0), scope)) >= toNumber(execute(children.getJSONObject(1), scope))) {
                    z = true;
                }
                return Boolean.valueOf(z);
            case 15:
                if (toNumber(execute(children.getJSONObject(0), scope)) <= toNumber(execute(children.getJSONObject(1), scope))) {
                    z = true;
                }
                return Boolean.valueOf(z);
            case 16:
                return Boolean.valueOf(equal(execute(children.getJSONObject(0), scope), execute(children.getJSONObject(1), scope)));
            case 17:
                return Boolean.valueOf(strictlyEqual(execute(children.getJSONObject(0), scope), execute(children.getJSONObject(1), scope)));
            case 18:
                return Boolean.valueOf(!equal(execute(children.getJSONObject(0), scope), execute(children.getJSONObject(1), scope)));
            case 19:
                return Boolean.valueOf(!strictlyEqual(execute(children.getJSONObject(0), scope), execute(children.getJSONObject(1), scope)));
            case 20:
                Object result = execute(children.getJSONObject(0), scope);
                if (!toBoolean(result)) {
                    return result;
                }
                return execute(children.getJSONObject(1), scope);
            case 21:
                Object result2 = execute(children.getJSONObject(0), scope);
                if (toBoolean(result2)) {
                    return result2;
                }
                return execute(children.getJSONObject(1), scope);
            case 22:
                return Boolean.valueOf(!toBoolean(execute(children.getJSONObject(0), scope)));
            default:
                return null;
        }
    }
}
