package com.alibaba.android.bindingx.core.internal;

import com.taobao.weex.el.parse.Operators;

/* access modifiers changed from: package-private */
public class Quaternion {
    double w;
    double x;
    double y;
    double z;

    Quaternion() {
    }

    Quaternion(double x2, double y2, double z2, double w2) {
        this.x = x2;
        this.y = y2;
        this.z = z2;
        this.w = w2;
    }

    /* access modifiers changed from: package-private */
    public Quaternion setFromEuler(Euler euler) {
        if (euler == null || !euler.isEuler) {
            return null;
        }
        double c1 = Math.cos(euler.x / 2.0d);
        double c2 = Math.cos(euler.y / 2.0d);
        double c3 = Math.cos(euler.z / 2.0d);
        double s1 = Math.sin(euler.x / 2.0d);
        double s2 = Math.sin(euler.y / 2.0d);
        double s3 = Math.sin(euler.z / 2.0d);
        String order = euler.order;
        if ("XYZ".equals(order)) {
            this.x = (s1 * c2 * c3) + (c1 * s2 * s3);
            this.y = ((c1 * s2) * c3) - ((s1 * c2) * s3);
            this.z = (c1 * c2 * s3) + (s1 * s2 * c3);
            this.w = ((c1 * c2) * c3) - ((s1 * s2) * s3);
        } else if ("YXZ".equals(order)) {
            this.x = (s1 * c2 * c3) + (c1 * s2 * s3);
            this.y = ((c1 * s2) * c3) - ((s1 * c2) * s3);
            this.z = ((c1 * c2) * s3) - ((s1 * s2) * c3);
            this.w = (c1 * c2 * c3) + (s1 * s2 * s3);
        } else if ("ZXY".equals(order)) {
            this.x = ((s1 * c2) * c3) - ((c1 * s2) * s3);
            this.y = (c1 * s2 * c3) + (s1 * c2 * s3);
            this.z = (c1 * c2 * s3) + (s1 * s2 * c3);
            this.w = ((c1 * c2) * c3) - ((s1 * s2) * s3);
        } else if ("ZYX".equals(order)) {
            this.x = ((s1 * c2) * c3) - ((c1 * s2) * s3);
            this.y = (c1 * s2 * c3) + (s1 * c2 * s3);
            this.z = ((c1 * c2) * s3) - ((s1 * s2) * c3);
            this.w = (c1 * c2 * c3) + (s1 * s2 * s3);
        } else if ("YZX".equals(order)) {
            this.x = (s1 * c2 * c3) + (c1 * s2 * s3);
            this.y = (c1 * s2 * c3) + (s1 * c2 * s3);
            this.z = ((c1 * c2) * s3) - ((s1 * s2) * c3);
            this.w = ((c1 * c2) * c3) - ((s1 * s2) * s3);
        } else if ("XZY".equals(order)) {
            this.x = ((s1 * c2) * c3) - ((c1 * s2) * s3);
            this.y = ((c1 * s2) * c3) - ((s1 * c2) * s3);
            this.z = (c1 * c2 * s3) + (s1 * s2 * c3);
            this.w = (c1 * c2 * c3) + (s1 * s2 * s3);
        }
        return this;
    }

    /* access modifiers changed from: package-private */
    public Quaternion setFromAxisAngle(Vector3 axis, double angle) {
        double halfAngle = angle / 2.0d;
        double s = Math.sin(halfAngle);
        this.x = axis.x * s;
        this.y = axis.y * s;
        this.z = axis.z * s;
        this.w = Math.cos(halfAngle);
        return this;
    }

    /* access modifiers changed from: package-private */
    public Quaternion multiply(Quaternion q) {
        return multiplyQuaternions(this, q);
    }

    /* JADX INFO: Multiple debug info for r7v1 double: [D('qbw' double), D('qaz' double)] */
    /* access modifiers changed from: package-private */
    public Quaternion multiplyQuaternions(Quaternion a, Quaternion b) {
        double qax = a.x;
        double qay = a.y;
        double qaz = a.z;
        double qaw = a.w;
        double qbx = b.x;
        double qby = b.y;
        double qbz = b.z;
        double qaz2 = b.w;
        this.x = (((qax * qaz2) + (qaw * qbx)) + (qay * qbz)) - (qaz * qby);
        this.y = (((qay * qaz2) + (qaw * qby)) + (qaz * qbx)) - (qax * qbz);
        this.z = (((qaz * qaz2) + (qaw * qbz)) + (qax * qby)) - (qay * qbx);
        this.w = (((qaw * qaz2) - (qax * qbx)) - (qay * qby)) - (qaz * qbz);
        return this;
    }

    public String toString() {
        return "Quaternion{x=" + this.x + ", y=" + this.y + ", z=" + this.z + ", w=" + this.w + Operators.BLOCK_END;
    }
}
