package com.alibaba.fastjson;

import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.io.Reader;

public abstract class JSONValidator implements Cloneable, Closeable {
    protected char ch;
    protected int count = 0;
    protected boolean eof;
    protected int pos = -1;
    protected boolean supportMultiValue = false;
    protected Type type;
    private Boolean validateResult;

    public enum Type {
        Object,
        Array,
        Value
    }

    /* access modifiers changed from: package-private */
    public abstract void next();

    public static JSONValidator fromUtf8(byte[] jsonBytes) {
        return new UTF8Validator(jsonBytes);
    }

    public static JSONValidator fromUtf8(InputStream is) {
        return new UTF8InputStreamValidator(is);
    }

    public static JSONValidator from(String jsonStr) {
        return new UTF16Validator(jsonStr);
    }

    public static JSONValidator from(Reader r) {
        return new ReaderValidator(r);
    }

    public boolean isSupportMultiValue() {
        return this.supportMultiValue;
    }

    public JSONValidator setSupportMultiValue(boolean supportMultiValue2) {
        this.supportMultiValue = supportMultiValue2;
        return this;
    }

    public Type getType() {
        if (this.type == null) {
            validate();
        }
        return this.type;
    }

    public boolean validate() {
        Boolean bool = this.validateResult;
        if (bool != null) {
            return bool.booleanValue();
        }
        while (any()) {
            skipWhiteSpace();
            this.count++;
            if (this.eof) {
                this.validateResult = true;
                return true;
            } else if (this.supportMultiValue) {
                skipWhiteSpace();
                if (this.eof) {
                    this.validateResult = true;
                    return true;
                }
            } else {
                this.validateResult = false;
                return false;
            }
        }
        this.validateResult = false;
        return false;
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
    }

    /* JADX WARNING: Removed duplicated region for block: B:126:0x0189  */
    private boolean any() {
        char c;
        char c2;
        char c3;
        char c4;
        char c5;
        char c6 = this.ch;
        if (c6 != '\"') {
            if (!(c6 == '+' || c6 == '-')) {
                if (c6 == '[') {
                    next();
                    skipWhiteSpace();
                    if (this.ch == ']') {
                        next();
                        this.type = Type.Array;
                        return true;
                    }
                    while (any()) {
                        skipWhiteSpace();
                        char c7 = this.ch;
                        if (c7 == ',') {
                            next();
                            skipWhiteSpace();
                        } else if (c7 != ']') {
                            return false;
                        } else {
                            next();
                            this.type = Type.Array;
                            return true;
                        }
                    }
                    return false;
                } else if (c6 == 'f') {
                    next();
                    if (this.ch != 'a') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (this.ch != 's') {
                        return false;
                    }
                    next();
                    if (this.ch != 'e') {
                        return false;
                    }
                    next();
                    if (!isWhiteSpace(this.ch) && (c3 = this.ch) != ',' && c3 != ']' && c3 != '}' && c3 != 0) {
                        return false;
                    }
                    this.type = Type.Value;
                    return true;
                } else if (c6 == 'n') {
                    next();
                    if (this.ch != 'u') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (this.ch != 'l') {
                        return false;
                    }
                    next();
                    if (!isWhiteSpace(this.ch) && (c4 = this.ch) != ',' && c4 != ']' && c4 != '}' && c4 != 0) {
                        return false;
                    }
                    this.type = Type.Value;
                    return true;
                } else if (c6 == 't') {
                    next();
                    if (this.ch != 'r') {
                        return false;
                    }
                    next();
                    if (this.ch != 'u') {
                        return false;
                    }
                    next();
                    if (this.ch != 'e') {
                        return false;
                    }
                    next();
                    if (!isWhiteSpace(this.ch) && (c5 = this.ch) != ',' && c5 != ']' && c5 != '}' && c5 != 0) {
                        return false;
                    }
                    this.type = Type.Value;
                    return true;
                } else if (c6 != '{') {
                    switch (c6) {
                        case '0':
                        case '1':
                        case '2':
                        case '3':
                        case '4':
                        case '5':
                        case '6':
                        case '7':
                        case '8':
                        case '9':
                            break;
                        default:
                            return false;
                    }
                } else {
                    next();
                    while (isWhiteSpace(this.ch)) {
                        next();
                    }
                    if (this.ch == '}') {
                        next();
                        this.type = Type.Object;
                        return true;
                    }
                    while (this.ch == '\"') {
                        fieldName();
                        skipWhiteSpace();
                        if (this.ch != ':') {
                            return false;
                        }
                        next();
                        skipWhiteSpace();
                        if (!any()) {
                            return false;
                        }
                        skipWhiteSpace();
                        char c8 = this.ch;
                        if (c8 == ',') {
                            next();
                            skipWhiteSpace();
                        } else if (c8 != '}') {
                            return false;
                        } else {
                            next();
                            this.type = Type.Object;
                            return true;
                        }
                    }
                    return false;
                }
            }
            char c9 = this.ch;
            if (c9 == '-' || c9 == '+') {
                next();
                skipWhiteSpace();
                char c10 = this.ch;
                if (c10 < '0' || c10 > '9') {
                    return false;
                }
            }
            do {
                next();
                c = this.ch;
                if (c >= '0') {
                }
                if (this.ch == '.') {
                    next();
                    char c11 = this.ch;
                    if (c11 < '0' || c11 > '9') {
                        return false;
                    }
                    while (true) {
                        char c12 = this.ch;
                        if (c12 >= '0' && c12 <= '9') {
                            next();
                        }
                    }
                }
                char c13 = this.ch;
                if (c13 == 'e' || c13 == 'E') {
                    next();
                    char c14 = this.ch;
                    if (c14 == '-' || c14 == '+') {
                        next();
                    }
                    c2 = this.ch;
                    if (c2 >= '0' || c2 > '9') {
                        return false;
                    }
                    next();
                    while (true) {
                        char c15 = this.ch;
                        if (c15 >= '0' && c15 <= '9') {
                            next();
                        }
                    }
                }
                this.type = Type.Value;
                return true;
            } while (c <= '9');
            if (this.ch == '.') {
            }
            char c132 = this.ch;
            next();
            char c142 = this.ch;
            next();
            c2 = this.ch;
            if (c2 >= '0') {
            }
            return false;
        }
        next();
        while (!this.eof) {
            char c16 = this.ch;
            if (c16 == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c16 == '\"') {
                next();
                this.type = Type.Value;
                return true;
            } else {
                next();
            }
        }
        return false;
    }

    /* access modifiers changed from: protected */
    public void fieldName() {
        next();
        while (true) {
            char c = this.ch;
            if (c == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c == '\"') {
                next();
                return;
            } else {
                next();
            }
        }
    }

    /* access modifiers changed from: protected */
    public boolean string() {
        next();
        while (!this.eof) {
            char c = this.ch;
            if (c == '\\') {
                next();
                if (this.ch == 'u') {
                    next();
                    next();
                    next();
                    next();
                    next();
                } else {
                    next();
                }
            } else if (c == '\"') {
                next();
                return true;
            } else {
                next();
            }
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public void skipWhiteSpace() {
        while (isWhiteSpace(this.ch)) {
            next();
        }
    }

    static final boolean isWhiteSpace(char ch2) {
        return ch2 == ' ' || ch2 == '\t' || ch2 == '\r' || ch2 == '\n' || ch2 == '\f' || ch2 == '\b';
    }

    static class UTF8Validator extends JSONValidator {
        private final byte[] bytes;

        public UTF8Validator(byte[] bytes2) {
            this.bytes = bytes2;
            next();
            skipWhiteSpace();
        }

        /* access modifiers changed from: package-private */
        @Override // com.alibaba.fastjson.JSONValidator
        public void next() {
            this.pos++;
            int i = this.pos;
            byte[] bArr = this.bytes;
            if (i >= bArr.length) {
                this.ch = 0;
                this.eof = true;
                return;
            }
            this.ch = (char) bArr[this.pos];
        }
    }

    static class UTF8InputStreamValidator extends JSONValidator {
        private static final ThreadLocal<byte[]> bufLocal = new ThreadLocal<>();
        private byte[] buf;
        private int end = -1;
        private final InputStream is;
        private int readCount = 0;

        public UTF8InputStreamValidator(InputStream is2) {
            this.is = is2;
            byte[] bArr = bufLocal.get();
            this.buf = bArr;
            if (bArr != null) {
                bufLocal.set(null);
            } else {
                this.buf = new byte[8192];
            }
            next();
            skipWhiteSpace();
        }

        /* access modifiers changed from: package-private */
        @Override // com.alibaba.fastjson.JSONValidator
        public void next() {
            if (this.pos < this.end) {
                byte[] bArr = this.buf;
                int i = this.pos + 1;
                this.pos = i;
                this.ch = (char) bArr[i];
            } else if (!this.eof) {
                try {
                    int len = this.is.read(this.buf, 0, this.buf.length);
                    this.readCount++;
                    if (len > 0) {
                        this.ch = (char) this.buf[0];
                        this.pos = 0;
                        this.end = len - 1;
                    } else if (len == -1) {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = 0;
                        this.eof = true;
                    } else {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = 0;
                        this.eof = true;
                        throw new JSONException("read error");
                    }
                } catch (IOException e) {
                    throw new JSONException("read error");
                }
            }
        }

        @Override // java.io.Closeable, com.alibaba.fastjson.JSONValidator, java.lang.AutoCloseable
        public void close() throws IOException {
            bufLocal.set(this.buf);
            this.is.close();
        }
    }

    static class UTF16Validator extends JSONValidator {
        private final String str;

        public UTF16Validator(String str2) {
            this.str = str2;
            next();
            skipWhiteSpace();
        }

        /* access modifiers changed from: package-private */
        @Override // com.alibaba.fastjson.JSONValidator
        public void next() {
            this.pos++;
            if (this.pos >= this.str.length()) {
                this.ch = 0;
                this.eof = true;
                return;
            }
            this.ch = this.str.charAt(this.pos);
        }

        /* access modifiers changed from: protected */
        @Override // com.alibaba.fastjson.JSONValidator
        public final void fieldName() {
            char ch;
            int i = this.pos;
            while (true) {
                i++;
                if (i >= this.str.length() || (ch = this.str.charAt(i)) == '\\') {
                    next();
                } else if (ch == '\"') {
                    this.ch = this.str.charAt(i + 1);
                    this.pos = i + 1;
                    return;
                }
            }
            next();
            while (true) {
                if (this.ch == '\\') {
                    next();
                    if (this.ch == 'u') {
                        next();
                        next();
                        next();
                        next();
                        next();
                    } else {
                        next();
                    }
                } else if (this.ch == '\"') {
                    next();
                    return;
                } else if (!this.eof) {
                    next();
                } else {
                    return;
                }
            }
        }
    }

    static class ReaderValidator extends JSONValidator {
        private static final ThreadLocal<char[]> bufLocal = new ThreadLocal<>();
        private char[] buf;
        private int end = -1;
        final Reader r;
        private int readCount = 0;

        ReaderValidator(Reader r2) {
            this.r = r2;
            char[] cArr = bufLocal.get();
            this.buf = cArr;
            if (cArr != null) {
                bufLocal.set(null);
            } else {
                this.buf = new char[8192];
            }
            next();
            skipWhiteSpace();
        }

        /* access modifiers changed from: package-private */
        @Override // com.alibaba.fastjson.JSONValidator
        public void next() {
            if (this.pos < this.end) {
                char[] cArr = this.buf;
                int i = this.pos + 1;
                this.pos = i;
                this.ch = cArr[i];
            } else if (!this.eof) {
                try {
                    int len = this.r.read(this.buf, 0, this.buf.length);
                    this.readCount++;
                    if (len > 0) {
                        this.ch = this.buf[0];
                        this.pos = 0;
                        this.end = len - 1;
                    } else if (len == -1) {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = 0;
                        this.eof = true;
                    } else {
                        this.pos = 0;
                        this.end = 0;
                        this.buf = null;
                        this.ch = 0;
                        this.eof = true;
                        throw new JSONException("read error");
                    }
                } catch (IOException e) {
                    throw new JSONException("read error");
                }
            }
        }

        @Override // java.io.Closeable, com.alibaba.fastjson.JSONValidator, java.lang.AutoCloseable
        public void close() throws IOException {
            bufLocal.set(this.buf);
            this.r.close();
        }
    }
}
