package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.TypeReference;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.ParameterizedTypeImpl;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Map;

public class ArrayListTypeFieldDeserializer extends FieldDeserializer {
    private ObjectDeserializer deserializer;
    private int itemFastMatchToken;
    private final Type itemType;

    public ArrayListTypeFieldDeserializer(ParserConfig mapping, Class<?> clazz, FieldInfo fieldInfo) {
        super(clazz, fieldInfo);
        if (fieldInfo.fieldType instanceof ParameterizedType) {
            Type argType = ((ParameterizedType) fieldInfo.fieldType).getActualTypeArguments()[0];
            if (argType instanceof WildcardType) {
                Type[] upperBounds = ((WildcardType) argType).getUpperBounds();
                if (upperBounds.length == 1) {
                    argType = upperBounds[0];
                }
            }
            this.itemType = argType;
            return;
        }
        this.itemType = Object.class;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.FieldDeserializer
    public int getFastMatchToken() {
        return 14;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.FieldDeserializer
    public void parseField(DefaultJSONParser parser, Object object, Type objectType, Map<String, Object> fieldValues) {
        JSONLexer lexer = parser.lexer;
        int token = lexer.token();
        if (token != 8 && (token != 4 || lexer.stringVal().length() != 0)) {
            ArrayList list = new ArrayList();
            ParseContext context = parser.getContext();
            parser.setContext(context, object, this.fieldInfo.name);
            parseArray(parser, objectType, list);
            parser.setContext(context);
            if (object == null) {
                fieldValues.put(this.fieldInfo.name, list);
            } else {
                setValue(object, list);
            }
        } else if (object == null) {
            fieldValues.put(this.fieldInfo.name, null);
        } else {
            setValue(object, (String) null);
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:59:0x0136  */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x0190  */
    public final void parseArray(DefaultJSONParser parser, Type objectType, Collection array) {
        int token;
        ObjectDeserializer itemTypeDeser;
        ObjectDeserializer itemTypeDeser2;
        ObjectDeserializer itemTypeDeser3;
        Type itemType2 = this.itemType;
        ObjectDeserializer itemTypeDeser4 = this.deserializer;
        if (objectType instanceof ParameterizedType) {
            if (itemType2 instanceof TypeVariable) {
                TypeVariable typeVar = (TypeVariable) itemType2;
                ParameterizedType paramType = (ParameterizedType) objectType;
                Class<?> objectClass = null;
                if (paramType.getRawType() instanceof Class) {
                    objectClass = (Class) paramType.getRawType();
                }
                int paramIndex = -1;
                if (objectClass != null) {
                    int i = 0;
                    int size = objectClass.getTypeParameters().length;
                    while (true) {
                        if (i >= size) {
                            break;
                        } else if (objectClass.getTypeParameters()[i].getName().equals(typeVar.getName())) {
                            paramIndex = i;
                            break;
                        } else {
                            i++;
                        }
                    }
                }
                if (paramIndex != -1) {
                    itemType2 = paramType.getActualTypeArguments()[paramIndex];
                    if (!itemType2.equals(this.itemType)) {
                        itemTypeDeser4 = parser.getConfig().getDeserializer(itemType2);
                    }
                }
            } else if (itemType2 instanceof ParameterizedType) {
                ParameterizedType parameterizedItemType = (ParameterizedType) itemType2;
                Type[] itemActualTypeArgs = parameterizedItemType.getActualTypeArguments();
                if (itemActualTypeArgs.length != 1 || !(itemActualTypeArgs[0] instanceof TypeVariable)) {
                    itemTypeDeser3 = itemTypeDeser4;
                } else {
                    TypeVariable typeVar2 = (TypeVariable) itemActualTypeArgs[0];
                    ParameterizedType paramType2 = (ParameterizedType) objectType;
                    Class<?> objectClass2 = null;
                    if (paramType2.getRawType() instanceof Class) {
                        objectClass2 = (Class) paramType2.getRawType();
                    }
                    int paramIndex2 = -1;
                    if (objectClass2 != null) {
                        int i2 = 0;
                        int size2 = objectClass2.getTypeParameters().length;
                        while (true) {
                            if (i2 >= size2) {
                                itemTypeDeser3 = itemTypeDeser4;
                                break;
                            }
                            itemTypeDeser3 = itemTypeDeser4;
                            if (objectClass2.getTypeParameters()[i2].getName().equals(typeVar2.getName())) {
                                paramIndex2 = i2;
                                break;
                            } else {
                                i2++;
                                itemTypeDeser4 = itemTypeDeser3;
                            }
                        }
                    } else {
                        itemTypeDeser3 = itemTypeDeser4;
                    }
                    if (paramIndex2 != -1) {
                        itemActualTypeArgs[0] = paramType2.getActualTypeArguments()[paramIndex2];
                        itemType2 = TypeReference.intern(new ParameterizedTypeImpl(itemActualTypeArgs, parameterizedItemType.getOwnerType(), parameterizedItemType.getRawType()));
                    }
                }
                itemTypeDeser4 = itemTypeDeser3;
            } else {
                itemTypeDeser2 = itemTypeDeser4;
            }
            JSONLexer lexer = parser.lexer;
            token = lexer.token();
            if (token == 14) {
                if (itemTypeDeser4 == null) {
                    ObjectDeserializer itemTypeDeser5 = parser.getConfig().getDeserializer(itemType2);
                    this.deserializer = itemTypeDeser5;
                    this.itemFastMatchToken = itemTypeDeser5.getFastMatchToken();
                    itemTypeDeser = itemTypeDeser5;
                } else {
                    itemTypeDeser = itemTypeDeser4;
                }
                lexer.nextToken(this.itemFastMatchToken);
                int i3 = 0;
                while (true) {
                    if (lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                        while (lexer.token() == 16) {
                            lexer.nextToken();
                        }
                    }
                    if (lexer.token() == 15) {
                        lexer.nextToken(16);
                        return;
                    }
                    array.add(itemTypeDeser.deserialze(parser, itemType2, Integer.valueOf(i3)));
                    parser.checkListResolve(array);
                    if (lexer.token() == 16) {
                        lexer.nextToken(this.itemFastMatchToken);
                    }
                    i3++;
                }
            } else if (token != 4 || !this.fieldInfo.unwrapped) {
                if (itemTypeDeser4 == null) {
                    ObjectDeserializer deserializer2 = parser.getConfig().getDeserializer(itemType2);
                    this.deserializer = deserializer2;
                    itemTypeDeser4 = deserializer2;
                }
                array.add(itemTypeDeser4.deserialze(parser, itemType2, 0));
                parser.checkListResolve(array);
                return;
            } else {
                String str = lexer.stringVal();
                lexer.nextToken();
                new DefaultJSONParser(str).parseArray(array);
                return;
            }
        } else {
            itemTypeDeser2 = itemTypeDeser4;
            if ((itemType2 instanceof TypeVariable) && (objectType instanceof Class)) {
                Class objectClass3 = (Class) objectType;
                TypeVariable typeVar3 = (TypeVariable) itemType2;
                objectClass3.getTypeParameters();
                int i4 = 0;
                int size3 = objectClass3.getTypeParameters().length;
                while (true) {
                    if (i4 >= size3) {
                        break;
                    }
                    TypeVariable item = objectClass3.getTypeParameters()[i4];
                    if (item.getName().equals(typeVar3.getName())) {
                        Type[] bounds = item.getBounds();
                        if (bounds.length == 1) {
                            itemType2 = bounds[0];
                            itemTypeDeser4 = itemTypeDeser2;
                        }
                    } else {
                        i4++;
                    }
                }
                JSONLexer lexer2 = parser.lexer;
                token = lexer2.token();
                if (token == 14) {
                }
            }
        }
        itemTypeDeser4 = itemTypeDeser2;
        JSONLexer lexer22 = parser.lexer;
        token = lexer22.token();
        if (token == 14) {
        }
    }
}
