package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.FieldInfo;
import com.efs.sdk.base.Constants;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Map;
import java.util.zip.GZIPInputStream;

public class DefaultFieldDeserializer extends FieldDeserializer {
    protected boolean customDeserilizer = false;
    protected ObjectDeserializer fieldValueDeserilizer;

    public DefaultFieldDeserializer(ParserConfig config, Class<?> clazz, FieldInfo fieldInfo) {
        super(clazz, fieldInfo);
        boolean z = false;
        JSONField annotation = fieldInfo.getAnnotation();
        if (annotation != null) {
            Class<?> deserializeUsing = annotation.deserializeUsing();
            if (!(deserializeUsing == null || deserializeUsing == Void.class)) {
                z = true;
            }
            this.customDeserilizer = z;
        }
    }

    public ObjectDeserializer getFieldValueDeserilizer(ParserConfig config) {
        if (this.fieldValueDeserilizer == null) {
            JSONField annotation = this.fieldInfo.getAnnotation();
            if (annotation == null || annotation.deserializeUsing() == Void.class) {
                this.fieldValueDeserilizer = config.getDeserializer(this.fieldInfo.fieldClass, this.fieldInfo.fieldType);
            } else {
                try {
                    this.fieldValueDeserilizer = (ObjectDeserializer) annotation.deserializeUsing().newInstance();
                } catch (Exception ex) {
                    throw new JSONException("create deserializeUsing ObjectDeserializer error", ex);
                }
            }
        }
        return this.fieldValueDeserilizer;
    }

    /* JADX WARNING: Removed duplicated region for block: B:39:0x00c3 A[Catch:{ IOException -> 0x00c9 }] */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x00d9  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00e9  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x00bd A[EDGE_INSN: B:51:0x00bd->B:38:0x00bd ?: BREAK  , SYNTHETIC] */
    @Override // com.alibaba.fastjson.parser.deserializer.FieldDeserializer
    public void parseField(DefaultJSONParser parser, Object object, Type objectType, Map<String, Object> fieldValues) {
        Type fieldType;
        Object value;
        GZIPInputStream gzipIn;
        int len;
        if (this.fieldValueDeserilizer == null) {
            getFieldValueDeserilizer(parser.getConfig());
        }
        ObjectDeserializer fieldValueDeserilizer2 = this.fieldValueDeserilizer;
        Type fieldType2 = this.fieldInfo.fieldType;
        if (objectType instanceof ParameterizedType) {
            ParseContext objContext = parser.getContext();
            if (objContext != null) {
                objContext.type = objectType;
            }
            if (fieldType2 != objectType) {
                Type fieldType3 = FieldInfo.getFieldType(this.clazz, objectType, fieldType2);
                if (fieldValueDeserilizer2 instanceof JavaObjectDeserializer) {
                    fieldValueDeserilizer2 = parser.getConfig().getDeserializer(fieldType3);
                    fieldType = fieldType3;
                } else {
                    fieldType = fieldType3;
                }
                if (!(fieldValueDeserilizer2 instanceof JavaBeanDeserializer) && this.fieldInfo.parserFeatures != 0) {
                    value = ((JavaBeanDeserializer) fieldValueDeserilizer2).deserialze(parser, fieldType, this.fieldInfo.name, this.fieldInfo.parserFeatures);
                } else if ((this.fieldInfo.format == null || this.fieldInfo.parserFeatures != 0) && (fieldValueDeserilizer2 instanceof ContextObjectDeserializer)) {
                    value = ((ContextObjectDeserializer) fieldValueDeserilizer2).deserialze(parser, fieldType, this.fieldInfo.name, this.fieldInfo.format, this.fieldInfo.parserFeatures);
                } else {
                    value = fieldValueDeserilizer2.deserialze(parser, fieldType, this.fieldInfo.name);
                }
                if ((value instanceof byte[]) && (Constants.CP_GZIP.equals(this.fieldInfo.format) || "gzip,base64".equals(this.fieldInfo.format))) {
                    gzipIn = new GZIPInputStream(new ByteArrayInputStream((byte[]) value));
                    ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
                    while (true) {
                        byte[] buf = new byte[1024];
                        len = gzipIn.read(buf);
                        if (len != -1) {
                            break;
                        } else if (len > 0) {
                            byteOut.write(buf, 0, len);
                        }
                    }
                    value = byteOut.toByteArray();
                }
                if (parser.getResolveStatus() != 1) {
                    DefaultJSONParser.ResolveTask task = parser.getLastResolveTask();
                    task.fieldDeserializer = this;
                    task.ownerContext = parser.getContext();
                    parser.setResolveStatus(0);
                    return;
                } else if (object == null) {
                    fieldValues.put(this.fieldInfo.name, value);
                    return;
                } else {
                    setValue(object, value);
                    return;
                }
            }
        }
        fieldType = fieldType2;
        if (!(fieldValueDeserilizer2 instanceof JavaBeanDeserializer)) {
        }
        if (this.fieldInfo.format == null) {
        }
        value = ((ContextObjectDeserializer) fieldValueDeserilizer2).deserialze(parser, fieldType, this.fieldInfo.name, this.fieldInfo.format, this.fieldInfo.parserFeatures);
        try {
            gzipIn = new GZIPInputStream(new ByteArrayInputStream((byte[]) value));
            ByteArrayOutputStream byteOut2 = new ByteArrayOutputStream();
            while (true) {
                byte[] buf2 = new byte[1024];
                len = gzipIn.read(buf2);
                if (len != -1) {
                }
            }
            value = byteOut2.toByteArray();
            if (parser.getResolveStatus() != 1) {
            }
        } catch (IOException ex) {
            throw new JSONException("unzip bytes error.", ex);
        }
    }

    @Override // com.alibaba.fastjson.parser.deserializer.FieldDeserializer
    public int getFastMatchToken() {
        ObjectDeserializer objectDeserializer = this.fieldValueDeserilizer;
        if (objectDeserializer != null) {
            return objectDeserializer.getFastMatchToken();
        }
        return 2;
    }

    public void parseFieldUnwrapped(DefaultJSONParser parser, Object object, Type objectType, Map<String, Object> map) {
        throw new JSONException("TODO");
    }
}
