package com.alibaba.fastjson.util;

import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.asm.ClassReader;
import com.alibaba.fastjson.asm.TypeCollector;
import com.alipay.sdk.m.u.i;
import com.taobao.weex.el.parse.Operators;
import com.tencent.qphone.base.util.QLog;
import io.dcloud.common.util.ExifInterface;
import java.io.IOException;
import java.io.InputStream;
import java.lang.annotation.Annotation;
import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.lang.reflect.Type;

public class ASMUtils {
    public static final boolean IS_ANDROID;
    public static final String JAVA_VM_NAME;

    static {
        String property = System.getProperty("java.vm.name");
        JAVA_VM_NAME = property;
        IS_ANDROID = isAndroid(property);
    }

    public static boolean isAndroid(String vmName) {
        if (vmName == null) {
            return false;
        }
        String lowerVMName = vmName.toLowerCase();
        if (lowerVMName.contains("dalvik") || lowerVMName.contains("lemur")) {
            return true;
        }
        return false;
    }

    public static String desc(Method method) {
        Class<?>[] types = method.getParameterTypes();
        StringBuilder buf = new StringBuilder((types.length + 1) << 4);
        buf.append(Operators.BRACKET_START);
        for (Class<?> cls : types) {
            buf.append(desc(cls));
        }
        buf.append(Operators.BRACKET_END);
        buf.append(desc(method.getReturnType()));
        return buf.toString();
    }

    public static String desc(Class<?> returnType) {
        if (returnType.isPrimitive()) {
            return getPrimitiveLetter(returnType);
        }
        if (returnType.isArray()) {
            return Operators.ARRAY_START_STR + desc(returnType.getComponentType());
        }
        return "L" + type(returnType) + i.b;
    }

    public static String type(Class<?> parameterType) {
        if (parameterType.isArray()) {
            return Operators.ARRAY_START_STR + desc(parameterType.getComponentType());
        } else if (!parameterType.isPrimitive()) {
            return parameterType.getName().replace(Operators.DOT, '/');
        } else {
            return getPrimitiveLetter(parameterType);
        }
    }

    public static String getPrimitiveLetter(Class<?> type) {
        if (Integer.TYPE == type) {
            return "I";
        }
        if (Void.TYPE == type) {
            return ExifInterface.GPS_MEASUREMENT_INTERRUPTED;
        }
        if (Boolean.TYPE == type) {
            return "Z";
        }
        if (Character.TYPE == type) {
            return "C";
        }
        if (Byte.TYPE == type) {
            return "B";
        }
        if (Short.TYPE == type) {
            return ExifInterface.LATITUDE_SOUTH;
        }
        if (Float.TYPE == type) {
            return "F";
        }
        if (Long.TYPE == type) {
            return "J";
        }
        if (Double.TYPE == type) {
            return QLog.TAG_REPORTLEVEL_DEVELOPER;
        }
        throw new IllegalStateException("Type: " + type.getCanonicalName() + " is not a primitive type");
    }

    public static Type getMethodType(Class<?> clazz, String methodName) {
        try {
            return clazz.getMethod(methodName, new Class[0]).getGenericReturnType();
        } catch (Exception e) {
            return null;
        }
    }

    public static boolean checkName(String name) {
        for (int i = 0; i < name.length(); i++) {
            char c = name.charAt(i);
            if (c < 1 || c > 127 || c == '.') {
                return false;
            }
        }
        return true;
    }

    /* JADX INFO: Multiple debug info for r0v15 java.lang.annotation.Annotation[][]: [D('parameterAnnotations' java.lang.annotation.Annotation[][]), D('method' java.lang.reflect.Method)] */
    public static String[] lookupParameterNames(AccessibleObject methodOrCtor) {
        Annotation[][] parameterAnnotations;
        Class<?> declaringClass;
        String name;
        Class<?>[] types;
        ClassLoader classLoader;
        String fieldName;
        if (IS_ANDROID) {
            return new String[0];
        }
        if (methodOrCtor instanceof Method) {
            Method method = (Method) methodOrCtor;
            types = method.getParameterTypes();
            name = method.getName();
            declaringClass = method.getDeclaringClass();
            parameterAnnotations = TypeUtils.getParameterAnnotations(method);
        } else {
            Constructor<?> constructor = (Constructor) methodOrCtor;
            types = constructor.getParameterTypes();
            declaringClass = constructor.getDeclaringClass();
            name = "<init>";
            parameterAnnotations = TypeUtils.getParameterAnnotations(constructor);
        }
        if (types.length == 0) {
            return new String[0];
        }
        ClassLoader classLoader2 = declaringClass.getClassLoader();
        if (classLoader2 == null) {
            classLoader = ClassLoader.getSystemClassLoader();
        } else {
            classLoader = classLoader2;
        }
        String className = declaringClass.getName();
        InputStream is = classLoader.getResourceAsStream(className.replace(Operators.DOT, '/') + ".class");
        if (is == null) {
            return new String[0];
        }
        try {
            ClassReader reader = new ClassReader(is, false);
            TypeCollector visitor = new TypeCollector(name, types);
            reader.accept(visitor);
            String[] parameterNames = visitor.getParameterNamesForMethod();
            for (int i = 0; i < parameterNames.length; i++) {
                Annotation[] annotations = parameterAnnotations[i];
                if (annotations != null) {
                    for (int j = 0; j < annotations.length; j++) {
                        if ((annotations[j] instanceof JSONField) && (fieldName = ((JSONField) annotations[j]).name()) != null && fieldName.length() > 0) {
                            parameterNames[i] = fieldName;
                        }
                    }
                }
            }
            return parameterNames;
        } catch (IOException e) {
            return new String[0];
        } finally {
            IOUtils.close(is);
        }
    }
}
