package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONCreator;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONPOJOBuilder;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IApp;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;

public class JavaBeanInfo {
    public final Method buildMethod;
    public final Class<?> builderClass;
    public final Class<?> clazz;
    public final Constructor<?> creatorConstructor;
    public Type[] creatorConstructorParameterTypes;
    public String[] creatorConstructorParameters;
    public final Constructor<?> defaultConstructor;
    public final int defaultConstructorParameterSize;
    public final Method factoryMethod;
    public final FieldInfo[] fields;
    public final JSONType jsonType;

    /* renamed from: kotlin  reason: collision with root package name */
    public boolean f80kotlin;
    public Constructor<?> kotlinDefaultConstructor;
    public String[] orders;
    public final int parserFeatures;
    public final FieldInfo[] sortedFields;
    public final String typeKey;
    public final String typeName;

    /* JADX INFO: Multiple debug info for r0v21 java.lang.annotation.Annotation: [D('paramAnnotation' java.lang.annotation.Annotation), D('paramAnnotationArrays' java.lang.annotation.Annotation[][])] */
    public JavaBeanInfo(Class<?> clazz2, Class<?> builderClass2, Constructor<?> defaultConstructor2, Constructor<?> creatorConstructor2, Method factoryMethod2, Method buildMethod2, JSONType jsonType2, List<FieldInfo> fieldList) {
        boolean match;
        Annotation[][] paramAnnotationArrays;
        this.clazz = clazz2;
        this.builderClass = builderClass2;
        this.defaultConstructor = defaultConstructor2;
        this.creatorConstructor = creatorConstructor2;
        this.factoryMethod = factoryMethod2;
        this.parserFeatures = TypeUtils.getParserFeatures(clazz2);
        this.buildMethod = buildMethod2;
        this.jsonType = jsonType2;
        String[] strArr = null;
        if (jsonType2 != null) {
            String typeName2 = jsonType2.typeName();
            String typeKey2 = jsonType2.typeKey();
            this.typeKey = typeKey2.length() > 0 ? typeKey2 : null;
            if (typeName2.length() != 0) {
                this.typeName = typeName2;
            } else {
                this.typeName = clazz2.getName();
            }
            String[] orders2 = jsonType2.orders();
            this.orders = orders2.length != 0 ? orders2 : strArr;
        } else {
            this.typeName = clazz2.getName();
            this.typeKey = null;
            this.orders = null;
        }
        FieldInfo[] fieldInfoArr = new FieldInfo[fieldList.size()];
        this.fields = fieldInfoArr;
        fieldList.toArray(fieldInfoArr);
        FieldInfo[] fieldInfoArr2 = this.fields;
        FieldInfo[] sortedFields2 = new FieldInfo[fieldInfoArr2.length];
        if (this.orders != null) {
            LinkedHashMap<String, FieldInfo> map = new LinkedHashMap<>(fieldList.size());
            FieldInfo[] fieldInfoArr3 = this.fields;
            for (FieldInfo field : fieldInfoArr3) {
                map.put(field.name, field);
            }
            int i = 0;
            String[] strArr2 = this.orders;
            for (String item : strArr2) {
                FieldInfo field2 = map.get(item);
                if (field2 != null) {
                    sortedFields2[i] = field2;
                    map.remove(item);
                    i++;
                }
            }
            for (FieldInfo field3 : map.values()) {
                sortedFields2[i] = field3;
                i++;
            }
        } else {
            System.arraycopy(fieldInfoArr2, 0, sortedFields2, 0, fieldInfoArr2.length);
            Arrays.sort(sortedFields2);
        }
        this.sortedFields = Arrays.equals(this.fields, sortedFields2) ? this.fields : sortedFields2;
        if (defaultConstructor2 != null) {
            this.defaultConstructorParameterSize = defaultConstructor2.getParameterTypes().length;
        } else if (factoryMethod2 != null) {
            this.defaultConstructorParameterSize = factoryMethod2.getParameterTypes().length;
        } else {
            this.defaultConstructorParameterSize = 0;
        }
        if (creatorConstructor2 != null) {
            this.creatorConstructorParameterTypes = creatorConstructor2.getParameterTypes();
            boolean isKotlin = TypeUtils.isKotlin(clazz2);
            this.f80kotlin = isKotlin;
            if (isKotlin) {
                this.creatorConstructorParameters = TypeUtils.getKoltinConstructorParameters(clazz2);
                int i2 = 0;
                try {
                    this.kotlinDefaultConstructor = clazz2.getConstructor(new Class[0]);
                } catch (Throwable th) {
                }
                Annotation[][] paramAnnotationArrays2 = TypeUtils.getParameterAnnotations(creatorConstructor2);
                int i3 = 0;
                while (i3 < this.creatorConstructorParameters.length && i3 < paramAnnotationArrays2.length) {
                    Annotation[] paramAnnotations = paramAnnotationArrays2[i3];
                    JSONField fieldAnnotation = null;
                    int length = paramAnnotations.length;
                    while (true) {
                        if (i2 >= length) {
                            paramAnnotationArrays = paramAnnotationArrays2;
                            break;
                        }
                        paramAnnotationArrays = paramAnnotationArrays2;
                        Annotation paramAnnotation = paramAnnotations[i2];
                        if (paramAnnotation instanceof JSONField) {
                            fieldAnnotation = (JSONField) paramAnnotation;
                            break;
                        } else {
                            i2++;
                            paramAnnotationArrays2 = paramAnnotationArrays;
                        }
                    }
                    if (fieldAnnotation != null) {
                        String fieldAnnotationName = fieldAnnotation.name();
                        if (fieldAnnotationName.length() > 0) {
                            this.creatorConstructorParameters[i3] = fieldAnnotationName;
                        }
                    }
                    i3++;
                    paramAnnotationArrays2 = paramAnnotationArrays;
                    i2 = 0;
                }
                return;
            }
            if (this.creatorConstructorParameterTypes.length != this.fields.length) {
                match = false;
            } else {
                match = true;
                int i4 = 0;
                while (true) {
                    Type[] typeArr = this.creatorConstructorParameterTypes;
                    if (i4 >= typeArr.length) {
                        break;
                    } else if (typeArr[i4] != this.fields[i4].fieldClass) {
                        match = false;
                        break;
                    } else {
                        i4++;
                    }
                }
            }
            if (!match) {
                this.creatorConstructorParameters = ASMUtils.lookupParameterNames(creatorConstructor2);
            }
        }
    }

    private static FieldInfo getField(List<FieldInfo> fieldList, String propertyName) {
        for (FieldInfo item : fieldList) {
            if (item.name.equals(propertyName)) {
                return item;
            }
            Field field = item.field;
            if (!(field == null || item.getAnnotation() == null || !field.getName().equals(propertyName))) {
                return item;
            }
        }
        return null;
    }

    static boolean add(List<FieldInfo> fieldList, FieldInfo field) {
        for (int i = fieldList.size() - 1; i >= 0; i--) {
            FieldInfo item = fieldList.get(i);
            if (item.name.equals(field.name) && (!item.getOnly || field.getOnly)) {
                if (item.fieldClass.isAssignableFrom(field.fieldClass)) {
                    fieldList.set(i, field);
                    return true;
                } else if (item.compareTo(field) >= 0) {
                    return false;
                } else {
                    fieldList.set(i, field);
                    return true;
                }
            }
        }
        fieldList.add(field);
        return true;
    }

    public static JavaBeanInfo build(Class<?> clazz2, Type type, PropertyNamingStrategy propertyNamingStrategy) {
        return build(clazz2, type, propertyNamingStrategy, false, TypeUtils.compatibleWithJavaBean, false);
    }

    private static Map<TypeVariable, Type> buildGenericInfo(Class<?> clazz2) {
        Class<?> childClass = clazz2;
        Class<?> currentClass = clazz2.getSuperclass();
        if (currentClass == null) {
            return null;
        }
        Map<TypeVariable, Type> typeVarMap = null;
        while (currentClass != null && currentClass != Object.class) {
            if (childClass.getGenericSuperclass() instanceof ParameterizedType) {
                Type[] childGenericParentActualTypeArgs = ((ParameterizedType) childClass.getGenericSuperclass()).getActualTypeArguments();
                TypeVariable[] currentTypeParameters = currentClass.getTypeParameters();
                for (int i = 0; i < childGenericParentActualTypeArgs.length; i++) {
                    if (typeVarMap == null) {
                        typeVarMap = new HashMap<>();
                    }
                    if (typeVarMap.containsKey(childGenericParentActualTypeArgs[i])) {
                        typeVarMap.put(currentTypeParameters[i], typeVarMap.get(childGenericParentActualTypeArgs[i]));
                    } else {
                        typeVarMap.put(currentTypeParameters[i], childGenericParentActualTypeArgs[i]);
                    }
                }
            }
            childClass = currentClass;
            currentClass = currentClass.getSuperclass();
        }
        return typeVarMap;
    }

    public static JavaBeanInfo build(Class<?> clazz2, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean fieldBased, boolean compatibleWithJavaBean) {
        return build(clazz2, type, propertyNamingStrategy, fieldBased, compatibleWithJavaBean, false);
    }

    /* JADX INFO: Multiple debug info for r15v20 java.lang.reflect.Method: [D('builderClass' java.lang.Class<?>), D('factoryMethod' java.lang.reflect.Method)] */
    /* JADX INFO: Multiple debug info for r8v22 java.lang.reflect.Field[]: [D('declaredFields' java.lang.reflect.Field[]), D('builderClass' java.lang.Class<?>)] */
    /* JADX INFO: Multiple debug info for r9v30 com.alibaba.fastjson.PropertyNamingStrategy: [D('fieldList' java.util.List<com.alibaba.fastjson.util.FieldInfo>), D('propertyNamingStrategy' com.alibaba.fastjson.PropertyNamingStrategy)] */
    /* JADX INFO: Multiple debug info for r26v3 'jsonType'  com.alibaba.fastjson.annotation.JSONType: [D('jsonType' com.alibaba.fastjson.annotation.JSONType), D('propertyNamingStrategy' com.alibaba.fastjson.PropertyNamingStrategy)] */
    /* JADX INFO: Multiple debug info for r12v35 'fieldList'  java.util.List<com.alibaba.fastjson.util.FieldInfo>: [D('paramAnnotationArrays' java.lang.annotation.Annotation[][]), D('fieldList' java.util.List<com.alibaba.fastjson.util.FieldInfo>)] */
    /* JADX WARNING: Code restructure failed: missing block: B:173:0x03f6, code lost:
        if (r10.length <= r3.length) goto L_0x0404;
     */
    /* JADX WARNING: Removed duplicated region for block: B:182:0x0415  */
    /* JADX WARNING: Removed duplicated region for block: B:183:0x041b  */
    /* JADX WARNING: Removed duplicated region for block: B:409:0x0aa1  */
    /* JADX WARNING: Removed duplicated region for block: B:411:0x0aa7  */
    /* JADX WARNING: Removed duplicated region for block: B:414:0x0ad2  */
    /* JADX WARNING: Removed duplicated region for block: B:418:0x0ad7  */
    /* JADX WARNING: Removed duplicated region for block: B:428:0x0b7e  */
    /* JADX WARNING: Removed duplicated region for block: B:431:0x0b97  */
    /* JADX WARNING: Removed duplicated region for block: B:432:0x0b9e  */
    public static JavaBeanInfo build(Class<?> clazz2, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean fieldBased, boolean compatibleWithJavaBean, boolean jacksonCompatible) {
        PropertyNamingStrategy propertyNamingStrategy2;
        Constructor<?> defaultConstructor2;
        PropertyNamingStrategy propertyNamingStrategy3;
        Class<?> builderClass2;
        JSONType jsonType2;
        Field[] declaredFields;
        Method[] methods;
        List<FieldInfo> fieldList;
        Class<?> cls;
        String str;
        Field[] declaredFields2;
        List<FieldInfo> fieldList2;
        Class<?> builderClass3;
        char c;
        String str2;
        int i;
        boolean fieldBased2;
        Field[] declaredFields3;
        PropertyNamingStrategy propertyNamingStrategy4;
        int i2;
        int i3;
        String str3;
        Method[] methodArr;
        Field[] fields2;
        Type type2;
        Field collectionField;
        String propertyName;
        String propertyName2;
        PropertyNamingStrategy propertyNamingStrategy5;
        String str4;
        Method[] methods2;
        Field[] declaredFields4;
        int i4;
        Class<?> builderClass4;
        Method method;
        Method method2;
        Class<?>[] types;
        String methodName;
        String str5;
        List<String> getMethodNameList;
        int i5;
        Class<?> cls2;
        Field[] declaredFields5;
        String propertyName3;
        Field field;
        Field field2;
        JSONField fieldAnnotation;
        String propertyName4;
        String withPrefix;
        String buildMethodName;
        Class<?> builderClass5;
        String withPrefix2;
        int i6;
        int i7;
        String str6;
        Field[] declaredFields6;
        List<FieldInfo> fieldList3;
        JSONField annotation;
        String withPrefix3;
        Method method3;
        int parserFeatures2;
        int serialzeFeatures;
        int ordinal;
        String str7;
        List<FieldInfo> fieldList4;
        String withPrefix4;
        StringBuilder properNameBuilder;
        char c0;
        Constructor<?> creatorConstructor2;
        Constructor<?> creatorConstructor3;
        Method factoryMethod2;
        Constructor<?>[] constructors;
        String[] paramNames;
        JSONField fieldAnnotation2;
        JSONField fieldAnnotation3;
        int serialzeFeatures2;
        int parserFeatures3;
        int ordinal2;
        String paramName;
        int i8;
        Constructor<?> constructor;
        Constructor<?> creatorConstructor4;
        JSONField fieldAnnotation4;
        int parserFeatures4;
        int serialzeFeatures3;
        int ordinal3;
        PropertyNamingStrategy propertyNamingStrategy6;
        List<FieldInfo> fieldList5;
        Annotation[][] paramAnnotationArrays;
        int parserFeatures5;
        int serialzeFeatures4;
        int parserFeatures6;
        String fieldName;
        Constructor<?> mixInCreator;
        PropertyNamingStrategy jsonTypeNaming;
        Class<?> cls3 = clazz2;
        JSONType jsonType3 = (JSONType) TypeUtils.getAnnotation(cls3, JSONType.class);
        if (jsonType3 == null || (jsonTypeNaming = jsonType3.naming()) == null || jsonTypeNaming == PropertyNamingStrategy.CamelCase) {
            propertyNamingStrategy2 = propertyNamingStrategy;
        } else {
            propertyNamingStrategy2 = jsonTypeNaming;
        }
        Class<?> builderClass6 = getBuilderClass(cls3, jsonType3);
        Field[] declaredFields7 = clazz2.getDeclaredFields();
        Method[] methods3 = clazz2.getMethods();
        Map<TypeVariable, Type> genericInfo = buildGenericInfo(clazz2);
        boolean kotlin2 = TypeUtils.isKotlin(clazz2);
        Constructor<?>[] constructors2 = clazz2.getDeclaredConstructors();
        if (kotlin2 && constructors2.length != 1) {
            defaultConstructor2 = null;
        } else if (builderClass6 == null) {
            defaultConstructor2 = getDefaultConstructor(cls3, constructors2);
        } else {
            defaultConstructor2 = getDefaultConstructor(builderClass6, builderClass6.getDeclaredConstructors());
        }
        Constructor<?> creatorConstructor5 = null;
        Method buildMethod2 = null;
        Method factoryMethod3 = null;
        List<FieldInfo> fieldList6 = new ArrayList<>();
        if (fieldBased) {
            for (Class<?> currentClass = clazz2; currentClass != null; currentClass = currentClass.getSuperclass()) {
                computeFields(cls3, type, propertyNamingStrategy2, fieldList6, currentClass.getDeclaredFields());
            }
            if (defaultConstructor2 != null) {
                TypeUtils.setAccessible(defaultConstructor2);
            }
            return new JavaBeanInfo(clazz2, builderClass6, defaultConstructor2, null, null, null, jsonType3, fieldList6);
        }
        boolean isInterfaceOrAbstract = clazz2.isInterface() || Modifier.isAbstract(clazz2.getModifiers());
        if (!(defaultConstructor2 == null && builderClass6 == null) && !isInterfaceOrAbstract) {
            fieldList = fieldList6;
            propertyNamingStrategy3 = propertyNamingStrategy2;
            builderClass2 = builderClass6;
            jsonType2 = jsonType3;
            declaredFields = declaredFields7;
            cls = cls3;
            methods = methods3;
        } else {
            Type mixInType = JSON.getMixInAnnotations(clazz2);
            if ((mixInType instanceof Class) && (mixInCreator = getCreatorConstructor(((Class) mixInType).getConstructors())) != null) {
                try {
                    creatorConstructor5 = cls3.getConstructor(mixInCreator.getParameterTypes());
                } catch (NoSuchMethodException e) {
                }
            }
            if (creatorConstructor5 == null) {
                creatorConstructor2 = getCreatorConstructor(constructors2);
            } else {
                creatorConstructor2 = creatorConstructor5;
            }
            if (creatorConstructor2 == null || isInterfaceOrAbstract) {
                List<FieldInfo> fieldList7 = fieldList6;
                Method factoryMethod4 = getFactoryMethod(cls3, methods3, jacksonCompatible);
                Class<?> builderClass7 = builderClass6;
                Method factoryMethod5 = factoryMethod4;
                if (factoryMethod4 != null) {
                    TypeUtils.setAccessible(factoryMethod5);
                    String[] lookupParameterNames = null;
                    Class<?>[] types2 = factoryMethod5.getParameterTypes();
                    if (types2.length > 0) {
                        Annotation[][] paramAnnotationArrays2 = TypeUtils.getParameterAnnotations(factoryMethod5);
                        int i9 = 0;
                        while (i9 < types2.length) {
                            Annotation[] paramAnnotations = paramAnnotationArrays2[i9];
                            int length = paramAnnotations.length;
                            int i10 = 0;
                            while (true) {
                                if (i10 >= length) {
                                    creatorConstructor4 = creatorConstructor2;
                                    fieldAnnotation4 = null;
                                    break;
                                }
                                Annotation paramAnnotation = paramAnnotations[i10];
                                creatorConstructor4 = creatorConstructor2;
                                if (paramAnnotation instanceof JSONField) {
                                    fieldAnnotation4 = (JSONField) paramAnnotation;
                                    break;
                                }
                                i10++;
                                creatorConstructor2 = creatorConstructor4;
                            }
                            if (fieldAnnotation4 != null || (jacksonCompatible && TypeUtils.isJacksonCreator(factoryMethod5))) {
                                String fieldName2 = null;
                                if (fieldAnnotation4 != null) {
                                    fieldName2 = fieldAnnotation4.name();
                                    ordinal3 = fieldAnnotation4.ordinal();
                                    serialzeFeatures3 = SerializerFeature.of(fieldAnnotation4.serialzeFeatures());
                                    parserFeatures4 = Feature.of(fieldAnnotation4.parseFeatures());
                                } else {
                                    ordinal3 = 0;
                                    serialzeFeatures3 = 0;
                                    parserFeatures4 = 0;
                                }
                                if (fieldName2 == null || fieldName2.length() == 0) {
                                    if (lookupParameterNames == null) {
                                        lookupParameterNames = ASMUtils.lookupParameterNames(factoryMethod5);
                                    }
                                    fieldName2 = lookupParameterNames[i9];
                                }
                                add(fieldList7, new FieldInfo(fieldName2, clazz2, types2[i9], factoryMethod5.getGenericParameterTypes()[i9], TypeUtils.getField(cls3, fieldName2, declaredFields7), ordinal3, serialzeFeatures3, parserFeatures4));
                                i9++;
                                creatorConstructor2 = creatorConstructor4;
                                fieldList7 = fieldList7;
                                lookupParameterNames = lookupParameterNames;
                                types2 = types2;
                                builderClass7 = builderClass7;
                                cls3 = clazz2;
                            } else {
                                throw new JSONException("illegal json creator");
                            }
                        }
                        return new JavaBeanInfo(clazz2, builderClass7, null, null, factoryMethod5, null, jsonType3, fieldList7);
                    }
                    creatorConstructor3 = creatorConstructor2;
                    builderClass2 = builderClass7;
                    jsonType2 = jsonType3;
                    fieldList = fieldList7;
                    cls = cls3;
                    methods = methods3;
                    propertyNamingStrategy3 = propertyNamingStrategy2;
                    factoryMethod2 = factoryMethod5;
                    declaredFields = declaredFields7;
                } else {
                    Type type3 = type;
                    creatorConstructor3 = creatorConstructor2;
                    builderClass2 = builderClass7;
                    List<FieldInfo> fieldList8 = fieldList7;
                    Field[] declaredFields8 = declaredFields7;
                    Method[] methods4 = methods3;
                    Class<?> cls4 = cls3;
                    PropertyNamingStrategy propertyNamingStrategy7 = propertyNamingStrategy2;
                    jsonType2 = jsonType3;
                    if (!isInterfaceOrAbstract) {
                        String className = clazz2.getName();
                        if (kotlin2) {
                            constructors = constructors2;
                            if (constructors.length > 0) {
                                String[] paramNames2 = TypeUtils.getKoltinConstructorParameters(clazz2);
                                Constructor<?> creatorConstructor6 = TypeUtils.getKotlinConstructor(constructors, paramNames2);
                                TypeUtils.setAccessible(creatorConstructor6);
                                paramNames = paramNames2;
                                creatorConstructor5 = creatorConstructor6;
                                Class<?>[] types3 = paramNames == null ? creatorConstructor5.getParameterTypes() : null;
                                if (paramNames == null && types3.length == paramNames.length) {
                                    Annotation[][] paramAnnotationArrays3 = TypeUtils.getParameterAnnotations(creatorConstructor5);
                                    int i11 = 0;
                                    while (i11 < types3.length) {
                                        Annotation[] paramAnnotations2 = paramAnnotationArrays3[i11];
                                        String paramName2 = paramNames[i11];
                                        int length2 = paramAnnotations2.length;
                                        int i12 = 0;
                                        while (true) {
                                            if (i12 >= length2) {
                                                fieldAnnotation2 = null;
                                                break;
                                            }
                                            Annotation paramAnnotation2 = paramAnnotations2[i12];
                                            if (paramAnnotation2 instanceof JSONField) {
                                                fieldAnnotation2 = (JSONField) paramAnnotation2;
                                                break;
                                            }
                                            i12++;
                                            length2 = length2;
                                            paramAnnotations2 = paramAnnotations2;
                                        }
                                        Class<?> fieldClass = types3[i11];
                                        Type fieldType = creatorConstructor5.getGenericParameterTypes()[i11];
                                        Field field3 = TypeUtils.getField(cls4, paramName2, declaredFields8);
                                        if (field3 == null || fieldAnnotation2 != null) {
                                            fieldAnnotation3 = fieldAnnotation2;
                                        } else {
                                            fieldAnnotation3 = (JSONField) TypeUtils.getAnnotation(field3, JSONField.class);
                                        }
                                        if (fieldAnnotation3 != null) {
                                            String nameAnnotated = fieldAnnotation3.name();
                                            if (nameAnnotated.length() != 0) {
                                                paramName2 = nameAnnotated;
                                            }
                                            int ordinal4 = fieldAnnotation3.ordinal();
                                            serialzeFeatures2 = SerializerFeature.of(fieldAnnotation3.serialzeFeatures());
                                            parserFeatures3 = Feature.of(fieldAnnotation3.parseFeatures());
                                            paramName = paramName2;
                                            ordinal2 = ordinal4;
                                        } else if (!"org.springframework.security.core.userdetails.User".equals(className) || !Constants.Value.PASSWORD.equals(paramName2)) {
                                            ordinal2 = 0;
                                            paramName = paramName2;
                                            parserFeatures3 = 0;
                                            serialzeFeatures2 = 0;
                                        } else {
                                            ordinal2 = 0;
                                            paramName = paramName2;
                                            parserFeatures3 = Feature.InitStringFieldAsEmpty.mask;
                                            serialzeFeatures2 = 0;
                                        }
                                        add(fieldList8, new FieldInfo(paramName, clazz2, fieldClass, fieldType, field3, ordinal2, serialzeFeatures2, parserFeatures3));
                                        i11++;
                                        type3 = type;
                                        cls4 = cls4;
                                        fieldList8 = fieldList8;
                                        methods4 = methods4;
                                        declaredFields8 = declaredFields8;
                                        types3 = types3;
                                        constructors = constructors;
                                        factoryMethod5 = factoryMethod5;
                                        propertyNamingStrategy7 = propertyNamingStrategy7;
                                        paramAnnotationArrays3 = paramAnnotationArrays3;
                                    }
                                    propertyNamingStrategy3 = propertyNamingStrategy7;
                                    fieldList = fieldList8;
                                    cls = cls4;
                                    methods = methods4;
                                    declaredFields = declaredFields8;
                                    if (!(kotlin2 || clazz2.getName().equals("javax.servlet.http.Cookie"))) {
                                        return new JavaBeanInfo(clazz2, builderClass2, null, creatorConstructor5, null, null, jsonType2, fieldList);
                                    }
                                    factoryMethod3 = factoryMethod5;
                                } else {
                                    throw new JSONException("default constructor not found. " + cls4);
                                }
                            }
                        } else {
                            constructors = constructors2;
                        }
                        int length3 = constructors.length;
                        String[] paramNames3 = null;
                        int i13 = 0;
                        Constructor<?> creatorConstructor7 = creatorConstructor3;
                        while (true) {
                            if (i13 >= length3) {
                                paramNames = paramNames3;
                                creatorConstructor5 = creatorConstructor7;
                                break;
                            }
                            Constructor<?> constructor2 = constructors[i13];
                            Class<?>[] parameterTypes = constructor2.getParameterTypes();
                            if (className.equals("org.springframework.security.web.authentication.WebAuthenticationDetails")) {
                                i8 = length3;
                                if (parameterTypes.length == 2 && parameterTypes[0] == String.class && parameterTypes[1] == String.class) {
                                    constructor2.setAccessible(true);
                                    creatorConstructor5 = constructor2;
                                    paramNames = ASMUtils.lookupParameterNames(constructor2);
                                    break;
                                }
                                constructor = creatorConstructor7;
                            } else {
                                i8 = length3;
                                if (className.equals("org.springframework.security.web.authentication.preauth.PreAuthenticatedAuthenticationToken")) {
                                    if (parameterTypes.length == 3 && parameterTypes[0] == Object.class && parameterTypes[1] == Object.class && parameterTypes[2] == Collection.class) {
                                        constructor2.setAccessible(true);
                                        creatorConstructor5 = constructor2;
                                        paramNames = new String[]{"principal", "credentials", "authorities"};
                                        break;
                                    }
                                    constructor = creatorConstructor7;
                                } else if (className.equals("org.springframework.security.core.authority.SimpleGrantedAuthority")) {
                                    if (parameterTypes.length == 1 && parameterTypes[0] == String.class) {
                                        creatorConstructor5 = constructor2;
                                        paramNames = new String[]{IApp.ConfigProperty.CONFIG_AUTHORITY};
                                        break;
                                    }
                                    constructor = creatorConstructor7;
                                } else if (!((constructor2.getModifiers() & 1) != 0)) {
                                    constructor = creatorConstructor7;
                                } else {
                                    String[] lookupParameterNames2 = ASMUtils.lookupParameterNames(constructor2);
                                    if (lookupParameterNames2 == null) {
                                        constructor = creatorConstructor7;
                                    } else if (lookupParameterNames2.length == 0) {
                                        constructor = creatorConstructor7;
                                    } else {
                                        if (creatorConstructor7 != null && paramNames3 != null) {
                                            constructor = creatorConstructor7;
                                        }
                                        paramNames3 = lookupParameterNames2;
                                        creatorConstructor7 = constructor2;
                                        i13++;
                                        length3 = i8;
                                    }
                                }
                            }
                            creatorConstructor7 = constructor;
                            i13++;
                            length3 = i8;
                        }
                        if (paramNames == null) {
                        }
                        if (paramNames == null) {
                        }
                        throw new JSONException("default constructor not found. " + cls4);
                    }
                    fieldList = fieldList8;
                    cls = cls4;
                    methods = methods4;
                    propertyNamingStrategy3 = propertyNamingStrategy7;
                    factoryMethod2 = factoryMethod5;
                    declaredFields = declaredFields8;
                }
                creatorConstructor5 = creatorConstructor3;
                factoryMethod3 = factoryMethod2;
            } else {
                TypeUtils.setAccessible(creatorConstructor2);
                Class<?>[] types4 = creatorConstructor2.getParameterTypes();
                String[] lookupParameterNames3 = null;
                if (types4.length > 0) {
                    Annotation[][] paramAnnotationArrays4 = TypeUtils.getParameterAnnotations(creatorConstructor2);
                    int i14 = 0;
                    while (i14 < types4.length && i14 < paramAnnotationArrays4.length) {
                        Annotation[] paramAnnotations3 = paramAnnotationArrays4[i14];
                        JSONField fieldAnnotation5 = null;
                        int length4 = paramAnnotations3.length;
                        int i15 = 0;
                        while (true) {
                            if (i15 >= length4) {
                                paramAnnotationArrays = paramAnnotationArrays4;
                                break;
                            }
                            Annotation paramAnnotation3 = paramAnnotations3[i15];
                            paramAnnotationArrays = paramAnnotationArrays4;
                            if (paramAnnotation3 instanceof JSONField) {
                                fieldAnnotation5 = (JSONField) paramAnnotation3;
                                break;
                            }
                            i15++;
                            paramAnnotationArrays4 = paramAnnotationArrays;
                        }
                        Class<?> fieldClass2 = types4[i14];
                        Type fieldType2 = creatorConstructor2.getGenericParameterTypes()[i14];
                        String fieldName3 = null;
                        Field field4 = null;
                        if (fieldAnnotation5 != null) {
                            field4 = TypeUtils.getField(cls3, fieldAnnotation5.name(), declaredFields7);
                            int ordinal5 = fieldAnnotation5.ordinal();
                            int serialzeFeatures5 = SerializerFeature.of(fieldAnnotation5.serialzeFeatures());
                            int parserFeatures7 = Feature.of(fieldAnnotation5.parseFeatures());
                            fieldName3 = fieldAnnotation5.name();
                            serialzeFeatures4 = serialzeFeatures5;
                            parserFeatures5 = parserFeatures7;
                            parserFeatures6 = ordinal5;
                        } else {
                            parserFeatures5 = 0;
                            parserFeatures6 = 0;
                            serialzeFeatures4 = 0;
                        }
                        if (fieldName3 == null || fieldName3.length() == 0) {
                            if (lookupParameterNames3 == null) {
                                lookupParameterNames3 = ASMUtils.lookupParameterNames(creatorConstructor2);
                            }
                            fieldName = lookupParameterNames3[i14];
                        } else {
                            fieldName = fieldName3;
                        }
                        if (field4 == null) {
                            if (lookupParameterNames3 == null) {
                                if (kotlin2) {
                                    lookupParameterNames3 = TypeUtils.getKoltinConstructorParameters(clazz2);
                                } else {
                                    lookupParameterNames3 = ASMUtils.lookupParameterNames(creatorConstructor2);
                                }
                            }
                            if (lookupParameterNames3.length > i14) {
                                field4 = TypeUtils.getField(cls3, lookupParameterNames3[i14], declaredFields7);
                            }
                        }
                        add(fieldList6, new FieldInfo(fieldName, clazz2, fieldClass2, fieldType2, field4, parserFeatures6, serialzeFeatures4, parserFeatures5));
                        i14++;
                        propertyNamingStrategy2 = propertyNamingStrategy2;
                        paramAnnotationArrays4 = paramAnnotationArrays;
                        lookupParameterNames3 = lookupParameterNames3;
                        types4 = types4;
                        mixInType = mixInType;
                    }
                    fieldList5 = fieldList6;
                    propertyNamingStrategy6 = propertyNamingStrategy2;
                } else {
                    fieldList5 = fieldList6;
                    propertyNamingStrategy6 = propertyNamingStrategy2;
                }
                creatorConstructor5 = creatorConstructor2;
                fieldList = fieldList5;
                builderClass2 = builderClass6;
                propertyNamingStrategy3 = propertyNamingStrategy6;
                declaredFields = declaredFields7;
                cls = cls3;
                jsonType2 = jsonType3;
                methods = methods3;
            }
        }
        if (defaultConstructor2 != null) {
            TypeUtils.setAccessible(defaultConstructor2);
        }
        String str8 = "set";
        Class<?> builderClass8 = builderClass2;
        if (builderClass8 != null) {
            String withPrefix5 = null;
            JSONPOJOBuilder builderAnno = (JSONPOJOBuilder) TypeUtils.getAnnotation(builderClass8, JSONPOJOBuilder.class);
            if (builderAnno != null) {
                withPrefix5 = builderAnno.withPrefix();
            }
            if (withPrefix5 == null) {
                withPrefix = "with";
            } else {
                withPrefix = withPrefix5;
            }
            Method[] methods5 = builderClass8.getMethods();
            int length5 = methods5.length;
            int i16 = 0;
            while (i16 < length5) {
                Method method4 = methods5[i16];
                if (Modifier.isStatic(method4.getModifiers())) {
                    i7 = i16;
                    i6 = length5;
                    withPrefix2 = withPrefix;
                    builderClass5 = builderClass8;
                    str6 = str8;
                    declaredFields6 = declaredFields;
                    fieldList3 = fieldList;
                } else if (!method4.getReturnType().equals(builderClass8)) {
                    i7 = i16;
                    i6 = length5;
                    withPrefix2 = withPrefix;
                    builderClass5 = builderClass8;
                    str6 = str8;
                    declaredFields6 = declaredFields;
                    fieldList3 = fieldList;
                } else {
                    JSONField annotation2 = (JSONField) TypeUtils.getAnnotation(method4, JSONField.class);
                    if (annotation2 == null) {
                        annotation = TypeUtils.getSuperMethodAnnotation(cls, method4);
                    } else {
                        annotation = annotation2;
                    }
                    if (annotation == null) {
                        method3 = method4;
                        i7 = i16;
                        i6 = length5;
                        withPrefix3 = withPrefix;
                        builderClass5 = builderClass8;
                        declaredFields6 = declaredFields;
                        str7 = str8;
                        fieldList4 = fieldList;
                        ordinal = 0;
                        serialzeFeatures = 0;
                        parserFeatures2 = 0;
                    } else if (!annotation.deserialize()) {
                        i7 = i16;
                        i6 = length5;
                        withPrefix2 = withPrefix;
                        builderClass5 = builderClass8;
                        str6 = str8;
                        declaredFields6 = declaredFields;
                        fieldList3 = fieldList;
                    } else {
                        ordinal = annotation.ordinal();
                        serialzeFeatures = SerializerFeature.of(annotation.serialzeFeatures());
                        parserFeatures2 = Feature.of(annotation.parseFeatures());
                        if (annotation.name().length() != 0) {
                            i7 = i16;
                            i6 = length5;
                            builderClass5 = builderClass8;
                            declaredFields6 = declaredFields;
                            add(fieldList, new FieldInfo(annotation.name(), method4, null, clazz2, type, ordinal, serialzeFeatures, parserFeatures2, annotation, null, null, genericInfo));
                            withPrefix2 = withPrefix;
                            str6 = str8;
                            fieldList3 = fieldList;
                        } else {
                            method3 = method4;
                            i7 = i16;
                            i6 = length5;
                            withPrefix3 = withPrefix;
                            builderClass5 = builderClass8;
                            declaredFields6 = declaredFields;
                            str7 = str8;
                            fieldList4 = fieldList;
                        }
                    }
                    String methodName2 = method3.getName();
                    if (methodName2.startsWith(str7)) {
                        if (methodName2.length() > 3) {
                            withPrefix4 = withPrefix3;
                            properNameBuilder = new StringBuilder(methodName2.substring(3));
                            c0 = properNameBuilder.charAt(0);
                            if (withPrefix4.length() != 0 || Character.isUpperCase(c0)) {
                                properNameBuilder.setCharAt(0, Character.toLowerCase(c0));
                                withPrefix2 = withPrefix4;
                                str6 = str7;
                                fieldList3 = fieldList4;
                                add(fieldList3, new FieldInfo(properNameBuilder.toString(), method3, null, clazz2, type, ordinal, serialzeFeatures, parserFeatures2, annotation, null, null, genericInfo));
                            } else {
                                withPrefix2 = withPrefix4;
                                str6 = str7;
                                fieldList3 = fieldList4;
                            }
                        }
                    }
                    if (withPrefix3.length() == 0) {
                        withPrefix4 = withPrefix3;
                        properNameBuilder = new StringBuilder(methodName2);
                    } else {
                        withPrefix4 = withPrefix3;
                        if (!methodName2.startsWith(withPrefix4)) {
                            withPrefix2 = withPrefix4;
                            str6 = str7;
                            fieldList3 = fieldList4;
                        } else if (methodName2.length() <= withPrefix4.length()) {
                            withPrefix2 = withPrefix4;
                            str6 = str7;
                            fieldList3 = fieldList4;
                        } else {
                            properNameBuilder = new StringBuilder(methodName2.substring(withPrefix4.length()));
                        }
                    }
                    c0 = properNameBuilder.charAt(0);
                    if (withPrefix4.length() != 0) {
                    }
                    properNameBuilder.setCharAt(0, Character.toLowerCase(c0));
                    withPrefix2 = withPrefix4;
                    str6 = str7;
                    fieldList3 = fieldList4;
                    add(fieldList3, new FieldInfo(properNameBuilder.toString(), method3, null, clazz2, type, ordinal, serialzeFeatures, parserFeatures2, annotation, null, null, genericInfo));
                }
                i16 = i7 + 1;
                cls = clazz2;
                fieldList = fieldList3;
                declaredFields = declaredFields6;
                str8 = str6;
                length5 = i6;
                withPrefix = withPrefix2;
                builderClass8 = builderClass5;
            }
            str = str8;
            declaredFields2 = declaredFields;
            fieldList2 = fieldList;
            builderClass3 = builderClass8;
            if (builderClass3 != null) {
                JSONPOJOBuilder builderAnnotation = (JSONPOJOBuilder) TypeUtils.getAnnotation(builderClass3, JSONPOJOBuilder.class);
                String buildMethodName2 = null;
                if (builderAnnotation != null) {
                    buildMethodName2 = builderAnnotation.buildMethod();
                }
                if (buildMethodName2 == null || buildMethodName2.length() == 0) {
                    buildMethodName = "build";
                } else {
                    buildMethodName = buildMethodName2;
                }
                c = 0;
                try {
                    buildMethod2 = builderClass3.getMethod(buildMethodName, new Class[0]);
                } catch (NoSuchMethodException | SecurityException e2) {
                }
                if (buildMethod2 == null) {
                    try {
                        buildMethod2 = builderClass3.getMethod("create", new Class[0]);
                    } catch (NoSuchMethodException | SecurityException e3) {
                    }
                }
                if (buildMethod2 != null) {
                    TypeUtils.setAccessible(buildMethod2);
                } else {
                    throw new JSONException("buildMethod not found.");
                }
            } else {
                c = 0;
            }
        } else {
            str = str8;
            declaredFields2 = declaredFields;
            builderClass3 = builderClass8;
            fieldList2 = fieldList;
            c = 0;
        }
        int length6 = methods.length;
        int i17 = 0;
        while (true) {
            str2 = "get";
            i = 4;
            if (i17 >= length6) {
                break;
            }
            Method method5 = methods[i17];
            int ordinal6 = 0;
            int serialzeFeatures6 = 0;
            int parserFeatures8 = 0;
            String methodName3 = method5.getName();
            if (Modifier.isStatic(method5.getModifiers())) {
                i4 = i17;
                builderClass4 = builderClass3;
                methods2 = methods;
                declaredFields4 = declaredFields2;
                str4 = str;
                propertyNamingStrategy5 = propertyNamingStrategy3;
            } else {
                Class<?> returnType = method5.getReturnType();
                if (!returnType.equals(Void.TYPE) && !returnType.equals(method5.getDeclaringClass())) {
                    i4 = i17;
                    builderClass4 = builderClass3;
                    methods2 = methods;
                    declaredFields4 = declaredFields2;
                    str4 = str;
                    propertyNamingStrategy5 = propertyNamingStrategy3;
                } else if (method5.getDeclaringClass() == Object.class) {
                    i4 = i17;
                    builderClass4 = builderClass3;
                    methods2 = methods;
                    declaredFields4 = declaredFields2;
                    str4 = str;
                    propertyNamingStrategy5 = propertyNamingStrategy3;
                } else {
                    Class<?>[] types5 = method5.getParameterTypes();
                    if (types5.length == 0) {
                        i4 = i17;
                        builderClass4 = builderClass3;
                        methods2 = methods;
                        declaredFields4 = declaredFields2;
                        str4 = str;
                        propertyNamingStrategy5 = propertyNamingStrategy3;
                    } else if (types5.length > 2) {
                        i4 = i17;
                        builderClass4 = builderClass3;
                        methods2 = methods;
                        declaredFields4 = declaredFields2;
                        str4 = str;
                        propertyNamingStrategy5 = propertyNamingStrategy3;
                    } else {
                        JSONField annotation3 = (JSONField) TypeUtils.getAnnotation(method5, JSONField.class);
                        if (annotation3 != null && types5.length == 2 && types5[c] == String.class && types5[1] == Object.class) {
                            i4 = i17;
                            builderClass4 = builderClass3;
                            add(fieldList2, new FieldInfo("", method5, null, clazz2, type, 0, 0, 0, annotation3, null, null, genericInfo));
                            methods2 = methods;
                            declaredFields4 = declaredFields2;
                            str4 = str;
                            propertyNamingStrategy5 = propertyNamingStrategy3;
                        } else {
                            i4 = i17;
                            builderClass4 = builderClass3;
                            if (types5.length != 1) {
                                methods2 = methods;
                                declaredFields4 = declaredFields2;
                                str4 = str;
                                propertyNamingStrategy5 = propertyNamingStrategy3;
                            } else {
                                if (annotation3 == null) {
                                    method = method5;
                                    annotation3 = TypeUtils.getSuperMethodAnnotation(clazz2, method);
                                } else {
                                    method = method5;
                                }
                                if (annotation3 != null || methodName3.length() >= 4) {
                                    if (annotation3 == null) {
                                        method2 = method;
                                        types = types5;
                                    } else if (!annotation3.deserialize()) {
                                        methods2 = methods;
                                        declaredFields4 = declaredFields2;
                                        str4 = str;
                                        propertyNamingStrategy5 = propertyNamingStrategy3;
                                    } else {
                                        ordinal6 = annotation3.ordinal();
                                        serialzeFeatures6 = SerializerFeature.of(annotation3.serialzeFeatures());
                                        parserFeatures8 = Feature.of(annotation3.parseFeatures());
                                        if (annotation3.name().length() != 0) {
                                            add(fieldList2, new FieldInfo(annotation3.name(), method, null, clazz2, type, ordinal6, serialzeFeatures6, parserFeatures8, annotation3, null, null, genericInfo));
                                            methods2 = methods;
                                            declaredFields4 = declaredFields2;
                                            str4 = str;
                                            propertyNamingStrategy5 = propertyNamingStrategy3;
                                        } else {
                                            method2 = method;
                                            types = types5;
                                        }
                                    }
                                    if (annotation3 == null) {
                                        methodName = methodName3;
                                        str5 = str;
                                        if (!methodName.startsWith(str5)) {
                                            str4 = str5;
                                            methods2 = methods;
                                            declaredFields4 = declaredFields2;
                                            propertyNamingStrategy5 = propertyNamingStrategy3;
                                        }
                                    } else {
                                        methodName = methodName3;
                                        str5 = str;
                                    }
                                    if (builderClass4 != null) {
                                        str4 = str5;
                                        methods2 = methods;
                                        declaredFields4 = declaredFields2;
                                        propertyNamingStrategy5 = propertyNamingStrategy3;
                                    } else {
                                        char c3 = methodName.charAt(3);
                                        Field field5 = null;
                                        if (kotlin2) {
                                            List<String> getMethodNameList2 = new ArrayList<>();
                                            for (int i18 = 0; i18 < methods.length; i18++) {
                                                if (methods[i18].getName().startsWith(str2)) {
                                                    getMethodNameList2.add(methods[i18].getName());
                                                }
                                            }
                                            getMethodNameList = getMethodNameList2;
                                        } else {
                                            getMethodNameList = null;
                                        }
                                        if (Character.isUpperCase(c3)) {
                                            i5 = 1;
                                            cls2 = clazz2;
                                            declaredFields5 = declaredFields2;
                                        } else if (c3 > 512) {
                                            i5 = 1;
                                            cls2 = clazz2;
                                            declaredFields5 = declaredFields2;
                                        } else {
                                            if (c3 != '_') {
                                                i5 = 1;
                                                cls2 = clazz2;
                                                declaredFields5 = declaredFields2;
                                                if (c3 == 'f') {
                                                    propertyName3 = methodName.substring(3);
                                                } else if (methodName.length() < 5 || !Character.isUpperCase(methodName.charAt(4))) {
                                                    propertyName3 = methodName.substring(3);
                                                    field5 = TypeUtils.getField(cls2, propertyName3, declaredFields5);
                                                    if (field5 == null) {
                                                        declaredFields4 = declaredFields5;
                                                        str4 = str5;
                                                        methods2 = methods;
                                                        propertyNamingStrategy5 = propertyNamingStrategy3;
                                                    }
                                                } else {
                                                    propertyName3 = TypeUtils.decapitalize(methodName.substring(3));
                                                }
                                            } else if (kotlin2) {
                                                StringBuilder sb = new StringBuilder();
                                                sb.append("g");
                                                i5 = 1;
                                                sb.append(methodName.substring(1));
                                                propertyName3 = getMethodNameList.contains(sb.toString()) ? methodName.substring(3) : "is" + methodName.substring(3);
                                                cls2 = clazz2;
                                                declaredFields5 = declaredFields2;
                                                field5 = TypeUtils.getField(cls2, propertyName3, declaredFields5);
                                            } else {
                                                i5 = 1;
                                                cls2 = clazz2;
                                                declaredFields5 = declaredFields2;
                                                propertyName3 = methodName.substring(4);
                                                field5 = TypeUtils.getField(cls2, propertyName3, declaredFields5);
                                                if (field5 == null && (field5 = TypeUtils.getField(cls2, (propertyName3 = methodName.substring(3)), declaredFields5)) == null) {
                                                    propertyName3 = propertyName3;
                                                }
                                            }
                                            if (field5 == null) {
                                                field5 = TypeUtils.getField(cls2, propertyName3, declaredFields5);
                                            }
                                            if (field5 != null) {
                                                if (types[0] == Boolean.TYPE) {
                                                    field = TypeUtils.getField(cls2, "is" + Character.toUpperCase(propertyName3.charAt(0)) + propertyName3.substring(i5), declaredFields5);
                                                    if (field != null) {
                                                        fieldAnnotation = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                                                        if (fieldAnnotation == null) {
                                                            declaredFields4 = declaredFields5;
                                                            field2 = field;
                                                            str4 = str5;
                                                            methods2 = methods;
                                                        } else if (!fieldAnnotation.deserialize()) {
                                                            declaredFields4 = declaredFields5;
                                                            str4 = str5;
                                                            methods2 = methods;
                                                            propertyNamingStrategy5 = propertyNamingStrategy3;
                                                        } else {
                                                            ordinal6 = fieldAnnotation.ordinal();
                                                            serialzeFeatures6 = SerializerFeature.of(fieldAnnotation.serialzeFeatures());
                                                            parserFeatures8 = Feature.of(fieldAnnotation.parseFeatures());
                                                            if (fieldAnnotation.name().length() != 0) {
                                                                declaredFields4 = declaredFields5;
                                                                methods2 = methods;
                                                                str4 = str5;
                                                                add(fieldList2, new FieldInfo(fieldAnnotation.name(), method2, field, clazz2, type, ordinal6, serialzeFeatures6, parserFeatures8, annotation3, fieldAnnotation, null, genericInfo));
                                                                propertyNamingStrategy5 = propertyNamingStrategy3;
                                                            } else {
                                                                declaredFields4 = declaredFields5;
                                                                field2 = field;
                                                                str4 = str5;
                                                                methods2 = methods;
                                                            }
                                                        }
                                                    } else {
                                                        declaredFields4 = declaredFields5;
                                                        field2 = field;
                                                        str4 = str5;
                                                        methods2 = methods;
                                                        fieldAnnotation = null;
                                                    }
                                                    if (propertyNamingStrategy3 != null) {
                                                        propertyName4 = propertyNamingStrategy3.translate(propertyName3);
                                                    } else {
                                                        propertyName4 = propertyName3;
                                                    }
                                                    propertyNamingStrategy5 = propertyNamingStrategy3;
                                                    add(fieldList2, new FieldInfo(propertyName4, method2, field2, clazz2, type, ordinal6, serialzeFeatures6, parserFeatures8, annotation3, fieldAnnotation, null, genericInfo));
                                                }
                                            }
                                            field = field5;
                                            if (field != null) {
                                            }
                                            if (propertyNamingStrategy3 != null) {
                                            }
                                            propertyNamingStrategy5 = propertyNamingStrategy3;
                                            add(fieldList2, new FieldInfo(propertyName4, method2, field2, clazz2, type, ordinal6, serialzeFeatures6, parserFeatures8, annotation3, fieldAnnotation, null, genericInfo));
                                        }
                                        if (kotlin2) {
                                            propertyName3 = TypeUtils.getPropertyNameByMethodName("g" + methodName.substring(i5));
                                        } else if (TypeUtils.compatibleWithJavaBean) {
                                            propertyName3 = TypeUtils.decapitalize(methodName.substring(3));
                                        } else {
                                            propertyName3 = TypeUtils.getPropertyNameByMethodName(methodName);
                                        }
                                        if (field5 == null) {
                                        }
                                        if (field5 != null) {
                                        }
                                        field = field5;
                                        if (field != null) {
                                        }
                                        if (propertyNamingStrategy3 != null) {
                                        }
                                        propertyNamingStrategy5 = propertyNamingStrategy3;
                                        add(fieldList2, new FieldInfo(propertyName4, method2, field2, clazz2, type, ordinal6, serialzeFeatures6, parserFeatures8, annotation3, fieldAnnotation, null, genericInfo));
                                    }
                                } else {
                                    methods2 = methods;
                                    declaredFields4 = declaredFields2;
                                    str4 = str;
                                    propertyNamingStrategy5 = propertyNamingStrategy3;
                                }
                            }
                        }
                    }
                }
            }
            i17 = i4 + 1;
            builderClass3 = builderClass4;
            declaredFields2 = declaredFields4;
            methods = methods2;
            str = str4;
            propertyNamingStrategy3 = propertyNamingStrategy5;
            c = 0;
        }
        Field[] fields3 = clazz2.getFields();
        Class<?> cls5 = clazz2;
        Type type4 = type;
        Field[] declaredFields9 = declaredFields2;
        PropertyNamingStrategy propertyNamingStrategy8 = propertyNamingStrategy3;
        computeFields(cls5, type4, propertyNamingStrategy8, fieldList2, fields3);
        Method[] methods6 = clazz2.getMethods();
        int length7 = methods6.length;
        int i19 = 0;
        while (i19 < length7) {
            Method method6 = methods6[i19];
            String methodName4 = method6.getName();
            if (methodName4.length() < i) {
                fields2 = fields3;
                i2 = i19;
                i3 = length7;
                methodArr = methods6;
                str3 = str2;
                propertyNamingStrategy4 = propertyNamingStrategy8;
                declaredFields3 = declaredFields9;
                type2 = type4;
            } else if (Modifier.isStatic(method6.getModifiers())) {
                fields2 = fields3;
                i2 = i19;
                i3 = length7;
                methodArr = methods6;
                str3 = str2;
                propertyNamingStrategy4 = propertyNamingStrategy8;
                declaredFields3 = declaredFields9;
                type2 = type4;
            } else if (builderClass3 != null || !methodName4.startsWith(str2) || !Character.isUpperCase(methodName4.charAt(3))) {
                fields2 = fields3;
                i2 = i19;
                i3 = length7;
                methodArr = methods6;
                str3 = str2;
                propertyNamingStrategy4 = propertyNamingStrategy8;
                declaredFields3 = declaredFields9;
                type2 = type4;
            } else if (method6.getParameterTypes().length != 0) {
                fields2 = fields3;
                i2 = i19;
                i3 = length7;
                methodArr = methods6;
                str3 = str2;
                propertyNamingStrategy4 = propertyNamingStrategy8;
                declaredFields3 = declaredFields9;
                type2 = type4;
            } else if (Collection.class.isAssignableFrom(method6.getReturnType()) || Map.class.isAssignableFrom(method6.getReturnType()) || AtomicBoolean.class == method6.getReturnType() || AtomicInteger.class == method6.getReturnType() || AtomicLong.class == method6.getReturnType()) {
                JSONField annotation4 = (JSONField) TypeUtils.getAnnotation(method6, JSONField.class);
                if (annotation4 == null || !annotation4.deserialize()) {
                    if (annotation4 == null || annotation4.name().length() <= 0) {
                        propertyName = TypeUtils.getPropertyNameByMethodName(methodName4);
                        Field field6 = TypeUtils.getField(cls5, propertyName, declaredFields9);
                        if (field6 != null) {
                            JSONField fieldAnnotation6 = (JSONField) TypeUtils.getAnnotation(field6, JSONField.class);
                            if (fieldAnnotation6 == null || fieldAnnotation6.deserialize()) {
                                fields2 = fields3;
                                collectionField = null;
                                if (Collection.class.isAssignableFrom(method6.getReturnType()) || Map.class.isAssignableFrom(method6.getReturnType())) {
                                    collectionField = field6;
                                }
                            } else {
                                fields2 = fields3;
                                i2 = i19;
                                i3 = length7;
                                methodArr = methods6;
                                str3 = str2;
                                propertyNamingStrategy4 = propertyNamingStrategy8;
                                declaredFields3 = declaredFields9;
                                type2 = type4;
                            }
                        } else {
                            fields2 = fields3;
                            collectionField = null;
                        }
                    } else {
                        propertyName = annotation4.name();
                        fields2 = fields3;
                        collectionField = null;
                    }
                    if (propertyNamingStrategy8 != null) {
                        propertyName2 = propertyNamingStrategy8.translate(propertyName);
                    } else {
                        propertyName2 = propertyName;
                    }
                    if (getField(fieldList2, propertyName2) != null) {
                        i2 = i19;
                        i3 = length7;
                        methodArr = methods6;
                        str3 = str2;
                        propertyNamingStrategy4 = propertyNamingStrategy8;
                        declaredFields3 = declaredFields9;
                        type2 = type4;
                    } else {
                        i2 = i19;
                        i3 = length7;
                        methodArr = methods6;
                        str3 = str2;
                        propertyNamingStrategy4 = propertyNamingStrategy8;
                        declaredFields3 = declaredFields9;
                        type2 = type4;
                        add(fieldList2, new FieldInfo(propertyName2, method6, collectionField, clazz2, type, 0, 0, 0, annotation4, null, null, genericInfo));
                    }
                } else {
                    fields2 = fields3;
                    i2 = i19;
                    i3 = length7;
                    methodArr = methods6;
                    str3 = str2;
                    propertyNamingStrategy4 = propertyNamingStrategy8;
                    declaredFields3 = declaredFields9;
                    type2 = type4;
                }
            } else {
                fields2 = fields3;
                i2 = i19;
                i3 = length7;
                methodArr = methods6;
                str3 = str2;
                propertyNamingStrategy4 = propertyNamingStrategy8;
                declaredFields3 = declaredFields9;
                type2 = type4;
            }
            i19 = i2 + 1;
            type4 = type2;
            fields3 = fields2;
            methods6 = methodArr;
            str2 = str3;
            length7 = i3;
            propertyNamingStrategy8 = propertyNamingStrategy4;
            declaredFields9 = declaredFields3;
            i = 4;
            cls5 = clazz2;
        }
        if (fieldList2.size() == 0) {
            if (TypeUtils.isXmlField(clazz2)) {
                fieldBased2 = true;
            } else {
                fieldBased2 = fieldBased;
            }
            if (fieldBased2) {
                for (Class<?> currentClass2 = clazz2; currentClass2 != null; currentClass2 = currentClass2.getSuperclass()) {
                    computeFields(clazz2, type4, propertyNamingStrategy8, fieldList2, declaredFields9);
                }
            }
        }
        return new JavaBeanInfo(clazz2, builderClass3, defaultConstructor2, creatorConstructor5, factoryMethod3, buildMethod2, jsonType2, fieldList2);
    }

    private static void computeFields(Class<?> clazz2, Type type, PropertyNamingStrategy propertyNamingStrategy, List<FieldInfo> fieldList, Field[] fields2) {
        int i;
        int i2;
        boolean contains;
        int parserFeatures2;
        int serialzeFeatures;
        int ordinal;
        String propertyName;
        Map<TypeVariable, Type> genericInfo = buildGenericInfo(clazz2);
        int length = fields2.length;
        int i3 = 0;
        while (i3 < length) {
            Field field = fields2[i3];
            int modifiers = field.getModifiers();
            if ((modifiers & 8) != 0) {
                i = i3;
                i2 = length;
            } else {
                if ((modifiers & 16) != 0) {
                    Class<?> fieldType = field.getType();
                    if (!(Map.class.isAssignableFrom(fieldType) || Collection.class.isAssignableFrom(fieldType) || AtomicLong.class.equals(fieldType) || AtomicInteger.class.equals(fieldType) || AtomicBoolean.class.equals(fieldType))) {
                        i = i3;
                        i2 = length;
                    }
                }
                Iterator<FieldInfo> it = fieldList.iterator();
                while (true) {
                    if (it.hasNext()) {
                        if (it.next().name.equals(field.getName())) {
                            contains = true;
                            break;
                        }
                    } else {
                        contains = false;
                        break;
                    }
                }
                if (contains) {
                    i = i3;
                    i2 = length;
                } else {
                    String propertyName2 = field.getName();
                    JSONField fieldAnnotation = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                    if (fieldAnnotation == null) {
                        ordinal = 0;
                        serialzeFeatures = 0;
                        parserFeatures2 = 0;
                    } else if (!fieldAnnotation.deserialize()) {
                        i = i3;
                        i2 = length;
                    } else {
                        int ordinal2 = fieldAnnotation.ordinal();
                        int serialzeFeatures2 = SerializerFeature.of(fieldAnnotation.serialzeFeatures());
                        int parserFeatures3 = Feature.of(fieldAnnotation.parseFeatures());
                        if (fieldAnnotation.name().length() != 0) {
                            propertyName2 = fieldAnnotation.name();
                            ordinal = ordinal2;
                            serialzeFeatures = serialzeFeatures2;
                            parserFeatures2 = parserFeatures3;
                        } else {
                            ordinal = ordinal2;
                            serialzeFeatures = serialzeFeatures2;
                            parserFeatures2 = parserFeatures3;
                        }
                    }
                    if (propertyNamingStrategy != null) {
                        propertyName = propertyNamingStrategy.translate(propertyName2);
                    } else {
                        propertyName = propertyName2;
                    }
                    i = i3;
                    i2 = length;
                    add(fieldList, new FieldInfo(propertyName, null, field, clazz2, type, ordinal, serialzeFeatures, parserFeatures2, null, fieldAnnotation, null, genericInfo));
                }
            }
            i3 = i + 1;
            length = i2;
        }
    }

    static Constructor<?> getDefaultConstructor(Class<?> clazz2, Constructor<?>[] constructors) {
        if (Modifier.isAbstract(clazz2.getModifiers())) {
            return null;
        }
        Constructor<?> defaultConstructor2 = null;
        int length = constructors.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            Constructor<?> constructor = constructors[i];
            if (constructor.getParameterTypes().length == 0) {
                defaultConstructor2 = constructor;
                break;
            }
            i++;
        }
        if (defaultConstructor2 != null || !clazz2.isMemberClass() || Modifier.isStatic(clazz2.getModifiers())) {
            return defaultConstructor2;
        }
        for (Constructor<?> constructor2 : constructors) {
            Class<?>[] types = constructor2.getParameterTypes();
            if (types.length == 1 && types[0].equals(clazz2.getDeclaringClass())) {
                return constructor2;
            }
        }
        return defaultConstructor2;
    }

    public static Constructor<?> getCreatorConstructor(Constructor[] constructors) {
        Constructor constructor = null;
        for (Constructor constructor2 : constructors) {
            if (((JSONCreator) constructor2.getAnnotation(JSONCreator.class)) != null) {
                if (constructor == null) {
                    constructor = constructor2;
                } else {
                    throw new JSONException("multi-JSONCreator");
                }
            }
        }
        if (constructor != null) {
            return constructor;
        }
        for (Constructor constructor3 : constructors) {
            Annotation[][] paramAnnotationArrays = TypeUtils.getParameterAnnotations(constructor3);
            if (paramAnnotationArrays.length != 0) {
                boolean match = true;
                int length = paramAnnotationArrays.length;
                int i = 0;
                while (true) {
                    if (i >= length) {
                        break;
                    }
                    Annotation[] paramAnnotationArray = paramAnnotationArrays[i];
                    boolean paramMatch = false;
                    int length2 = paramAnnotationArray.length;
                    int i2 = 0;
                    while (true) {
                        if (i2 >= length2) {
                            break;
                        } else if (paramAnnotationArray[i2] instanceof JSONField) {
                            paramMatch = true;
                            break;
                        } else {
                            i2++;
                        }
                    }
                    if (!paramMatch) {
                        match = false;
                        break;
                    }
                    i++;
                }
                if (!match) {
                    continue;
                } else if (constructor == null) {
                    constructor = constructor3;
                } else {
                    throw new JSONException("multi-JSONCreator");
                }
            }
        }
        return constructor;
    }

    private static Method getFactoryMethod(Class<?> clazz2, Method[] methods, boolean jacksonCompatible) {
        Method factoryMethod2 = null;
        for (Method method : methods) {
            if (Modifier.isStatic(method.getModifiers()) && clazz2.isAssignableFrom(method.getReturnType()) && ((JSONCreator) TypeUtils.getAnnotation(method, JSONCreator.class)) != null) {
                if (factoryMethod2 == null) {
                    factoryMethod2 = method;
                } else {
                    throw new JSONException("multi-JSONCreator");
                }
            }
        }
        if (factoryMethod2 != null || !jacksonCompatible) {
            return factoryMethod2;
        }
        for (Method method2 : methods) {
            if (TypeUtils.isJacksonCreator(method2)) {
                return method2;
            }
        }
        return factoryMethod2;
    }

    public static Class<?> getBuilderClass(JSONType type) {
        return getBuilderClass(null, type);
    }

    public static Class<?> getBuilderClass(Class<?> clazz2, JSONType type) {
        Class<?> builderClass2;
        if (clazz2 != null && clazz2.getName().equals("org.springframework.security.web.savedrequest.DefaultSavedRequest")) {
            return TypeUtils.loadClass("org.springframework.security.web.savedrequest.DefaultSavedRequest$Builder");
        }
        if (type == null || (builderClass2 = type.builder()) == Void.class) {
            return null;
        }
        return builderClass2;
    }
}
