package com.coremedia.iso;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.UserBox;
import com.googlecode.mp4parser.AbstractBox;
import com.taobao.weex.el.parse.Operators;
import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.net.URL;
import java.util.Enumeration;
import java.util.Properties;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class PropertyBoxParserImpl extends AbstractBoxParser {
    Properties mapping;
    Pattern p = Pattern.compile("(.*)\\((.*?)\\)");

    public PropertyBoxParserImpl(String... customProperties) {
        InputStream is = new BufferedInputStream(getClass().getResourceAsStream("/isoparser-default.properties"));
        try {
            Properties properties = new Properties();
            this.mapping = properties;
            try {
                properties.load(is);
                Enumeration<URL> enumeration = Thread.currentThread().getContextClassLoader().getResources("isoparser-custom.properties");
                while (enumeration.hasMoreElements()) {
                    InputStream customIS = new BufferedInputStream(enumeration.nextElement().openStream());
                    try {
                        this.mapping.load(customIS);
                    } finally {
                        customIS.close();
                    }
                }
                for (String customProperty : customProperties) {
                    this.mapping.load(new BufferedInputStream(getClass().getResourceAsStream(customProperty)));
                }
                try {
                    is.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            } catch (IOException e2) {
                throw new RuntimeException(e2);
            }
        } catch (Throwable e3) {
            try {
                is.close();
            } catch (IOException e4) {
                e4.printStackTrace();
            }
            throw e3;
        }
    }

    public PropertyBoxParserImpl(Properties mapping2) {
        this.mapping = mapping2;
    }

    /* JADX DEBUG: Type inference failed for r1v2. Raw type applied. Possible types: java.lang.Class<?>, java.lang.Class<? extends com.coremedia.iso.boxes.Box> */
    @Override // com.coremedia.iso.BoxParser
    public Class<? extends Box> getClassForFourCc(String type, byte[] userType, String parent) {
        try {
            return Class.forName(new FourCcToBox(type, userType, parent).invoke().clazzName);
        } catch (ClassNotFoundException e) {
            throw new RuntimeException(e);
        }
    }

    @Override // com.coremedia.iso.AbstractBoxParser
    public Box createBox(String type, byte[] userType, String parent) {
        Constructor<AbstractBox> constructorObject;
        FourCcToBox fourCcToBox = new FourCcToBox(type, userType, parent).invoke();
        String[] param = fourCcToBox.getParam();
        String clazzName = fourCcToBox.getClazzName();
        try {
            if (param[0].trim().length() == 0) {
                param = new String[0];
            }
            Class clazz = Class.forName(clazzName);
            Class[] constructorArgsClazz = new Class[param.length];
            Object[] constructorArgs = new Object[param.length];
            for (int i = 0; i < param.length; i++) {
                if ("userType".equals(param[i])) {
                    constructorArgs[i] = userType;
                    constructorArgsClazz[i] = byte[].class;
                } else if ("type".equals(param[i])) {
                    constructorArgs[i] = type;
                    constructorArgsClazz[i] = String.class;
                } else if ("parent".equals(param[i])) {
                    constructorArgs[i] = parent;
                    constructorArgsClazz[i] = String.class;
                } else {
                    throw new InternalError("No such param: " + param[i]);
                }
            }
            try {
                if (param.length > 0) {
                    constructorObject = clazz.getConstructor(constructorArgsClazz);
                } else {
                    constructorObject = clazz.getConstructor(new Class[0]);
                }
                return constructorObject.newInstance(constructorArgs);
            } catch (NoSuchMethodException e) {
                throw new RuntimeException(e);
            } catch (InvocationTargetException e2) {
                throw new RuntimeException(e2);
            } catch (InstantiationException e3) {
                throw new RuntimeException(e3);
            } catch (IllegalAccessException e4) {
                throw new RuntimeException(e4);
            }
        } catch (ClassNotFoundException e5) {
            throw new RuntimeException(e5);
        }
    }

    private class FourCcToBox {
        private String clazzName;
        private String[] param;
        private String parent;
        private String type;
        private byte[] userType;

        public FourCcToBox(String type2, byte[] userType2, String parent2) {
            this.type = type2;
            this.parent = parent2;
            this.userType = userType2;
        }

        public String getClazzName() {
            return this.clazzName;
        }

        public String[] getParam() {
            return this.param;
        }

        public FourCcToBox invoke() {
            String constructor;
            if (this.userType == null) {
                Properties properties = PropertyBoxParserImpl.this.mapping;
                constructor = properties.getProperty(this.parent + "-" + this.type);
                if (constructor == null) {
                    constructor = PropertyBoxParserImpl.this.mapping.getProperty(this.type);
                }
            } else if (UserBox.TYPE.equals(this.type)) {
                Properties properties2 = PropertyBoxParserImpl.this.mapping;
                constructor = properties2.getProperty(this.parent + "-uuid[" + Hex.encodeHex(this.userType).toUpperCase() + Operators.ARRAY_END_STR);
                if (constructor == null) {
                    Properties properties3 = PropertyBoxParserImpl.this.mapping;
                    constructor = properties3.getProperty("uuid[" + Hex.encodeHex(this.userType).toUpperCase() + Operators.ARRAY_END_STR);
                }
                if (constructor == null) {
                    constructor = PropertyBoxParserImpl.this.mapping.getProperty(UserBox.TYPE);
                }
            } else {
                throw new RuntimeException("we have a userType but no uuid box type. Something's wrong");
            }
            if (constructor == null) {
                constructor = PropertyBoxParserImpl.this.mapping.getProperty("default");
            }
            if (constructor != null) {
                Matcher m = PropertyBoxParserImpl.this.p.matcher(constructor);
                if (m.matches()) {
                    this.clazzName = m.group(1);
                    this.param = m.group(2).split(",");
                    return this;
                }
                throw new RuntimeException("Cannot work with that constructor: " + constructor);
            }
            throw new RuntimeException("No box object found for " + this.type);
        }
    }
}
