package com.facebook.drawee.generic;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.AttributeSet;
import com.facebook.drawee.R;
import com.facebook.drawee.drawable.AutoRotateDrawable;
import com.facebook.drawee.drawable.ScalingUtils;
import com.facebook.imagepipeline.systrace.FrescoSystrace;
import javax.annotation.Nullable;

public class GenericDraweeHierarchyInflater {
    public static GenericDraweeHierarchy inflateHierarchy(Context context, @Nullable AttributeSet attrs) {
        return inflateBuilder(context, attrs).build();
    }

    public static GenericDraweeHierarchyBuilder inflateBuilder(Context context, @Nullable AttributeSet attrs) {
        if (FrescoSystrace.isTracing()) {
            FrescoSystrace.beginSection("GenericDraweeHierarchyBuilder#inflateBuilder");
        }
        GenericDraweeHierarchyBuilder builder = updateBuilder(new GenericDraweeHierarchyBuilder(context.getResources()), context, attrs);
        if (FrescoSystrace.isTracing()) {
            FrescoSystrace.endSection();
        }
        return builder;
    }

    /* JADX WARNING: Removed duplicated region for block: B:148:0x024d  */
    /* JADX WARNING: Removed duplicated region for block: B:166:0x0279  */
    public static GenericDraweeHierarchyBuilder updateBuilder(GenericDraweeHierarchyBuilder builder, Context context, @Nullable AttributeSet attrs) {
        Throwable th;
        boolean z;
        int i;
        Context context2 = context;
        int progressBarAutoRotateInterval = 0;
        int roundedCornerRadius = 0;
        boolean roundTopLeft = true;
        boolean roundTopRight = true;
        boolean roundBottomLeft = true;
        boolean roundBottomRight = true;
        boolean roundTopStart = true;
        boolean roundTopEnd = true;
        boolean roundBottomStart = true;
        boolean roundBottomEnd = true;
        if (attrs != null) {
            TypedArray gdhAttrs = context2.obtainStyledAttributes(attrs, R.styleable.GenericDraweeHierarchy);
            try {
                int indexCount = gdhAttrs.getIndexCount();
                int i2 = 0;
                while (i2 < indexCount) {
                    int attr = gdhAttrs.getIndex(i2);
                    indexCount = indexCount;
                    if (attr == R.styleable.GenericDraweeHierarchy_actualImageScaleType) {
                        builder.setActualImageScaleType(getScaleTypeFromXml(gdhAttrs, attr));
                        i = i2;
                    } else if (attr == R.styleable.GenericDraweeHierarchy_placeholderImage) {
                        builder.setPlaceholderImage(getDrawable(context2, gdhAttrs, attr));
                        i = i2;
                    } else if (attr == R.styleable.GenericDraweeHierarchy_pressedStateOverlayImage) {
                        builder.setPressedStateOverlay(getDrawable(context2, gdhAttrs, attr));
                        i = i2;
                    } else if (attr == R.styleable.GenericDraweeHierarchy_progressBarImage) {
                        builder.setProgressBarImage(getDrawable(context2, gdhAttrs, attr));
                        i = i2;
                    } else if (attr == R.styleable.GenericDraweeHierarchy_fadeDuration) {
                        i = i2;
                        try {
                            builder.setFadeDuration(gdhAttrs.getInt(attr, 0));
                        } catch (Throwable th2) {
                            th = th2;
                            gdhAttrs.recycle();
                            if (Build.VERSION.SDK_INT < 17) {
                                z = true;
                                if (context.getResources().getConfiguration().getLayoutDirection() == 1) {
                                    if (!roundTopLeft || !roundTopEnd) {
                                    }
                                    if (!roundTopRight || !roundTopStart) {
                                    }
                                    if (!roundBottomRight || !roundBottomStart) {
                                    }
                                    if (!roundBottomLeft || !roundBottomEnd) {
                                        z = false;
                                    }
                                    throw th;
                                }
                            } else {
                                z = true;
                            }
                            if (roundTopLeft || !roundTopStart) {
                            }
                            if (roundTopRight || !roundTopEnd) {
                            }
                            if (roundBottomRight || !roundBottomEnd) {
                            }
                            if (!roundBottomLeft || !roundBottomStart) {
                                z = false;
                            }
                            throw th;
                        }
                    } else {
                        i = i2;
                        if (attr == R.styleable.GenericDraweeHierarchy_viewAspectRatio) {
                            builder.setDesiredAspectRatio(gdhAttrs.getFloat(attr, 0.0f));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_placeholderImageScaleType) {
                            builder.setPlaceholderImageScaleType(getScaleTypeFromXml(gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_retryImage) {
                            builder.setRetryImage(getDrawable(context2, gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_retryImageScaleType) {
                            builder.setRetryImageScaleType(getScaleTypeFromXml(gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_failureImage) {
                            builder.setFailureImage(getDrawable(context2, gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_failureImageScaleType) {
                            builder.setFailureImageScaleType(getScaleTypeFromXml(gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_progressBarImageScaleType) {
                            builder.setProgressBarImageScaleType(getScaleTypeFromXml(gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_progressBarAutoRotateInterval) {
                            progressBarAutoRotateInterval = gdhAttrs.getInteger(attr, progressBarAutoRotateInterval);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_backgroundImage) {
                            builder.setBackground(getDrawable(context2, gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_overlayImage) {
                            builder.setOverlay(getDrawable(context2, gdhAttrs, attr));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundAsCircle) {
                            getRoundingParams(builder).setRoundAsCircle(gdhAttrs.getBoolean(attr, false));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundedCornerRadius) {
                            roundedCornerRadius = gdhAttrs.getDimensionPixelSize(attr, roundedCornerRadius);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundTopLeft) {
                            roundTopLeft = gdhAttrs.getBoolean(attr, roundTopLeft);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundTopRight) {
                            roundTopRight = gdhAttrs.getBoolean(attr, roundTopRight);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundBottomLeft) {
                            roundBottomLeft = gdhAttrs.getBoolean(attr, roundBottomLeft);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundBottomRight) {
                            roundBottomRight = gdhAttrs.getBoolean(attr, roundBottomRight);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundTopStart) {
                            roundTopStart = gdhAttrs.getBoolean(attr, roundTopStart);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundTopEnd) {
                            roundTopEnd = gdhAttrs.getBoolean(attr, roundTopEnd);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundBottomStart) {
                            roundBottomStart = gdhAttrs.getBoolean(attr, roundBottomStart);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundBottomEnd) {
                            roundBottomEnd = gdhAttrs.getBoolean(attr, roundBottomEnd);
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundWithOverlayColor) {
                            getRoundingParams(builder).setOverlayColor(gdhAttrs.getColor(attr, 0));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundingBorderWidth) {
                            getRoundingParams(builder).setBorderWidth((float) gdhAttrs.getDimensionPixelSize(attr, 0));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundingBorderColor) {
                            getRoundingParams(builder).setBorderColor(gdhAttrs.getColor(attr, 0));
                        } else if (attr == R.styleable.GenericDraweeHierarchy_roundingBorderPadding) {
                            getRoundingParams(builder).setPadding((float) gdhAttrs.getDimensionPixelSize(attr, 0));
                        }
                    }
                    i2 = i + 1;
                    context2 = context;
                }
                gdhAttrs.recycle();
                if (Build.VERSION.SDK_INT < 17 || context.getResources().getConfiguration().getLayoutDirection() != 1) {
                    roundTopLeft = roundTopLeft && roundTopStart;
                    roundTopRight = roundTopRight && roundTopEnd;
                    roundBottomRight = roundBottomRight && roundBottomEnd;
                    roundBottomLeft = roundBottomLeft && roundBottomStart;
                } else {
                    roundTopLeft = roundTopLeft && roundTopEnd;
                    roundTopRight = roundTopRight && roundTopStart;
                    roundBottomRight = roundBottomRight && roundBottomStart;
                    roundBottomLeft = roundBottomLeft && roundBottomEnd;
                }
            } catch (Throwable th3) {
                th = th3;
                gdhAttrs.recycle();
                if (Build.VERSION.SDK_INT < 17) {
                }
                if (roundTopLeft) {
                }
                if (roundTopRight) {
                }
                if (roundBottomRight) {
                }
                z = false;
                throw th;
            }
        }
        if (builder.getProgressBarImage() != null && progressBarAutoRotateInterval > 0) {
            builder.setProgressBarImage(new AutoRotateDrawable(builder.getProgressBarImage(), progressBarAutoRotateInterval));
        }
        if (roundedCornerRadius > 0) {
            getRoundingParams(builder).setCornersRadii(roundTopLeft ? (float) roundedCornerRadius : 0.0f, roundTopRight ? (float) roundedCornerRadius : 0.0f, roundBottomRight ? (float) roundedCornerRadius : 0.0f, roundBottomLeft ? (float) roundedCornerRadius : 0.0f);
        }
        return builder;
    }

    private static RoundingParams getRoundingParams(GenericDraweeHierarchyBuilder builder) {
        if (builder.getRoundingParams() == null) {
            builder.setRoundingParams(new RoundingParams());
        }
        return builder.getRoundingParams();
    }

    @Nullable
    private static Drawable getDrawable(Context context, TypedArray gdhAttrs, int attrId) {
        int resourceId = gdhAttrs.getResourceId(attrId, 0);
        if (resourceId == 0) {
            return null;
        }
        return context.getResources().getDrawable(resourceId);
    }

    @Nullable
    private static ScalingUtils.ScaleType getScaleTypeFromXml(TypedArray gdhAttrs, int attrId) {
        switch (gdhAttrs.getInt(attrId, -2)) {
            case -1:
                return null;
            case 0:
                return ScalingUtils.ScaleType.FIT_XY;
            case 1:
                return ScalingUtils.ScaleType.FIT_START;
            case 2:
                return ScalingUtils.ScaleType.FIT_CENTER;
            case 3:
                return ScalingUtils.ScaleType.FIT_END;
            case 4:
                return ScalingUtils.ScaleType.CENTER;
            case 5:
                return ScalingUtils.ScaleType.CENTER_INSIDE;
            case 6:
                return ScalingUtils.ScaleType.CENTER_CROP;
            case 7:
                return ScalingUtils.ScaleType.FOCUS_CROP;
            case 8:
                return ScalingUtils.ScaleType.FIT_BOTTOM_START;
            default:
                throw new RuntimeException("XML attribute not specified!");
        }
    }
}
