package com.facebook.imagepipeline.memory;

import android.util.SparseArray;
import com.taobao.weex.el.parse.Operators;
import java.util.LinkedList;
import javax.annotation.Nullable;

public class BucketMap<T> {
    @Nullable
    LinkedEntry<T> mHead;
    protected final SparseArray<LinkedEntry<T>> mMap = new SparseArray<>();
    @Nullable
    LinkedEntry<T> mTail;

    /* access modifiers changed from: package-private */
    public static class LinkedEntry<I> {
        int key;
        @Nullable
        LinkedEntry<I> next;
        @Nullable
        LinkedEntry<I> prev;
        LinkedList<I> value;

        private LinkedEntry(@Nullable LinkedEntry<I> prev2, int key2, LinkedList<I> value2, @Nullable LinkedEntry<I> next2) {
            this.prev = prev2;
            this.key = key2;
            this.value = value2;
            this.next = next2;
        }

        public String toString() {
            return "LinkedEntry(key: " + this.key + Operators.BRACKET_END_STR;
        }
    }

    /* JADX WARN: Type inference failed for: r1v1, types: [T, java.lang.Object] */
    @Nullable
    public synchronized T acquire(int key) {
        LinkedEntry<T> bucket = this.mMap.get(key);
        if (bucket == null) {
            return null;
        }
        I pollFirst = bucket.value.pollFirst();
        moveToFront(bucket);
        return pollFirst;
    }

    public synchronized void release(int key, T value) {
        LinkedEntry<T> bucket = this.mMap.get(key);
        if (bucket == null) {
            bucket = new LinkedEntry<>(null, key, new LinkedList(), null);
            this.mMap.put(key, bucket);
        }
        bucket.value.addLast(value);
        moveToFront(bucket);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX DEBUG: Type inference failed for r2v1. Raw type applied. Possible types: com.facebook.imagepipeline.memory.BucketMap$LinkedEntry<I> */
    /* access modifiers changed from: package-private */
    public synchronized int valueCount() {
        int count;
        count = 0;
        for (LinkedEntry entry = this.mHead; entry != null; entry = (LinkedEntry<I>) entry.next) {
            if (entry.value != null) {
                count += entry.value.size();
            }
        }
        return count;
    }

    private synchronized void prune(LinkedEntry<T> bucket) {
        LinkedEntry linkedEntry = (LinkedEntry<I>) bucket.prev;
        LinkedEntry linkedEntry2 = (LinkedEntry<I>) bucket.next;
        if (linkedEntry != null) {
            linkedEntry.next = linkedEntry2;
        }
        if (linkedEntry2 != null) {
            linkedEntry2.prev = linkedEntry;
        }
        bucket.prev = null;
        bucket.next = null;
        if (bucket == this.mHead) {
            this.mHead = linkedEntry2;
        }
        if (bucket == this.mTail) {
            this.mTail = linkedEntry;
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: com.facebook.imagepipeline.memory.BucketMap$LinkedEntry<T> */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX DEBUG: Type inference failed for r0v1. Raw type applied. Possible types: com.facebook.imagepipeline.memory.BucketMap$LinkedEntry<T>, com.facebook.imagepipeline.memory.BucketMap$LinkedEntry<I> */
    private void moveToFront(LinkedEntry<T> bucket) {
        if (this.mHead != bucket) {
            prune(bucket);
            LinkedEntry linkedEntry = (LinkedEntry<T>) this.mHead;
            if (linkedEntry == null) {
                this.mHead = bucket;
                this.mTail = bucket;
                return;
            }
            bucket.next = linkedEntry;
            this.mHead.prev = bucket;
            this.mHead = bucket;
        }
    }

    /* JADX WARN: Type inference failed for: r1v1, types: [T, java.lang.Object] */
    @Nullable
    public synchronized T removeFromEnd() {
        LinkedEntry<T> last = this.mTail;
        if (last == null) {
            return null;
        }
        I pollLast = last.value.pollLast();
        maybePrune(last);
        return pollLast;
    }

    private void maybePrune(LinkedEntry<T> bucket) {
        if (bucket != null && bucket.value.isEmpty()) {
            prune(bucket);
            this.mMap.remove(bucket.key);
        }
    }
}
