package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.amf.AmfNumber;
import com.github.faucamp.simplertmp.amf.AmfString;
import com.github.faucamp.simplertmp.io.ChunkStreamInfo;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

public class Command extends VariableBodyRtmpPacket {
    private static final String TAG = "Command";
    private String commandName;
    private int transactionId;

    public Command(RtmpHeader header) {
        super(header);
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public Command(String commandName2, int transactionId2, ChunkStreamInfo channelInfo) {
        super(new RtmpHeader(channelInfo.canReusePrevHeaderTx(RtmpHeader.MessageType.COMMAND_AMF0) ? RtmpHeader.ChunkType.TYPE_1_RELATIVE_LARGE : RtmpHeader.ChunkType.TYPE_0_FULL, 3, RtmpHeader.MessageType.COMMAND_AMF0));
        this.commandName = commandName2;
        this.transactionId = transactionId2;
    }

    public Command(String commandName2, int transactionId2) {
        super(new RtmpHeader(RtmpHeader.ChunkType.TYPE_0_FULL, 3, RtmpHeader.MessageType.COMMAND_AMF0));
        this.commandName = commandName2;
        this.transactionId = transactionId2;
    }

    public String getCommandName() {
        return this.commandName;
    }

    public void setCommandName(String commandName2) {
        this.commandName = commandName2;
    }

    public int getTransactionId() {
        return this.transactionId;
    }

    public void setTransactionId(int transactionId2) {
        this.transactionId = transactionId2;
    }

    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void readBody(InputStream in) throws IOException {
        this.commandName = AmfString.readStringFrom(in, false);
        this.transactionId = (int) AmfNumber.readNumberFrom(in);
        readVariableData(in, AmfString.sizeOf(this.commandName, false) + 9);
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void writeBody(OutputStream out) throws IOException {
        AmfString.writeStringTo(out, this.commandName, false);
        AmfNumber.writeNumberTo(out, (double) this.transactionId);
        writeVariableData(out);
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public byte[] array() {
        return null;
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public int size() {
        return 0;
    }

    public String toString() {
        return "RTMP Command (command: " + this.commandName + ", transaction ID: " + this.transactionId + Operators.BRACKET_END_STR;
    }
}
