package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.Util;
import com.github.faucamp.simplertmp.io.ChunkStreamInfo;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

public class SetPeerBandwidth extends RtmpPacket {
    private int acknowledgementWindowSize;
    private LimitType limitType;

    public enum LimitType {
        HARD(0),
        SOFT(1),
        DYNAMIC(2);
        
        private static final Map<Integer, LimitType> quickLookupMap = new HashMap();
        private int intValue;

        static {
            LimitType[] values = values();
            for (LimitType type : values) {
                quickLookupMap.put(Integer.valueOf(type.getIntValue()), type);
            }
        }

        private LimitType(int intValue2) {
            this.intValue = intValue2;
        }

        public int getIntValue() {
            return this.intValue;
        }

        public static LimitType valueOf(int intValue2) {
            return quickLookupMap.get(Integer.valueOf(intValue2));
        }
    }

    public SetPeerBandwidth(RtmpHeader header) {
        super(header);
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public SetPeerBandwidth(int acknowledgementWindowSize2, LimitType limitType2, ChunkStreamInfo channelInfo) {
        super(new RtmpHeader(channelInfo.canReusePrevHeaderTx(RtmpHeader.MessageType.SET_PEER_BANDWIDTH) ? RtmpHeader.ChunkType.TYPE_2_RELATIVE_TIMESTAMP_ONLY : RtmpHeader.ChunkType.TYPE_0_FULL, 2, RtmpHeader.MessageType.WINDOW_ACKNOWLEDGEMENT_SIZE));
        this.acknowledgementWindowSize = acknowledgementWindowSize2;
        this.limitType = limitType2;
    }

    public int getAcknowledgementWindowSize() {
        return this.acknowledgementWindowSize;
    }

    public void setAcknowledgementWindowSize(int acknowledgementWindowSize2) {
        this.acknowledgementWindowSize = acknowledgementWindowSize2;
    }

    public LimitType getLimitType() {
        return this.limitType;
    }

    public void setLimitType(LimitType limitType2) {
        this.limitType = limitType2;
    }

    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void readBody(InputStream in) throws IOException {
        this.acknowledgementWindowSize = Util.readUnsignedInt32(in);
        this.limitType = LimitType.valueOf(in.read());
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void writeBody(OutputStream out) throws IOException {
        Util.writeUnsignedInt32(out, this.acknowledgementWindowSize);
        out.write(this.limitType.getIntValue());
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public byte[] array() {
        return null;
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public int size() {
        return 0;
    }

    public String toString() {
        return "RTMP Set Peer Bandwidth";
    }
}
