package com.github.faucamp.simplertmp.packets;

import com.github.faucamp.simplertmp.Util;
import com.github.faucamp.simplertmp.io.ChunkStreamInfo;
import com.github.faucamp.simplertmp.packets.RtmpHeader;
import com.taobao.weex.el.parse.Operators;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.HashMap;
import java.util.Map;

public class UserControl extends RtmpPacket {
    static final /* synthetic */ boolean $assertionsDisabled = false;
    private int[] eventData;
    private Type type;

    public enum Type {
        STREAM_BEGIN(0),
        STREAM_EOF(1),
        STREAM_DRY(2),
        SET_BUFFER_LENGTH(3),
        STREAM_IS_RECORDED(4),
        PING_REQUEST(6),
        PONG_REPLY(7),
        BUFFER_EMPTY(31),
        BUFFER_READY(32);
        
        private static final Map<Integer, Type> quickLookupMap = new HashMap();
        private int intValue;

        static {
            Type[] values = values();
            for (Type type : values) {
                quickLookupMap.put(Integer.valueOf(type.getIntValue()), type);
            }
        }

        private Type(int intValue2) {
            this.intValue = intValue2;
        }

        public int getIntValue() {
            return this.intValue;
        }

        public static Type valueOf(int intValue2) {
            return quickLookupMap.get(Integer.valueOf(intValue2));
        }
    }

    public UserControl(RtmpHeader header) {
        super(header);
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public UserControl(ChunkStreamInfo channelInfo) {
        super(new RtmpHeader(channelInfo.canReusePrevHeaderTx(RtmpHeader.MessageType.USER_CONTROL_MESSAGE) ? RtmpHeader.ChunkType.TYPE_2_RELATIVE_TIMESTAMP_ONLY : RtmpHeader.ChunkType.TYPE_0_FULL, 2, RtmpHeader.MessageType.USER_CONTROL_MESSAGE));
    }

    public UserControl(UserControl replyToPing, ChunkStreamInfo channelInfo) {
        this(Type.PONG_REPLY, channelInfo);
        this.eventData = replyToPing.eventData;
    }

    public UserControl(Type type2, ChunkStreamInfo channelInfo) {
        this(channelInfo);
        this.type = type2;
    }

    public Type getType() {
        return this.type;
    }

    public void setType(Type type2) {
        this.type = type2;
    }

    public int getFirstEventData() {
        return this.eventData[0];
    }

    public int[] getEventData() {
        return this.eventData;
    }

    public void setEventData(int eventData2) {
        if (this.type != Type.SET_BUFFER_LENGTH) {
            this.eventData = new int[]{eventData2};
            return;
        }
        throw new IllegalStateException("SET_BUFFER_LENGTH requires two event data values; use setEventData(int, int) instead");
    }

    public void setEventData(int streamId, int bufferLength) {
        if (this.type == Type.SET_BUFFER_LENGTH) {
            this.eventData = new int[]{streamId, bufferLength};
            return;
        }
        throw new IllegalStateException("User control type " + this.type + " requires only one event data value; use setEventData(int) instead");
    }

    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void readBody(InputStream in) throws IOException {
        Type valueOf = Type.valueOf(Util.readUnsignedInt16(in));
        this.type = valueOf;
        if (valueOf == Type.SET_BUFFER_LENGTH) {
            setEventData(Util.readUnsignedInt32(in), Util.readUnsignedInt32(in));
            int bytesRead = 2 + 8;
            return;
        }
        setEventData(Util.readUnsignedInt32(in));
        int bytesRead2 = 2 + 4;
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public void writeBody(OutputStream out) throws IOException {
        Util.writeUnsignedInt16(out, this.type.getIntValue());
        Util.writeUnsignedInt32(out, this.eventData[0]);
        if (this.type == Type.SET_BUFFER_LENGTH) {
            Util.writeUnsignedInt32(out, this.eventData[1]);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public byte[] array() {
        return null;
    }

    /* access modifiers changed from: protected */
    @Override // com.github.faucamp.simplertmp.packets.RtmpPacket
    public int size() {
        return 0;
    }

    public String toString() {
        return "RTMP User Control (type: " + this.type + ", event data: " + this.eventData + Operators.BRACKET_END_STR;
    }
}
