package com.googlecode.mp4parser.authoring.tracks;

import com.coremedia.iso.boxes.Box;
import com.coremedia.iso.boxes.CompositionTimeToSample;
import com.coremedia.iso.boxes.SampleDependencyTypeBox;
import com.coremedia.iso.boxes.SampleDescriptionBox;
import com.coremedia.iso.boxes.SubSampleInformationBox;
import com.coremedia.iso.boxes.TimeToSampleBox;
import com.coremedia.iso.boxes.sampleentry.AudioSampleEntry;
import com.googlecode.mp4parser.authoring.AbstractTrack;
import com.googlecode.mp4parser.authoring.Track;
import com.googlecode.mp4parser.authoring.TrackMetaData;
import com.googlecode.mp4parser.boxes.mp4.ESDescriptorBox;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.DecoderConfigDescriptor;
import com.googlecode.mp4parser.boxes.mp4.objectdescriptors.ESDescriptor;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.Channels;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

public class AppendTrack extends AbstractTrack {
    SampleDescriptionBox stsd;
    Track[] tracks;

    public AppendTrack(Track... tracks2) throws IOException {
        AudioSampleEntry aseResult;
        this.tracks = tracks2;
        for (Track track : tracks2) {
            if (this.stsd == null) {
                this.stsd = track.getSampleDescriptionBox();
            } else {
                ByteArrayOutputStream curBaos = new ByteArrayOutputStream();
                ByteArrayOutputStream refBaos = new ByteArrayOutputStream();
                track.getSampleDescriptionBox().getBox(Channels.newChannel(curBaos));
                this.stsd.getBox(Channels.newChannel(refBaos));
                if (!Arrays.equals(refBaos.toByteArray(), curBaos.toByteArray())) {
                    SampleDescriptionBox curStsd = track.getSampleDescriptionBox();
                    if (this.stsd.getBoxes().size() != 1 || curStsd.getBoxes().size() != 1 || !(this.stsd.getBoxes().get(0) instanceof AudioSampleEntry) || !(curStsd.getBoxes().get(0) instanceof AudioSampleEntry) || (aseResult = mergeAudioSampleEntries((AudioSampleEntry) this.stsd.getBoxes().get(0), (AudioSampleEntry) curStsd.getBoxes().get(0))) == null) {
                        throw new IOException("Cannot append " + track + " to " + tracks2[0] + " since their Sample Description Boxes differ: \n" + track.getSampleDescriptionBox() + "\n vs. \n" + tracks2[0].getSampleDescriptionBox());
                    }
                    this.stsd.setBoxes(Collections.singletonList(aseResult));
                    return;
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:107:0x0295  */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x02a4  */
    /* JADX WARNING: Removed duplicated region for block: B:132:0x0214 A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0215  */
    private AudioSampleEntry mergeAudioSampleEntries(AudioSampleEntry ase1, AudioSampleEntry ase2) throws IOException {
        DecoderConfigDescriptor dcd1;
        DecoderConfigDescriptor dcd2;
        if (!ase1.getType().equals(ase2.getType())) {
            return null;
        }
        AudioSampleEntry ase = new AudioSampleEntry(ase2.getType());
        if (ase1.getBytesPerFrame() != ase2.getBytesPerFrame()) {
            return null;
        }
        ase.setBytesPerFrame(ase1.getBytesPerFrame());
        if (ase1.getBytesPerPacket() != ase2.getBytesPerPacket()) {
            return null;
        }
        ase.setBytesPerPacket(ase1.getBytesPerPacket());
        if (ase1.getBytesPerSample() != ase2.getBytesPerSample()) {
            return null;
        }
        ase.setBytesPerSample(ase1.getBytesPerSample());
        if (ase1.getChannelCount() != ase2.getChannelCount()) {
            return null;
        }
        ase.setChannelCount(ase1.getChannelCount());
        if (ase1.getPacketSize() != ase2.getPacketSize()) {
            return null;
        }
        ase.setPacketSize(ase1.getPacketSize());
        if (ase1.getCompressionId() != ase2.getCompressionId()) {
            return null;
        }
        ase.setCompressionId(ase1.getCompressionId());
        if (ase1.getSampleRate() != ase2.getSampleRate()) {
            return null;
        }
        ase.setSampleRate(ase1.getSampleRate());
        if (ase1.getSampleSize() != ase2.getSampleSize()) {
            return null;
        }
        ase.setSampleSize(ase1.getSampleSize());
        if (ase1.getSamplesPerPacket() != ase2.getSamplesPerPacket()) {
            return null;
        }
        ase.setSamplesPerPacket(ase1.getSamplesPerPacket());
        if (ase1.getSoundVersion() != ase2.getSoundVersion()) {
            return null;
        }
        ase.setSoundVersion(ase1.getSoundVersion());
        if (!Arrays.equals(ase1.getSoundVersion2Data(), ase2.getSoundVersion2Data())) {
            return null;
        }
        ase.setSoundVersion2Data(ase1.getSoundVersion2Data());
        if (ase1.getBoxes().size() == ase2.getBoxes().size()) {
            Iterator<Box> bxs2 = ase2.getBoxes().iterator();
            for (Box cur1 : ase1.getBoxes()) {
                Box cur2 = bxs2.next();
                ByteArrayOutputStream baos1 = new ByteArrayOutputStream();
                ByteArrayOutputStream baos2 = new ByteArrayOutputStream();
                cur1.getBox(Channels.newChannel(baos1));
                cur2.getBox(Channels.newChannel(baos2));
                if (Arrays.equals(baos1.toByteArray(), baos2.toByteArray())) {
                    ase.addBox(cur1);
                } else if (ESDescriptorBox.TYPE.equals(cur1.getType()) && ESDescriptorBox.TYPE.equals(cur2.getType())) {
                    ESDescriptor esds1 = ((ESDescriptorBox) cur1).getEsDescriptor();
                    ESDescriptor esds2 = ((ESDescriptorBox) cur2).getEsDescriptor();
                    if (!(esds1.getURLFlag() == esds2.getURLFlag() && esds1.getURLLength() == esds2.getURLLength() && esds1.getDependsOnEsId() == esds2.getDependsOnEsId() && esds1.getEsId() == esds2.getEsId() && esds1.getoCREsId() == esds2.getoCREsId() && esds1.getoCRstreamFlag() == esds2.getoCRstreamFlag() && esds1.getRemoteODFlag() == esds2.getRemoteODFlag() && esds1.getStreamDependenceFlag() == esds2.getStreamDependenceFlag() && esds1.getStreamPriority() == esds2.getStreamPriority())) {
                        return null;
                    }
                    if (esds1.getURLString() != null) {
                        if (!esds1.getURLString().equals(esds2.getURLString())) {
                        }
                        if (esds1.getDecoderConfigDescriptor() == null ? esds2.getDecoderConfigDescriptor() != null : !esds1.getDecoderConfigDescriptor().equals(esds2.getDecoderConfigDescriptor())) {
                            dcd1 = esds1.getDecoderConfigDescriptor();
                            dcd2 = esds2.getDecoderConfigDescriptor();
                            if (dcd1.getAudioSpecificInfo().equals(dcd2.getAudioSpecificInfo())) {
                                return null;
                            }
                            dcd1.getAvgBitRate();
                            dcd2.getAvgBitRate();
                            dcd1.getBufferSizeDB();
                            dcd2.getBufferSizeDB();
                            if (dcd1.getDecoderSpecificInfo() != null) {
                                if (!dcd1.getDecoderSpecificInfo().equals(dcd2.getDecoderSpecificInfo())) {
                                }
                                dcd1.getMaxBitRate();
                                dcd2.getMaxBitRate();
                                if (!(dcd1.getProfileLevelIndicationDescriptors().equals(dcd2.getProfileLevelIndicationDescriptors()) && dcd1.getObjectTypeIndication() == dcd2.getObjectTypeIndication() && dcd1.getStreamType() == dcd2.getStreamType() && dcd1.getUpStream() == dcd2.getUpStream())) {
                                    return null;
                                }
                            } else {
                                if (dcd2.getDecoderSpecificInfo() != null) {
                                }
                                dcd1.getMaxBitRate();
                                dcd2.getMaxBitRate();
                                return null;
                            }
                            return null;
                        }
                        if (esds1.getOtherDescriptors() != null) {
                            if (!esds1.getOtherDescriptors().equals(esds2.getOtherDescriptors())) {
                            }
                            if (esds1.getSlConfigDescriptor() == null) {
                                if (!esds1.getSlConfigDescriptor().equals(esds2.getSlConfigDescriptor())) {
                                }
                                ase.addBox(cur1);
                            } else {
                                if (esds2.getSlConfigDescriptor() != null) {
                                }
                                ase.addBox(cur1);
                            }
                            return null;
                        }
                        if (esds2.getOtherDescriptors() != null) {
                        }
                        if (esds1.getSlConfigDescriptor() == null) {
                        }
                        return null;
                        return null;
                    }
                    if (esds2.getURLString() != null) {
                    }
                    dcd1 = esds1.getDecoderConfigDescriptor();
                    dcd2 = esds2.getDecoderConfigDescriptor();
                    if (dcd1.getAudioSpecificInfo().equals(dcd2.getAudioSpecificInfo())) {
                    }
                    return null;
                }
            }
        }
        return ase;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<ByteBuffer> getSamples() {
        ArrayList<ByteBuffer> lists = new ArrayList<>();
        for (Track track : this.tracks) {
            lists.addAll(track.getSamples());
        }
        return lists;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SampleDescriptionBox getSampleDescriptionBox() {
        return this.stsd;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<TimeToSampleBox.Entry> getDecodingTimeEntries() {
        if (this.tracks[0].getDecodingTimeEntries() == null || this.tracks[0].getDecodingTimeEntries().isEmpty()) {
            return null;
        }
        List<long[]> lists = new LinkedList<>();
        for (Track track : this.tracks) {
            lists.add(TimeToSampleBox.blowupTimeToSamples(track.getDecodingTimeEntries()));
        }
        LinkedList<TimeToSampleBox.Entry> returnDecodingEntries = new LinkedList<>();
        for (long[] list : lists) {
            for (long nuDecodingTime : list) {
                if (returnDecodingEntries.isEmpty() || returnDecodingEntries.getLast().getDelta() != nuDecodingTime) {
                    returnDecodingEntries.add(new TimeToSampleBox.Entry(1, nuDecodingTime));
                } else {
                    TimeToSampleBox.Entry e = returnDecodingEntries.getLast();
                    e.setCount(e.getCount() + 1);
                }
            }
        }
        return returnDecodingEntries;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<CompositionTimeToSample.Entry> getCompositionTimeEntries() {
        if (this.tracks[0].getCompositionTimeEntries() == null || this.tracks[0].getCompositionTimeEntries().isEmpty()) {
            return null;
        }
        List<int[]> lists = new LinkedList<>();
        for (Track track : this.tracks) {
            lists.add(CompositionTimeToSample.blowupCompositionTimes(track.getCompositionTimeEntries()));
        }
        LinkedList<CompositionTimeToSample.Entry> compositionTimeEntries = new LinkedList<>();
        for (int[] list : lists) {
            for (int compositionTime : list) {
                if (compositionTimeEntries.isEmpty() || compositionTimeEntries.getLast().getOffset() != compositionTime) {
                    compositionTimeEntries.add(new CompositionTimeToSample.Entry(1, compositionTime));
                } else {
                    CompositionTimeToSample.Entry e = compositionTimeEntries.getLast();
                    e.setCount(e.getCount() + 1);
                }
            }
        }
        return compositionTimeEntries;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public long[] getSyncSamples() {
        if (this.tracks[0].getSyncSamples() == null || this.tracks[0].getSyncSamples().length <= 0) {
            return null;
        }
        int numSyncSamples = 0;
        for (Track track : this.tracks) {
            numSyncSamples += track.getSyncSamples().length;
        }
        long[] returnSyncSamples = new long[numSyncSamples];
        int pos = 0;
        long samplesBefore = 0;
        Track[] trackArr = this.tracks;
        for (Track track2 : trackArr) {
            long[] syncSamples = track2.getSyncSamples();
            int length = syncSamples.length;
            int i = 0;
            while (i < length) {
                returnSyncSamples[pos] = samplesBefore + syncSamples[i];
                i++;
                pos++;
            }
            samplesBefore += (long) track2.getSamples().size();
        }
        return returnSyncSamples;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public List<SampleDependencyTypeBox.Entry> getSampleDependencies() {
        if (this.tracks[0].getSampleDependencies() == null || this.tracks[0].getSampleDependencies().isEmpty()) {
            return null;
        }
        List<SampleDependencyTypeBox.Entry> list = new LinkedList<>();
        for (Track track : this.tracks) {
            list.addAll(track.getSampleDependencies());
        }
        return list;
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public TrackMetaData getTrackMetaData() {
        return this.tracks[0].getTrackMetaData();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public String getHandler() {
        return this.tracks[0].getHandler();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public Box getMediaHeaderBox() {
        return this.tracks[0].getMediaHeaderBox();
    }

    @Override // com.googlecode.mp4parser.authoring.Track
    public SubSampleInformationBox getSubsampleInformationBox() {
        return this.tracks[0].getSubsampleInformationBox();
    }
}
