package com.heytap.msp.push.encrypt;

import com.taobao.weex.el.parse.Operators;
import com.umeng.analytics.pro.cv;
import java.math.BigInteger;
import org.apache.commons.codec.binary.StringUtils;
import org.mozilla.universalchardet.prober.HebrewProber;

public class Base64 extends BaseNCodec {
    private static final int BITS_PER_ENCODED_BYTE = 6;
    private static final int BYTES_PER_ENCODED_BLOCK = 4;
    private static final int BYTES_PER_UNENCODED_BLOCK = 3;
    static final byte[] CHUNK_SEPARATOR = {cv.k, 10};
    private static final byte[] DECODE_TABLE = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, 62, -1, 63, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -1, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, cv.k, cv.l, cv.m, cv.n, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, 63, -1, 26, 27, 28, 29, 30, 31, HebrewProber.SPACE, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51};
    private static final int MASK_6BITS = 63;
    private static final byte[] STANDARD_ENCODE_TABLE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 43, 47};
    private static final byte[] URL_SAFE_ENCODE_TABLE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 45, 95};
    private int bitWorkArea;
    private final int decodeSize;
    private final byte[] decodeTable;
    private final int encodeSize;
    private final byte[] encodeTable;
    private final byte[] lineSeparator;

    public Base64() {
        this(0);
    }

    public Base64(boolean urlSafe) {
        this(76, CHUNK_SEPARATOR, urlSafe);
    }

    public Base64(int lineLength) {
        this(lineLength, CHUNK_SEPARATOR);
    }

    public Base64(int lineLength, byte[] lineSeparator2) {
        this(lineLength, lineSeparator2, false);
    }

    /* JADX INFO: super call moved to the top of the method (can break code semantics) */
    public Base64(int lineLength, byte[] lineSeparator2, boolean urlSafe) {
        super(3, 4, lineLength, lineSeparator2 == null ? 0 : lineSeparator2.length);
        this.decodeTable = DECODE_TABLE;
        if (lineSeparator2 == null) {
            this.encodeSize = 4;
            this.lineSeparator = null;
        } else if (containsAlphabetOrPad(lineSeparator2)) {
            String sep = StringUtils.newStringUtf8(lineSeparator2);
            throw new IllegalArgumentException("lineSeparator must not contain base64 characters: [" + sep + Operators.ARRAY_END_STR);
        } else if (lineLength > 0) {
            this.encodeSize = lineSeparator2.length + 4;
            byte[] bArr = new byte[lineSeparator2.length];
            this.lineSeparator = bArr;
            System.arraycopy(lineSeparator2, 0, bArr, 0, lineSeparator2.length);
        } else {
            this.encodeSize = 4;
            this.lineSeparator = null;
        }
        this.decodeSize = this.encodeSize - 1;
        this.encodeTable = urlSafe ? URL_SAFE_ENCODE_TABLE : STANDARD_ENCODE_TABLE;
    }

    public boolean isUrlSafe() {
        return this.encodeTable == URL_SAFE_ENCODE_TABLE;
    }

    /* JADX INFO: Multiple debug info for r10v2 byte: [D('inPos' int), D('b' int)] */
    /* access modifiers changed from: package-private */
    @Override // com.heytap.msp.push.encrypt.BaseNCodec
    public void encode(byte[] in, int inPos, int inAvail) {
        if (!this.eof) {
            if (inAvail < 0) {
                this.eof = true;
                if (this.modulus != 0 || this.lineLength != 0) {
                    ensureBufferSize(this.encodeSize);
                    int savedPos = this.pos;
                    int i = this.modulus;
                    if (i == 1) {
                        byte[] bArr = this.buffer;
                        int i2 = this.pos;
                        this.pos = i2 + 1;
                        bArr[i2] = this.encodeTable[(this.bitWorkArea >> 2) & 63];
                        byte[] bArr2 = this.buffer;
                        int i3 = this.pos;
                        this.pos = i3 + 1;
                        byte[] bArr3 = this.encodeTable;
                        bArr2[i3] = bArr3[(this.bitWorkArea << 4) & 63];
                        if (bArr3 == STANDARD_ENCODE_TABLE) {
                            byte[] bArr4 = this.buffer;
                            int i4 = this.pos;
                            this.pos = i4 + 1;
                            bArr4[i4] = 61;
                            byte[] bArr5 = this.buffer;
                            int i5 = this.pos;
                            this.pos = i5 + 1;
                            bArr5[i5] = 61;
                        }
                    } else if (i == 2) {
                        byte[] bArr6 = this.buffer;
                        int i6 = this.pos;
                        this.pos = i6 + 1;
                        bArr6[i6] = this.encodeTable[(this.bitWorkArea >> 10) & 63];
                        byte[] bArr7 = this.buffer;
                        int i7 = this.pos;
                        this.pos = i7 + 1;
                        bArr7[i7] = this.encodeTable[(this.bitWorkArea >> 4) & 63];
                        byte[] bArr8 = this.buffer;
                        int i8 = this.pos;
                        this.pos = i8 + 1;
                        byte[] bArr9 = this.encodeTable;
                        bArr8[i8] = bArr9[(this.bitWorkArea << 2) & 63];
                        if (bArr9 == STANDARD_ENCODE_TABLE) {
                            byte[] bArr10 = this.buffer;
                            int i9 = this.pos;
                            this.pos = i9 + 1;
                            bArr10[i9] = 61;
                        }
                    }
                    this.currentLinePos += this.pos - savedPos;
                    if (this.lineLength > 0 && this.currentLinePos > 0) {
                        System.arraycopy(this.lineSeparator, 0, this.buffer, this.pos, this.lineSeparator.length);
                        this.pos += this.lineSeparator.length;
                        return;
                    }
                    return;
                }
                return;
            }
            int i10 = 0;
            while (i10 < inAvail) {
                ensureBufferSize(this.encodeSize);
                this.modulus = (this.modulus + 1) % 3;
                int inPos2 = inPos + 1;
                byte b = in[inPos];
                int inPos3 = b;
                if (b < 0) {
                    inPos3 = b + 256;
                }
                this.bitWorkArea = (this.bitWorkArea << 8) + (inPos3 == 1 ? 1 : 0);
                if (this.modulus == 0) {
                    byte[] bArr11 = this.buffer;
                    int i11 = this.pos;
                    this.pos = i11 + 1;
                    bArr11[i11] = this.encodeTable[(this.bitWorkArea >> 18) & 63];
                    byte[] bArr12 = this.buffer;
                    int i12 = this.pos;
                    this.pos = i12 + 1;
                    bArr12[i12] = this.encodeTable[(this.bitWorkArea >> 12) & 63];
                    byte[] bArr13 = this.buffer;
                    int i13 = this.pos;
                    this.pos = i13 + 1;
                    bArr13[i13] = this.encodeTable[(this.bitWorkArea >> 6) & 63];
                    byte[] bArr14 = this.buffer;
                    int i14 = this.pos;
                    this.pos = i14 + 1;
                    bArr14[i14] = this.encodeTable[this.bitWorkArea & 63];
                    this.currentLinePos += 4;
                    if (this.lineLength > 0 && this.lineLength <= this.currentLinePos) {
                        System.arraycopy(this.lineSeparator, 0, this.buffer, this.pos, this.lineSeparator.length);
                        this.pos += this.lineSeparator.length;
                        this.currentLinePos = 0;
                    }
                }
                i10++;
                inPos = inPos2;
            }
        }
    }

    /* JADX INFO: Multiple debug info for r9v2 byte: [D('inPos' int), D('b' byte)] */
    /* access modifiers changed from: package-private */
    @Override // com.heytap.msp.push.encrypt.BaseNCodec
    public void decode(byte[] in, int inPos, int inAvail) {
        byte b;
        if (!this.eof) {
            if (inAvail < 0) {
                this.eof = true;
            }
            int i = 0;
            while (true) {
                if (i >= inAvail) {
                    break;
                }
                ensureBufferSize(this.decodeSize);
                int inPos2 = inPos + 1;
                byte b2 = in[inPos];
                if (b2 == 61) {
                    this.eof = true;
                    break;
                }
                if (b2 >= 0) {
                    byte[] bArr = DECODE_TABLE;
                    if (b2 < bArr.length && (b = bArr[b2]) >= 0) {
                        this.modulus = (this.modulus + 1) % 4;
                        this.bitWorkArea = (this.bitWorkArea << 6) + b;
                        if (this.modulus == 0) {
                            byte[] bArr2 = this.buffer;
                            int i2 = this.pos;
                            this.pos = i2 + 1;
                            bArr2[i2] = (byte) ((this.bitWorkArea >> 16) & 255);
                            byte[] bArr3 = this.buffer;
                            int i3 = this.pos;
                            this.pos = i3 + 1;
                            bArr3[i3] = (byte) ((this.bitWorkArea >> 8) & 255);
                            byte[] bArr4 = this.buffer;
                            int i4 = this.pos;
                            this.pos = i4 + 1;
                            bArr4[i4] = (byte) (this.bitWorkArea & 255);
                        }
                    }
                }
                i++;
                inPos = inPos2;
            }
            if (this.eof && this.modulus != 0) {
                ensureBufferSize(this.decodeSize);
                int i5 = this.modulus;
                if (i5 == 2) {
                    this.bitWorkArea >>= 4;
                    byte[] bArr5 = this.buffer;
                    int i6 = this.pos;
                    this.pos = i6 + 1;
                    bArr5[i6] = (byte) (this.bitWorkArea & 255);
                } else if (i5 == 3) {
                    this.bitWorkArea >>= 2;
                    byte[] bArr6 = this.buffer;
                    int i7 = this.pos;
                    this.pos = i7 + 1;
                    bArr6[i7] = (byte) ((this.bitWorkArea >> 8) & 255);
                    byte[] bArr7 = this.buffer;
                    int i8 = this.pos;
                    this.pos = i8 + 1;
                    bArr7[i8] = (byte) (this.bitWorkArea & 255);
                }
            }
        }
    }

    public static boolean isArrayByteBase64(byte[] arrayOctet) {
        return isBase64(arrayOctet);
    }

    public static boolean isBase64(byte octet) {
        if (octet != 61) {
            if (octet >= 0) {
                byte[] bArr = DECODE_TABLE;
                if (octet >= bArr.length || bArr[octet] == -1) {
                    return false;
                }
            }
            return false;
        }
        return true;
    }

    public static boolean isBase64(String base64) {
        return isBase64(StringUtils.getBytesUtf8(base64));
    }

    public static boolean isBase64(byte[] arrayOctet) {
        for (int i = 0; i < arrayOctet.length; i++) {
            if (!(isBase64(arrayOctet[i]) || isWhiteSpace(arrayOctet[i]))) {
                return false;
            }
        }
        return true;
    }

    public static byte[] encodeBase64(byte[] binaryData) {
        return encodeBase64(binaryData, false);
    }

    public static String encodeBase64String(byte[] binaryData) {
        return StringUtils.newStringUtf8(encodeBase64(binaryData, false));
    }

    public static byte[] encodeBase64URLSafe(byte[] binaryData) {
        return encodeBase64(binaryData, false, true);
    }

    public static String encodeBase64URLSafeString(byte[] binaryData) {
        return StringUtils.newStringUtf8(encodeBase64(binaryData, false, true));
    }

    public static byte[] encodeBase64Chunked(byte[] binaryData) {
        return encodeBase64(binaryData, true);
    }

    public static byte[] encodeBase64(byte[] binaryData, boolean isChunked) {
        return encodeBase64(binaryData, isChunked, false);
    }

    public static byte[] encodeBase64(byte[] binaryData, boolean isChunked, boolean urlSafe) {
        return encodeBase64(binaryData, isChunked, urlSafe, Integer.MAX_VALUE);
    }

    public static byte[] encodeBase64(byte[] binaryData, boolean isChunked, boolean urlSafe, int maxResultSize) {
        Base64 b64;
        if (binaryData == null || binaryData.length == 0) {
            return binaryData;
        }
        if (!isChunked) {
            b64 = new Base64(0, CHUNK_SEPARATOR, urlSafe);
        }
        long len = b64.getEncodedLength(binaryData);
        if (len <= ((long) maxResultSize)) {
            return b64.encode(binaryData);
        }
        throw new IllegalArgumentException("Input array too big, the output array would be bigger (" + len + ") than the specified maximum size of " + maxResultSize);
    }

    public static byte[] decodeBase64(String base64String) {
        return new Base64().decode(base64String);
    }

    public static byte[] decodeBase64(byte[] base64Data) {
        return new Base64().decode(base64Data);
    }

    public static BigInteger decodeInteger(byte[] pArray) {
        return new BigInteger(1, decodeBase64(pArray));
    }

    public static byte[] encodeInteger(BigInteger bigInt) {
        if (bigInt != null) {
            return encodeBase64(toIntegerBytes(bigInt), false);
        }
        throw new NullPointerException("encodeInteger called with null parameter");
    }

    static byte[] toIntegerBytes(BigInteger bigInt) {
        int bitlen = ((bigInt.bitLength() + 7) >> 3) << 3;
        byte[] bigBytes = bigInt.toByteArray();
        if (bigInt.bitLength() % 8 != 0 && (bigInt.bitLength() / 8) + 1 == bitlen / 8) {
            return bigBytes;
        }
        int startSrc = 0;
        int len = bigBytes.length;
        if (bigInt.bitLength() % 8 == 0) {
            startSrc = 1;
            len--;
        }
        byte[] resizedBytes = new byte[(bitlen / 8)];
        System.arraycopy(bigBytes, startSrc, resizedBytes, (bitlen / 8) - len, len);
        return resizedBytes;
    }

    /* access modifiers changed from: protected */
    @Override // com.heytap.msp.push.encrypt.BaseNCodec
    public boolean isInAlphabet(byte octet) {
        if (octet >= 0) {
            byte[] bArr = this.decodeTable;
            return octet < bArr.length && bArr[octet] != -1;
        }
    }
}
