package com.taobao.weex.el.parse;

import com.taobao.weex.WXEnvironment;
import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.List;

public class Parser {
    private String code;
    private ArrayStack<Symbol> operators = new ArrayStack<>();
    private int position = 0;
    private ArrayStack<Token> stacks = new ArrayStack<>();

    public Parser(String code2) {
        this.code = code2;
    }

    public final Token parse() {
        while (hasNextToken()) {
            scanNextToken();
        }
        while (!this.operators.isEmpty()) {
            doOperator(this.operators.pop());
        }
        if (this.stacks.size() == 1) {
            return this.stacks.pop();
        }
        return new Block(this.stacks.getList(), 6);
    }

    public static Token parse(String code2) {
        try {
            return new Parser(code2).parse();
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("code " + code2, e);
            }
            return new Block(null, 6);
        }
    }

    /* access modifiers changed from: package-private */
    public final char scanNextToken() {
        char ch = nextToken();
        if (ch == '$') {
            this.position++;
            return ch;
        }
        if (Character.isJavaIdentifierStart(ch)) {
            scanIdentifier();
        } else if (ch == '(' || ch == '{') {
            scanBracket();
        } else if (ch == '[') {
            scanArray();
        } else if (ch == '\"' || ch == '\'') {
            scanString();
        } else if ((ch == '.' && Character.isDigit(this.code.charAt(this.position + 1))) || Character.isDigit(ch)) {
            scanNumber();
        } else if (ch == '?') {
            scanIf();
        } else if (ch == ':' || ch == ')' || ch == '}' || ch == ' ' || ch == ']') {
            this.position++;
            return ch;
        } else {
            scanOperator();
        }
        return ch;
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:8:0x003f  */
    public final void scanArray() {
        Token second;
        int stackSize = this.stacks.size();
        int opSize = this.operators.size();
        int type = 0;
        int i = this.position;
        if (i - 1 < 0 || !Character.isJavaIdentifierPart(this.code.charAt(i - 1))) {
            type = 7;
        }
        this.operators.push(new Symbol(Operators.ARRAY_START_STR, this.stacks.size()));
        this.position++;
        while (hasNextToken() && scanNextToken() != ']') {
            while (hasNextToken()) {
                while (hasNextToken()) {
                }
            }
        }
        if (this.stacks.size() <= stackSize) {
            while (this.operators.size() > opSize) {
                this.operators.pop();
            }
            return;
        }
        while (this.operators.size() > opSize) {
            Symbol op = this.operators.pop();
            if (this.stacks.size() > stackSize) {
                doOperator(op);
            }
        }
        List<Token> tokens = new ArrayList<>(4);
        for (int i2 = stackSize; i2 < this.stacks.size(); i2++) {
            tokens.add(this.stacks.get(i2));
        }
        while (this.stacks.size() > stackSize) {
            this.stacks.pop();
        }
        if (type == 7 || this.stacks.size() == 0) {
            this.stacks.push(new Block(tokens, 7));
            return;
        }
        Token identifer = this.stacks.pop();
        if (tokens.size() == 1) {
            second = tokens.get(0);
        } else {
            second = new Block(tokens, 6);
        }
        Operator operator = new Operator(Operators.DOT_STR, type);
        operator.first = identifer;
        operator.second = second;
        this.stacks.push(operator);
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:10:0x005d  */
    /* JADX WARNING: Removed duplicated region for block: B:5:0x0037  */
    public void scanBracket() {
        int stackSize = this.stacks.size();
        int opSize = this.operators.size();
        if (this.code.charAt(this.position) == '{') {
            this.operators.push(new Symbol(Operators.BLOCK_START_STR, this.stacks.size()));
            this.position++;
            while (hasNextToken() && scanNextToken() != '}') {
                while (hasNextToken()) {
                    while (hasNextToken()) {
                    }
                }
            }
        } else {
            this.operators.push(new Symbol(Operators.BRACKET_START_STR, this.stacks.size()));
            this.position++;
            while (hasNextToken() && scanNextToken() != ')') {
                while (hasNextToken()) {
                    while (hasNextToken()) {
                    }
                }
            }
        }
        if (this.stacks.size() <= stackSize) {
            while (this.operators.size() > opSize) {
                this.operators.pop();
            }
            return;
        }
        while (this.operators.size() > opSize) {
            Symbol op = this.operators.pop();
            if (this.stacks.size() > stackSize) {
                doOperator(op);
            }
        }
        List<Token> tokens = new ArrayList<>(4);
        for (int i = stackSize; i < this.stacks.size(); i++) {
            tokens.add(this.stacks.get(i));
        }
        while (this.stacks.size() > stackSize) {
            this.stacks.pop();
        }
        if (tokens.size() == 1) {
            this.stacks.push(tokens.get(0));
            return;
        }
        this.stacks.push(new Block(tokens, 6));
    }

    /* access modifiers changed from: package-private */
    public void scanOperator() {
        int start = this.position;
        String operator = this.code.substring(this.position, Math.min(this.position + 3, this.code.length()));
        if (operator.length() >= 3 && !Operators.OPERATORS_PRIORITY.containsKey(operator)) {
            operator = operator.substring(0, 2);
        }
        if (operator.length() >= 2 && !Operators.OPERATORS_PRIORITY.containsKey(operator)) {
            operator = operator.substring(0, 1);
        }
        if (!Operators.OPERATORS_PRIORITY.containsKey(operator)) {
            int illegalChar = Math.min(start + 1, this.code.length());
            WXLogUtils.e("weex", new IllegalArgumentException(this.code.substring(0, illegalChar) + " illegal code operator" + operator));
            this.position = this.position + operator.length();
            return;
        }
        if (!this.operators.isEmpty() && this.operators.peek() != null) {
            if (Operators.OPERATORS_PRIORITY.get(this.operators.peek().op).intValue() >= Operators.OPERATORS_PRIORITY.get(operator).intValue()) {
                doOperator(this.operators.pop());
            }
        }
        if (!Operators.isOpEnd(operator)) {
            this.operators.push(new Symbol(operator, this.stacks.size()));
        }
        this.position += operator.length();
    }

    /* access modifiers changed from: package-private */
    public void doOperator(Symbol symbol) {
        String op = symbol.op;
        if (!Operators.BRACKET_START_STR.equals(symbol.op) && !Operators.BLOCK_START_STR.equals(symbol.op) && !Operators.ARRAY_START_STR.equals(symbol.op) && !Operators.DOLLAR_STR.equals(symbol.op) && !Operators.BLOCK_START_STR.equals(symbol.op)) {
            int second = symbol.pos;
            int first = Math.max(symbol.pos - 1, 0);
            if (!this.operators.isEmpty()) {
                first = Math.max(first, this.operators.peek().pos);
            }
            Operator operator = new Operator(op, 5);
            if (Operators.AND_NOT.equals(op)) {
                if (this.stacks.size() > second) {
                    operator.self = this.stacks.remove(second);
                    this.stacks.add(second, operator);
                }
            } else if (this.stacks.size() > second) {
                operator.second = this.stacks.remove(second);
                if (this.stacks.size() > first) {
                    operator.first = this.stacks.remove(first);
                } else if (operator.second == null) {
                    return;
                }
                this.stacks.add(first, operator);
            }
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:9:0x004d  */
    public void scanIf() {
        Operator operator = new Operator(Operators.CONDITION_IF_STRING, 5);
        int selfIndex = 0;
        doStackOperators(0);
        if (this.operators.size() > 0) {
            selfIndex = Math.max(this.operators.peek().pos, 0);
        }
        if (this.stacks.size() > selfIndex) {
            operator.self = this.stacks.pop();
        }
        int stackSize = this.stacks.size();
        int leftOperatorSize = this.operators.size();
        this.position++;
        while (hasNextToken() && scanNextToken() != ':') {
            while (hasNextToken()) {
                while (hasNextToken()) {
                }
            }
        }
        while (this.operators.size() > leftOperatorSize) {
            doOperator(this.operators.pop());
        }
        while (this.stacks.size() > stackSize) {
            operator.first = this.stacks.pop();
        }
        int rightOperatorsSize = this.operators.size();
        while (hasNextToken()) {
            scanNextToken();
            if (hasNextToken()) {
                scanNextToken();
            }
            if (this.operators.size() <= rightOperatorsSize) {
                break;
            }
        }
        doStackOperators(rightOperatorsSize);
        while (this.stacks.size() > stackSize) {
            operator.second = this.stacks.pop();
        }
        this.stacks.push(operator);
    }

    private final void doStackOperators(int operatorSize) {
        while (this.operators.size() > operatorSize) {
            doOperator(this.operators.pop());
        }
    }

    /* access modifiers changed from: package-private */
    public final void scanNumber() {
        Token stack;
        boolean isInt = true;
        int start = this.position;
        if (this.code.charAt(this.position) == 'e' || this.code.charAt(this.position) == '.') {
            isInt = false;
        }
        this.position++;
        while (hasNext()) {
            char ch = this.code.charAt(this.position);
            if (!Character.isDigit(ch) && ch != '.' && ch != 'e') {
                break;
            }
            if (ch == 'e' || ch == '.') {
                isInt = false;
            }
            this.position++;
        }
        String number = this.code.substring(start, this.position);
        if (!Operators.DOT_STR.equals(number)) {
            if (isInt) {
                stack = new Token(number, 1);
            } else {
                stack = new Token(number, 2);
            }
            this.stacks.push(stack);
        }
    }

    /* access modifiers changed from: package-private */
    public final void scanString() {
        int start = this.position;
        ArrayStack operator = new ArrayStack();
        char quote = this.code.charAt(start);
        operator.push(Character.valueOf(quote));
        StringBuilder builder = new StringBuilder();
        int i = start + 1;
        while (true) {
            this.position = i;
            if (this.position >= this.code.length()) {
                break;
            }
            char ch = this.code.charAt(this.position);
            if (ch != quote) {
                builder.append(ch);
            } else if (this.code.charAt(this.position - 1) != '\\') {
                operator.pop();
                if (operator.size() == 0) {
                    this.position++;
                    break;
                }
            } else {
                builder.deleteCharAt(builder.length() - 1);
                builder.append(ch);
            }
            i = this.position + 1;
        }
        this.stacks.push(new Token(builder.toString(), 3));
    }

    /* access modifiers changed from: package-private */
    public final void scanIdentifier() {
        int start = this.position;
        this.position++;
        while (hasNext() && Character.isJavaIdentifierPart(this.code.charAt(this.position))) {
            this.position++;
        }
        String el = this.code.substring(start, this.position);
        if (el.startsWith(Operators.DOLLAR_STR)) {
            if (el.length() != Operators.DOLLAR_STR.length()) {
                el = el.substring(Operators.DOLLAR_STR.length());
            } else {
                return;
            }
        }
        int type = 0;
        if (Operators.KEYWORDS.containsKey(el) && (this.operators.isEmpty() || !Operators.isDot(this.operators.peek().op))) {
            type = 4;
        }
        this.stacks.push(new Token(el, type));
    }

    /* access modifiers changed from: package-private */
    public final boolean hasNext() {
        return this.position < this.code.length();
    }

    /* access modifiers changed from: package-private */
    public final boolean hasNextToken() {
        while (hasNext()) {
            if (this.code.charAt(this.position) != ' ') {
                return true;
            }
            this.position++;
        }
        return false;
    }

    /* access modifiers changed from: package-private */
    public final char nextToken() {
        char ch = this.code.charAt(this.position);
        while (ch == ' ') {
            this.position++;
            int length = this.code.length();
            int i = this.position;
            if (length <= i) {
                break;
            }
            ch = this.code.charAt(i);
        }
        return ch;
    }
}
