package com.taobao.weex.ui.component;

import android.app.Activity;
import android.content.Context;
import android.graphics.Rect;
import android.text.Editable;
import android.text.InputFilter;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.text.method.PasswordTransformationMethod;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.TextView;
import androidx.core.view.GravityCompat;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSConstants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.layout.MeasureMode;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.helper.SoftKeyboardDetector;
import com.taobao.weex.ui.component.helper.WXTimeInputHelper;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.view.WXEditText;
import com.taobao.weex.utils.TypefaceUtil;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;

public abstract class AbstractEditComponent extends WXComponent<WXEditText> {
    private static final int MAX_TEXT_FORMAT_REPEAT = 3;
    private boolean mAutoFocus;
    private String mBeforeText = "";
    private int mEditorAction = 6;
    private List<TextView.OnEditorActionListener> mEditorActionListeners;
    private int mFormatRepeatCount = 0;
    private TextFormatter mFormatter = null;
    private boolean mIgnoreNextOnInputEvent = false;
    private final InputMethodManager mInputMethodManager = ((InputMethodManager) getContext().getSystemService("input_method"));
    private boolean mKeepSelectionIndex = false;
    private String mLastValue = "";
    private int mLineHeight = -1;
    private boolean mListeningKeyboard = false;
    private String mMax = null;
    private String mMin = null;
    private WXComponent.OnClickListener mOnClickListener = new WXComponent.OnClickListener() {
        /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass3 */

        /* JADX WARNING: Removed duplicated region for block: B:12:0x002e  */
        /* JADX WARNING: Removed duplicated region for block: B:17:0x004d  */
        @Override // com.taobao.weex.ui.component.WXComponent.OnClickListener
        public void onHostViewClick() {
            char c;
            String str = AbstractEditComponent.this.mType;
            int hashCode = str.hashCode();
            if (hashCode != 3076014) {
                if (hashCode == 3560141 && str.equals(Constants.Value.TIME)) {
                    c = 1;
                    if (c == 0) {
                        AbstractEditComponent.this.hideSoftKeyboard();
                        if (AbstractEditComponent.this.getParent() != null) {
                            AbstractEditComponent.this.getParent().interceptFocus();
                        }
                        WXTimeInputHelper.pickDate(AbstractEditComponent.this.mMax, AbstractEditComponent.this.mMin, AbstractEditComponent.this);
                        return;
                    } else if (c == 1) {
                        AbstractEditComponent.this.hideSoftKeyboard();
                        if (AbstractEditComponent.this.getParent() != null) {
                            AbstractEditComponent.this.getParent().interceptFocus();
                        }
                        WXTimeInputHelper.pickTime(AbstractEditComponent.this);
                        return;
                    } else {
                        return;
                    }
                }
            } else if (str.equals("date")) {
                c = 0;
                if (c == 0) {
                }
            }
            c = 65535;
            if (c == 0) {
            }
        }
    };
    private TextPaint mPaint = new TextPaint();
    private String mReturnKeyType = null;
    private TextWatcher mTextChangedEventDispatcher;
    private List<TextWatcher> mTextChangedListeners;
    private String mType = "text";
    private SoftKeyboardDetector.Unregister mUnregister;

    private interface ReturnTypes {
        public static final String DEFAULT = "default";
        public static final String DONE = "done";
        public static final String GO = "go";
        public static final String NEXT = "next";
        public static final String SEARCH = "search";
        public static final String SEND = "send";
    }

    public AbstractEditComponent(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        setContentBoxMeasurement(new ContentBoxMeasurement() {
            /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass1 */

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                if (CSSConstants.isUndefined(width) || widthMeasureMode == MeasureMode.UNSPECIFIED) {
                    width = 0.0f;
                }
                this.mMeasureWidth = width;
                this.mMeasureHeight = AbstractEditComponent.this.getMeasureHeight();
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
                AbstractEditComponent.this.updateStyleAndAttrs();
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void layoutDirectionDidChanged(boolean isRTL) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        if (getHostView() instanceof WXEditText) {
            ((WXEditText) getHostView()).setGravity(getVerticalGravity() | textAlign);
        }
    }

    /* access modifiers changed from: protected */
    public final float getMeasuredLineHeight() {
        int i = this.mLineHeight;
        return (i == -1 || i <= 0) ? this.mPaint.getFontMetrics(null) : (float) i;
    }

    /* access modifiers changed from: protected */
    public float getMeasureHeight() {
        return getMeasuredLineHeight();
    }

    /* access modifiers changed from: protected */
    public void updateStyleAndAttrs() {
        if (getStyles().size() > 0) {
            int fontSize = -1;
            int fontStyle = -1;
            int fontWeight = -1;
            String fontFamily = null;
            if (getStyles().containsKey(Constants.Name.FONT_SIZE)) {
                fontSize = WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getViewPortWidthForFloat());
            }
            if (getStyles().containsKey(Constants.Name.FONT_FAMILY)) {
                fontFamily = WXStyle.getFontFamily(getStyles());
            }
            if (getStyles().containsKey(Constants.Name.FONT_STYLE)) {
                fontStyle = WXStyle.getFontStyle(getStyles());
            }
            if (getStyles().containsKey(Constants.Name.FONT_WEIGHT)) {
                fontWeight = WXStyle.getFontWeight(getStyles());
            }
            int lineHeight = WXStyle.getLineHeight(getStyles(), getViewPortWidthForFloat());
            if (lineHeight != -1) {
                this.mLineHeight = lineHeight;
            }
            if (fontSize != -1) {
                this.mPaint.setTextSize((float) fontSize);
            }
            if (fontFamily != null) {
                TypefaceUtil.applyFontStyle(this.mPaint, fontStyle, fontWeight, fontFamily);
            }
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXEditText initComponentHostView(Context context) {
        WXEditText inputView = new WXEditText(context, getInstanceId());
        appleStyleAfterCreated(inputView);
        return inputView;
    }

    /* access modifiers changed from: protected */
    public void onHostViewInitialized(WXEditText host) {
        super.onHostViewInitialized((View) host);
        addFocusChangeListener(new WXComponent.OnFocusChangeListener() {
            /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass2 */

            @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
            public void onFocusChange(boolean hasFocus) {
                if (!hasFocus) {
                    AbstractEditComponent.this.decideSoftKeyboard();
                }
                AbstractEditComponent.this.setPseudoClassStatus(Constants.PSEUDO.FOCUS, hasFocus);
            }
        });
        addKeyboardListener(host);
    }

    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean isConsumeTouch() {
        return !isDisabled();
    }

    private void applyOnClickListener() {
        addClickListener(this.mOnClickListener);
    }

    /* access modifiers changed from: protected */
    public int getVerticalGravity() {
        return 16;
    }

    /* access modifiers changed from: protected */
    public void appleStyleAfterCreated(final WXEditText editText) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        editText.setGravity(getVerticalGravity() | textAlign);
        int colorInt = WXResourceUtils.getColor("#999999");
        if (colorInt != Integer.MIN_VALUE) {
            editText.setHintTextColor(colorInt);
        }
        AnonymousClass4 r3 = new TextWatcher() {
            /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass4 */

            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher watcher : AbstractEditComponent.this.mTextChangedListeners) {
                        watcher.beforeTextChanged(s, start, count, after);
                    }
                }
            }

            public void onTextChanged(CharSequence s, int start, int before, int count) {
                if (AbstractEditComponent.this.mFormatter != null) {
                    String result = AbstractEditComponent.this.mFormatter.format(AbstractEditComponent.this.mFormatter.recover(s.toString()));
                    if (result.equals(s.toString()) || AbstractEditComponent.this.mFormatRepeatCount >= 3) {
                        AbstractEditComponent.this.mFormatRepeatCount = 0;
                    } else {
                        AbstractEditComponent.this.mFormatRepeatCount++;
                        int cursorIndex = AbstractEditComponent.this.mFormatter.format(AbstractEditComponent.this.mFormatter.recover(s.subSequence(0, editText.getSelectionStart()).toString())).length();
                        editText.setText(result);
                        editText.setSelection(cursorIndex);
                        return;
                    }
                }
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher watcher : AbstractEditComponent.this.mTextChangedListeners) {
                        watcher.onTextChanged(s, start, before, count);
                    }
                }
            }

            public void afterTextChanged(Editable s) {
                if (AbstractEditComponent.this.mTextChangedListeners != null) {
                    for (TextWatcher watcher : AbstractEditComponent.this.mTextChangedListeners) {
                        watcher.afterTextChanged(s);
                    }
                }
            }
        };
        this.mTextChangedEventDispatcher = r3;
        editText.addTextChangedListener(r3);
        editText.setTextSize(0, (float) WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (getHostView() != null && !TextUtils.isEmpty(type)) {
            final TextView text = (TextView) getHostView();
            if (type.equals(Constants.Event.CHANGE)) {
                addFocusChangeListener(new WXComponent.OnFocusChangeListener() {
                    /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass5 */

                    @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
                    public void onFocusChange(boolean hasFocus) {
                        if (hasFocus) {
                            AbstractEditComponent.this.mLastValue = text.getText().toString();
                            return;
                        }
                        CharSequence newValue = text.getText();
                        String newValue2 = newValue == null ? "" : newValue;
                        if (!newValue2.toString().equals(AbstractEditComponent.this.mLastValue)) {
                            AbstractEditComponent.this.fireEvent((AbstractEditComponent) Constants.Event.CHANGE, newValue2.toString());
                            AbstractEditComponent.this.mLastValue = text.getText().toString();
                        }
                    }
                });
                addEditorActionListener(new TextView.OnEditorActionListener() {
                    /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass6 */

                    public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                        if (actionId != AbstractEditComponent.this.mEditorAction) {
                            return false;
                        }
                        CharSequence newValue = text.getText();
                        String newValue2 = newValue == null ? "" : newValue;
                        if (!newValue2.toString().equals(AbstractEditComponent.this.mLastValue)) {
                            AbstractEditComponent.this.fireEvent((AbstractEditComponent) Constants.Event.CHANGE, newValue2.toString());
                            AbstractEditComponent.this.mLastValue = text.getText().toString();
                        }
                        if (AbstractEditComponent.this.getParent() != null) {
                            AbstractEditComponent.this.getParent().interceptFocus();
                        }
                        AbstractEditComponent.this.hideSoftKeyboard();
                        return true;
                    }
                });
            } else if (type.equals("input")) {
                addTextChangedListener(new TextWatcher() {
                    /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass7 */

                    public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                    }

                    public void onTextChanged(CharSequence s, int start, int before, int count) {
                        if (AbstractEditComponent.this.mIgnoreNextOnInputEvent) {
                            AbstractEditComponent.this.mIgnoreNextOnInputEvent = false;
                            AbstractEditComponent.this.mBeforeText = s.toString();
                        } else if (!AbstractEditComponent.this.mBeforeText.equals(s.toString())) {
                            AbstractEditComponent.this.mBeforeText = s.toString();
                            AbstractEditComponent.this.fireEvent((AbstractEditComponent) "input", s.toString());
                        }
                    }

                    public void afterTextChanged(Editable s) {
                    }
                });
            }
            if (Constants.Event.RETURN.equals(type)) {
                addEditorActionListener(new TextView.OnEditorActionListener() {
                    /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass8 */

                    public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                        if (actionId != AbstractEditComponent.this.mEditorAction) {
                            return false;
                        }
                        Map<String, Object> ret = new HashMap<>(2);
                        ret.put(Constants.Name.RETURN_KEY_TYPE, AbstractEditComponent.this.mReturnKeyType);
                        ret.put("value", v.getText().toString());
                        AbstractEditComponent.this.fireEvent(Constants.Event.RETURN, ret);
                        return true;
                    }
                });
            }
            if (Constants.Event.KEYBOARD.equals(type)) {
                this.mListeningKeyboard = true;
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void fireEvent(String event, String value) {
        if (event != null) {
            Map<String, Object> params = new HashMap<>(2);
            params.put("value", value);
            params.put("timeStamp", Long.valueOf(System.currentTimeMillis()));
            Map<String, Object> domChanges = new HashMap<>();
            Map<String, Object> attrsChanges = new HashMap<>();
            attrsChanges.put("value", value);
            domChanges.put(TemplateDom.KEY_ATTRS, attrsChanges);
            WXSDKManager.getInstance().fireEvent(getInstanceId(), getRef(), event, params, domChanges);
        }
    }

    public void performOnChange(String value) {
        if (getEvents() != null) {
            WXEvent events = getEvents();
            String event = Constants.Event.CHANGE;
            if (!events.contains(event)) {
                event = null;
            }
            fireEvent(event, value);
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        char c;
        switch (key.hashCode()) {
            case -1898657397:
                if (key.equals(Constants.Name.KEEP_SELECTION_INDEX)) {
                    c = 15;
                    break;
                }
                c = 65535;
                break;
            case -1576785488:
                if (key.equals(Constants.Name.PLACEHOLDER_COLOR)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1065511464:
                if (key.equals(Constants.Name.TEXT_ALIGN)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case -791400086:
                if (key.equals(Constants.Name.MAX_LENGTH)) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case 107876:
                if (key.equals("max")) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case 108114:
                if (key.equals(Constants.Name.MIN)) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case 3575610:
                if (key.equals("type")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 94842723:
                if (key.equals("color")) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 102977279:
                if (key.equals(Constants.Name.LINES)) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 124732746:
                if (key.equals(Constants.Name.MAXLENGTH)) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 270940796:
                if (key.equals(Constants.Name.DISABLED)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 365601008:
                if (key.equals(Constants.Name.FONT_SIZE)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 598246771:
                if (key.equals(Constants.Name.PLACEHOLDER)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 914346044:
                if (key.equals(Constants.Name.SINGLELINE)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 947486441:
                if (key.equals(Constants.Name.RETURN_KEY_TYPE)) {
                    c = 14;
                    break;
                }
                c = 65535;
                break;
            case 1625554645:
                if (key.equals(Constants.Name.ALLOW_COPY_PASTE)) {
                    c = 16;
                    break;
                }
                c = 65535;
                break;
            case 1667607689:
                if (key.equals(Constants.Name.AUTOFOCUS)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                Boolean disabled = WXUtils.getBoolean(param, null);
                if (!(disabled == null || this.mHost == null)) {
                    if (disabled.booleanValue()) {
                        ((WXEditText) this.mHost).setFocusable(false);
                        ((WXEditText) this.mHost).setFocusableInTouchMode(false);
                    } else {
                        ((WXEditText) this.mHost).setFocusableInTouchMode(true);
                        ((WXEditText) this.mHost).setFocusable(true);
                    }
                }
                return true;
            case 1:
                String placeholder = WXUtils.getString(param, null);
                if (placeholder != null) {
                    setPlaceholder(placeholder);
                }
                return true;
            case 2:
                String placeholder_color = WXUtils.getString(param, null);
                if (placeholder_color != null) {
                    setPlaceholderColor(placeholder_color);
                }
                return true;
            case 3:
                String input_type = WXUtils.getString(param, null);
                if (input_type != null) {
                    setType(input_type);
                }
                return true;
            case 4:
                Boolean result = WXUtils.getBoolean(param, null);
                if (result != null) {
                    setAutofocus(result.booleanValue());
                }
                return true;
            case 5:
                String color = WXUtils.getString(param, null);
                if (color != null) {
                    setColor(color);
                }
                return true;
            case 6:
                String fontsize = WXUtils.getString(param, null);
                if (fontsize != null) {
                    setFontSize(fontsize);
                }
                return true;
            case 7:
                String text_align = WXUtils.getString(param, null);
                if (text_align != null) {
                    setTextAlign(text_align);
                }
                return true;
            case '\b':
                Boolean singLineResult = WXUtils.getBoolean(param, null);
                if (singLineResult != null) {
                    setSingleLine(singLineResult.booleanValue());
                }
                return true;
            case '\t':
                Integer lines = WXUtils.getInteger(param, null);
                if (lines != null) {
                    setLines(lines.intValue());
                }
                return true;
            case '\n':
                Integer maxlength = WXUtils.getInteger(param, null);
                if (maxlength != null) {
                    setMaxLength(maxlength.intValue());
                }
                return true;
            case 11:
                Integer maxLength = WXUtils.getInteger(param, null);
                if (maxLength != null) {
                    setMaxLength(maxLength.intValue());
                }
                return true;
            case '\f':
                setMax(String.valueOf(param));
                return true;
            case '\r':
                setMin(String.valueOf(param));
                return true;
            case 14:
                setReturnKeyType(String.valueOf(param));
                return true;
            case 15:
                this.mKeepSelectionIndex = WXUtils.getBoolean(param, false).booleanValue();
                return true;
            case 16:
                boolean allowCopyPaste = WXUtils.getBoolean(param, true).booleanValue();
                if (getHostView() != null) {
                    ((WXEditText) getHostView()).setAllowCopyPaste(allowCopyPaste);
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @WXComponentProp(name = Constants.Name.RETURN_KEY_TYPE)
    public void setReturnKeyType(String type) {
        if (getHostView() != null && !type.equals(this.mReturnKeyType)) {
            this.mReturnKeyType = type;
            char c = 65535;
            switch (type.hashCode()) {
                case -906336856:
                    if (type.equals("search")) {
                        c = 3;
                        break;
                    }
                    break;
                case 3304:
                    if (type.equals("go")) {
                        c = 1;
                        break;
                    }
                    break;
                case 3089282:
                    if (type.equals("done")) {
                        c = 5;
                        break;
                    }
                    break;
                case 3377907:
                    if (type.equals("next")) {
                        c = 2;
                        break;
                    }
                    break;
                case 3526536:
                    if (type.equals("send")) {
                        c = 4;
                        break;
                    }
                    break;
                case 1544803905:
                    if (type.equals("default")) {
                        c = 0;
                        break;
                    }
                    break;
            }
            if (c == 0) {
                this.mEditorAction = 0;
            } else if (c == 1) {
                this.mEditorAction = 2;
            } else if (c == 2) {
                this.mEditorAction = 5;
            } else if (c == 3) {
                this.mEditorAction = 3;
            } else if (c == 4) {
                this.mEditorAction = 4;
            } else if (c == 5) {
                this.mEditorAction = 6;
            }
            blur();
            ((WXEditText) getHostView()).setImeOptions(this.mEditorAction);
        }
    }

    @WXComponentProp(name = Constants.Name.PLACEHOLDER)
    public void setPlaceholder(String placeholder) {
        if (placeholder != null && getHostView() != null) {
            ((WXEditText) getHostView()).setHint(placeholder);
        }
    }

    @WXComponentProp(name = Constants.Name.PLACEHOLDER_COLOR)
    public void setPlaceholderColor(String color) {
        int colorInt;
        if (getHostView() != null && !TextUtils.isEmpty(color) && (colorInt = WXResourceUtils.getColor(color)) != Integer.MIN_VALUE) {
            ((WXEditText) getHostView()).setHintTextColor(colorInt);
        }
    }

    @WXComponentProp(name = "type")
    public void setType(String type) {
        Log.e("weex", "setType=" + type);
        if (type != null && getHostView() != null && !this.mType.equals(type)) {
            this.mType = type;
            ((EditText) getHostView()).setInputType(getInputType(this.mType));
            String str = this.mType;
            char c = 65535;
            int hashCode = str.hashCode();
            if (hashCode != 3076014) {
                if (hashCode == 3560141 && str.equals(Constants.Value.TIME)) {
                    c = 1;
                }
            } else if (str.equals("date")) {
                c = 0;
            }
            if (c == 0 || c == 1) {
                applyOnClickListener();
            }
        }
    }

    @WXComponentProp(name = Constants.Name.AUTOFOCUS)
    public void setAutofocus(boolean autofocus) {
        if (getHostView() != null) {
            this.mAutoFocus = autofocus;
            EditText inputView = (EditText) getHostView();
            if (this.mAutoFocus) {
                inputView.setFocusable(true);
                inputView.requestFocus();
                inputView.setFocusableInTouchMode(true);
                showSoftKeyboard();
                return;
            }
            hideSoftKeyboard();
        }
    }

    @WXComponentProp(name = "value")
    public void setValue(String value) {
        WXEditText view = (WXEditText) getHostView();
        if (view != null && !TextUtils.equals(view.getText(), value)) {
            this.mIgnoreNextOnInputEvent = true;
            int oldIndex = view.getSelectionStart();
            view.setText(value);
            view.setSelection(value == null ? 0 : this.mKeepSelectionIndex ? oldIndex : value.length());
        }
    }

    @WXComponentProp(name = "color")
    public void setColor(String color) {
        int colorInt;
        if (getHostView() != null && !TextUtils.isEmpty(color) && (colorInt = WXResourceUtils.getColor(color)) != Integer.MIN_VALUE) {
            ((WXEditText) getHostView()).setTextColor(colorInt);
        }
    }

    @WXComponentProp(name = Constants.Name.FONT_SIZE)
    public void setFontSize(String fontSize) {
        if (getHostView() != null && fontSize != null) {
            Map<String, Object> map = new HashMap<>(1);
            map.put(Constants.Name.FONT_SIZE, fontSize);
            ((WXEditText) getHostView()).setTextSize(0, (float) WXStyle.getFontSize(map, getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
        }
    }

    @WXComponentProp(name = Constants.Name.TEXT_ALIGN)
    public void setTextAlign(String textAlign) {
        int align = getTextAlign(textAlign);
        if (align > 0) {
            ((WXEditText) getHostView()).setGravity(getVerticalGravity() | align);
        }
    }

    @WXComponentProp(name = Constants.Name.SINGLELINE)
    public void setSingleLine(boolean singleLine) {
        if (getHostView() != null) {
            ((WXEditText) getHostView()).setSingleLine(singleLine);
        }
    }

    @WXComponentProp(name = Constants.Name.LINES)
    public void setLines(int lines) {
        if (getHostView() != null) {
            ((WXEditText) getHostView()).setLines(lines);
        }
    }

    @WXComponentProp(name = Constants.Name.MAX_LENGTH)
    public void setMaxLength(int maxLength) {
        if (getHostView() != null) {
            ((WXEditText) getHostView()).setFilters(new InputFilter[]{new InputFilter.LengthFilter(maxLength)});
        }
    }

    @WXComponentProp(name = Constants.Name.MAXLENGTH)
    @Deprecated
    public void setMaxlength(int maxLength) {
        setMaxLength(maxLength);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private int getInputType(String type) {
        char c;
        switch (type.hashCode()) {
            case -1034364087:
                if (type.equals("number")) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 114715:
                if (type.equals(Constants.Value.TEL)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case 116079:
                if (type.equals("url")) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case 3076014:
                if (type.equals("date")) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 3556653:
                if (type.equals("text")) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case 3560141:
                if (type.equals(Constants.Value.TIME)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case 96619420:
                if (type.equals("email")) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 1216985755:
                if (type.equals(Constants.Value.PASSWORD)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 1793702779:
                if (type.equals(Constants.Value.DATETIME)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                return 1;
            case 1:
                ((WXEditText) getHostView()).setFocusable(false);
                return 0;
            case 2:
                return 4;
            case 3:
                return 33;
            case 4:
                if (getHostView() == null) {
                    return 129;
                }
                ((WXEditText) getHostView()).setTransformationMethod(PasswordTransformationMethod.getInstance());
                return 129;
            case 5:
                return 3;
            case 6:
                if (getHostView() == null) {
                    return 0;
                }
                ((WXEditText) getHostView()).setFocusable(false);
                return 0;
            case 7:
                return 17;
            case '\b':
                return 8194;
            default:
                return 1;
        }
    }

    @WXComponentProp(name = "max")
    public void setMax(String max) {
        this.mMax = max;
    }

    @WXComponentProp(name = Constants.Name.MIN)
    public void setMin(String min) {
        this.mMin = min;
    }

    private boolean showSoftKeyboard() {
        if (getHostView() == null) {
            return false;
        }
        ((WXEditText) getHostView()).postDelayed(WXThread.secure(new Runnable() {
            /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass9 */

            public void run() {
                AbstractEditComponent.this.mInputMethodManager.showSoftInput(AbstractEditComponent.this.getHostView(), 1);
            }
        }), 100);
        return true;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void hideSoftKeyboard() {
        if (getHostView() != null) {
            ((WXEditText) getHostView()).postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass10 */

                public void run() {
                    AbstractEditComponent.this.mInputMethodManager.hideSoftInputFromWindow(((WXEditText) AbstractEditComponent.this.getHostView()).getWindowToken(), 0);
                }
            }), 16);
        }
    }

    private int getTextAlign(String textAlign) {
        int align = isLayoutRTL() ? GravityCompat.END : GravityCompat.START;
        if (TextUtils.isEmpty(textAlign)) {
            return align;
        }
        if (textAlign.equals("left")) {
            return GravityCompat.START;
        }
        if (textAlign.equals("center")) {
            return 17;
        }
        if (textAlign.equals("right")) {
            return GravityCompat.END;
        }
        return align;
    }

    @JSMethod
    public void blur() {
        WXEditText host = (WXEditText) getHostView();
        if (host != null && host.hasFocus()) {
            if (getParent() != null) {
                getParent().interceptFocus();
            }
            host.clearFocus();
            hideSoftKeyboard();
        }
    }

    @JSMethod
    public void focus() {
        WXEditText host = (WXEditText) getHostView();
        if (host != null && !host.hasFocus()) {
            if (getParent() != null) {
                getParent().ignoreFocus();
            }
            host.requestFocus();
            host.setFocusable(true);
            host.setFocusableInTouchMode(true);
            showSoftKeyboard();
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:12:0x0027  */
    /* JADX WARNING: Removed duplicated region for block: B:16:0x0031  */
    @Override // com.taobao.weex.ui.component.WXComponent
    public Object convertEmptyProperty(String propName, Object originalValue) {
        char c;
        int hashCode = propName.hashCode();
        if (hashCode != 94842723) {
            if (hashCode == 365601008 && propName.equals(Constants.Name.FONT_SIZE)) {
                c = 0;
                if (c == 0) {
                    return Integer.valueOf(getInstance().getDefaultFontSize());
                }
                if (c != 1) {
                    return super.convertEmptyProperty(propName, originalValue);
                }
                return "black";
            }
        } else if (propName.equals("color")) {
            c = 1;
            if (c == 0) {
            }
        }
        c = 65535;
        if (c == 0) {
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Code restructure failed: missing block: B:2:0x0007, code lost:
        r0 = getContext();
     */
    private void decideSoftKeyboard() {
        final Context context;
        View hostView = getHostView();
        if (hostView != null && context != null && (context instanceof Activity)) {
            hostView.postDelayed(WXThread.secure(new Runnable() {
                /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass11 */

                public void run() {
                    View currentFocus = ((Activity) context).getCurrentFocus();
                    if (currentFocus != null && !(currentFocus instanceof EditText) && !currentFocus.isFocused()) {
                        AbstractEditComponent.this.mInputMethodManager.hideSoftInputFromWindow(((WXEditText) AbstractEditComponent.this.getHostView()).getWindowToken(), 0);
                    }
                }
            }), 16);
        }
    }

    @JSMethod
    public void setSelectionRange(int selectionStart, int selectionEnd) {
        int length;
        EditText hostView = (EditText) getHostView();
        if (hostView != null && selectionStart <= (length = ((WXEditText) getHostView()).length()) && selectionEnd <= length) {
            focus();
            hostView.setSelection(selectionStart, selectionEnd);
        }
    }

    @JSMethod
    public void getSelectionRange(String callbackId) {
        Map<String, Object> result = new HashMap<>(2);
        EditText hostView = (EditText) getHostView();
        if (hostView != null) {
            int start = hostView.getSelectionStart();
            int end = hostView.getSelectionEnd();
            if (!hostView.hasFocus()) {
                start = 0;
                end = 0;
            }
            result.put(Constants.Name.SELECTION_START, Integer.valueOf(start));
            result.put(Constants.Name.SELECTION_END, Integer.valueOf(end));
        }
        WXBridgeManager.getInstance().callback(getInstanceId(), callbackId, result, false);
    }

    @JSMethod
    public void setTextFormatter(JSONObject params) {
        try {
            String formatRule = params.getString("formatRule");
            String formatReplace = params.getString("formatReplace");
            String recoverRule = params.getString("recoverRule");
            String recoverReplace = params.getString("recoverReplace");
            PatternWrapper format = parseToPattern(formatRule, formatReplace);
            PatternWrapper recover = parseToPattern(recoverRule, recoverReplace);
            if (format != null && recover != null) {
                this.mFormatter = new TextFormatter(format, recover);
            }
        } catch (Throwable t) {
            t.printStackTrace();
        }
    }

    /* access modifiers changed from: protected */
    public final void addEditorActionListener(TextView.OnEditorActionListener listener) {
        TextView view;
        if (listener != null && (view = (TextView) getHostView()) != null) {
            if (this.mEditorActionListeners == null) {
                this.mEditorActionListeners = new ArrayList();
                view.setOnEditorActionListener(new TextView.OnEditorActionListener() {
                    /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass12 */
                    private boolean handled = true;

                    public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                        for (TextView.OnEditorActionListener l : AbstractEditComponent.this.mEditorActionListeners) {
                            if (l != null) {
                                this.handled &= l.onEditorAction(v, actionId, event);
                            }
                        }
                        return this.handled;
                    }
                });
            }
            this.mEditorActionListeners.add(listener);
        }
    }

    public final void addTextChangedListener(TextWatcher watcher) {
        if (this.mTextChangedListeners == null) {
            this.mTextChangedListeners = new ArrayList();
        }
        this.mTextChangedListeners.add(watcher);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:2:0x0003, code lost:
        r0 = r4.getContext();
     */
    private void addKeyboardListener(WXEditText host) {
        final Context context;
        if (host != null && context != null && (context instanceof Activity)) {
            this.mUnregister = SoftKeyboardDetector.registerKeyboardEventListener((Activity) context, new SoftKeyboardDetector.OnKeyboardEventListener() {
                /* class com.taobao.weex.ui.component.AbstractEditComponent.AnonymousClass13 */

                @Override // com.taobao.weex.ui.component.helper.SoftKeyboardDetector.OnKeyboardEventListener
                public void onKeyboardEvent(boolean isShown) {
                    if (AbstractEditComponent.this.mListeningKeyboard) {
                        if (AbstractEditComponent.this.getInstance() != null && !AbstractEditComponent.this.getInstance().isDestroy()) {
                            Map<String, Object> event = new HashMap<>(1);
                            event.put("isShow", Boolean.valueOf(isShown));
                            if (isShown) {
                                Rect r = new Rect();
                                ((Activity) context).getWindow().getDecorView().getWindowVisibleDisplayFrame(r);
                                event.put("keyboardSize", Float.valueOf(WXViewUtils.getWebPxByWidth((float) (WXViewUtils.getScreenHeight(context) - (r.bottom - r.top)), AbstractEditComponent.this.getInstance().getInstanceViewPortWidthWithFloat())));
                            }
                            AbstractEditComponent.this.fireEvent(Constants.Event.KEYBOARD, event);
                        } else {
                            return;
                        }
                    }
                    if (!isShown) {
                        AbstractEditComponent.this.blur();
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        if (getHostView() != null) {
            ((WXEditText) getHostView()).destroy();
        }
        SoftKeyboardDetector.Unregister unregister = this.mUnregister;
        if (unregister != null) {
            try {
                unregister.execute();
                this.mUnregister = null;
            } catch (Throwable throwable) {
                WXLogUtils.w("Unregister throw ", throwable);
            }
        }
    }

    private PatternWrapper parseToPattern(String jsPattern, String replace) {
        if (jsPattern == null || replace == null) {
            return null;
        }
        if (!Pattern.compile("/[\\S]+/[i]?[m]?[g]?").matcher(jsPattern).matches()) {
            WXLogUtils.w("WXInput", "Illegal js pattern syntax: " + jsPattern);
            return null;
        }
        int flags = 0;
        boolean global = false;
        String flagsStr = jsPattern.substring(jsPattern.lastIndexOf("/") + 1);
        String regExp = jsPattern.substring(jsPattern.indexOf("/") + 1, jsPattern.lastIndexOf("/"));
        if (flagsStr.contains("i")) {
            flags = 0 | 2;
        }
        if (flagsStr.contains(WXComponent.PROP_FS_MATCH_PARENT)) {
            flags |= 32;
        }
        if (flagsStr.contains("g")) {
            global = true;
        }
        Pattern pattern = null;
        try {
            pattern = Pattern.compile(regExp, flags);
        } catch (PatternSyntaxException e) {
            WXLogUtils.w("WXInput", "Pattern syntax error: " + regExp);
        }
        if (pattern == null) {
            return null;
        }
        PatternWrapper wrapper = new PatternWrapper();
        wrapper.global = global;
        wrapper.matcher = pattern;
        wrapper.replace = replace;
        return wrapper;
    }

    /* access modifiers changed from: private */
    public static class PatternWrapper {
        private boolean global;
        private Pattern matcher;
        private String replace;

        private PatternWrapper() {
            this.global = false;
        }
    }

    /* access modifiers changed from: private */
    public static class TextFormatter {
        private PatternWrapper format;
        private PatternWrapper recover;

        private TextFormatter(PatternWrapper format2, PatternWrapper recover2) {
            this.format = format2;
            this.recover = recover2;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String format(String src) {
            try {
                if (this.format != null) {
                    if (this.format.global) {
                        return this.format.matcher.matcher(src).replaceAll(this.format.replace);
                    }
                    return this.format.matcher.matcher(src).replaceFirst(this.format.replace);
                }
            } catch (Throwable t) {
                WXLogUtils.w("WXInput", "[format] " + t.getMessage());
            }
            return src;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String recover(String formatted) {
            try {
                if (this.recover != null) {
                    if (this.recover.global) {
                        return this.recover.matcher.matcher(formatted).replaceAll(this.recover.replace);
                    }
                    return this.recover.matcher.matcher(formatted).replaceFirst(this.recover.replace);
                }
            } catch (Throwable t) {
                WXLogUtils.w("WXInput", "[formatted] " + t.getMessage());
            }
            return formatted;
        }
    }
}
