package com.taobao.weex.ui.module;

import android.content.Context;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.os.Build;
import android.os.LocaleList;
import android.text.TextUtils;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.WXModule;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;

public class WXLocaleModule extends WXModule {
    @JSMethod(uiThread = false)
    public String getLanguageSync() {
        return getLanguageImpl();
    }

    @JSMethod(uiThread = false)
    public void getLanguage(JSCallback callback) {
        callback.invoke(getLanguageImpl());
    }

    private String getLanguageImpl() {
        Locale locale;
        if (Build.VERSION.SDK_INT >= 24) {
            locale = LocaleList.getDefault().get(0);
        } else {
            locale = Locale.getDefault();
        }
        return locale.getLanguage() + "-" + locale.getCountry();
    }

    @JSMethod(uiThread = false)
    public List<String> getLanguages() {
        return Arrays.asList(getLanguageTags().split(","));
    }

    @JSMethod(uiThread = false)
    public void getLanguages(JSCallback callback) {
        callback.invoke(getLanguageTags().split(","));
    }

    /* JADX INFO: Multiple debug info for r3v1 java.util.Locale: [D('local' java.util.Locale), D('localeList' android.os.LocaleList)] */
    private String getLanguageTags() {
        Resources res;
        Configuration configuration;
        Context application = WXEnvironment.getApplication();
        if (application == null || (res = application.getResources()) == null || (configuration = res.getConfiguration()) == null) {
            return "";
        }
        if (Build.VERSION.SDK_INT >= 24) {
            return configuration.getLocales().toLanguageTags();
        }
        Locale local = configuration.locale;
        if (local != null) {
            return toLanguageTag(local);
        }
        return "";
    }

    private String toLanguageTag(Locale locale) {
        if (Build.VERSION.SDK_INT >= 21) {
            return locale.toLanguageTag();
        }
        StringBuilder sb = new StringBuilder();
        String language = locale.getLanguage();
        String region = locale.getCountry();
        sb.append(language);
        if (!TextUtils.isEmpty(region)) {
            sb.append("-");
            sb.append(region);
        }
        return sb.toString();
    }
}
