package com.taobao.weex.utils;

import android.graphics.Typeface;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Base64;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import io.dcloud.feature.uniapp.adapter.AbsURIAdapter;
import java.io.File;

public class FontDO {
    public static final int STATE_FAILED = 3;
    public static final int STATE_INIT = 0;
    public static final int STATE_INVALID = -1;
    public static final int STATE_LOADING = 1;
    public static final int STATE_SUCCESS = 2;
    public static final int TYPE_BASE64 = 5;
    public static final int TYPE_FILE = 2;
    public static final int TYPE_LOCAL = 3;
    public static final int TYPE_NATIVE = 4;
    public static final int TYPE_NETWORK = 1;
    public static final int TYPE_UNKNOWN = 0;
    private String mFilePath;
    private final String mFontFamilyName;
    private int mState = -1;
    private int mType = 1;
    private Typeface mTypeface;
    private String mUrl = "";

    public FontDO(String fontFamilyName, String src, WXSDKInstance instance) {
        this.mFontFamilyName = fontFamilyName;
        parseSrc(src, instance);
    }

    public FontDO(String fontFamilyName, Typeface typeface) {
        this.mFontFamilyName = fontFamilyName;
        this.mTypeface = typeface;
        this.mType = 4;
        this.mState = 2;
    }

    public String getFontFamilyName() {
        return this.mFontFamilyName;
    }

    /* JADX WARNING: Removed duplicated region for block: B:13:0x002f  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x0037  */
    private void parseSrc(String src, WXSDKInstance instance) {
        String localUrl;
        Uri uri;
        String src2 = src != null ? src.trim() : "";
        if (!(instance == null || instance.getCustomFontNetworkHandler() == null)) {
            localUrl = instance.getCustomFontNetworkHandler().fetchLocal(src2);
            if (!TextUtils.isEmpty(localUrl)) {
                if (!localUrl.isEmpty()) {
                    this.mState = -1;
                    WXLogUtils.e("TypefaceUtil", "font src is empty.");
                    return;
                }
                if (localUrl.matches("^url\\((('.*')|(\".*\"))\\)$")) {
                    Uri uri2 = Uri.parse(localUrl.substring(5, localUrl.length() - 2));
                    if (instance != null) {
                        uri = instance.rewriteUri(uri2, AbsURIAdapter.FONT);
                    } else {
                        uri = uri2;
                    }
                    this.mUrl = uri.toString();
                    try {
                        String scheme = uri.getScheme();
                        if (!"http".equals(scheme)) {
                            if (!"https".equals(scheme)) {
                                if ("file".equals(scheme)) {
                                    this.mType = 2;
                                    this.mUrl = uri.getEncodedSchemeSpecificPart();
                                } else if ("local".equals(scheme)) {
                                    this.mType = 3;
                                } else if ("data".equals(scheme)) {
                                    long start = System.currentTimeMillis();
                                    String[] data = this.mUrl.split(",");
                                    if (data != null && data.length == 2) {
                                        String identify = data[0];
                                        if (!TextUtils.isEmpty(identify) && identify.endsWith("base64")) {
                                            String base64Data = data[1];
                                            if (!TextUtils.isEmpty(base64Data)) {
                                                String md5 = WXFileUtils.md5(base64Data);
                                                File cacheDir = new File(WXEnvironment.getApplication().getCacheDir(), TypefaceUtil.FONT_CACHE_DIR_NAME);
                                                if (!cacheDir.exists()) {
                                                    cacheDir.mkdirs();
                                                }
                                                File tmpFile = new File(cacheDir, md5);
                                                if (!tmpFile.exists()) {
                                                    tmpFile.createNewFile();
                                                    WXFileUtils.saveFile(tmpFile.getPath(), Base64.decode(base64Data, 0), WXEnvironment.getApplication());
                                                }
                                                this.mUrl = tmpFile.getPath();
                                                this.mType = 5;
                                                WXLogUtils.d("TypefaceUtil", "Parse base64 font cost " + (System.currentTimeMillis() - start) + " ms");
                                            }
                                        }
                                    }
                                } else {
                                    WXLogUtils.e("TypefaceUtil", "Unknown scheme for font url: " + this.mUrl);
                                    this.mType = 0;
                                }
                                this.mState = 0;
                            }
                        }
                        this.mType = 1;
                        this.mState = 0;
                    } catch (Exception e) {
                        this.mType = -1;
                        WXLogUtils.e("TypefaceUtil", "URI.create(mUrl) failed mUrl: " + this.mUrl + "\n" + WXLogUtils.getStackTrace(e));
                    }
                } else {
                    this.mUrl = localUrl;
                    this.mState = -1;
                }
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("TypefaceUtil", "src:" + localUrl + ", mUrl:" + this.mUrl + ", mType:" + this.mType);
                    return;
                }
                return;
            }
        }
        localUrl = src2;
        if (!localUrl.isEmpty()) {
        }
    }

    public String getUrl() {
        return this.mUrl;
    }

    public int getType() {
        return this.mType;
    }

    public Typeface getTypeface() {
        return this.mTypeface;
    }

    public void setTypeface(Typeface typeface) {
        this.mTypeface = typeface;
    }

    public int getState() {
        return this.mState;
    }

    public void setState(int state) {
        this.mState = state;
    }

    public String getFilePath() {
        return this.mFilePath;
    }

    public void setFilePath(String mFilePath2) {
        this.mFilePath = mFilePath2;
    }
}
