package io.dcloud.feature.bluetooth;

import android.bluetooth.BluetoothDevice;
import android.bluetooth.le.ScanResult;
import android.os.ParcelUuid;
import android.util.SparseArray;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.util.PdrUtil;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DCBluetoothDevice {
    public static final ParcelUuid BASE_UUID = ParcelUuid.fromString("00000000-0000-1000-8000-00805F9B34FB");
    private static final int DATA_TYPE_FLAGS = 1;
    private static final int DATA_TYPE_LOCAL_NAME_COMPLETE = 9;
    private static final int DATA_TYPE_LOCAL_NAME_SHORT = 8;
    private static final int DATA_TYPE_MANUFACTURER_SPECIFIC_DATA = 255;
    private static final int DATA_TYPE_SERVICE_DATA_128_BIT = 33;
    private static final int DATA_TYPE_SERVICE_DATA_16_BIT = 22;
    private static final int DATA_TYPE_SERVICE_DATA_32_BIT = 32;
    private static final int DATA_TYPE_SERVICE_UUIDS_128_BIT_COMPLETE = 7;
    private static final int DATA_TYPE_SERVICE_UUIDS_128_BIT_PARTIAL = 6;
    private static final int DATA_TYPE_SERVICE_UUIDS_16_BIT_COMPLETE = 3;
    private static final int DATA_TYPE_SERVICE_UUIDS_16_BIT_PARTIAL = 2;
    private static final int DATA_TYPE_SERVICE_UUIDS_32_BIT_COMPLETE = 5;
    private static final int DATA_TYPE_SERVICE_UUIDS_32_BIT_PARTIAL = 4;
    private static final int DATA_TYPE_TX_POWER_LEVEL = 10;
    public static final int UUID_BYTES_128_BIT = 16;
    public static final int UUID_BYTES_16_BIT = 2;
    public static final int UUID_BYTES_32_BIT = 4;
    private int RSSI;
    private String advertisData;
    private JSONArray advertisServiceUUIDs;
    private String deviceId;
    private String localName;
    private String name;
    private JSONObject serviceData;

    public DCBluetoothDevice(ScanResult result) {
        setDeviceId(result.getDevice().getAddress());
        String str = "";
        setName(PdrUtil.isEmpty(result.getDevice().getName()) ? str : result.getDevice().getName());
        setRSSI(result.getRssi());
        SparseArray<byte[]> mManufacturerSpecificData = result.getScanRecord().getManufacturerSpecificData();
        if (mManufacturerSpecificData != null && mManufacturerSpecificData.size() > 0) {
            setAdvertisData(bytesToHexString(mManufacturerSpecificData.valueAt(0)));
        }
        setLocalName(!PdrUtil.isEmpty(result.getScanRecord().getDeviceName()) ? result.getScanRecord().getDeviceName() : str);
        try {
            setServiceData(map2Str(result.getScanRecord().getServiceData()));
            setAdvertisServiceUUIDs(list2Str(result.getScanRecord().getServiceUuids()));
        } catch (JSONException e) {
            setAdvertisServiceUUIDs(new JSONArray());
        }
    }

    static byte[] concat(byte[] a, byte[] b) {
        byte[] c = new byte[(a.length + b.length)];
        System.arraycopy(a, 0, c, 0, a.length);
        System.arraycopy(b, 0, c, a.length, b.length);
        return c;
    }

    public static String bytesToHexString(byte[] bArray) {
        StringBuffer sb = new StringBuffer(bArray.length);
        for (byte b : bArray) {
            String sTemp = Integer.toHexString(b & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE);
            if (sTemp.length() < 2) {
                sb.append(0);
            }
            sb.append(sTemp.toUpperCase());
        }
        return sb.toString();
    }

    public DCBluetoothDevice(BluetoothDevice device, byte[] result) {
        setDeviceId(device.getAddress());
        setName(PdrUtil.isEmpty(device.getName()) ? "" : device.getName());
        parseFromBytes(result);
    }

    /* JADX INFO: Multiple debug info for r8v2 'dataLength'  int: [D('fieldType' int), D('dataLength' int)] */
    /* JADX INFO: Multiple debug info for r8v3 'dataLength'  int: [D('fieldType' int), D('dataLength' int)] */
    /* JADX WARNING: Removed duplicated region for block: B:108:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x0143  */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x0146  */
    /* JADX WARNING: Removed duplicated region for block: B:83:0x0169  */
    private void parseFromBytes(byte[] scanRecord) {
        Map<ParcelUuid, byte[]> serviceData2;
        Exception e;
        List<ParcelUuid> serviceUuids;
        int fieldType;
        int currentPos;
        if (scanRecord != null) {
            List<ParcelUuid> serviceUuids2 = new ArrayList<>();
            SparseArray<byte[]> manufacturerData = new SparseArray<>();
            Map<ParcelUuid, byte[]> serviceData3 = new HashMap<>();
            String localName2 = "";
            int serviceUuidLength = 0;
            while (true) {
                try {
                    if (serviceUuidLength < scanRecord.length) {
                        int currentPos2 = serviceUuidLength + 1;
                        try {
                            int length = scanRecord[serviceUuidLength] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
                            if (length == 0) {
                                serviceData2 = serviceData3;
                            } else {
                                int dataLength = length - 1;
                                int currentPos3 = currentPos2 + 1;
                                try {
                                    int fieldType2 = scanRecord[currentPos2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE;
                                    if (fieldType2 != 22) {
                                        if (fieldType2 == 255) {
                                            currentPos = currentPos3;
                                            fieldType = dataLength;
                                            serviceData2 = serviceData3;
                                            int manufacturerId = ((scanRecord[currentPos + 1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8) + (255 & scanRecord[currentPos]);
                                            byte[] manufacturerDataBytes = extractBytes(scanRecord, currentPos, fieldType);
                                            byte[] preByte = manufacturerData.get(manufacturerId);
                                            if (preByte == null) {
                                                manufacturerData.put(manufacturerId, manufacturerDataBytes);
                                            } else if (manufacturerDataBytes.length > 2) {
                                                byte[] bytes = new byte[((preByte.length + manufacturerDataBytes.length) - 2)];
                                                System.arraycopy(preByte, 0, bytes, 0, preByte.length);
                                                System.arraycopy(manufacturerDataBytes, 2, bytes, preByte.length, manufacturerDataBytes.length - 2);
                                                manufacturerData.put(manufacturerId, bytes);
                                            }
                                        } else if (!(fieldType2 == 32 || fieldType2 == 33)) {
                                            switch (fieldType2) {
                                                case 1:
                                                    currentPos = currentPos3;
                                                    serviceData2 = serviceData3;
                                                    try {
                                                        int i = 255 & scanRecord[currentPos];
                                                        fieldType = dataLength;
                                                        continue;
                                                    } catch (Exception e2) {
                                                        e = e2;
                                                        e.printStackTrace();
                                                        setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                                                        setServiceData(map2Str(serviceData2));
                                                        setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                                                        if (manufacturerData.size() <= 0) {
                                                        }
                                                    }
                                                    break;
                                                case 2:
                                                case 3:
                                                    currentPos = currentPos3;
                                                    parseServiceUuid(scanRecord, currentPos3, dataLength, 2, serviceUuids2);
                                                    serviceData2 = serviceData3;
                                                    fieldType = dataLength;
                                                    continue;
                                                case 4:
                                                case 5:
                                                    currentPos = currentPos3;
                                                    try {
                                                        parseServiceUuid(scanRecord, currentPos3, dataLength, 4, serviceUuids2);
                                                        serviceData2 = serviceData3;
                                                        fieldType = dataLength;
                                                        continue;
                                                    } catch (Exception e3) {
                                                        e = e3;
                                                        serviceData2 = serviceData3;
                                                        e.printStackTrace();
                                                        setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                                                        setServiceData(map2Str(serviceData2));
                                                        setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                                                        if (manufacturerData.size() <= 0) {
                                                        }
                                                    }
                                                    break;
                                                case 6:
                                                case 7:
                                                    parseServiceUuid(scanRecord, currentPos3, dataLength, 16, serviceUuids2);
                                                    currentPos = currentPos3;
                                                    fieldType = dataLength;
                                                    serviceData2 = serviceData3;
                                                    continue;
                                                case 8:
                                                case 9:
                                                    localName2 = new String(extractBytes(scanRecord, currentPos3, dataLength));
                                                    currentPos = currentPos3;
                                                    fieldType = dataLength;
                                                    serviceData2 = serviceData3;
                                                    continue;
                                                case 10:
                                                    try {
                                                        byte b = scanRecord[currentPos3];
                                                        currentPos = currentPos3;
                                                        fieldType = dataLength;
                                                        serviceData2 = serviceData3;
                                                        continue;
                                                    } catch (Exception e4) {
                                                        e = e4;
                                                        serviceData2 = serviceData3;
                                                        e.printStackTrace();
                                                        setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                                                        setServiceData(map2Str(serviceData2));
                                                        setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                                                        if (manufacturerData.size() <= 0) {
                                                        }
                                                    }
                                                    break;
                                                default:
                                                    currentPos = currentPos3;
                                                    fieldType = dataLength;
                                                    serviceData2 = serviceData3;
                                                    continue;
                                            }
                                        }
                                        serviceUuidLength = currentPos + fieldType;
                                        serviceData3 = serviceData2;
                                    }
                                    currentPos = currentPos3;
                                    fieldType = dataLength;
                                    serviceData2 = serviceData3;
                                    int serviceUuidLength2 = 2;
                                    if (fieldType2 == 32) {
                                        serviceUuidLength2 = 4;
                                    } else if (fieldType2 == 33) {
                                        serviceUuidLength2 = 16;
                                    }
                                    serviceData2.put(parseUuidFrom(extractBytes(scanRecord, currentPos, serviceUuidLength2)), extractBytes(scanRecord, currentPos + serviceUuidLength2, fieldType - serviceUuidLength2));
                                    serviceUuidLength = currentPos + fieldType;
                                    serviceData3 = serviceData2;
                                } catch (Exception e5) {
                                    e = e5;
                                    serviceData2 = serviceData3;
                                    e.printStackTrace();
                                    setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                                    setServiceData(map2Str(serviceData2));
                                    setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                                    if (manufacturerData.size() <= 0) {
                                    }
                                }
                            }
                        } catch (Exception e6) {
                            e = e6;
                            serviceData2 = serviceData3;
                            e.printStackTrace();
                            setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                            setServiceData(map2Str(serviceData2));
                            setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                            if (manufacturerData.size() <= 0) {
                            }
                        }
                    } else {
                        serviceData2 = serviceData3;
                    }
                } catch (Exception e7) {
                    e = e7;
                    serviceData2 = serviceData3;
                    e.printStackTrace();
                    setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                    setServiceData(map2Str(serviceData2));
                    setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                    if (manufacturerData.size() <= 0) {
                    }
                }
            }
            try {
                if (serviceUuids2.isEmpty()) {
                    serviceUuids = null;
                } else {
                    serviceUuids = serviceUuids2;
                }
                serviceUuids2 = serviceUuids;
            } catch (Exception e8) {
                e = e8;
                e.printStackTrace();
                setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
                setServiceData(map2Str(serviceData2));
                setAdvertisServiceUUIDs(list2Str(serviceUuids2));
                if (manufacturerData.size() <= 0) {
                }
            }
            setLocalName(!PdrUtil.isEmpty(localName2) ? "" : localName2);
            try {
                setServiceData(map2Str(serviceData2));
                setAdvertisServiceUUIDs(list2Str(serviceUuids2));
            } catch (JSONException e9) {
                setAdvertisServiceUUIDs(new JSONArray());
            }
            if (manufacturerData.size() <= 0) {
                byte[] all = new byte[0];
                for (int i2 = 0; i2 < manufacturerData.size(); i2++) {
                    if (manufacturerData.valueAt(i2) != null) {
                        all = concat(all, manufacturerData.valueAt(i2));
                    }
                }
                setAdvertisData(bytesToHexString(all));
            }
        }
    }

    private int parseServiceUuid(byte[] scanRecord, int currentPos, int dataLength, int uuidLength, List<ParcelUuid> serviceUuids) {
        while (dataLength > 0) {
            serviceUuids.add(parseUuidFrom(extractBytes(scanRecord, currentPos, uuidLength)));
            dataLength -= uuidLength;
            currentPos += uuidLength;
        }
        return currentPos;
    }

    public ParcelUuid parseUuidFrom(byte[] uuidBytes) {
        long shortUuid;
        if (uuidBytes != null) {
            int length = uuidBytes.length;
            if (length != 2 && length != 4 && length != 16) {
                throw new IllegalArgumentException("uuidBytes length invalid - " + length);
            } else if (length == 16) {
                ByteBuffer buf = ByteBuffer.wrap(uuidBytes).order(ByteOrder.LITTLE_ENDIAN);
                return new ParcelUuid(new UUID(buf.getLong(8), buf.getLong(0)));
            } else {
                if (length == 2) {
                    shortUuid = ((long) (uuidBytes[0] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE)) + ((long) ((uuidBytes[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8));
                } else {
                    shortUuid = ((long) ((uuidBytes[3] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 24)) + ((long) (uuidBytes[0] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE)) + ((long) ((uuidBytes[1] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 8)) + ((long) ((uuidBytes[2] & IApp.ABS_PRIVATE_WWW_DIR_APP_MODE) << 16));
                }
                return new ParcelUuid(new UUID(BASE_UUID.getUuid().getMostSignificantBits() + (shortUuid << 32), BASE_UUID.getUuid().getLeastSignificantBits()));
            }
        } else {
            throw new IllegalArgumentException("uuidBytes cannot be null");
        }
    }

    private byte[] extractBytes(byte[] scanRecord, int start, int length) {
        byte[] bytes = new byte[length];
        System.arraycopy(scanRecord, start, bytes, 0, length);
        return bytes;
    }

    private JSONObject map2Str(Map<ParcelUuid, byte[]> map) throws JSONException {
        JSONObject object = new JSONObject();
        if (map != null) {
            for (ParcelUuid key : map.keySet()) {
                object.put(key.toString().toUpperCase(), bytesToHexString(map.get(key)));
            }
        }
        if (object.length() <= 0) {
            return null;
        }
        return object;
    }

    private JSONArray list2Str(List<ParcelUuid> list) {
        JSONArray array = new JSONArray();
        if (list != null) {
            for (Object object : list) {
                array.put(object.toString().toUpperCase());
            }
        }
        return array;
    }

    public String getLocalName() {
        return this.localName;
    }

    public void setLocalName(String localName2) {
        this.localName = localName2;
    }

    public DCBluetoothDevice(String deviceId2, String name2, int RSSI2, String advertisData2, JSONObject serviceData2, JSONArray advertisServiceUUIDs2) {
        this.deviceId = deviceId2;
        this.name = name2;
        this.RSSI = RSSI2;
        this.advertisData = advertisData2;
        this.serviceData = serviceData2;
        this.advertisServiceUUIDs = advertisServiceUUIDs2;
    }

    public String getDeviceId() {
        return this.deviceId;
    }

    public void setDeviceId(String deviceId2) {
        this.deviceId = deviceId2;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name2) {
        this.name = name2;
    }

    public int getRSSI() {
        return this.RSSI;
    }

    public void setRSSI(int RSSI2) {
        this.RSSI = RSSI2;
    }

    public String getAdvertisData() {
        return this.advertisData;
    }

    public void setAdvertisData(String advertisData2) {
        this.advertisData = advertisData2;
    }

    public JSONObject getServiceData() {
        return this.serviceData;
    }

    public void setServiceData(JSONObject serviceData2) {
        this.serviceData = serviceData2;
    }

    public JSONArray getAdvertisServiceUUIDs() {
        return this.advertisServiceUUIDs;
    }

    public void setAdvertisServiceUUIDs(JSONArray advertisServiceUUIDs2) {
        this.advertisServiceUUIDs = advertisServiceUUIDs2;
    }

    public String toString() {
        JSONObject object = new JSONObject();
        try {
            object.put("deviceId", this.deviceId);
            object.put("name", this.name);
            object.put("RSSI", this.RSSI);
            object.put("localName", this.localName);
            object.put("advertisServiceUUIDs", this.advertisServiceUUIDs);
            if (this.advertisData != null) {
                object.put("advertisData", this.advertisData);
            }
            if (this.serviceData != null) {
                object.put("serviceData", this.serviceData);
            }
        } catch (JSONException e) {
        }
        return object.toString();
    }
}
