package io.dcloud.share.mm;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.Bundle;
import android.view.Display;
import android.view.WindowManager;
import com.tencent.mm.opensdk.modelbiz.WXLaunchMiniProgram;
import com.tencent.mm.opensdk.modelmsg.SendMessageToWX;
import com.tencent.mm.opensdk.modelmsg.WXImageObject;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.PdrUtil;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

public class WeiXinMediator implements ProcessMediator.Logic {
    public static String WX_MINI_PROGRAM_KEY = "isLaunchMiniProgram";
    private String APPID;
    private IWXAPI api;

    @Override // io.dcloud.ProcessMediator.Logic
    public void exec(Context context, Intent intent) {
        byte[] thumbData;
        String metaValue = AndroidResources.getMetaValue("WX_APPID");
        this.APPID = metaValue;
        IWXAPI createWXAPI = WXAPIFactory.createWXAPI(context, metaValue, true);
        this.api = createWXAPI;
        createWXAPI.registerApp(this.APPID);
        Bundle bundle = intent.getBundleExtra(ProcessMediator.REQ_DATA);
        if (!intent.hasExtra(WX_MINI_PROGRAM_KEY) || !intent.getBooleanExtra(WX_MINI_PROGRAM_KEY, false)) {
            SendMessageToWX.Req req = new SendMessageToWX.Req();
            req.fromBundle(bundle);
            String pImg = bundle.getString("pThumbImg");
            String pThumbImg = bundle.getString("pImg");
            String absFullPath = bundle.getString("absFullPath");
            String AbsFullPathThumb = bundle.getString("AbsFullPathThumb");
            int mRunningMode = bundle.getInt("mRunningMode");
            if (PdrUtil.isEmpty(pImg) || PdrUtil.isEmpty(pThumbImg) || PdrUtil.isEmpty(absFullPath) || PdrUtil.isEmpty(AbsFullPathThumb)) {
                this.api.sendReq(req);
                return;
            }
            WXImageObject imgObj = new WXImageObject();
            if (PdrUtil.isNetPath(pImg)) {
                Bitmap bmp = null;
                try {
                    bmp = BitmapFactory.decodeStream(new URL(pImg).openStream());
                } catch (IOException e) {
                    e.printStackTrace();
                }
                imgObj.imageData = WeiXinApiManager.bmpToByteArray(bmp, true);
                thumbData = buildThumbData(context, PdrUtil.isEmpty(pThumbImg) ? pImg : pThumbImg, AbsFullPathThumb, mRunningMode);
            } else {
                Bitmap bmp2 = null;
                try {
                    bmp2 = scaleLoadPic(context, absFullPath);
                } catch (IOException e2) {
                    e2.printStackTrace();
                }
                imgObj = new WXImageObject(bmp2);
                thumbData = buildThumbData(context, pThumbImg, AbsFullPathThumb, mRunningMode);
            }
            req.message.mediaObject = imgObj;
            req.message.thumbData = thumbData;
            this.api.sendReq(req);
            return;
        }
        WXLaunchMiniProgram.Req req2 = new WXLaunchMiniProgram.Req();
        req2.userName = bundle.getString("userName");
        req2.path = bundle.getString("path");
        req2.miniprogramType = bundle.getInt("miniprogramType");
        if (!this.api.sendReq(req2) && (context instanceof ProcessMediator)) {
            ((ProcessMediator) context).finish();
        }
    }

    /* JADX INFO: Multiple debug info for r2v1 int: [D('imgStream' java.io.InputStream), D('imageWidth' int)] */
    public Bitmap scaleLoadPic(Context context, String path) throws IOException {
        BitmapFactory.Options opts = new BitmapFactory.Options();
        opts.inJustDecodeBounds = true;
        if (FileUtil.checkPrivatePath(context, path)) {
            BitmapFactory.decodeFile(path, opts);
        } else {
            InputStream imgStream = FileUtil.getImageFileStream(context, new File(path));
            if (imgStream != null) {
                BitmapFactory.decodeStream(imgStream, null, opts);
                imgStream.close();
            }
        }
        int imageWidth = opts.outWidth;
        int imageHeigth = opts.outHeight;
        Display dp = ((WindowManager) context.getSystemService("window")).getDefaultDisplay();
        int scale = 1;
        int scaleWidth = imageWidth / dp.getWidth();
        int scaleHeight = imageHeigth / dp.getHeight();
        if (scaleWidth >= scaleHeight && scaleWidth >= 1) {
            scale = scaleWidth;
        } else if (scaleWidth < scaleHeight && scaleHeight >= 1) {
            scale = scaleHeight;
        }
        opts.inSampleSize = scale;
        opts.inJustDecodeBounds = false;
        if (FileUtil.checkPrivatePath(context, path)) {
            return BitmapFactory.decodeFile(path, opts);
        }
        InputStream imgStream2 = FileUtil.getImageFileStream(context, new File(path));
        Bitmap bm = BitmapFactory.decodeStream(imgStream2, null, opts);
        imgStream2.close();
        return bm;
    }

    private byte[] buildThumbData(Context context, String thumeImgPath, String absFullPathThumb, int mRuningMode) {
        Bitmap bitmap = null;
        try {
            if (PdrUtil.isNetPath(thumeImgPath)) {
                InputStream is = new URL(thumeImgPath).openStream();
                if (is != null) {
                    bitmap = BitmapFactory.decodeStream(is);
                }
            } else {
                bitmap = scaleLoadPic(context, absFullPathThumb);
            }
            if (bitmap != null) {
                bitmap = cpBitmap(bitmap);
            }
            return WeiXinApiManager.bmpToByteArray(bitmap, true);
        } catch (Exception e) {
            Logger.e("buildThumbData Exception=" + e);
            return null;
        }
    }

    private static Bitmap cpBitmap(Bitmap orgBitmap) {
        if (PdrUtil.isEmpty(orgBitmap)) {
            return null;
        }
        while (orgBitmap.getHeight() * orgBitmap.getRowBytes() >= 32768) {
            Bitmap tmp = Bitmap.createScaledBitmap(orgBitmap, (orgBitmap.getWidth() * 2) / 3, (orgBitmap.getHeight() * 2) / 3, true);
            if (orgBitmap != tmp) {
                orgBitmap.recycle();
            }
            orgBitmap = tmp;
        }
        return orgBitmap;
    }
}
