package io.dcloud.share.qq;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.text.TextUtils;
import com.tencent.connect.common.Constants;
import com.tencent.tauth.IUiListener;
import com.tencent.tauth.Tencent;
import com.tencent.tauth.UiError;
import io.dcloud.RInformation;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.Deprecated_JSUtil;
import io.dcloud.common.util.FileUtil;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.JSUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.share.qq.R;
import io.dcloud.share.IFShareApi;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class QQApiManager implements IFShareApi {
    public static final String AUTHORIZE_TEMPLATE = "{authenticated:%s,accessToken:'%s'}";
    public static final String KEY_APPID = "appid";
    private static final String PACKAGENAME = "com.tencent.mobileqq";
    private static final String TAG = "WeiXinApiManager";
    private String APPID;
    private String QQ_SHARE_DES = Constants.SOURCE_QQ;
    private String QQ_SHARE_ID = "qq";
    private Tencent mTencent;
    private MyIUiListener myIUiListener;

    @Override // io.dcloud.share.IFShareApi
    public void initConfig() {
        this.APPID = AndroidResources.getMetaValue("QQ_APPID");
    }

    @Override // io.dcloud.share.IFShareApi
    public String getId() {
        return this.QQ_SHARE_ID;
    }

    public void send(Activity context, String pShareMsg) {
        initConfig();
        if (this.mTencent == null) {
            if (!AppRuntime.hasPrivacyForNotShown(context)) {
                Tencent.setIsPermissionGranted(true, Build.MODEL);
            }
            this.mTencent = Tencent.createInstance(this.APPID, context);
        }
        Bundle params = new Bundle();
        try {
            JSONObject _msg = new JSONObject(pShareMsg);
            String _content = _msg.optString("content");
            String href = _msg.optString("href");
            String thumbs = _msg.optString("thumbs");
            String title = _msg.optString("title");
            if (!TextUtils.isEmpty(_content)) {
                params.putString("summary", _content);
            }
            params.putString("title", title);
            params.putInt("req_type", 1);
            params.putString("targetUrl", href);
            params.putString("imageLocalUrl", thumbs);
            this.mTencent.shareToQQ(context, params, new IUiListener() {
                /* class io.dcloud.share.qq.QQApiManager.AnonymousClass1 */

                @Override // com.tencent.tauth.IUiListener
                public void onError(UiError arg0) {
                }

                @Override // com.tencent.tauth.IUiListener
                public void onComplete(Object arg0) {
                }

                @Override // com.tencent.tauth.IUiListener
                public void onCancel() {
                }

                @Override // com.tencent.tauth.IUiListener
                public void onWarning(int i) {
                }
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // io.dcloud.share.IFShareApi
    public void send(IWebview pWebViewImpl, String pCallbackId, String pShareMsg) {
        char c;
        if (this.mTencent == null) {
            if (!AppRuntime.hasPrivacyForNotShown(pWebViewImpl.getContext())) {
                Tencent.setIsPermissionGranted(true, Build.MODEL);
            }
            this.mTencent = Tencent.createInstance(this.APPID, pWebViewImpl.getActivity(), DeviceInfo.mAppAuthorities);
        }
        pWebViewImpl.obtainApp().registerSysEventListener(new ISysEventListener() {
            /* class io.dcloud.share.qq.QQApiManager.AnonymousClass2 */

            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Object[] _args = (Object[]) pArgs;
                int requestCode = ((Integer) _args[0]).intValue();
                int resultCode = ((Integer) _args[1]).intValue();
                Intent data = (Intent) _args[2];
                if (requestCode == 10103 && resultCode == -1) {
                    Tencent.handleResultData(data, QQApiManager.this.myIUiListener);
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
        Bundle params = new Bundle();
        try {
            JSONObject _msg = new JSONObject(pShareMsg);
            String type = _msg.optString("type");
            String _content = _msg.optString("content");
            String _title = _msg.optString("title");
            String href = _msg.optString("href");
            String media = _msg.optString("media");
            JSONArray _thumbs = _msg.optJSONArray("thumbs");
            JSONArray _pictures = _msg.optJSONArray("pictures");
            String thumbImgPath = null;
            String imgPath = _pictures != null ? _pictures.optString(0, null) : null;
            if (_thumbs != null) {
                thumbImgPath = _thumbs.optString(0, null);
            }
            if (!TextUtils.isEmpty(_title)) {
                params.putString("title", _title);
            }
            if (!TextUtils.isEmpty(_content)) {
                params.putString("summary", _content);
            }
            if (!TextUtils.isEmpty(type)) {
                switch (type.hashCode()) {
                    case 117588:
                        if (type.equals("web")) {
                            c = 0;
                            break;
                        }
                        c = 65535;
                        break;
                    case 3556653:
                        if (type.equals("text")) {
                            c = 1;
                            break;
                        }
                        c = 65535;
                        break;
                    case 100313435:
                        if (type.equals("image")) {
                            c = 2;
                            break;
                        }
                        c = 65535;
                        break;
                    case 104263205:
                        if (type.equals("music")) {
                            c = 3;
                            break;
                        }
                        c = 65535;
                        break;
                    default:
                        c = 65535;
                        break;
                }
                if (c != 0) {
                    if (c != 1) {
                        if (c == 2) {
                            if (TextUtils.isEmpty(href)) {
                                params.putInt("req_type", 5);
                            } else {
                                params.putInt("req_type", 1);
                                params.putString("targetUrl", href);
                            }
                            if (!TextUtils.isEmpty(imgPath)) {
                                setBundleImgUrl(pWebViewImpl, imgPath, params, true);
                            } else if (!TextUtils.isEmpty(thumbImgPath)) {
                                setBundleImgUrl(pWebViewImpl, thumbImgPath, params, true);
                            }
                        } else if (c == 3) {
                            if (TextUtils.isEmpty(href)) {
                                callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_error_href_empty)), -1);
                                return;
                            }
                            params.putInt("req_type", 2);
                            params.putString("targetUrl", href);
                            params.putString("audio_url", media);
                        }
                    } else if (TextUtils.isEmpty(href)) {
                        callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_error_href_empty)), -1);
                        return;
                    } else {
                        params.putString("targetUrl", href);
                    }
                } else if (TextUtils.isEmpty(href)) {
                    callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_error_webpage_url_empty)), -1);
                    return;
                } else {
                    params.putInt("req_type", 1);
                    params.putString("targetUrl", href);
                    if (!TextUtils.isEmpty(imgPath)) {
                        setBundleImgUrl(pWebViewImpl, imgPath, params, true);
                    } else if (!TextUtils.isEmpty(thumbImgPath)) {
                        setBundleImgUrl(pWebViewImpl, thumbImgPath, params, true);
                    }
                }
            } else if (!TextUtils.isEmpty(type)) {
                callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_error_type_param)), -100);
                return;
            } else if (!PdrUtil.isEmpty(href)) {
                params.putInt("req_type", 1);
                params.putString("targetUrl", href);
                if (!TextUtils.isEmpty(imgPath)) {
                    setBundleImgUrl(pWebViewImpl, imgPath, params, true);
                } else if (!TextUtils.isEmpty(thumbImgPath)) {
                    setBundleImgUrl(pWebViewImpl, thumbImgPath, params, true);
                }
            } else if (!TextUtils.isEmpty(imgPath)) {
                setBundleImgUrl(pWebViewImpl, imgPath, params, false);
                params.putInt("req_type", 5);
            } else {
                callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_error_href_empty)), -1);
                return;
            }
            this.myIUiListener = new MyIUiListener(pWebViewImpl, pCallbackId);
            this.mTencent.shareToQQ(pWebViewImpl.getActivity(), params, this.myIUiListener);
        } catch (JSONException e) {
            e.printStackTrace();
            callBackError(pWebViewImpl, pCallbackId, DOMException.toString(DOMException.MSG_UNKNOWN_ERROR), -99);
        }
    }

    private void setBundleImgUrl(IWebview pWebViewImpl, String imgPath, Bundle params, boolean defaultImg) {
        if (PdrUtil.isNetPath(imgPath)) {
            params.putString("imageUrl", imgPath);
            return;
        }
        String imgPath2 = pWebViewImpl.obtainFrameView().obtainApp().convert2LocalFullPath(pWebViewImpl.obtainFullUrl(), imgPath);
        if (imgPath2.startsWith("content:")) {
            imgPath2 = getRealPathFromURI(pWebViewImpl.getContext(), Uri.parse(imgPath2));
        } else if (!DHFile.exists(imgPath2) && defaultImg) {
            InputStream is = pWebViewImpl.getActivity().getResources().openRawResource(RInformation.DRAWABLE_ICON);
            if (Build.VERSION.SDK_INT >= 29) {
                imgPath2 = pWebViewImpl.getContext().getExternalFilesDir("Images") + "/tmp/" + System.currentTimeMillis();
            } else {
                imgPath2 = pWebViewImpl.obtainFrameView().obtainApp().obtainAppTempPath() + System.currentTimeMillis();
            }
            try {
                DHFile.writeFile(is, imgPath2);
                is.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        } else if (Build.VERSION.SDK_INT >= 29) {
            Context context = pWebViewImpl.getContext();
            if (FileUtil.checkPrivatePath(context, imgPath2)) {
                String pat = context.getExternalFilesDir("Images") + "/tmp/" + imgPath2.substring(imgPath2.lastIndexOf("/"));
                DHFile.copyFile(imgPath2, pat);
                File d = new File(pat);
                if (d.exists()) {
                    imgPath2 = d.getPath();
                }
            }
        }
        params.putString("imageLocalUrl", imgPath2);
    }

    private String getRealPathFromURI(Context context, Uri contentUri) {
        return FileUtil.getPathFromUri(context, contentUri);
    }

    /* access modifiers changed from: package-private */
    public class MyIUiListener implements IUiListener {
        String pCallbackId;
        IWebview pWebViewImpl;

        public MyIUiListener(IWebview pWebViewImpl2, String CallBackId) {
            this.pCallbackId = CallBackId;
            this.pWebViewImpl = pWebViewImpl2;
        }

        @Override // com.tencent.tauth.IUiListener
        public void onCancel() {
            QQApiManager.this.callBackError(this.pWebViewImpl, this.pCallbackId, DOMException.toString(DOMException.MSG_USER_CANCEL), -2);
        }

        @Override // com.tencent.tauth.IUiListener
        public void onWarning(int i) {
        }

        @Override // com.tencent.tauth.IUiListener
        public void onComplete(Object arg0) {
            Deprecated_JSUtil.execCallback(this.pWebViewImpl, this.pCallbackId, arg0.toString(), JSUtil.OK, false, false);
        }

        @Override // com.tencent.tauth.IUiListener
        public void onError(UiError arg0) {
            QQApiManager.this.callBackError(this.pWebViewImpl, this.pCallbackId, DOMException.toString(arg0.errorCode, DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_share_qq_name), arg0.errorMessage, IFShareApi.mLink), -100);
        }
    }

    @Override // io.dcloud.share.IFShareApi
    public void forbid(IWebview pWebViewImpl) {
    }

    @Override // io.dcloud.share.IFShareApi
    public void authorize(IWebview pWebViewImpl, String pCallbackId, String options) {
        JSONObject jsonOptions = JSONUtil.createJSONObject(options);
        if (jsonOptions != null) {
            this.APPID = jsonOptions.optString("appid", this.APPID);
            Logger.e(TAG, "authorize: appId" + this.APPID);
        }
        if (PdrUtil.isEmpty(this.APPID)) {
            Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format(DOMException.JSON_ERROR_INFO, -7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT)), JSUtil.ERROR, true, false);
            return;
        }
        Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, StringUtil.format("{authenticated:%s,accessToken:'%s'}", AbsoluteConst.TRUE, ""), JSUtil.OK, true, false);
    }

    @Override // io.dcloud.share.IFShareApi
    public String getJsonObject(IWebview pWebViewImpl) {
        try {
            JSONObject _weiXinObj = new JSONObject();
            _weiXinObj.put("id", this.QQ_SHARE_ID);
            _weiXinObj.put("description", this.QQ_SHARE_DES);
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_AUTHENTICATED, false);
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_ACCESSTOKEN, "");
            _weiXinObj.put(AbsoluteConst.JSON_SHARE_NATIVECLIENT, PlatformUtil.hasAppInstalled(pWebViewImpl.getContext(), "com.tencent.mobileqq"));
            return _weiXinObj.toString();
        } catch (JSONException e) {
            e.printStackTrace();
            return null;
        }
    }

    public void callBackError(IWebview pWebViewImpl, String pCallbackId, String errorMsg, int errorCode) {
        Deprecated_JSUtil.execCallback(pWebViewImpl, pCallbackId, DOMException.toJSON(errorCode, errorMsg), JSUtil.ERROR, true, false);
    }

    @Override // io.dcloud.share.IFShareApi
    public void dispose() {
        this.mTencent = null;
        this.myIUiListener = null;
    }
}
