package master.flame.danmaku.controller;

import android.content.Context;
import android.graphics.Canvas;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.DisplayMetrics;
import java.util.LinkedList;
import master.flame.danmaku.controller.IDrawTask;
import master.flame.danmaku.danmaku.model.AbsDanmakuSync;
import master.flame.danmaku.danmaku.model.AbsDisplayer;
import master.flame.danmaku.danmaku.model.BaseDanmaku;
import master.flame.danmaku.danmaku.model.DanmakuTimer;
import master.flame.danmaku.danmaku.model.IDanmakus;
import master.flame.danmaku.danmaku.model.IDisplayer;
import master.flame.danmaku.danmaku.model.android.DanmakuContext;
import master.flame.danmaku.danmaku.parser.BaseDanmakuParser;
import master.flame.danmaku.danmaku.renderer.IRenderer;
import master.flame.danmaku.danmaku.util.AndroidUtils;
import master.flame.danmaku.danmaku.util.SystemClock;
import tv.cjump.jni.DeviceUtils;

public class DrawHandler extends Handler {
    private static final int CLEAR_DANMAKUS_ON_SCREEN = 13;
    private static final int HIDE_DANMAKUS = 9;
    private static final long INDEFINITE_TIME = 10000000;
    private static final int MAX_RECORD_SIZE = 500;
    private static final int NOTIFY_DISP_SIZE_CHANGED = 10;
    private static final int NOTIFY_RENDERING = 11;
    private static final int PAUSE = 7;
    public static final int PREPARE = 5;
    private static final int QUIT = 6;
    public static final int RESUME = 3;
    public static final int SEEK_POS = 4;
    private static final int SHOW_DANMAKUS = 8;
    public static final int START = 1;
    public static final int UPDATE = 2;
    private static final int UPDATE_WHEN_PAUSED = 12;
    public IDrawTask drawTask;
    private Callback mCallback;
    private DanmakuContext mContext;
    private long mCordonTime = 30;
    private long mCordonTime2 = 60;
    private IDanmakuViewController mDanmakuView;
    private boolean mDanmakusVisible = true;
    private long mDesireSeekingTime;
    private AbsDisplayer mDisp;
    private LinkedList<Long> mDrawTimes = new LinkedList<>();
    private long mFrameUpdateRate = 16;
    private boolean mIdleSleep;
    private boolean mInSeekingAction;
    private boolean mInSyncAction;
    private boolean mInWaitingState;
    private long mLastDeltaTime;
    private BaseDanmakuParser mParser;
    private boolean mReady;
    private long mRemainingTime;
    private final IRenderer.RenderingState mRenderingState = new IRenderer.RenderingState();
    private UpdateThread mThread;
    private long mThresholdTime;
    private long mTimeBase;
    private final boolean mUpdateInNewThread;
    private long pausedPosition = 0;
    private boolean quitFlag = true;
    private DanmakuTimer timer = new DanmakuTimer();

    public interface Callback {
        void danmakuShown(BaseDanmaku baseDanmaku);

        void drawingFinished();

        void prepared();

        void updateTimer(DanmakuTimer danmakuTimer);
    }

    public DrawHandler(Looper looper, IDanmakuViewController view, boolean danmakuVisibile) {
        super(looper);
        this.mUpdateInNewThread = Runtime.getRuntime().availableProcessors() > 3;
        this.mIdleSleep = true ^ DeviceUtils.isProblemBoxDevice();
        bindView(view);
        if (danmakuVisibile) {
            showDanmakus(null);
        } else {
            hideDanmakus(false);
        }
        this.mDanmakusVisible = danmakuVisibile;
    }

    private void bindView(IDanmakuViewController view) {
        this.mDanmakuView = view;
    }

    public void setConfig(DanmakuContext config) {
        this.mContext = config;
    }

    public void setParser(BaseDanmakuParser parser) {
        this.mParser = parser;
    }

    public void setCallback(Callback cb) {
        this.mCallback = cb;
    }

    public void quit() {
        sendEmptyMessage(6);
    }

    public boolean isStop() {
        return this.quitFlag;
    }

    /* JADX WARNING: Removed duplicated region for block: B:102:? A[RETURN, SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x00f8  */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x0104  */
    /* JADX WARNING: Removed duplicated region for block: B:51:0x0116  */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x011e  */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x0180  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x0187  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x0193  */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x01d5  */
    /* JADX WARNING: Removed duplicated region for block: B:91:0x0207  */
    public void handleMessage(Message msg) {
        Long startTime;
        IDrawTask iDrawTask;
        IDanmakuViewController iDanmakuViewController;
        IDrawTask iDrawTask2;
        int what = msg.what;
        Long start = null;
        switch (what) {
            case 1:
                startTime = (Long) msg.obj;
                if (startTime == null) {
                    this.pausedPosition = startTime.longValue();
                } else {
                    this.pausedPosition = 0;
                }
                if (what == 4) {
                    this.quitFlag = true;
                    quitUpdateThread();
                    Long position = (Long) msg.obj;
                    this.mTimeBase -= position.longValue() - this.timer.currMillisecond;
                    this.timer.update(position.longValue());
                    this.mContext.mGlobalFlagValues.updateMeasureFlag();
                    IDrawTask iDrawTask3 = this.drawTask;
                    if (iDrawTask3 != null) {
                        iDrawTask3.seek(position.longValue());
                    }
                    this.pausedPosition = position.longValue();
                }
                removeMessages(7);
                this.quitFlag = false;
                if (!this.mReady) {
                    this.mRenderingState.reset();
                    this.mDrawTimes.clear();
                    long uptimeMillis = SystemClock.uptimeMillis();
                    long j = this.pausedPosition;
                    this.mTimeBase = uptimeMillis - j;
                    this.timer.update(j);
                    removeMessages(3);
                    sendEmptyMessage(2);
                    this.drawTask.start();
                    notifyRendering();
                    this.mInSeekingAction = false;
                    IDrawTask iDrawTask4 = this.drawTask;
                    if (iDrawTask4 != null) {
                        iDrawTask4.onPlayStateChanged(1);
                        return;
                    }
                    return;
                }
                sendEmptyMessageDelayed(3, 100);
                return;
            case 2:
                if (this.mUpdateInNewThread) {
                    updateInNewThread();
                    return;
                } else {
                    updateInCurrentThread();
                    return;
                }
            case 3:
                removeMessages(7);
                this.quitFlag = false;
                if (!this.mReady) {
                }
                break;
            case 4:
                if (what == 4) {
                }
                removeMessages(7);
                this.quitFlag = false;
                if (!this.mReady) {
                }
                break;
            case 5:
                this.mTimeBase = SystemClock.uptimeMillis();
                if (this.mParser == null || !this.mDanmakuView.isViewReady()) {
                    sendEmptyMessageDelayed(5, 100);
                    return;
                } else {
                    prepare(new Runnable() {
                        /* class master.flame.danmaku.controller.DrawHandler.AnonymousClass1 */

                        public void run() {
                            DrawHandler.this.pausedPosition = 0;
                            DrawHandler.this.mReady = true;
                            if (DrawHandler.this.mCallback != null) {
                                DrawHandler.this.mCallback.prepared();
                            }
                        }
                    });
                    return;
                }
            case 6:
                if (what == 6) {
                    removeCallbacksAndMessages(null);
                }
                this.quitFlag = true;
                syncTimerIfNeeded();
                this.pausedPosition = this.timer.currMillisecond;
                if (this.mThread != null) {
                    notifyRendering();
                    quitUpdateThread();
                }
                if (what == 6) {
                    IDrawTask iDrawTask5 = this.drawTask;
                    if (iDrawTask5 != null) {
                        iDrawTask5.quit();
                    }
                    BaseDanmakuParser baseDanmakuParser = this.mParser;
                    if (baseDanmakuParser != null) {
                        baseDanmakuParser.release();
                    }
                    if (getLooper() != Looper.getMainLooper()) {
                        getLooper().quit();
                        return;
                    }
                    return;
                }
                return;
            case 7:
                removeMessages(3);
                removeMessages(2);
                iDrawTask = this.drawTask;
                if (iDrawTask != null) {
                    iDrawTask.onPlayStateChanged(2);
                }
                if (what == 6) {
                }
                this.quitFlag = true;
                syncTimerIfNeeded();
                this.pausedPosition = this.timer.currMillisecond;
                if (this.mThread != null) {
                }
                if (what == 6) {
                }
                break;
            case 8:
                this.mDanmakusVisible = true;
                start = (Long) msg.obj;
                boolean resume = false;
                IDrawTask iDrawTask6 = this.drawTask;
                if (iDrawTask6 != null) {
                    if (start == null) {
                        this.timer.update(getCurrentTime());
                        this.drawTask.requestClear();
                    } else {
                        iDrawTask6.start();
                        this.drawTask.seek(start.longValue());
                        this.drawTask.requestClear();
                        resume = true;
                    }
                }
                if (this.quitFlag && (iDanmakuViewController = this.mDanmakuView) != null) {
                    iDanmakuViewController.drawDanmakus();
                }
                notifyRendering();
                if (!resume) {
                    return;
                }
                startTime = (Long) msg.obj;
                if (startTime == null) {
                }
                if (what == 4) {
                }
                removeMessages(7);
                this.quitFlag = false;
                if (!this.mReady) {
                }
                break;
            case 9:
                this.mDanmakusVisible = false;
                IDanmakuViewController iDanmakuViewController2 = this.mDanmakuView;
                if (iDanmakuViewController2 != null) {
                    iDanmakuViewController2.clear();
                }
                IDrawTask iDrawTask7 = this.drawTask;
                if (iDrawTask7 != null) {
                    iDrawTask7.requestClear();
                    this.drawTask.requestHide();
                }
                Boolean quitDrawTask = (Boolean) msg.obj;
                if (quitDrawTask.booleanValue() && (iDrawTask2 = this.drawTask) != null) {
                    iDrawTask2.quit();
                }
                if (!quitDrawTask.booleanValue()) {
                    return;
                }
                removeMessages(3);
                removeMessages(2);
                iDrawTask = this.drawTask;
                if (iDrawTask != null) {
                }
                if (what == 6) {
                }
                this.quitFlag = true;
                syncTimerIfNeeded();
                this.pausedPosition = this.timer.currMillisecond;
                if (this.mThread != null) {
                }
                if (what == 6) {
                }
                break;
            case 10:
                this.mContext.mDanmakuFactory.notifyDispSizeChanged(this.mContext);
                Boolean updateFlag = (Boolean) msg.obj;
                if (updateFlag != null && updateFlag.booleanValue()) {
                    this.mContext.mGlobalFlagValues.updateMeasureFlag();
                    this.mContext.mGlobalFlagValues.updateVisibleFlag();
                    this.drawTask.requestClearRetainer();
                    return;
                }
                return;
            case 11:
                notifyRendering();
                return;
            case 12:
                if (this.quitFlag && this.mDanmakuView != null) {
                    this.drawTask.requestClear();
                    this.mDanmakuView.drawDanmakus();
                    notifyRendering();
                    return;
                }
                return;
            case 13:
                IDrawTask iDrawTask8 = this.drawTask;
                if (iDrawTask8 != null) {
                    iDrawTask8.clearDanmakusOnScreen(getCurrentTime());
                    return;
                }
                return;
            default:
                return;
        }
    }

    private void quitUpdateThread() {
        if (this.mThread != null) {
            UpdateThread thread = this.mThread;
            this.mThread = null;
            synchronized (this.drawTask) {
                this.drawTask.notifyAll();
            }
            thread.quit();
            try {
                thread.join();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }

    private void updateInCurrentThread() {
        if (!this.quitFlag) {
            long d = syncTimer(SystemClock.uptimeMillis());
            if (d < 0) {
                removeMessages(2);
                sendEmptyMessageDelayed(2, 60 - d);
                return;
            }
            long d2 = this.mDanmakuView.drawDanmakus();
            removeMessages(2);
            if (d2 > this.mCordonTime2) {
                this.timer.add(d2);
                this.mDrawTimes.clear();
            }
            if (!this.mDanmakusVisible) {
                waitRendering(INDEFINITE_TIME);
                return;
            }
            if (this.mRenderingState.nothingRendered && this.mIdleSleep) {
                long dTime = this.mRenderingState.endTime - this.timer.currMillisecond;
                if (dTime > 500) {
                    waitRendering(dTime - 10);
                    return;
                }
            }
            long dTime2 = this.mFrameUpdateRate;
            if (d2 < dTime2) {
                sendEmptyMessageDelayed(2, dTime2 - d2);
            } else {
                sendEmptyMessage(2);
            }
        }
    }

    private void updateInNewThread() {
        if (this.mThread == null) {
            AnonymousClass2 r0 = new UpdateThread("DFM Update") {
                /* class master.flame.danmaku.controller.DrawHandler.AnonymousClass2 */

                @Override // master.flame.danmaku.controller.UpdateThread
                public void run() {
                    long lastTime = SystemClock.uptimeMillis();
                    while (!isQuited() && !DrawHandler.this.quitFlag) {
                        long startMS = SystemClock.uptimeMillis();
                        if (DrawHandler.this.mFrameUpdateRate - (SystemClock.uptimeMillis() - lastTime) > 1) {
                            SystemClock.sleep(1);
                        } else {
                            lastTime = startMS;
                            long d = DrawHandler.this.syncTimer(startMS);
                            if (d < 0) {
                                SystemClock.sleep(60 - d);
                            } else {
                                long d2 = DrawHandler.this.mDanmakuView.drawDanmakus();
                                if (d2 > DrawHandler.this.mCordonTime2) {
                                    DrawHandler.this.timer.add(d2);
                                    DrawHandler.this.mDrawTimes.clear();
                                }
                                if (!DrawHandler.this.mDanmakusVisible) {
                                    DrawHandler.this.waitRendering(DrawHandler.INDEFINITE_TIME);
                                } else if (DrawHandler.this.mRenderingState.nothingRendered && DrawHandler.this.mIdleSleep) {
                                    long dTime = DrawHandler.this.mRenderingState.endTime - DrawHandler.this.timer.currMillisecond;
                                    if (dTime > 500) {
                                        DrawHandler.this.notifyRendering();
                                        DrawHandler.this.waitRendering(dTime - 10);
                                    }
                                }
                            }
                        }
                    }
                }
            };
            this.mThread = r0;
            r0.start();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final long syncTimer(long startMS) {
        long gapTime;
        if (this.mInSeekingAction || this.mInSyncAction) {
            return 0;
        }
        this.mInSyncAction = true;
        long d = 0;
        long time = startMS - this.mTimeBase;
        if (!this.mDanmakusVisible || this.mRenderingState.nothingRendered || this.mInWaitingState) {
            this.timer.update(time);
            this.mRemainingTime = 0;
        } else {
            long gapTime2 = time - this.timer.currMillisecond;
            long averageTime = Math.max(this.mFrameUpdateRate, getAverageRenderingTime());
            if (gapTime2 <= 2000) {
                long j = this.mRenderingState.consumingTime;
                long j2 = this.mCordonTime;
                if (j <= j2 && averageTime <= j2) {
                    long j3 = this.mFrameUpdateRate;
                    long d2 = Math.min(this.mCordonTime, Math.max(j3, (gapTime2 / j3) + averageTime));
                    long j4 = this.mLastDeltaTime;
                    long a = d2 - j4;
                    if (a > 3 && a < 8 && j4 >= this.mFrameUpdateRate && j4 <= this.mCordonTime) {
                        d2 = this.mLastDeltaTime;
                    }
                    gapTime = gapTime2 - d2;
                    this.mLastDeltaTime = d2;
                    d = d2;
                    this.mRemainingTime = gapTime;
                    this.timer.add(d);
                }
            }
            gapTime = 0;
            d = gapTime2;
            this.mRemainingTime = gapTime;
            this.timer.add(d);
        }
        Callback callback = this.mCallback;
        if (callback != null) {
            callback.updateTimer(this.timer);
        }
        this.mInSyncAction = false;
        return d;
    }

    private void syncTimerIfNeeded() {
        if (this.mInWaitingState) {
            syncTimer(SystemClock.uptimeMillis());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void initRenderingConfigs() {
        long max = Math.max(33L, (long) (((float) 16) * 2.5f));
        this.mCordonTime = max;
        this.mCordonTime2 = (long) (((float) max) * 2.5f);
        long max2 = Math.max(16L, (16 / 15) * 15);
        this.mFrameUpdateRate = max2;
        this.mThresholdTime = max2 + 3;
    }

    private void prepare(final Runnable runnable) {
        if (this.drawTask == null) {
            this.drawTask = createDrawTask(this.mDanmakuView.isDanmakuDrawingCacheEnabled(), this.timer, this.mDanmakuView.getContext(), this.mDanmakuView.getWidth(), this.mDanmakuView.getHeight(), this.mDanmakuView.isHardwareAccelerated(), new IDrawTask.TaskListener() {
                /* class master.flame.danmaku.controller.DrawHandler.AnonymousClass3 */

                @Override // master.flame.danmaku.controller.IDrawTask.TaskListener
                public void ready() {
                    DrawHandler.this.initRenderingConfigs();
                    runnable.run();
                }

                @Override // master.flame.danmaku.controller.IDrawTask.TaskListener
                public void onDanmakuAdd(BaseDanmaku danmaku) {
                    if (!danmaku.isTimeOut()) {
                        long delay = danmaku.getActualTime() - DrawHandler.this.timer.currMillisecond;
                        if (delay > 0) {
                            DrawHandler.this.sendEmptyMessageDelayed(11, delay);
                        } else if (DrawHandler.this.mInWaitingState) {
                            DrawHandler.this.notifyRendering();
                        }
                    }
                }

                @Override // master.flame.danmaku.controller.IDrawTask.TaskListener
                public void onDanmakuShown(BaseDanmaku danmaku) {
                    if (DrawHandler.this.mCallback != null) {
                        DrawHandler.this.mCallback.danmakuShown(danmaku);
                    }
                }

                @Override // master.flame.danmaku.controller.IDrawTask.TaskListener
                public void onDanmakusDrawingFinished() {
                    if (DrawHandler.this.mCallback != null) {
                        DrawHandler.this.mCallback.drawingFinished();
                    }
                }

                @Override // master.flame.danmaku.controller.IDrawTask.TaskListener
                public void onDanmakuConfigChanged() {
                    DrawHandler.this.redrawIfNeeded();
                }
            });
        } else {
            runnable.run();
        }
    }

    public boolean isPrepared() {
        return this.mReady;
    }

    private IDrawTask createDrawTask(boolean useDrwaingCache, DanmakuTimer timer2, Context context, int width, int height, boolean isHardwareAccelerated, IDrawTask.TaskListener taskListener) {
        AbsDisplayer displayer = this.mContext.getDisplayer();
        this.mDisp = displayer;
        displayer.setSize(width, height);
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        this.mDisp.setDensities(displayMetrics.density, displayMetrics.densityDpi, displayMetrics.scaledDensity);
        this.mDisp.resetSlopPixel(this.mContext.scaleTextSize);
        this.mDisp.setHardwareAccelerated(isHardwareAccelerated);
        IDrawTask task = useDrwaingCache ? new CacheManagingDrawTask(timer2, this.mContext, taskListener, (AndroidUtils.getMemoryClass(context) * 1048576) / 3) : new DrawTask(timer2, this.mContext, taskListener);
        task.setParser(this.mParser);
        task.prepare();
        obtainMessage(10, false).sendToTarget();
        return task;
    }

    public void seekTo(Long ms) {
        this.mInSeekingAction = true;
        this.mDesireSeekingTime = ms.longValue();
        removeMessages(2);
        removeMessages(3);
        removeMessages(4);
        obtainMessage(4, ms).sendToTarget();
    }

    public void addDanmaku(BaseDanmaku item) {
        if (this.drawTask != null) {
            item.flags = this.mContext.mGlobalFlagValues;
            item.setTimer(this.timer);
            this.drawTask.addDanmaku(item);
            obtainMessage(11).sendToTarget();
        }
    }

    public void invalidateDanmaku(BaseDanmaku item, boolean remeasure) {
        IDrawTask iDrawTask = this.drawTask;
        if (!(iDrawTask == null || item == null)) {
            iDrawTask.invalidateDanmaku(item, remeasure);
        }
        redrawIfNeeded();
    }

    public void resume() {
        removeMessages(7);
        sendEmptyMessage(3);
    }

    public void prepare() {
        sendEmptyMessage(5);
    }

    public void pause() {
        removeMessages(3);
        syncTimerIfNeeded();
        sendEmptyMessage(7);
    }

    public void showDanmakus(Long position) {
        if (!this.mDanmakusVisible) {
            this.mDanmakusVisible = true;
            removeMessages(8);
            removeMessages(9);
            obtainMessage(8, position).sendToTarget();
        }
    }

    public long hideDanmakus(boolean quitDrawTask) {
        if (!this.mDanmakusVisible) {
            return this.timer.currMillisecond;
        }
        this.mDanmakusVisible = false;
        removeMessages(8);
        removeMessages(9);
        obtainMessage(9, Boolean.valueOf(quitDrawTask)).sendToTarget();
        return this.timer.currMillisecond;
    }

    public boolean getVisibility() {
        return this.mDanmakusVisible;
    }

    public IRenderer.RenderingState draw(Canvas canvas) {
        AbsDanmakuSync danmakuSync;
        boolean isSyncPlayingState;
        if (this.drawTask == null) {
            return this.mRenderingState;
        }
        if (!this.mInWaitingState && (danmakuSync = this.mContext.danmakuSync) != null && ((isSyncPlayingState = danmakuSync.isSyncPlayingState()) || this.quitFlag)) {
            int syncState = danmakuSync.getSyncState();
            if (syncState == 2) {
                long fromTime = this.timer.currMillisecond;
                long toTime = danmakuSync.getUptimeMillis();
                long offset = toTime - fromTime;
                if (Math.abs(offset) > danmakuSync.getThresholdTimeMills()) {
                    if (isSyncPlayingState && this.quitFlag) {
                        resume();
                    }
                    this.drawTask.requestSync(fromTime, toTime, offset);
                    this.timer.update(toTime);
                    this.mTimeBase = SystemClock.uptimeMillis() - toTime;
                    this.mRemainingTime = 0;
                }
            } else if (syncState == 1 && isSyncPlayingState && !this.quitFlag) {
                pause();
            }
        }
        this.mDisp.setExtraData(canvas);
        this.mRenderingState.set(this.drawTask.draw(this.mDisp));
        recordRenderingTime();
        return this.mRenderingState;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void redrawIfNeeded() {
        if (this.quitFlag && this.mDanmakusVisible) {
            obtainMessage(12).sendToTarget();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyRendering() {
        if (this.mInWaitingState) {
            IDrawTask iDrawTask = this.drawTask;
            if (iDrawTask != null) {
                iDrawTask.requestClear();
            }
            if (this.mUpdateInNewThread) {
                synchronized (this) {
                    this.mDrawTimes.clear();
                }
                synchronized (this.drawTask) {
                    this.drawTask.notifyAll();
                }
            } else {
                this.mDrawTimes.clear();
                removeMessages(2);
                sendEmptyMessage(2);
            }
            this.mInWaitingState = false;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void waitRendering(long dTime) {
        this.mRenderingState.sysTime = SystemClock.uptimeMillis();
        this.mInWaitingState = true;
        if (this.mUpdateInNewThread) {
            if (this.mThread != null) {
                try {
                    synchronized (this.drawTask) {
                        if (dTime == INDEFINITE_TIME) {
                            this.drawTask.wait();
                        } else {
                            this.drawTask.wait(dTime);
                        }
                        sendEmptyMessage(11);
                    }
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        } else if (dTime == INDEFINITE_TIME) {
            removeMessages(11);
            removeMessages(2);
        } else {
            removeMessages(11);
            removeMessages(2);
            sendEmptyMessageDelayed(11, dTime);
        }
    }

    private synchronized long getAverageRenderingTime() {
        int frames = this.mDrawTimes.size();
        if (frames <= 0) {
            return 0;
        }
        Long first = this.mDrawTimes.peekFirst();
        Long last = this.mDrawTimes.peekLast();
        if (first == null || last == null) {
            return 0;
        }
        return (last.longValue() - first.longValue()) / ((long) frames);
    }

    private synchronized void recordRenderingTime() {
        this.mDrawTimes.addLast(Long.valueOf(SystemClock.uptimeMillis()));
        if (this.mDrawTimes.size() > 500) {
            this.mDrawTimes.removeFirst();
        }
    }

    public IDisplayer getDisplayer() {
        return this.mDisp;
    }

    public void notifyDispSizeChanged(int width, int height) {
        AbsDisplayer absDisplayer = this.mDisp;
        if (absDisplayer != null) {
            if (absDisplayer.getWidth() != width || this.mDisp.getHeight() != height) {
                this.mDisp.setSize(width, height);
                obtainMessage(10, true).sendToTarget();
            }
        }
    }

    public void removeAllDanmakus(boolean isClearDanmakusOnScreen) {
        IDrawTask iDrawTask = this.drawTask;
        if (iDrawTask != null) {
            iDrawTask.removeAllDanmakus(isClearDanmakusOnScreen);
        }
    }

    public void removeAllLiveDanmakus() {
        IDrawTask iDrawTask = this.drawTask;
        if (iDrawTask != null) {
            iDrawTask.removeAllLiveDanmakus();
        }
    }

    public IDanmakus getCurrentVisibleDanmakus() {
        IDrawTask iDrawTask = this.drawTask;
        if (iDrawTask != null) {
            return iDrawTask.getVisibleDanmakusOnTime(getCurrentTime());
        }
        return null;
    }

    public long getCurrentTime() {
        if (!this.mReady) {
            return 0;
        }
        if (this.mInSeekingAction) {
            return this.mDesireSeekingTime;
        }
        if (this.quitFlag || !this.mInWaitingState) {
            return this.timer.currMillisecond - this.mRemainingTime;
        }
        return SystemClock.uptimeMillis() - this.mTimeBase;
    }

    public void clearDanmakusOnScreen() {
        obtainMessage(13).sendToTarget();
    }

    public DanmakuContext getConfig() {
        return this.mContext;
    }
}
