package master.flame.danmaku.danmaku.model.android;

import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import java.lang.reflect.Array;
import tv.cjump.jni.NativeBitmapFactory;

public class DrawingCacheHolder {
    public Bitmap bitmap;
    public Bitmap[][] bitmapArray;
    public Canvas canvas;
    public boolean drawn;
    public Object extra;
    public int height;
    private int mDensity;
    public int width;

    public DrawingCacheHolder() {
    }

    public DrawingCacheHolder(int w, int h) {
        buildCache(w, h, 0, true);
    }

    public DrawingCacheHolder(int w, int h, int density) {
        this.mDensity = density;
        buildCache(w, h, density, true);
    }

    public void buildCache(int w, int h, int density, boolean checkSizeEquals) {
        Bitmap bitmap2;
        boolean reuse = true;
        int i = this.width;
        if (!checkSizeEquals ? w > i || h > this.height : !(w == i && h == this.height)) {
            reuse = false;
        }
        if (!reuse || (bitmap2 = this.bitmap) == null) {
            if (this.bitmap != null) {
                recycle();
            }
            this.width = w;
            this.height = h;
            Bitmap createBitmap = NativeBitmapFactory.createBitmap(w, h, Bitmap.Config.ARGB_8888);
            this.bitmap = createBitmap;
            if (density > 0) {
                this.mDensity = density;
                createBitmap.setDensity(density);
            }
            Canvas canvas2 = this.canvas;
            if (canvas2 == null) {
                Canvas canvas3 = new Canvas(this.bitmap);
                this.canvas = canvas3;
                canvas3.setDensity(density);
                return;
            }
            canvas2.setBitmap(this.bitmap);
            return;
        }
        bitmap2.eraseColor(0);
        this.canvas.setBitmap(this.bitmap);
        recycleBitmapArray();
    }

    public void erase() {
        eraseBitmap(this.bitmap);
        eraseBitmapArray();
    }

    public synchronized void recycle() {
        Bitmap bitmapReserve = this.bitmap;
        this.bitmap = null;
        this.height = 0;
        this.width = 0;
        if (bitmapReserve != null) {
            bitmapReserve.recycle();
        }
        recycleBitmapArray();
        this.extra = null;
    }

    /* JADX INFO: Multiple debug info for r1v5 int: [D('maximumCacheWidth' int), D('top' int)] */
    public void splitWith(int dispWidth, int dispHeight, int maximumCacheWidth, int maximumCacheHeight) {
        int i;
        recycleBitmapArray();
        int i2 = this.width;
        if (i2 > 0 && (i = this.height) > 0) {
            if (this.bitmap != null) {
                if (i2 > maximumCacheWidth || i > maximumCacheHeight) {
                    int maximumCacheWidth2 = Math.min(maximumCacheWidth, dispWidth);
                    int maximumCacheHeight2 = Math.min(maximumCacheHeight, dispHeight);
                    int i3 = this.width;
                    int xCount = (i3 / maximumCacheWidth2) + (i3 % maximumCacheWidth2 == 0 ? 0 : 1);
                    int i4 = this.height;
                    int yCount = (i4 / maximumCacheHeight2) + (i4 % maximumCacheHeight2 == 0 ? 0 : 1);
                    int averageWidth = this.width / xCount;
                    int averageHeight = this.height / yCount;
                    int[] iArr = new int[2];
                    iArr[1] = xCount;
                    iArr[0] = yCount;
                    Bitmap[][] bmpArray = (Bitmap[][]) Array.newInstance(Bitmap.class, iArr);
                    if (this.canvas == null) {
                        Canvas canvas2 = new Canvas();
                        this.canvas = canvas2;
                        int i5 = this.mDensity;
                        if (i5 > 0) {
                            canvas2.setDensity(i5);
                        }
                    }
                    Rect rectSrc = new Rect();
                    Rect rectDst = new Rect();
                    for (int yIndex = 0; yIndex < yCount; yIndex++) {
                        int xIndex = 0;
                        while (xIndex < xCount) {
                            Bitmap[] bitmapArr = bmpArray[yIndex];
                            Bitmap bmp = NativeBitmapFactory.createBitmap(averageWidth, averageHeight, Bitmap.Config.ARGB_8888);
                            bitmapArr[xIndex] = bmp;
                            int i6 = this.mDensity;
                            if (i6 > 0) {
                                bmp.setDensity(i6);
                            }
                            this.canvas.setBitmap(bmp);
                            int left = xIndex * averageWidth;
                            int top = yIndex * averageHeight;
                            rectSrc.set(left, top, left + averageWidth, top + averageHeight);
                            rectDst.set(0, 0, bmp.getWidth(), bmp.getHeight());
                            this.canvas.drawBitmap(this.bitmap, rectSrc, rectDst, (Paint) null);
                            xIndex++;
                            maximumCacheHeight2 = maximumCacheHeight2;
                            maximumCacheWidth2 = maximumCacheWidth2;
                        }
                    }
                    this.canvas.setBitmap(this.bitmap);
                    this.bitmapArray = bmpArray;
                }
            }
        }
    }

    private void eraseBitmap(Bitmap bmp) {
        if (bmp != null) {
            bmp.eraseColor(0);
        }
    }

    private void eraseBitmapArray() {
        if (this.bitmapArray != null) {
            for (int i = 0; i < this.bitmapArray.length; i++) {
                int j = 0;
                while (true) {
                    Bitmap[][] bitmapArr = this.bitmapArray;
                    if (j >= bitmapArr[i].length) {
                        break;
                    }
                    eraseBitmap(bitmapArr[i][j]);
                    j++;
                }
            }
        }
    }

    private void recycleBitmapArray() {
        Bitmap[][] bitmapArrayReserve = this.bitmapArray;
        this.bitmapArray = null;
        if (bitmapArrayReserve != null) {
            for (int i = 0; i < bitmapArrayReserve.length; i++) {
                for (int j = 0; j < bitmapArrayReserve[i].length; j++) {
                    if (bitmapArrayReserve[i][j] != null) {
                        bitmapArrayReserve[i][j].recycle();
                        bitmapArrayReserve[i][j] = null;
                    }
                }
            }
        }
    }

    public final synchronized boolean draw(Canvas canvas2, float left, float top, Paint paint) {
        if (this.bitmapArray != null) {
            for (int i = 0; i < this.bitmapArray.length; i++) {
                for (int j = 0; j < this.bitmapArray[i].length; j++) {
                    Bitmap bmp = this.bitmapArray[i][j];
                    if (bmp != null) {
                        float dleft = ((float) (bmp.getWidth() * j)) + left;
                        if (dleft <= ((float) canvas2.getWidth())) {
                            if (((float) bmp.getWidth()) + dleft >= 0.0f) {
                                float dtop = ((float) (bmp.getHeight() * i)) + top;
                                if (dtop <= ((float) canvas2.getHeight())) {
                                    if (((float) bmp.getHeight()) + dtop >= 0.0f) {
                                        canvas2.drawBitmap(bmp, dleft, dtop, paint);
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return true;
        } else if (this.bitmap == null) {
            return false;
        } else {
            canvas2.drawBitmap(this.bitmap, left, top, paint);
            return true;
        }
    }
}
